@@ -3,7 +3,7 @@
  * @author Joas Schilling <coding@schilljs.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -151,7 +151,6 @@ class Extension implements IExtension {
 	 * @return bool|string
 	 */
 	protected function translateShort($text, IL10N $l, array $params) {
-
 		switch ($text) {
 			case self::ADD_COMMENT_SUBJECT:
 				if ($this->authorIsCurrentUser($params[0])) {
@@ -172,7 +171,6 @@ class Extension implements IExtension {
 	 * @return bool|string
 	 */
 	protected function translateLong($text, IL10N $l, array $params) {
-
 		switch ($text) {
 			case self::ADD_COMMENT_SUBJECT:
 				if ($this->authorIsCurrentUser($params[0])) {
@@ -194,7 +192,7 @@ class Extension implements IExtension {
 	 */
 	protected function authorIsCurrentUser($user) {
 		try {
-			return strip_tags($user) === $this->activityManager->getCurrentUserId();
+			return \strip_tags($user) === $this->activityManager->getCurrentUserId();
 		} catch (\UnexpectedValueException $e) {
 			return false;
 		}
@@ -279,7 +277,7 @@ class Extension implements IExtension {
 		if ($filter === self::APP_NAME) {
 			return [self::APP_NAME];
 		}
-		if (in_array($filter, ['all', 'by', 'self', 'filter'])) {
+		if (\in_array($filter, ['all', 'by', 'self', 'filter'])) {
 			$types[] = self::APP_NAME;
 			return $types;
 		}
@@ -304,11 +302,11 @@ class Extension implements IExtension {
 	 * @return string
 	 */
 	protected function convertParameterToComment($parameter) {
-		if (preg_match('/^\<parameter\>(\d*)\<\/parameter\>$/', $parameter, $matches)) {
+		if (\preg_match('/^\<parameter\>(\d*)\<\/parameter\>$/', $parameter, $matches)) {
 			try {
 				$comment = $this->commentsManager->get((int) $matches[1]);
 				$message = $comment->getMessage();
-				$message = str_replace("\n", '<br />', str_replace(['<', '>'], ['&lt;', '&gt;'], $message));
+				$message = \str_replace("\n", '<br />', \str_replace(['<', '>'], ['&lt;', '&gt;'], $message));
 				return $message;
 			} catch (NotFoundException $e) {
 				return '';
