@@ -4,7 +4,7 @@
  * @author Joas Schilling <coding@schilljs.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -69,8 +69,7 @@ class RootCollection implements ICollection {
 		IUserManager $userManager,
 		IUserSession $userSession,
 		EventDispatcherInterface $dispatcher,
-		ILogger $logger)
-	{
+		ILogger $logger) {
 		$this->commentsManager = $commentsManager;
 		$this->logger = $logger;
 		$this->userManager = $userManager;
@@ -86,14 +85,14 @@ class RootCollection implements ICollection {
 	 * @throws NotAuthenticated
 	 */
 	protected function initCollections() {
-		if($this->entityTypeCollections !== null) {
+		if ($this->entityTypeCollections !== null) {
 			return;
 		}
-		if(is_null($this->userSession)) {
+		if ($this->userSession === null) {
 			throw new NotAuthenticated();
 		}
 		$user = $this->userSession->getUser();
-		if(is_null($user)) {
+		if ($user === null) {
 			throw new NotAuthenticated();
 		}
 
@@ -121,7 +120,7 @@ class RootCollection implements ICollection {
 	 * @return null|string
 	 * @throws Forbidden
 	 */
-	function createFile($name, $data = null) {
+	public function createFile($name, $data = null) {
 		throw new Forbidden('Cannot create comments by id');
 	}
 
@@ -131,7 +130,7 @@ class RootCollection implements ICollection {
 	 * @param string $name
 	 * @throws Forbidden
 	 */
-	function createDirectory($name) {
+	public function createDirectory($name) {
 		throw new Forbidden('Permission denied to create collections');
 	}
 
@@ -145,9 +144,9 @@ class RootCollection implements ICollection {
 	 * @return \Sabre\DAV\INode
 	 * @throws NotFound
 	 */
-	function getChild($name) {
+	public function getChild($name) {
 		$this->initCollections();
-		if(isset($this->entityTypeCollections[$name])) {
+		if (isset($this->entityTypeCollections[$name])) {
 			return $this->entityTypeCollections[$name];
 		}
 		throw new NotFound('Entity type "' . $name . '" not found."');
@@ -158,7 +157,7 @@ class RootCollection implements ICollection {
 	 *
 	 * @return \Sabre\DAV\INode[]
 	 */
-	function getChildren() {
+	public function getChildren() {
 		$this->initCollections();
 		return $this->entityTypeCollections;
 	}
@@ -169,7 +168,7 @@ class RootCollection implements ICollection {
 	 * @param string $name
 	 * @return bool
 	 */
-	function childExists($name) {
+	public function childExists($name) {
 		$this->initCollections();
 		return isset($this->entityTypeCollections[$name]);
 	}
@@ -179,7 +178,7 @@ class RootCollection implements ICollection {
 	 *
 	 * @throws Forbidden
 	 */
-	function delete() {
+	public function delete() {
 		throw new Forbidden('Permission denied to delete this collection');
 	}
 
@@ -190,7 +189,7 @@ class RootCollection implements ICollection {
 	 *
 	 * @return string
 	 */
-	function getName() {
+	public function getName() {
 		return $this->name;
 	}
 
@@ -200,7 +199,7 @@ class RootCollection implements ICollection {
 	 * @param string $name The new name
 	 * @throws Forbidden
 	 */
-	function setName($name) {
+	public function setName($name) {
 		throw new Forbidden('Permission denied to rename this collection');
 	}
 
@@ -209,7 +208,7 @@ class RootCollection implements ICollection {
 	 *
 	 * @return int
 	 */
-	function getLastModified() {
+	public function getLastModified() {
 		return null;
 	}
 }
