@@ -4,7 +4,7 @@
  * @author Joas Schilling <coding@schilljs.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,28 +29,28 @@ use Symfony\Component\EventDispatcher\GenericEvent;
 $app = new Application();
 $app->registerHooks();
 
-\OC::$server->registerService('CardDAVSyncService', function() use ($app) {
+\OC::$server->registerService('CardDAVSyncService', function () use ($app) {
 	return $app->getSyncService();
 });
 
 $eventDispatcher = \OC::$server->getEventDispatcher();
 
 $eventDispatcher->addListener('OCP\Federation\TrustedServerEvent::remove',
-	function(GenericEvent $event) use ($app) {
+	function (GenericEvent $event) use ($app) {
 		/** @var CardDavBackend $cardDavBackend */
 		$cardDavBackend = $app->getContainer()->query(CardDavBackend::class);
 		$addressBookUri = $event->getSubject();
 		$addressBook = $cardDavBackend->getAddressBooksByUri('principals/system/system', $addressBookUri);
-		if (!is_null($addressBook)) {
+		if ($addressBook !== null) {
 			$cardDavBackend->deleteAddressBook($addressBook['id']);
 		}
 	}
 );
 
 $cm = \OC::$server->getContactsManager();
-$cm->register(function() use ($cm, $app) {
+$cm->register(function () use ($cm, $app) {
 	$user = \OC::$server->getUserSession()->getUser();
-	if (!is_null($user)) {
+	if ($user !== null) {
 		$app->setupContactsProvider($cm, $user->getUID());
 	}
 });
