@@ -2,7 +2,7 @@
 /**
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,21 +21,34 @@
 
 namespace OCA\DAV\CalDAV;
 
+use Sabre\DAV;
+use Sabre\DAV\Xml\Property\ShareAccess;
 use Sabre\HTTP\URLUtil;
 
 class Plugin extends \Sabre\CalDAV\Plugin {
+	public function initialize(DAV\Server $server) {
+		parent::initialize($server);
+	}
+
+	public function propFind(DAV\PropFind $propFind, DAV\INode $node) {
+		parent::propFind($propFind, $node);
+
+		if ($node instanceof Calendar && $node->getName() === BirthdayService::BIRTHDAY_CALENDAR_URI) {
+			$propFind->handle('{DAV:}share-access', function () use ($node) {
+				return new ShareAccess(DAV\Sharing\Plugin::ACCESS_NOACCESS);
+			});
+		}
+	}
 
 	/**
 	 * @inheritdoc
 	 */
-	function getCalendarHomeForPrincipal($principalUrl) {
-
-		if (strrpos($principalUrl, 'principals/users', -strlen($principalUrl)) !== false) {
+	public function getCalendarHomeForPrincipal($principalUrl) {
+		if (\strrpos($principalUrl, 'principals/users', -\strlen($principalUrl)) !== false) {
 			list(, $principalId) = URLUtil::splitPath($principalUrl);
 			return self::CALENDAR_ROOT .'/' . $principalId;
 		}
 
 		return;
 	}
-
 }
