@@ -2,7 +2,7 @@
 /**
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,18 +19,38 @@
  *
  */
 
-
 namespace OCA\DAV;
 
 use OCP\Capabilities\ICapability;
+use OCP\IConfig;
 
 class Capabilities implements ICapability {
+	/** @var IConfig */
+	private $config;
+
+	/**
+	 * Capabilities constructor.
+	 *
+	 * @param IConfig $config
+	 */
+	public function __construct(IConfig $config) {
+		$this->config = $config;
+	}
 
 	public function getCapabilities() {
-		return [
+		$cap =  [
 			'dav' => [
 				'chunking' => '1.0',
+				'reports' => [
+					'search-files',
+				]
 			]
 		];
+
+		if ($this->config->getSystemValue('dav.enable.async', false)) {
+			$cap['async'] = '1.0';
+		}
+
+		return $cap;
 	}
 }
