@@ -6,7 +6,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -28,10 +28,9 @@ namespace OCA\DAV\Connector\Sabre\Exception;
 use Exception;
 
 class FileLocked extends \Sabre\DAV\Exception {
-
 	public function __construct($message = "", $code = 0, Exception $previous = null) {
-		if($previous instanceof \OCP\Files\LockNotAcquiredException) {
-			$message = sprintf('Target file %s is locked by another process.', $previous->path);
+		if ($previous instanceof \OCP\Files\LockNotAcquiredException) {
+			$message = \sprintf('Target file %s is locked by another process.', $previous->path);
 		}
 		parent::__construct($message, $code, $previous);
 	}
@@ -42,7 +41,6 @@ class FileLocked extends \Sabre\DAV\Exception {
 	 * @return int
 	 */
 	public function getHTTPCode() {
-
 		return 423;
 	}
 }
