@@ -14,7 +14,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -40,9 +40,11 @@ use OCA\DAV\Connector\Sabre\Exception\EntityTooLarge;
 use OCA\DAV\Connector\Sabre\Exception\FileLocked;
 use OCA\DAV\Connector\Sabre\Exception\Forbidden as DAVForbiddenException;
 use OCA\DAV\Connector\Sabre\Exception\UnsupportedMediaType;
+use OCA\DAV\Files\IFileNode;
 use OCP\Encryption\Exceptions\GenericEncryptionException;
 use OCP\Events\EventEmitterTrait;
 use OCP\Files\EntityTooLargeException;
+use OCP\Files\FileContentNotAllowedException;
 use OCP\Files\ForbiddenException;
 use OCP\Files\InvalidContentException;
 use OCP\Files\InvalidPathException;
@@ -60,8 +62,7 @@ use Sabre\DAV\Exception\ServiceUnavailable;
 use Sabre\DAV\IFile;
 use Symfony\Component\EventDispatcher\GenericEvent;
 
-class File extends Node implements IFile {
-
+class File extends Node implements IFile, IFileNode {
 	use EventEmitterTrait;
 	protected $request;
 	
@@ -80,7 +81,30 @@ class File extends Node implements IFile {
 		}
 		parent::__construct($view, $info, $shareManager);
 	}
-	
+
+	/**
+	 * Handles metadata updates for the target storage (mtime, propagation)
+	 *
+	 * @param Storage $targetStorage
+	 * @param $targetInternalPath
+	 */
+	private function handleMetadataUpdate(\OC\Files\Storage\Storage $targetStorage, $targetInternalPath) {
+		// since we skipped the view we need to scan and emit the hooks ourselves
+		
+		// allow sync clients to send the mtime along in a header
+		if (isset($this->request->server['HTTP_X_OC_MTIME'])) {
+			$mtime = $this->sanitizeMtime(
+				$this->request->server ['HTTP_X_OC_MTIME']
+			);
+			if ($targetStorage->touch($targetInternalPath, $mtime)) {
+				$this->header('X-OC-MTime: accepted');
+			}
+			$targetStorage->getUpdater()->update($targetInternalPath, $mtime);
+		} else {
+			$targetStorage->getUpdater()->update($targetInternalPath);
+		}
+	}
+
 	/**
 	 * Updates the data
 	 *
@@ -110,163 +134,170 @@ class File extends Node implements IFile {
 	 * @return string|null
 	 */
 	public function put($data) {
-		$path = $this->fileView->getAbsolutePath($this->path);
-		return $this->emittingCall(function () use (&$data) {
+		try {
+			$exists = $this->fileView->file_exists($this->path);
+			if ($this->info && $exists && !$this->info->isUpdateable()) {
+				throw new Forbidden();
+			}
+		} catch (StorageNotAvailableException $e) {
+			throw new ServiceUnavailable("File is not updatable: " . $e->getMessage());
+		}
+
+		// verify path of the target
+		$this->verifyPath();
+
+		// chunked handling
+		if (\OC_FileChunking::isWebdavChunk()) {
 			try {
-				$exists = $this->fileView->file_exists($this->path);
-				if ($this->info && $exists && !$this->info->isUpdateable()) {
-					throw new Forbidden();
+				return $this->createFileChunked($data);
+			} catch (\Exception $e) {
+				$this->convertToSabreException($e);
+			}
+		}
+
+		$newFile = false;
+		$path = $this->fileView->getAbsolutePath($this->path);
+		$beforeEvent = new GenericEvent(null, ['path' => $path]);
+		if (!$this->fileView->file_exists($this->path)) {
+			\OC::$server->getEventDispatcher()->dispatch('file.beforecreate', $beforeEvent);
+			$newFile = true;
+		} else {
+			\OC::$server->getEventDispatcher()->dispatch('file.beforeupdate', $beforeEvent);
+		}
+
+		list($partStorage) = $this->fileView->resolvePath($this->path);
+		$needsPartFile = $this->needsPartFile($partStorage) && (\strlen($this->path) > 1);
+
+		if ($needsPartFile) {
+			// mark file as partial while uploading (ignored by the scanner)
+			$partFilePath = $this->getPartFileBasePath($this->path) . '.ocTransferId' . \rand() . '.part';
+		} else {
+			// upload file directly as the final path
+			$partFilePath = $this->path;
+		}
+
+		// the part file and target file might be on a different storage in case of a single file storage (e.g. single file share)
+		/** @var \OC\Files\Storage\Storage $partStorage */
+		list($partStorage, $internalPartPath) = $this->fileView->resolvePath($partFilePath);
+		/** @var \OC\Files\Storage\Storage $storage */
+		list($storage, $internalPath) = $this->fileView->resolvePath($this->path);
+		try {
+			try {
+				$this->changeLock(ILockingProvider::LOCK_EXCLUSIVE);
+			} catch (LockedException $e) {
+				if ($needsPartFile) {
+					$partStorage->unlink($internalPartPath);
 				}
-			} catch (StorageNotAvailableException $e) {
-				throw new ServiceUnavailable("File is not updatable: " . $e->getMessage());
+				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
+			}
+			$target = $partStorage->fopen($internalPartPath, 'wb');
+			if (!\is_resource($target)) {
+				\OCP\Util::writeLog('webdav', '\OC\Files\Filesystem::fopen() failed', \OCP\Util::ERROR);
+				// because we have no clue about the cause we can only throw back a 500/Internal Server Error
+				throw new Exception('Could not write file contents');
 			}
 
-			// verify path of the target
-			$this->verifyPath();
+			list($count, $result) = \OC_Helper::streamCopy($data, $target);
+			\fclose($target);
 
-			// chunked handling
-			if (\OC_FileChunking::isWebdavChunk()) {
+			try {
+				$this->changeLock(ILockingProvider::LOCK_SHARED);
+			} catch (LockedException $e) {
+				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
+			}
+
+			if (!self::isChecksumValid($partStorage, $internalPartPath)) {
+				throw new BadRequest('The computed checksum does not match the one received from the client.');
+			}
+
+			if ($result === false) {
+				$expected = -1;
+				if (isset($_SERVER['CONTENT_LENGTH'])) {
+					$expected = $_SERVER['CONTENT_LENGTH'];
+				}
+				throw new Exception('Error while copying file to target location (copied bytes: ' . $count . ', expected filesize: ' . $expected . ' )');
+			}
+
+			// if content length is sent by client:
+			// double check if the file was fully received
+			// compare expected and actual size
+			if (isset($_SERVER['CONTENT_LENGTH']) && $_SERVER['REQUEST_METHOD'] === 'PUT') {
+				$expected = $_SERVER['CONTENT_LENGTH'];
+				if ($count != $expected) {
+					throw new BadRequest('expected filesize ' . $expected . ' got ' . $count);
+				}
+			}
+		} catch (\Exception $e) {
+			if ($needsPartFile) {
+				$partStorage->unlink($internalPartPath);
+			}
+			$this->convertToSabreException($e);
+		}
+
+		try {
+			$view = \OC\Files\Filesystem::getView();
+			if ($view) {
+				$run = $this->emitPreHooks($exists);
+				if ($run === false) {
+					$view->unlockFile($this->path, ILockingProvider::LOCK_SHARED);
+					return null;
+				}
+			} else {
+				$run = true;
+			}
+
+			try {
+				$this->changeLock(ILockingProvider::LOCK_EXCLUSIVE);
+			} catch (LockedException $e) {
+				if ($needsPartFile) {
+					$partStorage->unlink($internalPartPath);
+				}
+				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
+			}
+
+			if ($needsPartFile) {
+				// rename to correct path
 				try {
-					return $this->createFileChunked($data);
+					if ($run) {
+						$renameOkay = $storage->moveFromStorage($partStorage, $internalPartPath, $internalPath);
+						$fileExists = $storage->file_exists($internalPath);
+					}
+					if (!$run || $renameOkay === false || $fileExists === false) {
+						\OCP\Util::writeLog('webdav', 'renaming part file to final file failed', \OCP\Util::ERROR);
+						throw new Exception('Could not rename part file to final file');
+					}
+				} catch (ForbiddenException $ex) {
+					throw new DAVForbiddenException($ex->getMessage(), $ex->getRetry());
 				} catch (\Exception $e) {
+					$partStorage->unlink($internalPartPath);
 					$this->convertToSabreException($e);
 				}
 			}
 
-			list($partStorage) = $this->fileView->resolvePath($this->path);
-			$needsPartFile = $this->needsPartFile($partStorage) && (strlen($this->path) > 1);
-
-			if ($needsPartFile) {
-				// mark file as partial while uploading (ignored by the scanner)
-				$partFilePath = $this->getPartFileBasePath($this->path) . '.ocTransferId' . rand() . '.part';
-			} else {
-				// upload file directly as the final path
-				$partFilePath = $this->path;
-			}
-
-			// the part file and target file might be on a different storage in case of a single file storage (e.g. single file share)
-			/** @var \OC\Files\Storage\Storage $partStorage */
-			list($partStorage, $internalPartPath) = $this->fileView->resolvePath($partFilePath);
-			/** @var \OC\Files\Storage\Storage $storage */
-			list($storage, $internalPath) = $this->fileView->resolvePath($this->path);
-			try {
-				$target = $partStorage->fopen($internalPartPath, 'wb');
-				if ($target === false) {
-					\OCP\Util::writeLog('webdav', '\OC\Files\Filesystem::fopen() failed', \OCP\Util::ERROR);
-					// because we have no clue about the cause we can only throw back a 500/Internal Server Error
-					throw new Exception('Could not write file contents');
-				}
-				list($count, $result) = \OC_Helper::streamCopy($data, $target);
-				fclose($target);
-
-				if (!self::isChecksumValid($partStorage, $internalPartPath)) {
-					throw new BadRequest('The computed checksum does not match the one received from the client.');
-				}
-
-				if ($result === false) {
-					$expected = -1;
-					if (isset($_SERVER['CONTENT_LENGTH'])) {
-						$expected = $_SERVER['CONTENT_LENGTH'];
-					}
-					throw new Exception('Error while copying file to target location (copied bytes: ' . $count . ', expected filesize: ' . $expected . ' )');
-				}
-
-				// if content length is sent by client:
-				// double check if the file was fully received
-				// compare expected and actual size
-				if (isset($_SERVER['CONTENT_LENGTH']) && $_SERVER['REQUEST_METHOD'] === 'PUT') {
-					$expected = $_SERVER['CONTENT_LENGTH'];
-					if ($count != $expected) {
-						throw new BadRequest('expected filesize ' . $expected . ' got ' . $count);
-					}
-				}
-
-			} catch (\Exception $e) {
-				if ($needsPartFile) {
-					$partStorage->unlink($internalPartPath);
-				}
-				$this->convertToSabreException($e);
-			}
+			$this->handleMetadataUpdate($storage, $internalPath);
 
 			try {
-				$view = \OC\Files\Filesystem::getView();
-				if ($view) {
-					$run = $this->emitPreHooks($exists);
-				} else {
-					$run = true;
-				}
-
-				try {
-					$this->changeLock(ILockingProvider::LOCK_EXCLUSIVE);
-				} catch (LockedException $e) {
-					if ($needsPartFile) {
-						$partStorage->unlink($internalPartPath);
-					}
-					throw new FileLocked($e->getMessage(), $e->getCode(), $e);
-				}
-
-				if ($needsPartFile) {
-					// rename to correct path
-					try {
-						if ($run) {
-							$renameOkay = $storage->moveFromStorage($partStorage, $internalPartPath, $internalPath);
-							$fileExists = $storage->file_exists($internalPath);
-						}
-						if (!$run || $renameOkay === false || $fileExists === false) {
-							\OCP\Util::writeLog('webdav', 'renaming part file to final file failed', \OCP\Util::ERROR);
-							throw new Exception('Could not rename part file to final file');
-						}
-					} catch (ForbiddenException $ex) {
-						throw new DAVForbiddenException($ex->getMessage(), $ex->getRetry());
-					} catch (\Exception $e) {
-						$partStorage->unlink($internalPartPath);
-						$this->convertToSabreException($e);
-					}
-				}
-
-				// since we skipped the view we need to scan and emit the hooks ourselves
-				$storage->getUpdater()->update($internalPath);
-
-				try {
-					$this->changeLock(ILockingProvider::LOCK_SHARED);
-				} catch (LockedException $e) {
-					throw new FileLocked($e->getMessage(), $e->getCode(), $e);
-				}
-
-				// allow sync clients to send the mtime along in a header
-				if (isset($this->request->server['HTTP_X_OC_MTIME'])) {
-					$mtime = $this->sanitizeMtime($this->request->server ['HTTP_X_OC_MTIME']);
-					if ($this->fileView->touch($this->path, $mtime)) {
-						$this->header('X-OC-MTime: accepted');
-					}
-				}
-
-				if ($view) {
-					$this->emitPostHooks($exists);
-				}
-
-				$this->refreshInfo();
-
-				$meta = $partStorage->getMetaData($internalPartPath);
-
-				if (isset($meta['checksum'])) {
-					$this->fileView->putFileInfo(
-						$this->path,
-						['checksum' => $meta['checksum']]
-					);
-				}
-
-				$this->refreshInfo();
-
-			} catch (StorageNotAvailableException $e) {
-				throw new ServiceUnavailable("Failed to check file size: " . $e->getMessage());
+				$this->changeLock(ILockingProvider::LOCK_SHARED);
+			} catch (LockedException $e) {
+				throw new FileLocked($e->getMessage(), $e->getCode(), $e);
 			}
 
-			return '"' . $this->info->getEtag() . '"';
-		},[
-			'before' => ['path' => $path],
-			'after' => ['path' => $path],
-		], 'file', 'create');
+			if ($view) {
+				$this->emitPostHooks($exists);
+			}
+
+			$this->refreshInfo();
+		} catch (StorageNotAvailableException $e) {
+			throw new ServiceUnavailable("Failed to check file size: " . $e->getMessage());
+		}
+
+		$afterEvent = new GenericEvent(null, ['path' => $path]);
+		if ($newFile === true) {
+			\OC::$server->getEventDispatcher()->dispatch('file.aftercreate', $afterEvent);
+		} else {
+			\OC::$server->getEventDispatcher()->dispatch('file.afterupdate', $afterEvent);
+		}
+		return '"' . $this->info->getEtag() . '"';
 	}
 
 	private function getPartFileBasePath($path) {
@@ -274,7 +305,7 @@ class File extends Node implements IFile {
 		if ($partFileInStorage) {
 			return $path;
 		} else {
-			return md5($path); // will place it in the root of the view with a unique name
+			return \md5($path); // will place it in the root of the view with a unique name
 		}
 	}
 
@@ -282,7 +313,7 @@ class File extends Node implements IFile {
 	 * @param string $path
 	 */
 	private function emitPreHooks($exists, $path = null) {
-		if (is_null($path)) {
+		if ($path === null) {
 			$path = $this->path;
 		}
 		$hookPath = Filesystem::getView()->getRelativePath($this->fileView->getAbsolutePath($path));
@@ -326,7 +357,7 @@ class File extends Node implements IFile {
 	 * @param string $path
 	 */
 	private function emitPostHooks($exists, $path = null) {
-		if (is_null($path)) {
+		if ($path === null) {
 			$path = $this->path;
 		}
 		$hookPath = Filesystem::getView()->getRelativePath($this->fileView->getAbsolutePath($path));
@@ -354,7 +385,7 @@ class File extends Node implements IFile {
 	public function get() {
 		//throw exception if encryption is disabled but files are still encrypted
 		try {
-			$viewPath = ltrim($this->path, '/');
+			$viewPath = \ltrim($this->path, '/');
 			if (!$this->info->isReadable() || !$this->fileView->file_exists($viewPath)) {
 				// do a if the file did not exist
 				throw new NotFound();
@@ -365,8 +396,8 @@ class File extends Node implements IFile {
 			}
 			return $res;
 		} catch (GenericEncryptionException $e) {
-			// returning 503 will allow retry of the operation at a later point in time
-			throw new ServiceUnavailable("Encryption not ready: " . $e->getMessage());
+			// returning 403 because some apps stops syncing if 503 is returned.
+			throw new Forbidden("Encryption not ready: " . $e->getMessage());
 		} catch (StorageNotAvailableException $e) {
 			throw new ServiceUnavailable("Failed to open file: " . $e->getMessage());
 		} catch (ForbiddenException $ex) {
@@ -427,7 +458,7 @@ class File extends Node implements IFile {
 		}
 		/** @var \OCP\Files\Storage $storage */
 		list($storage, $internalPath) = $this->fileView->resolvePath($this->path);
-		if (is_null($storage)) {
+		if ($storage === null) {
 			return [];
 		}
 
@@ -454,7 +485,7 @@ class File extends Node implements IFile {
 		$bytesWritten = $chunk_handler->store($info['index'], $data);
 
 		//detect aborted upload
-		if (isset ($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'PUT') {
+		if (isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'PUT') {
 			if (isset($_SERVER['CONTENT_LENGTH'])) {
 				$expected = $_SERVER['CONTENT_LENGTH'];
 				if ($bytesWritten != $expected) {
@@ -466,11 +497,21 @@ class File extends Node implements IFile {
 		}
 
 		if ($chunk_handler->isComplete()) {
-			list($storage,) = $this->fileView->resolvePath($path);
+			list($storage, ) = $this->fileView->resolvePath($path);
 			$needsPartFile = $this->needsPartFile($storage);
 			$partFile = null;
 
 			$targetPath = $path . '/' . $info['name'];
+			$absPath = $this->fileView->getAbsolutePath($targetPath);
+			$beforeEvent = new GenericEvent(null, ['path' => $absPath]);
+			$newFile = false;
+			if (!$this->fileView->file_exists($targetPath)) {
+				\OC::$server->getEventDispatcher()->dispatch('file.beforecreate', $beforeEvent);
+				$newFile = true;
+			} else {
+				\OC::$server->getEventDispatcher()->dispatch('file.beforeupdate', $beforeEvent);
+			}
+
 			/** @var \OC\Files\Storage\Storage $targetStorage */
 			list($targetStorage, $targetInternalPath) = $this->fileView->resolvePath($targetPath);
 
@@ -490,7 +531,6 @@ class File extends Node implements IFile {
 					/** @var \OC\Files\Storage\Storage $targetStorage */
 					list($partStorage, $partInternalPath) = $this->fileView->resolvePath($partFile);
 
-
 					$chunk_handler->file_assemble($partStorage, $partInternalPath);
 
 					if (!self::isChecksumValid($partStorage, $partInternalPath)) {
@@ -517,18 +557,7 @@ class File extends Node implements IFile {
 					$chunk_handler->file_assemble($targetStorage, $targetInternalPath);
 				}
 
-				// allow sync clients to send the mtime along in a header
-				if (isset($this->request->server['HTTP_X_OC_MTIME'])) {
-					$mtime = $this->sanitizeMtime(
-						$this->request->server ['HTTP_X_OC_MTIME']
-					);
-					if ($targetStorage->touch($targetInternalPath, $mtime)) {
-						$this->header('X-OC-MTime: accepted');
-					}
-				}
-
-				// since we skipped the view we need to scan and emit the hooks ourselves
-				$targetStorage->getUpdater()->update($targetInternalPath);
+				$this->handleMetadataUpdate($targetStorage, $targetInternalPath);
 
 				$this->fileView->changeLock($targetPath, ILockingProvider::LOCK_SHARED);
 
@@ -537,8 +566,7 @@ class File extends Node implements IFile {
 				// FIXME: should call refreshInfo but can't because $this->path is not the of the final file
 				$info = $this->fileView->getFileInfo($targetPath);
 
-
-				if (isset($partStorage) && isset($partInternalPath)) {
+				if (isset($partStorage, $partInternalPath)) {
 					$checksums = $partStorage->getMetaData($partInternalPath)['checksum'];
 				} else {
 					$checksums = $targetStorage->getMetaData($targetInternalPath)['checksum'];
@@ -553,7 +581,16 @@ class File extends Node implements IFile {
 
 				$this->fileView->unlockFile($targetPath, ILockingProvider::LOCK_SHARED);
 
-				return $info->getEtag();
+				$etag = $info->getEtag();
+				if ($etag !== null) {
+					$afterEvent = new GenericEvent(null, ['path' => $absPath]);
+					if ($newFile === true) {
+						\OC::$server->getEventDispatcher()->dispatch('file.aftercreate', $afterEvent);
+					} else {
+						\OC::$server->getEventDispatcher()->dispatch('file.afterupdate', $afterEvent);
+					}
+				}
+				return $etag;
 			} catch (\Exception $e) {
 				if ($partFile !== null) {
 					$targetStorage->unlink($targetInternalPath);
@@ -581,11 +618,10 @@ class File extends Node implements IFile {
 			return true;
 		}
 
-		$expectedChecksum = trim($request->server['HTTP_OC_CHECKSUM']);
+		$expectedChecksum = \trim($request->server['HTTP_OC_CHECKSUM']);
 		$computedChecksums = $meta['checksum'];
 
-		return strpos($computedChecksums, $expectedChecksum) !== false;
-
+		return \strpos($computedChecksums, $expectedChecksum) !== false;
 	}
 
 	/**
@@ -612,6 +648,10 @@ class File extends Node implements IFile {
 	 * @throws \Sabre\DAV\Exception
 	 */
 	private function convertToSabreException(\Exception $e) {
+		if ($e instanceof FileContentNotAllowedException) {
+			// the file content is not permitted
+			throw new DAVForbiddenException($e->getMessage(), $e->getRetry(), $e);
+		}
 		if ($e instanceof \Sabre\DAV\Exception) {
 			throw $e;
 		}
@@ -664,12 +704,12 @@ class File extends Node implements IFile {
 			return $allChecksums;
 		}
 
-		$checksums = explode(' ', $allChecksums);
-		$algoPrefix = strtoupper($algo) . ':';
+		$checksums = \explode(' ', $allChecksums);
+		$algoPrefix = \strtoupper($algo) . ':';
 
 		foreach ($checksums as $checksum) {
 			// starts with $algoPrefix
-			if (substr($checksum, 0, strlen($algoPrefix)) === $algoPrefix) {
+			if (\substr($checksum, 0, \strlen($algoPrefix)) === $algoPrefix) {
 				return $checksum;
 			}
 		}
@@ -680,4 +720,11 @@ class File extends Node implements IFile {
 	protected function header($string) {
 		\header($string);
 	}
+
+	/**
+	 * @return \OCP\Files\Node
+	 */
+	public function getNode() {
+		return \OC::$server->getRootFolder()->get($this->getFileInfo()->getPath());
+	}
 }
