@@ -6,7 +6,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -46,12 +46,11 @@ class MaintenancePlugin extends ServerPlugin {
 	 */
 	public function __construct(IConfig $config = null) {
 		$this->config = $config;
-		if (is_null($config)) {
+		if ($config === null) {
 			$this->config = \OC::$server->getConfig();
 		}
 	}
 
-
 	/**
 	 * This initializes the plugin.
 	 *
