@@ -8,7 +8,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -71,7 +71,7 @@ class ObjectTree extends \Sabre\DAV\Tree {
 	 * is present.
 	 *
 	 * @param string $path chunk file path to convert
-	 * 
+	 *
 	 * @return string path to real file
 	 */
 	private function resolveChunkFile($path) {
@@ -88,14 +88,14 @@ class ObjectTree extends \Sabre\DAV\Tree {
 				// getNodePath is called for multiple nodes within a chunk
 				// upload call
 				$path = $dir . '/' . $info['name'];
-				$path = ltrim($path, '/');
+				$path = \ltrim($path, '/');
 			}
 		}
 		return $path;
 	}
 
 	public function cacheNode(Node $node) {
-		$this->cache[trim($node->getPath(), '/')] = $node;
+		$this->cache[\trim($node->getPath(), '/')] = $node;
 	}
 
 	/**
@@ -104,9 +104,9 @@ class ObjectTree extends \Sabre\DAV\Tree {
 	 * @param string $path
 	 * @return bool
 	 */
-	function nodeExists($path) {
-		$path = trim($path, '/');
-		if (isset($this->cache[$path]) && $this->cache[$path] === false){
+	public function nodeExists($path) {
+		$path = \trim($path, '/');
+		if (isset($this->cache[$path]) && $this->cache[$path] === false) {
 			// Node is not existing, as it was explicitely set in the cache
 			// Next call to getNodeForPath will create cache instance and unset the cached value
 			return false;
@@ -130,7 +130,7 @@ class ObjectTree extends \Sabre\DAV\Tree {
 			throw new \Sabre\DAV\Exception\ServiceUnavailable('filesystem not setup');
 		}
 
-		$path = trim($path, '/');
+		$path = \trim($path, '/');
 
 		if (isset($this->cache[$path]) && $this->cache[$path] !== false) {
 			return $this->cache[$path];
@@ -143,18 +143,18 @@ class ObjectTree extends \Sabre\DAV\Tree {
 
 		if ($path !== '') {
 			try {
-				$this->fileView->verifyPath($path, basename($path));
+				$this->fileView->verifyPath($path, \basename($path));
 			} catch (\OCP\Files\InvalidPathException $ex) {
 				throw new InvalidPath($ex->getMessage());
 			}
 		}
 
 		// Is it the root node?
-		if (!strlen($path)) {
+		if (!\strlen($path)) {
 			return $this->rootNode;
 		}
 
-		if (pathinfo($path, PATHINFO_EXTENSION) === 'part') {
+		if (\pathinfo($path, PATHINFO_EXTENSION) === 'part') {
 			// read from storage
 			$absPath = $this->fileView->getAbsolutePath($path);
 			$mount = $this->fileView->getMount($path);
@@ -201,7 +201,6 @@ class ObjectTree extends \Sabre\DAV\Tree {
 
 		$this->cache[$path] = $node;
 		return $node;
-
 	}
 
 	/**
@@ -256,7 +255,7 @@ class ObjectTree extends \Sabre\DAV\Tree {
 			throw new FileLocked($e->getMessage(), $e->getCode(), $e);
 		}
 
-		list($destinationDir,) = \Sabre\HTTP\URLUtil::splitPath($destination);
+		list($destinationDir, ) = \Sabre\HTTP\URLUtil::splitPath($destination);
 		$this->markDirty($destinationDir);
 	}
 
