@@ -9,7 +9,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,6 +29,7 @@
 namespace OCA\DAV\Connector\Sabre;
 
 use OCA\DAV\DAV\FileCustomPropertiesBackend;
+use OCA\DAV\DAV\FileCustomPropertiesPlugin;
 use OCA\DAV\Files\BrowserErrorPagePlugin;
 use OCP\Files\Mount\IMountManager;
 use OCP\IConfig;
@@ -112,8 +113,9 @@ class ServerFactory {
 		$server->addPlugin(new \OCA\DAV\Connector\Sabre\LockPlugin());
 		// Some WebDAV clients do require Class 2 WebDAV support (locking), since
 		// we do not provide locking we emulate it using a fake locking plugin.
-		if($this->request->isUserAgent([
+		if ($this->request->isUserAgent([
 			'/WebDAVFS/',
+			'/OneNote/',
 			'/Microsoft Office OneNote 2013/',
 			'/Microsoft-WebDAV-MiniRedir/',
 		])) {
@@ -132,7 +134,7 @@ class ServerFactory {
 
 			/** @var \OC\Files\View $view */
 			$view = $viewCallBack($server);
-			if (!is_null($userFolder)) {
+			if ($userFolder !== null) {
 				// User folder exists and user is active and not anonymous
 				$rootInfo = $userFolder->getFileInfo();
 			} else {
@@ -160,7 +162,7 @@ class ServerFactory {
 			);
 			$server->addPlugin(new \OCA\DAV\Connector\Sabre\QuotaPlugin($view));
 
-			if($this->userSession->isLoggedIn()) {
+			if ($this->userSession->isLoggedIn()) {
 				$server->addPlugin(new \OCA\DAV\Connector\Sabre\TagsPlugin($objectTree, $this->tagManager));
 				$server->addPlugin(new \OCA\DAV\Connector\Sabre\SharesPlugin(
 					$objectTree,
@@ -178,10 +180,15 @@ class ServerFactory {
 					\OC::$server->getGroupManager(),
 					$userFolder
 				));
+				$server->addPlugin(
+					new \OCA\DAV\Connector\Sabre\FilesSearchReportPlugin(
+						\OC::$server->getSearch()
+					)
+				);
 
 				// custom properties plugin must be the last one
 				$server->addPlugin(
-					new \Sabre\DAV\PropertyStorage\Plugin(
+					new FileCustomPropertiesPlugin(
 						new FileCustomPropertiesBackend(
 							$objectTree,
 							$this->databaseConnection,
