@@ -3,7 +3,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,7 +29,6 @@ use Sabre\DAV\PropFind;
  * Sabre Plugin to provide share-related properties
  */
 class SharesPlugin extends \Sabre\DAV\ServerPlugin {
-
 	const NS_OWNCLOUD = 'http://owncloud.org/ns';
 	const SHARETYPES_PROPERTYNAME = '{http://owncloud.org/ns}share-types';
 
@@ -164,7 +163,7 @@ class SharesPlugin extends \Sabre\DAV\ServerPlugin {
 		// need prefetch ?
 		if ($sabreNode instanceof \OCA\DAV\Connector\Sabre\Directory
 			&& $propFind->getDepth() !== 0
-			&& !is_null($propFind->getStatus(self::SHARETYPES_PROPERTYNAME))
+			&& $propFind->getStatus(self::SHARETYPES_PROPERTYNAME) !== null
 		) {
 			$children = $sabreNode->getChildren();
 
@@ -185,7 +184,7 @@ class SharesPlugin extends \Sabre\DAV\ServerPlugin {
 
 				// Put node ID into an array and initialize cache for it
 				$nodeId = $childNode->getId();
-				array_push($nodeIdsArray, $nodeId);
+				\array_push($nodeIdsArray, $nodeId);
 				
 				// Initialize share types array for this node in case there would be no shares for this node
 				$initShareTypes[$nodeId] = [];
@@ -198,7 +197,7 @@ class SharesPlugin extends \Sabre\DAV\ServerPlugin {
 			$this->cachedShareTypes = $this->convertToHashMap($returnedShares, $initShareTypes);
 		}
 
-		$propFind->handle(self::SHARETYPES_PROPERTYNAME, function() use ($sabreNode) {
+		$propFind->handle(self::SHARETYPES_PROPERTYNAME, function () use ($sabreNode) {
 			if (isset($this->cachedShareTypes[$sabreNode->getId()])) {
 				// Share types in cache for this node
 				$shareTypesHash = $this->cachedShareTypes[$sabreNode->getId()];
@@ -211,7 +210,7 @@ class SharesPlugin extends \Sabre\DAV\ServerPlugin {
 				$initShareTypes[$nodeId] = [];
 				$shareTypesHash = $this->convertToHashMap($returnedShares, $initShareTypes)[$nodeId];
 			}
-			$shareTypes = array_keys($shareTypesHash);
+			$shareTypes = \array_keys($shareTypesHash);
 
 			return new ShareTypeList($shareTypes);
 		});
