@@ -5,7 +5,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,6 +26,7 @@ namespace OCA\Encryption\Hooks;
 
 
 use OC\Files\Filesystem;
+use OCP\IConfig;
 use OCP\IUserManager;
 use OCP\Util as OCUtil;
 use OCA\Encryption\Hooks\Contracts\IHook;
@@ -76,6 +77,10 @@ class UserHooks implements IHook {
 	 * @var Crypt
 	 */
 	private $crypt;
+	/**
+	 * @var IConfig
+	 */
+	private $config;
 
 	/**
 	 * UserHooks constructor.
@@ -89,6 +94,7 @@ class UserHooks implements IHook {
 	 * @param Session $session
 	 * @param Crypt $crypt
 	 * @param Recovery $recovery
+	 * @param IConfig $config
 	 */
 	public function __construct(KeyManager $keyManager,
 								IUserManager $userManager,
@@ -98,7 +104,7 @@ class UserHooks implements IHook {
 								Util $util,
 								Session $session,
 								Crypt $crypt,
-								Recovery $recovery) {
+								Recovery $recovery, IConfig $config) {
 
 		$this->keyManager = $keyManager;
 		$this->userManager = $userManager;
@@ -109,6 +115,7 @@ class UserHooks implements IHook {
 		$this->session = $session;
 		$this->recovery = $recovery;
 		$this->crypt = $crypt;
+		$this->config = $config;
 	}
 
 	/**
@@ -166,6 +173,11 @@ class UserHooks implements IHook {
 			$this->userSetup->setupUser($params['uid'], $params['password']);
 		}
 
+		if (($this->util->isMasterKeyEnabled() === false) &&
+			($this->config->getAppValue('encryption', 'userSpecificKey', '') === '')) {
+			$this->config->setAppValue('encryption', 'userSpecificKey', '1');
+		}
+
 		$this->keyManager->init($params['uid'], $params['password']);
 	}
 
@@ -234,9 +246,14 @@ class UserHooks implements IHook {
 	 */
 	public function setPassphrase($params) {
 
-		// Get existing decrypted private key
-		$privateKey = $this->session->getPrivateKey();
-		$user = $this->user->getUser();
+		$privateKey = null;
+		$user = null;
+		//Check if the session is there or not
+		if ($this->user->getUser() !== null) {
+			// Get existing decrypted private key
+			$privateKey = $this->session->getPrivateKey();
+			$user = $this->user->getUser();
+		}
 
 		// current logged in user changes his own password
 		if ($user && $params['uid'] === $user->getUID() && $privateKey) {
