@@ -10,6 +10,7 @@ OC.L10N.register(
     "Share it:" : "Сподели го:",
     "Add to your website" : "Додади на твојот веб сајт",
     "Share with me via ownCloud" : "Сподели со мене преку ownCloud",
-    "HTML Code:" : "HTML код:"
+    "HTML Code:" : "HTML код:",
+    "Add to your ownCloud" : "Додади во вашиот ownCloud"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
