@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014
+ * Copyright (c) 2018
  *
  * This file is licensed under the Affero General Public License version 3
  * or later.
@@ -114,6 +114,17 @@ OC.FileUpload.prototype = {
 		return this.getFile().name;
 	},
 
+	getLastModified: function() {
+		var file = this.getFile();
+		if (file.lastModifiedDate) {
+			return file.lastModifiedDate.getTime() / 1000;
+		}
+		if (file.lastModified) {
+			return file.lastModified / 1000;
+		}
+		return null;
+	},
+
 	setTargetFolder: function(targetFolder) {
 		this._targetFolder = targetFolder;
 	},
@@ -238,9 +249,10 @@ OC.FileUpload.prototype = {
 			this.data.headers['OC-Autorename'] = '1';
 		}
 
-		if (file.lastModified) {
+		var lastModified = this.getLastModified();
+		if (lastModified) {
 			// preserve timestamp
-			this.data.headers['X-OC-Mtime'] = file.lastModified / 1000;
+			this.data.headers['X-OC-Mtime'] = '' + lastModified;
 		}
 
 		var userName = this.uploader.davClient.getUserName();
@@ -287,23 +299,56 @@ OC.FileUpload.prototype = {
 		}
 
 		var uid = OC.getCurrentUser().uid;
-		var mtime = this.getFile().lastModified;
+		var mtime = this.getLastModified();
 		var size = this.getFile().size;
 		var headers = {};
 		if (mtime) {
-			headers['X-OC-Mtime'] = mtime / 1000;
+			headers['X-OC-Mtime'] = mtime;
 		}
 		if (size) {
 			headers['OC-Total-Length'] = size;
-
 		}
+		headers['OC-LazyOps'] = 1;
 
-		return this.uploader.davClient.move(
+		var doneDeferred = $.Deferred();
+
+		this.uploader.davClient.move(
 			'uploads/' + uid + '/' + this.getId() + '/.file',
 			'files/' + uid + '/' + OC.joinPaths(this.getFullPath(), this.getFileName()),
 			true,
 			headers
-		);
+		).then(function (status, response) {
+			// a 202 response means the server is performing the final MOVE in an async manner,
+			// so we need to poll its status
+			if (status === 202) {
+				var poll = function() {
+					$.ajax(response.xhr.getResponseHeader('oc-jobstatus-location')).then(function(data) {
+						var obj = JSON.parse(data);
+						if (obj.status === 'finished') {
+							doneDeferred.resolve(status, response);
+						}
+						if (obj.status === 'error') {
+							OC.Notification.show(obj.errorMessage);
+							doneDeferred.reject(status, response);
+						}
+						if (obj.status === 'started' || obj.status === 'initial') {
+							// call it again after some short delay
+							setTimeout(poll, 1000);
+						}
+					});
+				};
+
+				// start the polling
+				poll();
+			} else {
+				doneDeferred.resolve(status, response);
+			}
+
+		}).fail( function(status, response) {
+			doneDeferred.reject(status, response);
+		});
+
+		return doneDeferred.promise();
 	},
 
 	_deleteChunkFolder: function() {
@@ -320,10 +365,22 @@ OC.FileUpload.prototype = {
 		if (this.data.isChunked) {
 			this._deleteChunkFolder();
 		}
+		this.data.stalled = false;
 		this.data.abort();
 		this.deleteUpload();
 	},
 
+	/**
+	 * retry the upload
+	 */
+	retry: function() {
+		if (!this.data.stalled) {
+			console.log('Retrying upload ' + this.id);
+			this.data.stalled = true;
+			this.data.abort();
+		}
+	},
+
 	/**
 	 * Fail the upload
 	 */
@@ -472,6 +529,17 @@ OC.Uploader.prototype = _.extend({
 	 */
 	davClient: null,
 
+	/**
+	 * Upload progressbar element
+	 *
+	 * @type Object
+	 */
+	$uploadprogressbar: null,
+
+	/**
+	 * @type int
+	 */
+	_uploadStallTimeout: 60,
 	/**
 	 * Function that will allow us to know if Ajax uploads are supported
 	 * @link https://github.com/New-Bamboo/example-ajax-upload/blob/master/public/index.html
@@ -794,34 +862,41 @@ OC.Uploader.prototype = _.extend({
 		var self = this;
 		window.clearInterval(this._progressBarInterval);
 		$('#uploadprogresswrapper .stop').fadeOut();
-		$('#uploadprogressbar').fadeOut(function() {
+		this.$uploadprogressbar.fadeOut(function() {
 			self.$uploadEl.trigger(new $.Event('resized'));
 		});
 	},
 
 	_showProgressBar: function() {
-		$('#uploadprogressbar').fadeIn();
+		this.$uploadprogressbar.fadeIn();
 		this.$uploadEl.trigger(new $.Event('resized'));
 		if (this._progressBarInterval) {
 			window.clearInterval(this._progressBarInterval);
 		}
 		this._progressBarInterval = window.setInterval(_.bind(this._updateProgressBar, this), 1000);
 		this._lastProgress = 0;
-		this._lastProgressStalledSeconds = 0;
 	},
-	
+
 	_updateProgressBar: function() {
-		var progress = parseInt($('#uploadprogressbar').attr('data-loaded'), 10);
-		var total = parseInt($('#uploadprogressbar').attr('data-total'), 10);
+		var progress = parseInt(this.$uploadprogressbar.attr('data-loaded'), 10);
+		var total = parseInt(this.$uploadprogressbar.attr('data-total'), 10);
 		if (progress !== this._lastProgress) {
 			this._lastProgress = progress;
-			this._lastProgressStalledSeconds = 0;
+			this._lastProgressTime = new Date().getTime();
 		} else {
-			if (this._lastProgressStalledSeconds < 1) {
-				this._lastProgressStalledSeconds++;
-			} else if (progress >= total) {
+			if (progress >= total) {
 				// change message if we stalled at 100%
-				$('#uploadprogressbar .label .desktop').text(t('core', 'Processing files...'));
+				this.$uploadprogressbar.find('.label .desktop').text(t('core', 'Processing files...'));
+			}
+			if (new Date().getTime() - this._lastProgressTime >= this._uploadStallTimeout * 1000 ) {
+				// TODO: move to "fileuploadprogress" event instead and use data.uploadedBytes
+				// stalling needs to be checked here because the file upload no longer triggers events
+				// restart upload
+				this.log('progress stalled'); // retry chunk (and prevent IE from dying)
+				_.each(this._uploads, function(upload) {
+					// FIXME: harden by only retry pending, not the finished ones
+					upload.retry();
+				});
 			}
 		}
 	},
@@ -858,6 +933,9 @@ OC.Uploader.prototype = _.extend({
 		var self = this;
 		options = options || {};
 
+		this._uploads = {};
+		this._knownDirs = {};
+
 		this.fileList = options.fileList;
 		this.filesClient = options.filesClient || OC.Files.getClient();
 		this.davClient = new OC.Files.Client({
@@ -871,10 +949,15 @@ OC.Uploader.prototype = _.extend({
 		if (options.url) {
 			this.url = options.url;
 		}
+		if (options.uploadStallTimeout) {
+			this._uploadStallTimeout = options.uploadStallTimeout;
+		}
 
 		$uploadEl = $($uploadEl);
 		this.$uploadEl = $uploadEl;
 
+		this.$uploadprogressbar = $('#uploadprogressbar');
+
 		if ($uploadEl.exists()) {
 			$('#uploadprogresswrapper .stop').on('click', function() {
 				self.cancelUploads();
@@ -885,10 +968,12 @@ OC.Uploader.prototype = _.extend({
 				dropZone: options.dropZone, // restrict dropZone to content div
 				autoUpload: false,
 				sequentialUploads: true,
+				maxRetries: options.uploadStallRetries || 3,
+				retryTimeout: 500,
 				//singleFileUploads is on by default, so the data.files array will always have length 1
 				/**
 				 * on first add of every selection
-				 * - check all files of originalFiles array with files in dir
+
 				 * - on conflict show dialog
 				 *   - skip all -> remember as single skip action for all conflicting files
 				 *   - replace all -> remember as single replace action for all conflicting files
@@ -1049,6 +1134,54 @@ OC.Uploader.prototype = _.extend({
 				},
 				fail: function(e, data) {
 					var upload = self.getUpload(data);
+					if (upload && upload.data && upload.data.stalled) {
+						self.log('retry', e, upload);
+						// jQuery Widget Factory uses "namespace-widgetname" since version 1.10.0:
+						var fu = $(this).data('blueimp-fileupload') || $(this).data('fileupload'),
+							retries = upload.data.retries || 0,
+							retry = function () {
+								var uid = OC.getCurrentUser().uid;
+								upload.uploader.davClient.getFolderContents(
+									'uploads/' + uid + '/' + upload.getId()
+								)
+								.done(function (status, files) {
+									data.uploadedBytes = 0;
+									_.each(files, function(file) {
+										// only count numeric file names to omit .file and .file.zsync
+										if (!isNaN(parseFloat(file.name))
+											&& isFinite(file.name)
+											// only count full chunks
+											&& file.size === fu.options.maxChunkSize
+										) {
+											data.uploadedBytes += file.size;
+										}
+									});
+
+									// clear the previous data:
+									upload.data.stalled = false;
+									data.data = null;
+									// overwrite chunk
+									delete data.headers['If-None-Match'];
+									data.submit();
+								})
+								.fail(function (status, ex) {
+									self.log('failed to retry', status, ex);
+									fu._trigger('fail', e, data);
+								});
+							};
+						if (upload && upload.data && upload.data.stalled &&
+							data.uploadedBytes < data.files[0].size &&
+							retries < fu.options.maxRetries) {
+							retries += 1;
+							upload.data.retries = retries;
+							window.setTimeout(retry, retries * fu.options.retryTimeout);
+							return;
+						}
+						fu.prototype
+							.options.fail.call(this, e, data);
+						return;
+					}
+
 					var status = null;
 					if (upload) {
 						status = upload.getResponseStatus();
@@ -1146,14 +1279,14 @@ OC.Uploader.prototype = _.extend({
 					self.log('progress handle fileuploadstart', e, data);
 					$('#uploadprogresswrapper .stop').show();
 					$('#uploadprogresswrapper .label').show();
-					$('#uploadprogressbar').progressbar({value: 0});
-					$('#uploadprogressbar .ui-progressbar-value').
+					self.$uploadprogressbar.progressbar({value: 0});
+					self.$uploadprogressbar.find('.ui-progressbar-value').
 						html('<em class="label inner"><span class="desktop">'
 							+ t('files', 'Uploading...')
 							+ '</span><span class="mobile">'
 							+ t('files', '...')
 							+ '</span></em>');
-                    $('#uploadprogressbar').tipsy({gravity:'n', fade:true, live:true});
+					self.$uploadprogressbar.tipsy({gravity:'n', fade:true, live:true});
 					self._showProgressBar();
 					self.trigger('start', e, data);
 				});
@@ -1172,25 +1305,25 @@ OC.Uploader.prototype = _.extend({
 					lastSize = data.loaded;
 					diffSize = diffSize / diffUpdate; // apply timing factor, eg. 1mb/2s = 0.5mb/s
 					var remainingSeconds = ((data.total - data.loaded) / diffSize);
-					if(remainingSeconds >= 0) {
+					if (isFinite(remainingSeconds) && remainingSeconds >= 0) {
 						bufferTotal = bufferTotal - (buffer[bufferIndex]) + remainingSeconds;
 						buffer[bufferIndex] = remainingSeconds; //buffer to make it smoother
 						bufferIndex = (bufferIndex + 1) % bufferSize;
 					}
 					var smoothRemainingSeconds = (bufferTotal / bufferSize); //seconds
 					var h = moment.duration(smoothRemainingSeconds, "seconds").humanize();
-					$('#uploadprogressbar').attr('data-loaded', data.loaded);
-					$('#uploadprogressbar').attr('data-total', data.total);
-					$('#uploadprogressbar .label .mobile').text(h);
-					$('#uploadprogressbar .label .desktop').text(h);
-					$('#uploadprogressbar').attr('original-title',
+					self.$uploadprogressbar.attr('data-loaded', data.loaded);
+					self.$uploadprogressbar.attr('data-total', data.total);
+					self.$uploadprogressbar.find('.label .mobile').text(h);
+					self.$uploadprogressbar.find('.label .desktop').text(h);
+					self.$uploadprogressbar.attr('original-title',
 						t('files', '{loadedSize} of {totalSize} ({bitrate})' , {
 							loadedSize: humanFileSize(data.loaded),
 							totalSize: humanFileSize(data.total),
 							bitrate: humanFileSize(data.bitrate) + '/s'
 						})
 					);
-					$('#uploadprogressbar').progressbar('value', progress);
+					self.$uploadprogressbar.progressbar('value', progress);
 					self.trigger('progressall', e, data);
 				});
 				fileupload.on('fileuploadstop', function(e, data) {
@@ -1220,6 +1353,12 @@ OC.Uploader.prototype = _.extend({
 						'/' + encodeURIComponent(chunkId);
 					delete data.contentRange;
 					delete data.headers['Content-Range'];
+
+					// reset retries
+					upload.data.retries = 0;
+				});
+				fileupload.on('fileuploadchunkdone', function(e, data) {
+					$(data.xhr().upload).unbind('progress');
 				});
 				fileupload.on('fileuploaddone', function(e, data) {
 					var upload = self.getUpload(data);
