@@ -256,7 +256,6 @@
 				this.$el.toggleClass('hide-hidden-files', !this._filesConfig.get('showhidden'));
 			}
 
-
 			if (_.isUndefined(options.detailsViewEnabled) || options.detailsViewEnabled) {
 				this._detailsView = new OCA.Files.DetailsView();
 				this._detailsView.$el.insertBefore(this.$el);
@@ -333,7 +332,7 @@
 
 			if (options.scrollTo) {
 				this.$fileList.one('updated', function() {
-					self.scrollTo(options.scrollTo);
+					self.scrollTo(options.scrollTo, options.detailTabId);
 				});
 			}
 
@@ -345,7 +344,9 @@
 						fileList: this,
 						filesClient: this.filesClient,
 						dropZone: $('#content'),
-						maxChunkSize: options.maxChunkSize
+						maxChunkSize: options.maxChunkSize,
+						uploadStallTimeout: options.uploadStallTimeout,
+						uploadStallRetries: options.uploadStallRetries
 					});
 
 					this.setupUploadEvents(this._uploader);
@@ -373,6 +374,11 @@
 			this.fileActions.off('setDefault', this._onFileActionsUpdated);
 			OC.Plugins.detach('OCA.Files.FileList', this);
 			$('#app-content').off('appresized', this._onResize);
+			// HACK: this will make reload work when reused
+			this.$el.find('#dir').val('');
+			// remove summary
+			this.$el.find('tfoot tr.summary').remove();
+			this.$fileList.empty();
 		},
 
 		/**
@@ -475,11 +481,13 @@
 		 * @param {string} [tabId] optional tab id to select
 		 */
 		showDetailsView: function(fileName, tabId) {
-			this._updateDetailsView(fileName);
+			if (!this._detailsView) {
+				return;
+			}
+			this._updateDetailsView(fileName, true);
 			if (tabId) {
 				this._detailsView.selectTab(tabId);
 			}
-			OC.Apps.showAppSidebar(this._detailsView.$el);
 		},
 
 		/**
@@ -495,7 +503,7 @@
 
 			// show defaults to true
 			show = _.isUndefined(show) || !!show;
-			var oldFileInfo = this._detailsView.getFileInfo();
+			var oldFileInfo = this._currentFileModel;
 			if (oldFileInfo) {
 				// TODO: use more efficient way, maybe track the highlight
 				this.$fileList.children().filterAttr('data-id', '' + oldFileInfo.get('id')).removeClass('highlighted');
@@ -514,6 +522,8 @@
 
 			if (show && this._detailsView.$el.hasClass('disappear')) {
 				OC.Apps.showAppSidebar(this._detailsView.$el);
+			} else if (show === false) {
+				OC.Apps.hideAppSidebar(this._detailsView.$el);
 			}
 
 			var $tr = this.findFileEl(fileName);
@@ -523,8 +533,12 @@
 
 			$tr.addClass('highlighted');
 
-			this._detailsView.setFileInfo(model);
-			this._detailsView.$el.scrollTop(0);
+			if (show === false) {
+				this._detailsView.setFileInfo(null);
+			} else {
+				this._detailsView.setFileInfo(model);
+				this._detailsView.$el.scrollTop(0);
+			}
 		},
 
 		/**
@@ -598,6 +612,11 @@
 		 * Event handler for when clicking on files to select them
 		 */
 		_onClickFile: function(event) {
+			var $link = $(event.target).closest('a');
+			if ($link.attr('href') === '#' || $link.hasClass('disable-click')) {
+				event.preventDefault();
+				return;
+			}
 			var $tr = $(event.target).closest('tr');
 			if ($tr.hasClass('dragging')) {
 				return;
@@ -677,16 +696,21 @@
 
 		/**
 		 * Event handler for when selecting/deselecting all files
+		 * modifiedFiles if not passed then this.files would be used.
+		 * modifiedFiles was introduced, so that if we have to alter
+		 * any fields of this.files, its better to use modifiedFiles
+		 * instead of directly making change in this.files.
 		 */
-		_onClickSelectAll: function(e) {
+		_onClickSelectAll: function(e, modifiedFiles) {
+			var filesViewed = modifiedFiles ? modifiedFiles : this.files;
 			var checked = $(e.target).prop('checked');
 			this.$fileList.find('td.filename>.selectCheckBox').prop('checked', checked)
 				.closest('tr').toggleClass('selected', checked);
 			this._selectedFiles = {};
 			this._selectionSummary.clear();
 			if (checked) {
-				for (var i = 0; i < this.files.length; i++) {
-					var fileData = this.files[i];
+				for (var i = 0; i < filesViewed.length; i++) {
+					var fileData = filesViewed[i];
 					this._selectedFiles[fileData.id] = fileData;
 					this._selectionSummary.add(fileData);
 				}
@@ -1540,7 +1564,8 @@
 			if (persist && OC.getCurrentUser().uid !== null) {
 				$.post(OC.generateUrl('/apps/files/api/v1/sorting'), {
 					mode: sort,
-					direction: direction
+					direction: direction,
+					view: this.id
 				});
 			}
 		},
@@ -1609,7 +1634,7 @@
 			if (status === 500) {
 				// Go home
 				this.changeDirectory('/');
-				OC.Notification.show(t('files', 'This directory is unavailable, please check the logs or contact the administrator'), 
+				OC.Notification.show(t('files', 'This directory is unavailable, please check the logs or contact the administrator'),
 					{type: 'error'}
 				);
 				return false;
@@ -1620,7 +1645,7 @@
 				if (this.getCurrentDirectory() !== '/') {
 					this.changeDirectory('/');
 					// TODO: read error message from exception
-					OC.Notification.show(t('files', 'Storage is temporarily not available'), 
+					OC.Notification.show(t('files', 'Storage is temporarily not available'),
 						{type: 'error'}
 					);
 				}
@@ -1703,7 +1728,7 @@
 		 * @param {int} urlSpec.x width
 		 * @param {int} urlSpec.y height
 		 * @param {String} urlSpec.file path to the file
-		 * @return preview URL
+		 * @return {String} preview URL
 		 */
 		generatePreviewUrl: function(urlSpec) {
 			urlSpec = urlSpec || {};
@@ -1718,7 +1743,16 @@
 			urlSpec.x = Math.ceil(urlSpec.x);
 			urlSpec.y = Math.ceil(urlSpec.y);
 			urlSpec.forceIcon = 0;
-			return OC.generateUrl('/core/preview.png?') + $.param(urlSpec);
+			var parts = urlSpec.file.split('/');
+			var encoded = [];
+			for (var i = 0; i < parts.length; i++) {
+				encoded.push(encodeURIComponent(parts[i]));
+			}
+			var file = encoded.join('/');
+			delete urlSpec.file;
+			urlSpec.preview = 1;
+
+			return OC.linkToRemoteBase('dav') + '/files/' + OC.getCurrentUser().uid + file + '?' + $.param(urlSpec);
 		},
 
 		/**
@@ -1938,14 +1972,18 @@
 							self.remove(fileName);
 						}
 					})
-					.fail(function(status) {
+					.fail(function(status, result) {
 						if (status === 412) {
 							// TODO: some day here we should invoke the conflict dialog
-							OC.Notification.show(t('files', 'Could not move "{file}", target exists', 
-								{file: fileName}), {type: 'error'}
+							OC.Notification.show(t('files', 'Could not move "{file}", target exists',
+								{file: fileName}, null, {escape: false}), {type: 'error'}
+							);
+						} else if (result != null && typeof result.message !== "undefined") {
+							OC.Notification.show(t('files', 'Could not move "{file}": {message}',
+								{file: fileName, message: result.message}), {type: 'error'}
 							);
 						} else {
-							OC.Notification.show(t('files', 'Could not move "{file}"', 
+							OC.Notification.show(t('files', 'Could not move "{file}"',
 								{file: fileName}), {type: 'error'}
 							);
 						}
@@ -2021,9 +2059,10 @@
 				td.children('a.name').show();
 			}
 
-			function updateInList(fileInfo) {
-				self.updateRow(tr, fileInfo);
-				self._updateDetailsView(fileInfo.name, false);
+			function updateInList(newFileInfo, oldFileInfo) {
+				self.updateRow(tr, newFileInfo);
+				self.fileSummary.updateHidden(newFileInfo, oldFileInfo);
+				self._updateDetailsView(newFileInfo.name, false);
 			}
 
 			// TODO: too many nested blocks, move parts into functions
@@ -2045,23 +2084,30 @@
 						self.showFileBusyState(tr, true);
 						tr.attr('data-file', newName);
 						var basename = newName;
-						if (newName.indexOf('.') > 0 && tr.data('type') !== 'dir') {
-							basename = newName.substr(0, newName.lastIndexOf('.'));
+						if (tr.data('type') !== 'dir') {
+							var extension = '';
+							if (newName.indexOf('.') > 0) {
+								var lastDotIndex = newName.lastIndexOf('.');
+								basename = newName.substr(0, lastDotIndex);
+								extension = newName.substr(lastDotIndex);
+							}
+							td.find('a.name span.nametext span.extension').text(extension);
 						}
-						td.find('a.name span.nametext').text(basename);
+						td.find('a.name span.nametext span.innernametext').text(basename);
 						td.children('a.name').show();
 
 						var path = tr.attr('data-path') || self.getCurrentDirectory();
 						self.filesClient.move(OC.joinPaths(path, oldName), OC.joinPaths(path, newName))
 							.done(function() {
-								oldFileInfo.name = newName;
-								updateInList(oldFileInfo);
+								newFileInfo = Object.create(oldFileInfo);
+								newFileInfo.name = newName;
+								updateInList(newFileInfo, oldFileInfo);
 							})
 							.fail(function(status) {
 								// TODO: 409 means current folder does not exist, redirect ?
 								if (status === 404) {
 									// source not found, so remove it from the list
-									OC.Notification.show(t('files', 'Could not rename "{fileName}", it does not exist any more', 
+									OC.Notification.show(t('files', 'Could not rename "{fileName}", it does not exist any more',
 										{fileName: oldName}), {timeout: 7, type: 'error'}
 									);
 
@@ -2070,7 +2116,7 @@
 								} else if (status === 412) {
 									// target exists
 									OC.Notification.show(
-										t('files', 'The name "{targetName}" is already used in the folder "{dir}". Please choose a different name.', 
+										t('files', 'The name "{targetName}" is already used in the folder "{dir}". Please choose a different name.',
 										{
 											targetName: newName,
 											dir: self.getCurrentDirectory(),
@@ -2081,11 +2127,11 @@
 									);
 								} else {
 									// restore the item to its previous state
-									OC.Notification.show(t('files', 'Could not rename "{fileName}"', 
+									OC.Notification.show(t('files', 'Could not rename "{fileName}"',
 										{fileName: oldName}), {type: 'error'}
 									);
 								}
-								updateInList(oldFileInfo);
+								updateInList(oldFileInfo, oldFileInfo);
 							});
 					} else {
 						// add back the old file info when cancelled
@@ -2166,18 +2212,18 @@
 					self.addAndFetchFileInfo(targetPath, '', {scrollTo: true}).then(function(status, data) {
 						deferred.resolve(status, data);
 					}, function() {
-						OC.Notification.show(t('files', 'Could not create file "{file}"', 
+						OC.Notification.show(t('files', 'Could not create file "{file}"',
 							{file: name}), {type: 'error'}
 						);
 					});
 				})
 				.fail(function(status) {
 					if (status === 412) {
-						OC.Notification.show(t('files', 'Could not create file "{file}" because it already exists', 
+						OC.Notification.show(t('files', 'Could not create file "{file}" because it already exists',
 							{file: name}), {type: 'error'}
 						);
 					} else {
-						OC.Notification.show(t('files', 'Could not create file "{file}"', 
+						OC.Notification.show(t('files', 'Could not create file "{file}"',
 							{file: name}), {type: 'error'}
 						);
 					}
@@ -2216,7 +2262,7 @@
 					self.addAndFetchFileInfo(targetPath, '', {scrollTo:true}).then(function(status, data) {
 						deferred.resolve(status, data);
 					}, function() {
-						OC.Notification.show(t('files', 'Could not create folder "{dir}"', 
+						OC.Notification.show(t('files', 'Could not create folder "{dir}"',
 							{dir: name}), {type: 'error'}
 						);
 					});
@@ -2227,20 +2273,20 @@
 						// add it to the list, for completeness
 						self.addAndFetchFileInfo(targetPath, '', {scrollTo:true})
 							.done(function(status, data) {
-								OC.Notification.show(t('files', 'Could not create folder "{dir}" because it already exists', 
+								OC.Notification.show(t('files', 'Could not create folder "{dir}" because it already exists',
 									{dir: name}), {type: 'error'}
 								);
 								// still consider a failure
 								deferred.reject(createStatus, data);
 							})
 							.fail(function() {
-								OC.Notification.show(t('files', 'Could not create folder "{dir}"', 
+								OC.Notification.show(t('files', 'Could not create folder "{dir}"',
 									{dir: name}), {type: 'error'}
 								);
 								deferred.reject(status);
 							});
 					} else {
-						OC.Notification.show(t('files', 'Could not create folder "{dir}"', 
+						OC.Notification.show(t('files', 'Could not create folder "{dir}"',
 							{dir: name}), {type: 'error'}
 						);
 						deferred.reject(createStatus);
@@ -2297,7 +2343,7 @@
 					deferred.resolve(status, data);
 				})
 				.fail(function(status) {
-					OC.Notification.show(t('files', 'Could not create file "{file}"', 
+					OC.Notification.show(t('files', 'Could not create file "{file}"',
 						{file: name}), {type: 'error'}
 					);
 					deferred.reject(status);
@@ -2408,7 +2454,7 @@
 							removeFromList(file);
 						} else {
 							// only reset the spinner for that one file
-							OC.Notification.show(t('files', 'Error deleting file "{fileName}".', 
+							OC.Notification.show(t('files', 'Error deleting file "{fileName}".',
 								{fileName: file}), {type: 'error'}
 							);
 							var deleteAction = self.findFileEl(file).find('.action.delete');
@@ -2465,10 +2511,14 @@
 			this.$el.find('.mask').remove();
 			this.$table.removeClass('hidden');
 		},
-		scrollTo:function(file) {
+		scrollTo:function(file, detailTabId) {
 			if (!_.isArray(file)) {
 				file = [file];
 			}
+			if (!_.isUndefined(detailTabId)) {
+				var filename = file[file.length - 1];
+				this.showDetailsView(filename, detailTabId);
+			}
 			this.highlightFiles(file, function($tr) {
 				$tr.addClass('searchresult');
 				$tr.one('hover', function() {
@@ -2843,6 +2893,36 @@
 
 		},
 
+		/**
+		 * Scrolls the container to make the given row visible
+		 *
+		 * @param $fileRow row to make visible
+		 * @param {Function} callback callback to call after scroll is complete
+		 */
+		_scrollToRow: function($fileRow, callback) {
+			var currentOffset = this.$container.scrollTop();
+			var additionalOffset = 0;
+			var $controls = this.$el.find('#controls');
+			if ($controls.exists()) {
+				additionalOffset += $controls.height() + $controls.offset().top;
+			}
+
+			// Animation
+			var $scrollContainer = this.$container;
+			if ($scrollContainer[0] === window) {
+				// need to use "body" to animate scrolling
+				// when the scroll container is the window
+				$scrollContainer = $('body');
+			}
+			$scrollContainer.animate({
+				// Scrolling to the top of the new element
+				scrollTop: currentOffset + $fileRow.offset().top - $fileRow.height() * 2 - additionalOffset
+			}, {
+				duration: 500,
+				complete: callback
+			});
+		},
+
 		/**
 		 * Scroll to the last file of the given list
 		 * Highlight the list of files
@@ -2863,44 +2943,27 @@
 				return;
 			}
 
-			var currentOffset = this.$container.scrollTop();
-			var additionalOffset = this.$el.find("#controls").height()+this.$el.find("#controls").offset().top;
-
-			// Animation
 			var _this = this;
-			var $scrollContainer = this.$container;
-			if ($scrollContainer[0] === window) {
-				// need to use "body" to animate scrolling
-				// when the scroll container is the window
-				$scrollContainer = $('body');
-			}
-			$scrollContainer.animate({
-				// Scrolling to the top of the new element
-				scrollTop: currentOffset + $fileRow.offset().top - $fileRow.height() * 2 - additionalOffset
-			}, {
-				duration: 500,
-				complete: function() {
-					// Highlighting function
-					var highlightRow = highlightFunction;
+			this._scrollToRow($fileRow, function() {
+				// Highlighting function
+				var highlightRow = highlightFunction;
 
-					if (!highlightRow) {
-						highlightRow = function($fileRow) {
-							$fileRow.addClass("highlightUploaded");
-							setTimeout(function() {
-								$fileRow.removeClass("highlightUploaded");
-							}, 2500);
-						};
+				if (!highlightRow) {
+					highlightRow = function($fileRow) {
+						$fileRow.addClass("highlightUploaded");
+						setTimeout(function() {
+							$fileRow.removeClass("highlightUploaded");
+						}, 2500);
+					};
+				}
+
+				// Loop over uploaded files
+				for(var i=0; i<files.length; i++) {
+					var $fileRow = _this.findFileEl(files[i]);
+
+					if($fileRow.length !== 0) { // Checking element existence
+						highlightRow($fileRow);
 					}
-
-					// Loop over uploaded files
-					for(var i=0; i<files.length; i++) {
-						var $fileRow = _this.findFileEl(files[i]);
-
-						if($fileRow.length !== 0) { // Checking element existence
-							highlightRow($fileRow);
-						}
-					}
-
 				}
 			});
 		},
