@@ -1,33 +1,17 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Memoro ne disponeblas",
     "Storage invalid" : "Memoro ne validas",
     "Unknown error" : "Nekonata eraro",
-    "Unable to set upload directory." : "Ne povis agordiĝi la alŝuta dosierujo.",
-    "No file was uploaded. Unknown error" : "Neniu dosiero alŝutiĝis. Nekonata eraro.",
-    "There is no error, the file uploaded with success" : "Ne estas eraro, la dosiero alŝutiĝis sukcese.",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "La dosiero alŝutita superas la regulon upload_max_filesize el php.ini: ",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon MAX_FILE_SIZE, kiu estas difinita en la HTML-formularo",
-    "The uploaded file was only partially uploaded" : "la alŝutita dosiero nur parte alŝutiĝis",
-    "No file was uploaded" : "Neniu dosiero alŝutiĝis.",
-    "Missing a temporary folder" : "Mankas provizora dosierujo.",
-    "Failed to write to disk" : "Malsukcesis skribo al disko",
-    "Not enough storage available" : "Ne haveblas sufiĉa memoro",
-    "The target folder has been moved or deleted." : "La cela dosierujo moviĝis aŭ foriĝis.",
-    "Upload failed. Could not find uploaded file" : "La alŝuto malsukcesis. Ne troviĝis alŝutota dosiero.",
-    "Upload failed. Could not get file info." : "La alŝuto malsukcesis. Ne povis ekhaviĝi informo pri dosiero.",
-    "Invalid directory." : "Nevalida dosierujo.",
-    "Files" : "Dosieroj",
     "All files" : "Ĉiuj dosieroj",
+    "Saved" : "Konservita",
     "Home" : "Hejmo",
     "Close" : "Fermi",
     "Favorites" : "Favoratoj",
+    "Could not create folder \"{dir}\"" : "Ne eblas krei dosierujon “{dir}”",
     "Upload cancelled." : "La alŝuto nuliĝis.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ne povis alŝutiĝi {filename} ĉar ĝi estas dosierujo aŭ ĝi havas 0 duumokojn",
-    "Total file size {size1} exceeds upload limit {size2}" : "Tuta dosiergrando {size1} transpasas alŝutolimon {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ne sufiĉas libera spaco: vi alŝutas {size1} sed nur {size2} restas",
-    "Could not get result from server." : "Ne povis ekhaviĝi rezulto el la servilo.",
     "Uploading..." : "Alŝutante...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Dosieralŝuto plenumiĝas. Lasi la paĝon nun nuligus la alŝuton.",
     "Actions" : "Agoj",
@@ -36,10 +20,12 @@ OC.L10N.register(
     "Delete" : "Forigi",
     "Disconnect storage" : "Malkonekti memoron",
     "Unshare" : "Malkunhavigi",
+    "Files" : "Dosieroj",
     "Details" : "Detaloj",
     "Select" : "Elekti",
     "Pending" : "Traktotaj",
     "Unable to determine date" : "Ne eblas determini daton",
+    "Invalid path" : "Nevalida vojo",
     "This operation is forbidden" : "Ĉi tiu operacio malpermesatas",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ĉi tiu dosierujo maldisponeblas, bonvolu kontroli la protokolojn aŭ kontakti la administranton",
     "Could not move \"{file}\", target exists" : "Ne eblas movi “{file}”-n, celo jam ekzistas",
@@ -50,7 +36,6 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "Ne eblas alinomigi “{fileName}”",
     "Could not create file \"{file}\"" : "Ne eblas krei dosieron “{file}”",
     "Could not create file \"{file}\" because it already exists" : "Ne eblas krei dosieron “{file}” ĉar ĝi jam ekzistas",
-    "Could not create folder \"{dir}\"" : "Ne eblas krei dosierujon “{dir}”",
     "Could not create folder \"{dir}\" because it already exists" : "Ne eblas krei dosierujon “{dir}” ĉar ĝi jam ekzistas",
     "Error deleting file \"{fileName}\"." : "Eraris forigo de dosiero “{fileName}”.",
     "Name" : "Nomo",
