@@ -69,6 +69,8 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate učitati premašuju maksimalnu veličinu za unos datoteka na ovom poslužitelju.",
     "No favorites" : "Nema favorita",
     "Files and folders you mark as favorite will show up here" : "Fajlovi i folderi koje oznacite kao favorite ce se prikazati ovdje",
-    "Text file" : "Tekstualna datoteka"
+    "Text file" : "Tekstualna datoteka",
+    "This operation is forbidden" : "Ova radnja je zabranjena",
+    "..." : "..."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
