@@ -2,42 +2,44 @@ OC.L10N.register(
     "files",
     {
     "Unknown error" : "Et ass en onbekannte Fehler opgetrueden",
-    "There is no error, the file uploaded with success" : "Keen Feeler, Datei ass komplett ropgelueden ginn",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
-    "The uploaded file was only partially uploaded" : "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
-    "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
-    "Missing a temporary folder" : "Et feelt en temporären Dossier",
-    "Failed to write to disk" : "Konnt net op den Disk schreiwen",
-    "Files" : "Dateien",
-    "Favorites" : "Favoriten",
+    "All files" : "All d'Fichieren",
+    "Saved" : "Gespäichert",
     "Home" : "Doheem",
     "Close" : "Zoumaachen",
+    "Favorites" : "Favoriten",
     "Upload cancelled." : "Upload ofgebrach.",
+    "Uploading..." : "Lueden erop...",
+    "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "File Upload am gaang. Wann's de des Säit verléiss gëtt den Upload ofgebrach.",
     "Download" : "Download",
     "Rename" : "Ëmbenennen",
     "Delete" : "Läschen",
     "Unshare" : "Net méi deelen",
+    "Files" : "Dateien",
     "Details" : "Detailer",
     "Select" : "Auswielen",
+    "This operation is forbidden" : "Dës Operatioun ass verbueden.",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Dësen Dossier ass net disponibel, w.e.g. kontrolléiert d'Logs oder kontaktéiert den Administrateur",
     "Name" : "Numm",
     "Size" : "Gréisst",
     "Modified" : "Geännert",
     "New" : "Nei",
+    "\"{name}\" is an invalid file name." : "\"{Numm}\" ass een ongültegen Numm fir e Fichier.",
+    "File name cannot be empty." : "Den Numm vum Fichier kann net eidel sinn.",
     "Folder" : "Dossier",
     "New folder" : "Neien Dossier",
     "Upload" : "Eroplueden",
+    "Upload (max. %s)" : "Eroplueden (max. %s)",
     "File handling" : "Fichier handling",
     "Maximum upload size" : "Maximum Upload Gréisst ",
     "max. possible: " : "max. méiglech:",
     "Save" : "Späicheren",
     "Settings" : "Astellungen",
-    "Cancel upload" : "Upload ofbriechen",
+    "No files in here" : "Hei sinn keng Fichieren",
     "No entries found in this folder" : "Keng Elementer an dësem Dossier fonnt",
     "Select all" : "All auswielen",
     "Upload too large" : "Upload ze grouss",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Déi Dateien déi Dir probéiert erop ze lueden sinn méi grouss wei déi Maximal Gréisst déi op dësem Server erlaabt ass.",
-    "Text file" : "Text Fichier",
-    "Upload cancelled." : "Upload ofgebrach."
+    "Text file" : "Text Fichier"
 },
 "nplurals=2; plural=(n != 1);");
