@@ -1,34 +1,17 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Glabātuve nav pieejama",
     "Storage invalid" : "Nepareiza krātuve",
     "Unknown error" : "Nezināma kļūda",
-    "Unable to set upload directory." : "Nevar uzstādīt augšupielādes mapi.",
-    "Invalid Token" : "Nepareiza pilnvara",
-    "No file was uploaded. Unknown error" : "Netika augšupielādēta neviena datne. Nezināma kļūda",
-    "There is no error, the file uploaded with success" : "Viss kārtībā, datne augšupielādēta veiksmīga",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Augšupielādētā datne pārsniedz upload_max_filesize norādījumu php.ini datnē:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
-    "The uploaded file was only partially uploaded" : "Augšupielādētā datne ir tikai daļēji augšupielādēta",
-    "No file was uploaded" : "Neviena datne netika augšupielādēta",
-    "Missing a temporary folder" : "Trūkst pagaidu mapes",
-    "Failed to write to disk" : "Neizdevās saglabāt diskā",
-    "Not enough storage available" : "Nav pietiekami daudz vietas",
-    "The target folder has been moved or deleted." : "Mērķa mape ir pārvietota vai dzēsta",
-    "Upload failed. Could not find uploaded file" : "Augšupielāde nesekmīga. Neizdevās atrast augšupielādēto failu.",
-    "Upload failed. Could not get file info." : "Augšupielāde nesekmīga. Neizdevās iegūt informāciju par failu.",
-    "Invalid directory." : "Nederīga direktorija.",
-    "Files" : "Datnes",
     "All files" : "Visas datnes",
-    "Favorites" : "Iecienītie",
+    "Saved" : "Saglabāts",
     "Home" : "Mājas",
     "Close" : "Aizvērt",
+    "Favorites" : "Iecienītie",
     "Upload cancelled." : "Augšupielāde ir atcelta.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturošs fails.",
-    "Total file size {size1} exceeds upload limit {size2}" : "Kopējais faila izmērs {size1} pārsniedz augšupielādes ierobežojumu {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
-    "Could not get result from server." : "Nevar saņemt rezultātus no servera",
+    "Uploading..." : "Augšupielādē...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Notiek augšupielāde. Pametot lapu tagad, tiks atcelta augšupielāde.",
     "Actions" : "Darbības",
     "Download" : "Lejupielādēt",
@@ -36,11 +19,13 @@ OC.L10N.register(
     "Delete" : "Dzēst",
     "Disconnect storage" : "Atvienot krātuvi",
     "Unshare" : "Pārtraukt dalīšanos",
+    "Files" : "Datnes",
     "Details" : "Detaļas",
     "Select" : "Norādīt",
     "Pending" : "Gaida savu kārtu",
     "Unable to determine date" : "Neizdevās noteikt datumu",
-    "No entries in this folder match '{filter}'" : "Šajā mapē nekas nav atrasts, meklējot pēc '{filter}'",
+    "This operation is forbidden" : "Šī darbība ir aizliegta",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
     "Name" : "Nosaukums",
     "Size" : "Izmērs",
     "Modified" : "Mainīts",
@@ -81,8 +66,6 @@ OC.L10N.register(
     "Save" : "Saglabāt",
     "Settings" : "Iestatījumi",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Izmantojot šo adresi, <a href=\"%s\" target=\"_blank\">piekļūstiet saviem failiem, izmantojot WebDAV</a>",
-    "Cancel upload" : "Atcelt augšupielādi",
     "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
     "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
     "Select all" : "Atzīmēt visu",
@@ -90,10 +73,6 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
     "No favorites" : "Nav favorītu",
     "Files and folders you mark as favorite will show up here" : "Faili un mapes, ko atzīmēsit kā favorītus, tiks rādīti šeit",
-    "Text file" : "Teksta datne",
-    "You changed %1$s" : "Tu izmainīji %1$s",
-    "You created %1$s" : "Tu izveidoji %1$s",
-    "You deleted %1$s" : "Tu izdzēsi %1$s",
-    "You restored %1$s" : "Tu atjaunoji %1$s"
+    "Text file" : "Teksta datne"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
