@@ -113,6 +113,11 @@ OC.L10N.register(
     "No favorites" : "Sem favoritos",
     "Files and folders you mark as favorite will show up here" : "Arquivos e pastas que você marcou como favoritos são mostrados aqui",
     "Text file" : "Arquivo texto",
-    "New text file.txt" : "Novo texto file.txt"
+    "New text file.txt" : "Novo texto file.txt",
+    "Upload timeout for file \"{file}\"" : "Tempo de envio do arquivo \"{file}\" expirou",
+    "Processing files..." : "Processando arquivos...",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Limite as notificações sobre a criação e as alterações nos seus <strong>arquivos favoritos</strong>",
+    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Você não tem permissões para acessar este arquivo/pasta - Entre em contato com o proprietário para compartilhá-lo com você.",
+    "Error when assembling chunks, status code {status}" : "Erro ao montar partes do todo, código de status {status}"
 },
 "nplurals=2; plural=(n > 1);");
