@@ -113,6 +113,11 @@ OC.L10N.register(
     "No favorites" : "Нет избранного",
     "Files and folders you mark as favorite will show up here" : "Здесь появятся файлы и каталоги, отмеченные как избранные",
     "Text file" : "Текстовый файл",
-    "New text file.txt" : "Новый текстовый документ.txt"
+    "New text file.txt" : "Новый текстовый документ.txt",
+    "Upload timeout for file \"{file}\"" : "Тайм-аут для загрузки файла \"{file}\"",
+    "Processing files..." : "Обработка файлов...",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Ограничить уведомления о создании и изменений только вашими <strong>избранными файлами</strong>",
+    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "У вас нет разрешения на доступ к этому файлу или папке. Пожалуйста обратитесь к владельцу, чтобы он предоставил вам доступ.",
+    "Error when assembling chunks, status code {status}" : "Ошибка при сборке блоков, код состояния {status}"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
