@@ -2,39 +2,31 @@ OC.L10N.register(
     "files",
     {
     "Unknown error" : "يوچۇن خاتالىق",
-    "Could not move %s" : "%s يۆتكىيەلمەيدۇ",
-    "No file was uploaded. Unknown error" : "ھېچقانداق ھۆججەت يۈكلەنمىدى. يوچۇن خاتالىق",
-    "No file was uploaded" : "ھېچقانداق ھۆججەت يۈكلەنمىدى",
-    "Missing a temporary folder" : "ۋاقىتلىق قىسقۇچ كەم.",
-    "Failed to write to disk" : "دىسكىغا يازالمىدى",
-    "Not enough storage available" : "يېتەرلىك ساقلاش بوشلۇقى يوق",
-    "Files" : "ھۆججەتلەر",
-    "Favorites" : "يىغقۇچ",
     "Home" : "ئۆي",
     "Close" : "ياپ",
+    "Favorites" : "يىغقۇچ",
     "Upload cancelled." : "يۈكلەشتىن ۋاز كەچتى.",
+    "Uploading..." : "يۈكلەۋاتىدۇ…",
     "File upload is in progress. Leaving the page now will cancel the upload." : "ھۆججەت يۈكلەش مەشغۇلاتى ئېلىپ بېرىلىۋاتىدۇ. Leaving the page now will cancel the upload.",
     "Actions" : "مەشغۇلاتلار",
     "Download" : "چۈشۈر",
     "Rename" : "ئات ئۆزگەرت",
     "Delete" : "ئۆچۈر",
+    "Unshare" : "ھەمبەھىرلىمە",
+    "Files" : "ھۆججەتلەر",
     "Pending" : "كۈتۈۋاتىدۇ",
-    "Error" : "خاتالىق",
-    "{new_name} already exists" : "{new_name} مەۋجۇت",
     "Name" : "ئاتى",
     "Size" : "چوڭلۇقى",
     "Modified" : "ئۆزگەرتكەن",
     "New" : "يېڭى",
     "Favorite" : "يىغقۇچ",
-    "Upload" : "يۈكلە",
-    "Text file" : "تېكىست ھۆججەت",
     "Folder" : "قىسقۇچ",
     "New folder" : "يېڭى قىسقۇچ",
+    "Upload" : "يۈكلە",
     "Save" : "ساقلا",
     "Settings" : "تەڭشەكلەر",
     "WebDAV" : "WebDAV",
-    "Cancel upload" : "يۈكلەشتىن ۋاز كەچ",
     "Upload too large" : "يۈكلەندىغىنى بەك چوڭ",
-    "Upload cancelled." : "يۈكلەشتىن ۋاز كەچتى."
+    "Text file" : "تېكىست ھۆججەت"
 },
 "nplurals=1; plural=0;");
