@@ -7,8 +7,9 @@
  * @author Robin Appelman <icewind@owncloud.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Sujith Haridasan <sharidasan@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -37,9 +38,11 @@ use OCP\Files\IMimeTypeLoader;
 use OCP\Files\StorageNotAvailableException;
 use OCP\IConfig;
 use OCP\IDBConnection;
+use OCP\IGroupManager;
 use OCP\IUserManager;
 use OCP\Lock\ILockingProvider;
 use OCP\Lock\LockedException;
+use OCP\ILogger;
 use Symfony\Component\Console\Helper\Table;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputInterface;
@@ -50,10 +53,14 @@ class Scan extends Base {
 
 	/** @var IUserManager $userManager */
 	private $userManager;
+	/** @var  IGroupManager $groupManager */
+	private $groupManager;
 	/** @var ILockingProvider */
 	private $lockingProvider;
 	/** @var IMimeTypeLoader */
 	private $mimeTypeLoader;
+	/** @var ILogger */
+	private $logger;
 	/** @var IConfig */
 	private $config;
 	/** @var float */
@@ -65,13 +72,17 @@ class Scan extends Base {
 
 	public function __construct(
 		IUserManager $userManager,
+		IGroupManager $groupManager,
 		ILockingProvider $lockingProvider,
 		IMimeTypeLoader $mimeTypeLoader,
+		ILogger $logger,
 		IConfig $config
 	) {
 		$this->userManager = $userManager;
+		$this->groupManager = $groupManager;
 		$this->lockingProvider = $lockingProvider;
 		$this->mimeTypeLoader = $mimeTypeLoader;
+		$this->logger = $logger;
 		$this->config = $config;
 		parent::__construct();
 	}
@@ -93,6 +104,12 @@ class Scan extends Base {
 				InputArgument::OPTIONAL,
 				'Limit rescan to this path, e.g., --path="/alice/files/Music", the user_id is determined by the path and the user_id parameter and --all are ignored.'
 			)
+			->addOption(
+				'groups',
+				'g',
+				InputArgument::OPTIONAL,
+				'Scan user(s) under the group(s). This option can be used as --groups=foo,bar to scan groups foo and bar'
+			)
 			->addOption(
 				'quiet',
 				'q',
@@ -125,8 +142,8 @@ class Scan extends Base {
 	}
 
 	public function checkScanWarning($fullPath, OutputInterface $output) {
-		$normalizedPath = basename(\OC\Files\Filesystem::normalizePath($fullPath));
-		$path = basename($fullPath);
+		$normalizedPath = \basename(\OC\Files\Filesystem::normalizePath($fullPath));
+		$path = \basename($fullPath);
 
 		if ($normalizedPath !== $path) {
 			$output->writeln("\t<error>Entry \"" . $fullPath . '" will not be accessible due to incompatible encoding</error>');
@@ -142,11 +159,13 @@ class Scan extends Base {
 		$connection = $this->reconnectToDatabase($output);
 		$repairStep = new RepairMismatchFileCachePath(
 			$connection,
-			$this->mimeTypeLoader
+			$this->mimeTypeLoader,
+			$this->logger,
+			$this->config
 		);
 		$repairStep->setStorageNumericId(null);
 		$repairStep->setCountOnly(false);
-		$repairStep->run(new ConsoleOutput($output));
+		$repairStep->doRepair(new ConsoleOutput($output));
 	}
 
 	protected function scanFiles($user, $path, $verbose, OutputInterface $output, $backgroundScan = false, $shouldRepair = false) {
@@ -164,7 +183,9 @@ class Scan extends Base {
 				try {
 					$repairStep = new RepairMismatchFileCachePath(
 						$connection,
-						$this->mimeTypeLoader
+						$this->mimeTypeLoader,
+						$this->logger,
+						$this->config
 					);
 					$repairStep->setStorageNumericId($storage->getCache()->getNumericStorageId());
 					$repairStep->setCountOnly(false);
@@ -210,41 +231,73 @@ class Scan extends Base {
 				}
 			});
 		}
-		$scanner->listen('\OC\Files\Utils\Scanner', 'scanFile', function($path) use ($output) {
+		$scanner->listen('\OC\Files\Utils\Scanner', 'scanFile', function ($path) use ($output) {
 			$this->checkScanWarning($path, $output);
 		});
-		$scanner->listen('\OC\Files\Utils\Scanner', 'scanFolder', function($path) use ($output) {
+		$scanner->listen('\OC\Files\Utils\Scanner', 'scanFolder', function ($path) use ($output) {
 			$this->checkScanWarning($path, $output);
 		});
 
 		try {
 			if ($backgroundScan) {
 				$scanner->backgroundScan($path);
-			}else {
+			} else {
 				$scanner->scan($path, $shouldRepair);
 			}
 		} catch (ForbiddenException $e) {
 			$output->writeln("<error>Home storage for user $user not writable</error>");
 			$output->writeln("Make sure you're running the scan command only as the user the web server runs as");
 		} catch (InterruptedException $e) {
-			# exit the function if ctrl-c has been pressed 
+			# exit the function if ctrl-c has been pressed
 			$output->writeln('Interrupted by user');
 			return;
 		} catch (\Exception $e) {
-			$output->writeln('<error>Exception during scan: ' . get_class($e) . ': ' . $e->getMessage() . "\n" . $e->getTraceAsString() . '</error>');
+			$output->writeln('<error>Exception during scan: ' . \get_class($e) . ': ' . $e->getMessage() . "\n" . $e->getTraceAsString() . '</error>');
 		}
 	}
 
+	protected function getAllUsersFromGroup($group) {
+		$count = 0;
+		$users = [];
+		foreach ($this->groupManager->findUsersInGroup($group) as $user) {
+			\array_push($users, $user->getUID());
+			$count++;
+			//Take 200 users at a time
+			if ($count > 199) {
+				yield $users;
+				$count = 1;
+				$users = [];
+			}
+		}
+		if (\count($users) > 0) {
+			yield $users;
+		}
+	}
 
 	protected function execute(InputInterface $input, OutputInterface $output) {
 		$inputPath = $input->getOption('path');
+		$groups = $input->getOption('groups') ? \explode(',', $input->getOption('groups')) : [];
 		$shouldRepairStoragesIndividually = (bool) $input->getOption('repair');
 
-		if ($inputPath) {
-			$inputPath = '/' . trim($inputPath, '/');
-			list (, $user,) = explode('/', $inputPath, 3);
+		if (\count($groups) >= 1) {
+			$users = [];
+			foreach ($groups as $group) {
+				if ($this->groupManager->groupExists($group) === false) {
+					$output->writeln("Group name $group doesn't exist");
+					return 1;
+				} else {
+					$users[$group] = [];
+					foreach ($this->getAllUsersFromGroup($group) as $users_array) {
+						$users[$group] = $users_array;
+						$this->processUserChunks($input, $output, $users, $inputPath, $shouldRepairStoragesIndividually, $group);
+					}
+				}
+			}
+		} elseif ($inputPath) {
+			$inputPath = '/' . \trim($inputPath, '/');
+			list(, $user, ) = \explode('/', $inputPath, 3);
 			$users = [$user];
-		} else if ($input->getOption('all')) {
+		} elseif ($input->getOption('all')) {
 			// we can only repair all storages in bulk (more efficient) if singleuser or maintenance mode
 			// is enabled to prevent concurrent user access
 			if ($input->getOption('repair')) {
@@ -264,6 +317,12 @@ class Scan extends Base {
 			$users = $input->getArgument('user_id');
 		}
 
+		if (\count($groups) === 0) {
+			$this->processUserChunks($input, $output, $users, $inputPath, $shouldRepairStoragesIndividually);
+		}
+	}
+
+	protected function processUserChunks($input, $output, $users, $inputPath, $shouldRepairStoragesIndividually, $group = null) {
 		# no messaging level option means: no full printout but statistics
 		# $quiet   means no print at all
 		# $verbose means full printout including statistics
@@ -282,38 +341,18 @@ class Scan extends Base {
 		}
 
 		# check quantity of users to be process and show it on the command line
-		$users_total = count($users);
+		$users_total = \count($users);
 		if ($users_total === 0) {
 			$output->writeln("<error>Please specify the user id to scan, \"--all\" to scan for all users or \"--path=...\"</error>");
 			return;
 		} else {
-			if ($users_total > 1) {
+			$this->initTools();
+			if ($group !== null) {
+				$output->writeln("Scanning group $group");
+				$this->userScan($users[$group], $inputPath, $shouldRepairStoragesIndividually, $input, $output, $verbose);
+			} elseif ($users_total >= 1) {
 				$output->writeln("\nScanning files for $users_total users");
-			}
-		}
-
-		$this->initTools();
-
-		$user_count = 0;
-		foreach ($users as $user) {
-			if (is_object($user)) {
-				$user = $user->getUID();
-			}
-			$path = $inputPath ? $inputPath : '/' . $user;
-			$user_count += 1;
-			if ($this->userManager->userExists($user)) {
-				# add an extra line when verbose is set to optical separate users
-				if ($verbose) {$output->writeln(""); }
-				$r = $shouldRepairStoragesIndividually ? ' (and repair)' : '';
-				$output->writeln("Starting scan$r for user $user_count out of $users_total ($user)");
-				# full: printout data if $verbose was set
-				$this->scanFiles($user, $path, $verbose, $output, $input->getOption('unscanned'), $shouldRepairStoragesIndividually);
-			} else {
-				$output->writeln("<error>Unknown user $user_count $user</error>");
-			}
-			# check on each user if there was a user interrupt (ctrl-c) and exit foreach
-			if ($this->hasBeenInterrupted()) {
-				break;
+				$this->userScan($users, $inputPath, $shouldRepairStoragesIndividually, $input, $output, $verbose);
 			}
 		}
 
@@ -328,9 +367,37 @@ class Scan extends Base {
 	 */
 	protected function initTools() {
 		// Start the timer
-		$this->execTime = -microtime(true);
+		$this->execTime = -\microtime(true);
 		// Convert PHP errors to exceptions
-		set_error_handler([$this, 'exceptionErrorHandler'], E_ALL);
+		\set_error_handler([$this, 'exceptionErrorHandler'], E_ALL);
+	}
+
+	protected function userScan($users, $inputPath, $shouldRepairStoragesIndividually, $input, $output, $verbose) {
+		$users_total = \count($users);
+		$user_count = 0;
+		foreach ($users as $user) {
+			if (\is_object($user)) {
+				$user = $user->getUID();
+			}
+			$path = $inputPath ? $inputPath : '/' . $user;
+			$user_count += 1;
+			if ($this->userManager->userExists($user)) {
+				# add an extra line when verbose is set to optical separate users
+				if ($verbose) {
+					$output->writeln("");
+				}
+				$r = $shouldRepairStoragesIndividually ? ' (and repair)' : '';
+				$output->writeln("Starting scan$r for user $user_count out of $users_total ($user)");
+				# full: printout data if $verbose was set
+				$this->scanFiles($user, $path, $verbose, $output, $input->getOption('unscanned'), $shouldRepairStoragesIndividually);
+			} else {
+				$output->writeln("<error>Unknown user $user_count $user</error>");
+			}
+			# check on each user if there was a user interrupt (ctrl-c) and exit foreach
+			if ($this->hasBeenInterrupted()) {
+				break;
+			}
+		}
 	}
 
 	/**
@@ -346,7 +413,7 @@ class Scan extends Base {
 	 * @throws \ErrorException
 	 */
 	public function exceptionErrorHandler($severity, $message, $file, $line) {
-		if (!(error_reporting() & $severity)) {
+		if (!(\error_reporting() & $severity)) {
 			// This error code is not included in error_reporting
 			return;
 		}
@@ -358,11 +425,11 @@ class Scan extends Base {
 	 */
 	protected function presentStats(OutputInterface $output) {
 		// Stop the timer
-		$this->execTime += microtime(true);
+		$this->execTime += \microtime(true);
 		$output->writeln("");
 
 		$headers = [
-			'Folders', 'Files', 'Elapsed time'
+			'Folders', 'Files', 'Elapsed time', 'Items per second'
 		];
 
 		$this->showSummary($headers, null, $output);
@@ -377,11 +444,13 @@ class Scan extends Base {
 	 */
 	protected function showSummary($headers, $rows, OutputInterface $output) {
 		$niceDate = $this->formatExecTime();
+		$itemsPerSecond = $this->getItemsPerSecond();
 		if (!$rows) {
 			$rows = [
 				$this->foldersCounter,
 				$this->filesCounter,
 				$niceDate,
+				$itemsPerSecond
 			];
 		}
 		$table = new Table($output);
@@ -391,6 +460,21 @@ class Scan extends Base {
 		$table->render();
 	}
 
+	/**
+	 * Get items per second processed, no fractions
+	 *
+	 * @return string
+	 */
+	protected function getItemsPerSecond() {
+		$items = $this->foldersCounter + $this->filesCounter;
+		if ($this->execTime === 0) {
+			// catch div by 0
+			$itemsPerSecond = 0;
+		} else {
+			$itemsPerSecond = $items / $this->execTime;
+		}
+		return \sprintf("%.0f", $itemsPerSecond);
+	}
 
 	/**
 	 * Formats microtime into a human readable format
@@ -398,10 +482,10 @@ class Scan extends Base {
 	 * @return string
 	 */
 	protected function formatExecTime() {
-		list($secs, $tens) = explode('.', sprintf("%.1f", ($this->execTime)));
+		list($secs, $tens) = \explode('.', \sprintf("%.1f", ($this->execTime)));
 
 		# if you want to have microseconds add this:   . '.' . $tens;
-		return date('H:i:s', $secs);
+		return \date('H:i:s', $secs);
 	}
 
 	/**
@@ -420,10 +504,9 @@ class Scan extends Base {
 				$connection->connect();
 			} catch (\Exception $ex) {
 				$output->writeln("<info>Error while re-connecting to database: {$ex->getMessage()}</info>");
-				sleep(60);
+				\sleep(60);
 			}
 		}
 		return $connection;
 	}
-
 }
