@@ -5,7 +5,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@ namespace OCA\Files\Command;
 use OC\Encryption\Manager;
 use OC\Files\Filesystem;
 use OC\Files\View;
+use OC\Share20\ProviderFactory;
 use OCP\Files\FileInfo;
 use OCP\Files\Mount\IMountManager;
 use OCP\ILogger;
@@ -55,10 +56,16 @@ class TransferOwnership extends Command {
 	private $encryptionManager;
 
 	/** @var ILogger  */
-	private  $logger;
+	private $logger;
 
-	/** @var FileInfo[] */
-	private $allFiles = [];
+	/** @var ProviderFactory  */
+	private $shareProviderFactory;
+
+	/** @var bool */
+	private $filesExist = false;
+
+	/** @var bool */
+	private $foldersExist = false;
 
 	/** @var FileInfo[] */
 	private $encryptedFiles = [];
@@ -78,12 +85,13 @@ class TransferOwnership extends Command {
 	/** @var string */
 	private $finalTarget;
 
-	public function __construct(IUserManager $userManager, IManager $shareManager, IMountManager $mountManager, Manager $encryptionManager, ILogger $logger) {
+	public function __construct(IUserManager $userManager, IManager $shareManager, IMountManager $mountManager, Manager $encryptionManager, ILogger $logger, ProviderFactory $shareProviderFactory) {
 		$this->userManager = $userManager;
 		$this->shareManager = $shareManager;
 		$this->mountManager = $mountManager;
 		$this->encryptionManager = $encryptionManager;
 		$this->logger = $logger;
+		$this->shareProviderFactory = $shareProviderFactory;
 		parent::__construct();
 	}
 
@@ -112,11 +120,11 @@ class TransferOwnership extends Command {
 	protected function execute(InputInterface $input, OutputInterface $output) {
 		$sourceUserObject = $this->userManager->get($input->getArgument('source-user'));
 		$destinationUserObject = $this->userManager->get($input->getArgument('destination-user'));
-		if (is_null($sourceUserObject)) {
+		if ($sourceUserObject === null) {
 			$output->writeln("<error>Unknown source user $this->sourceUser</error>");
 			return 1;
 		}
-		if (is_null($destinationUserObject)) {
+		if ($destinationUserObject === null) {
 			$output->writeln("<error>Unknown destination user $this->destinationUser</error>");
 			return 1;
 		}
@@ -124,7 +132,7 @@ class TransferOwnership extends Command {
 		$this->sourceUser = $sourceUserObject->getUID();
 		$this->destinationUser = $destinationUserObject->getUID();
 		$this->inputPath = $input->getOption('path');
-		$this->inputPath = ltrim($this->inputPath, '/');
+		$this->inputPath = \ltrim($this->inputPath, '/');
 
 		// target user has to be ready
 		if (!\OC::$server->getEncryptionManager()->isReadyForUser($this->destinationUser)) {
@@ -133,14 +141,14 @@ class TransferOwnership extends Command {
 		}
 
 		// use a date format compatible across client OS
-		$date = date('Ymd_his');
+		$date = \date('Ymd_his');
 		$this->finalTarget = "$this->destinationUser/files/transferred from $this->sourceUser on $date";
 
 		// setup filesystem
 		Filesystem::initMountPoints($this->sourceUser);
 		Filesystem::initMountPoints($this->destinationUser);
 
-		if (strlen($this->inputPath) >= 1) {
+		if (\strlen($this->inputPath) >= 1) {
 			$view = new View();
 			$unknownDir = $this->inputPath;
 			$this->inputPath = $this->sourceUser . "/files/" . $this->inputPath;
@@ -153,6 +161,11 @@ class TransferOwnership extends Command {
 		// analyse source folder
 		$this->analyse($output);
 
+		if (!$this->filesExist and !$this->foldersExist) {
+			$output->writeln("<comment>No files/folders to transfer</comment>");
+			return 1;
+		}
+
 		// collect all the shares
 		$this->collectUsersShares($output);
 
@@ -160,7 +173,7 @@ class TransferOwnership extends Command {
 		$this->transfer($output);
 
 		// restore the shares
-		$this->restoreShares($output);
+		return $this->restoreShares($output);
 	}
 
 	private function walkFiles(View $view, $path, \Closure $callBack) {
@@ -185,9 +198,10 @@ class TransferOwnership extends Command {
 		$progress->start();
 		$self = $this;
 		$walkPath = "$this->sourceUser/files";
-		if ( strlen($this->inputPath) > 0) {
+		if (\strlen($this->inputPath) > 0) {
 			if ($this->inputPath !== "$this->sourceUser/files") {
 				$walkPath = $this->inputPath;
+				$this->foldersExist = true;
 			}
 		}
 
@@ -199,10 +213,12 @@ class TransferOwnership extends Command {
 						if ($fileInfo->getInternalPath() === '' && $fileInfo->getPath() !== '') {
 							return false;
 						}
+
+						$this->foldersExist = true;
 						return true;
 					}
 					$progress->advance();
-					$this->allFiles[] = $fileInfo;
+					$this->filesExist = true;
 					if ($fileInfo->isEncrypted()) {
 						if (\OC::$server->getAppConfig()->getValue('encryption', 'useMasterKey', 0) !== 0) {
 							/**
@@ -222,13 +238,12 @@ class TransferOwnership extends Command {
 		// no file is allowed to be encrypted
 		if (!empty($this->encryptedFiles)) {
 			$output->writeln("<error>Some files are encrypted - please decrypt them first</error>");
-			foreach($this->encryptedFiles as $encryptedFile) {
+			foreach ($this->encryptedFiles as $encryptedFile) {
 				/** @var FileInfo $encryptedFile */
 				$output->writeln("  " . $encryptedFile->getPath());
 			}
 			throw new \Exception('Execution terminated.');
 		}
-
 	}
 
 	/**
@@ -237,16 +252,17 @@ class TransferOwnership extends Command {
 	private function collectUsersShares(OutputInterface $output) {
 		$output->writeln("Collecting all share information for files and folder of $this->sourceUser ...");
 
-		$progress = new ProgressBar($output, count($this->shares));
-		foreach([\OCP\Share::SHARE_TYPE_GROUP, \OCP\Share::SHARE_TYPE_USER, \OCP\Share::SHARE_TYPE_LINK, \OCP\Share::SHARE_TYPE_REMOTE] as $shareType) {
-		$offset = 0;
+		$progress = new ProgressBar($output, \count($this->shares));
+		foreach ([\OCP\Share::SHARE_TYPE_GROUP, \OCP\Share::SHARE_TYPE_USER, \OCP\Share::SHARE_TYPE_LINK, \OCP\Share::SHARE_TYPE_REMOTE] as $shareType) {
+			$offset = 0;
 			while (true) {
 				$sharePage = $this->shareManager->getSharesBy($this->sourceUser, $shareType, null, true, 50, $offset);
-				$progress->advance(count($sharePage));
+				$progress->advance(\count($sharePage));
 				if (empty($sharePage)) {
 					break;
 				}
-				$this->shares = array_merge($this->shares, $sharePage);
+
+				$this->shares = \array_merge($this->shares, $sharePage);
 				$offset += 50;
 			}
 		}
@@ -261,19 +277,19 @@ class TransferOwnership extends Command {
 	protected function transfer(OutputInterface $output) {
 		$view = new View();
 		$output->writeln("Transferring files to $this->finalTarget ...");
-		$sourcePath = (strlen($this->inputPath) > 0) ? $this->inputPath : "$this->sourceUser/files";
+		$sourcePath = (\strlen($this->inputPath) > 0) ? $this->inputPath : "$this->sourceUser/files";
 		// This change will help user to transfer the folder specified using --path option.
 		// Else only the content inside folder is transferred which is not correct.
-		if (strlen($this->inputPath) > 0) {
-			if($this->inputPath !== ltrim("$this->sourceUser/files", '/')) {
+		if (\strlen($this->inputPath) > 0) {
+			if ($this->inputPath !== \ltrim("$this->sourceUser/files", '/')) {
 				$view->mkdir($this->finalTarget);
-				$this->finalTarget = $this->finalTarget . '/' . basename($sourcePath);
+				$this->finalTarget = $this->finalTarget . '/' . \basename($sourcePath);
 			}
 		}
 
 		$view->rename($sourcePath, $this->finalTarget);
 
-		if (!is_dir("$this->sourceUser/files")) {
+		if (!\is_dir("$this->sourceUser/files")) {
 			// because the files folder is moved away we need to recreate it
 			$view->mkdir("$this->sourceUser/files");
 		}
@@ -284,35 +300,48 @@ class TransferOwnership extends Command {
 	 */
 	private function restoreShares(OutputInterface $output) {
 		$output->writeln("Restoring shares ...");
-		$progress = new ProgressBar($output, count($this->shares));
+		$progress = new ProgressBar($output, \count($this->shares));
+		$status = 0;
 
-		foreach($this->shares as $share) {
+		$childShares = [];
+		foreach ($this->shares as $share) {
 			try {
+				/**
+				 * Do not process children which are already processed.
+				 * This piece of code populates the childShare array
+				 * with the child shares which will be processed. And
+				 * hence will avoid further processing of same share
+				 * again.
+				 */
 				if ($share->getSharedWith() === $this->destinationUser) {
-					// Unmount the shares before deleting, so we don't try to get the storage later on.
-					$shareMountPoint = $this->mountManager->find('/' . $this->destinationUser . '/files' . $share->getTarget());
-					if ($shareMountPoint) {
-						$this->mountManager->removeMount($shareMountPoint->getMountPoint());
+					$provider = $this->shareProviderFactory->getProviderForType($share->getShareType());
+					foreach ($provider->getChildren($share) as $child) {
+						$childShares[] = $child->getId();
 					}
-					$this->shareManager->deleteShare($share);
 				} else {
-					if ($share->getShareOwner() === $this->sourceUser) {
-						$share->setShareOwner($this->destinationUser);
+					/**
+					 * Before doing handover to transferShare, check if the share
+					 * id is present in the childShares. If so then just ignore
+					 * this share and continue. If not ignored, the child shares
+					 * would be processed again, if their parent share was shared
+					 * with destination user. And hence we can safely avoid the
+					 * duplicate processing of shares here.
+					 */
+					if (\in_array($share->getId(), $childShares, true)) {
+						continue;
 					}
-					if ($share->getSharedBy() === $this->sourceUser) {
-						$share->setSharedBy($this->destinationUser);
-					}
-
-					$this->shareManager->updateShare($share);
 				}
+				$this->shareManager->transferShare($share, $this->sourceUser, $this->destinationUser, $this->finalTarget);
 			} catch (\OCP\Files\NotFoundException $e) {
 				$output->writeln('<error>Share with id ' . $share->getId() . ' points at deleted file, skipping</error>');
 			} catch (\Exception $e) {
 				$output->writeln('<error>Could not restore share with id ' . $share->getId() . ':' . $e->getTraceAsString() . '</error>');
+				$status = 1;
 			}
 			$progress->advance();
 		}
 		$progress->finish();
 		$output->writeln('');
+		return $status;
 	}
 }
