@@ -1,13 +1,15 @@
 <div id="app-navigation">
 	<ul class="with-icon">
-		<?php foreach ($_['navigationItems'] as $item) { ?>
+		<?php foreach ($_['navigationItems'] as $item) {
+	?>
 		<li data-id="<?php p($item['id']) ?>" class="nav-<?php p($item['id']) ?>">
 			<a href="<?php p(isset($item['href']) ? $item['href'] : '#') ?>"
 				class="nav-icon-<?php p($item['icon'] !== '' ? $item['icon'] : $item['id']) ?> svg">
-				<?php p($item['name']);?>
+				<?php p($item['name']); ?>
 			</a>
 		</li>
-		<?php } ?>
+		<?php
+} ?>
 	</ul>
 	<div id="app-settings">
 		<div id="app-settings-header">
