@@ -7,17 +7,16 @@ OC.L10N.register(
     "Personal" : "Osobno",
     "System" : "Sustav",
     "Grant access" : "Dodijeli pristup",
-    "Access granted" : "Pristup odobren",
     "All users. Type to select user or group." : "Svi korisnici. Započnite unos za izbor korisnika ili grupe.",
     "(group)" : "(grupa)",
     "Saved" : "Spremljeno",
-    "None" : "Ništa",
+    "Username" : "Korisničko ime",
+    "Password" : "Lozinka",
+    "Save" : "Spremi",
     "App key" : "Ključ za aplikacije",
     "App secret" : "Tajna aplikacije",
     "Client ID" : "ID klijenta",
     "Client secret" : "Klijentski tajni ključ",
-    "Username" : "Korisničko ime",
-    "Password" : "Lozinka",
     "Amazon S3" : "Amazon S3",
     "Bucket" : "Kantica",
     "Hostname" : "Naziv poslužitelja",
@@ -29,11 +28,10 @@ OC.L10N.register(
     "URL" : "URL",
     "Remote subfolder" : "Udaljena podmapa",
     "Secure https://" : "Siguran https://",
-    "Host" : "Glavno računalo",
-    "Secure ftps://" : "Sigurni ftps://",
     "Local" : "Lokalno",
     "Location" : "Lokacija",
     "ownCloud" : "OwnCloud",
+    "Host" : "Glavno računalo",
     "Root" : "Korijen",
     "Share" : "Dijeljenje zhajedničkih resursa",
     "SMB / CIFS using OC login" : "SMB / CIFS uz prijavu putem programa OC",
@@ -41,7 +39,6 @@ OC.L10N.register(
     "OpenStack Object Storage" : "Prostor za pohranu.....",
     "<b>Note:</b> " : "<b>Bilješka:</b>",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> Podrška cURL u PHP nije omogućena ili nije instalirana. Postavljanje%s nije moguće. Molimo zamolite svog administratora sustava da je instalira.",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> Podrška FTP u PHP nije omogućena ili nije instalirana. Postavljanje%s nije moguće. Molimo zamolite svotg administratora sustava da je instalira.",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> \"%s\" nije instaliran. Postavljanje %s nije moguće. Molimo zamolitesvog administratora sustava da ga instalira.",
     "Name" : "Naziv",
     "Storage type" : "Vrsta spremišta",
@@ -50,9 +47,8 @@ OC.L10N.register(
     "Folder name" : "Naziv mape",
     "Configuration" : "Konfiguracija",
     "Available for" : "Dostupno za",
-    "Delete" : "Izbrišite",
     "Add storage" : "Dodajte spremište",
-    "Enable User External Storage" : "Omogućite korisničko vanjsko spremište",
+    "Delete" : "Izbrišite",
     "Allow users to mount the following external storage" : "Dopustite korisnicima postavljanje sljedećeg vanjskog spremišta"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
