@@ -118,6 +118,10 @@ OC.L10N.register(
     "Advanced settings" : "Impostazioni avanzate",
     "Delete" : "Elimina",
     "Allow users to mount external storage" : "Consenti agli utenti di montare archiviazioni esterne",
-    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente archiviazione esterna"
+    "Allow users to mount the following external storage" : "Consenti agli utenti di montare la seguente archiviazione esterna",
+    "No URL provided by backend " : "Non fornito URL per la gestione",
+    "Error getting OAuth2 URL for " : "Errore recuperando OAuth2 Url per",
+    "Please make sure that the app that provides this backend is installed and enabled" : "Assicurarsi che l'app che fornisce questa gestione sia installata ed abilitata",
+    "Allow sharing on user-mounted external storages" : "Permetti la condivisione di volumi esterni montati dall'utente"
 },
 "nplurals=2; plural=(n != 1);");
