@@ -4,19 +4,17 @@ OC.L10N.register(
     "External storage" : "ექსტერნალ საცავი",
     "Personal" : "პირადი",
     "Grant access" : "დაშვების მინიჭება",
-    "Access granted" : "დაშვება მინიჭებულია",
     "Username" : "მომხმარებლის სახელი",
     "Password" : "პაროლი",
     "Save" : "შენახვა",
-    "None" : "არა",
     "API key" : "API გასაღები",
     "Port" : "პორტი",
     "Region" : "რეგიონი",
     "WebDAV" : "WebDAV",
     "URL" : "URL",
-    "Host" : "ჰოსტი",
     "Location" : "ადგილმდებარეობა",
     "ownCloud" : "ownCloud–ი",
+    "Host" : "ჰოსტი",
     "Share" : "გაზიარება",
     "Name" : "სახელი",
     "External Storage" : "ექსტერნალ საცავი",
