@@ -1,15 +1,17 @@
 OC.L10N.register(
     "files_external",
     {
-    "Local" : "ಸ್ಥಳೀಯ",
-    "Port" : "﻿ರೇವು",
-    "Host" : "ಅತಿಥೆಯ-ಗಣಕ",
-    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
-    "Password" : "ಗುಪ್ತ ಪದ",
-    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
-    "URL" : "ಜಾಲದ ಕೊಂಡಿ",
     "Personal" : "﻿ವೈಯಕ್ತಿಕ",
     "Saved" : "﻿ಉಳಿಸಿದ",
+    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
+    "Password" : "ಗುಪ್ತ ಪದ",
+    "Save" : "﻿ಉಳಿಸಿ",
+    "Port" : "﻿ರೇವು",
+    "WebDAV" : "﻿WebDAV",
+    "URL" : "ಜಾಲದ ಕೊಂಡಿ",
+    "Local" : "ಸ್ಥಳೀಯ",
+    "Host" : "ಅತಿಥೆಯ-ಗಣಕ",
+    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
     "Name" : "﻿ಹೆಸರು",
     "Delete" : "﻿ಅಳಿಸಿ"
 },
