@@ -7,26 +7,45 @@ OC.L10N.register(
     "External storage" : "Išorinė saugykla",
     "Personal" : "Asmeniniai",
     "Grant access" : "Suteikti priėjimą",
-    "Access granted" : "Priėjimas suteiktas",
+    "(group)" : "(grupė)",
     "Saved" : "Išsaugoti",
     "Username" : "Prisijungimo vardas",
     "Password" : "Slaptažodis",
     "Save" : "Išsaugoti",
-    "None" : "Nieko",
+    "Storage with id \"%i\" not found" : "Saugykla, kurios id \"%i\" nerasta",
+    "%s" : "%s",
+    "OpenStack" : "OpenStack",
     "API key" : "API raktas",
+    "Public key" : "Viešasis raktas",
+    "Amazon S3" : "Amazon S3",
+    "Hostname" : "Hostname",
     "Port" : "Prievadas",
     "Region" : "Regionas",
+    "Enable SSL" : "Įjungti SSL",
     "WebDAV" : "WebDAV",
     "URL" : "URL",
-    "Host" : "Mazgas",
+    "Remote subfolder" : "Ištrinti katalogą",
+    "Secure https://" : "Saugus https://",
+    "Dropbox" : "Dropbox",
+    "Google Drive" : "Google Drive",
     "Location" : "Vieta",
     "ownCloud" : "ownCloud",
+    "SFTP" : "SFTP",
+    "Host" : "Mazgas",
+    "Root" : "Root",
+    "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Dalintis",
+    "Domain" : "Domenas",
+    "<b>Note:</b> " : "<b>Užrašai:</b> ",
     "Name" : "Pavadinimas",
+    "Storage type" : "Saugyklos tipas",
+    "Enable encryption" : "Įjungti šifravimą",
+    "Never" : "Niekada",
     "External Storage" : "Išorinės saugyklos",
     "Folder name" : "Katalogo pavadinimas",
     "Configuration" : "Konfigūracija",
     "Add storage" : "Pridėti saugyklą",
-    "Delete" : "Ištrinti"
+    "Delete" : "Ištrinti",
+    "Allow users to mount external storage" : "Leisti naudotojams prijungti išorines saugyklas"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
