@@ -3,17 +3,15 @@ OC.L10N.register(
     {
     "Personal" : "පෞද්ගලික",
     "Grant access" : "පිවිසුම ලබාදෙන්න",
-    "Access granted" : "පිවිසීමට හැක",
     "Username" : "පරිශීලක නම",
     "Password" : "මුර පදය",
     "Save" : "සුරකින්න",
-    "None" : "කිසිවක් නැත",
     "Port" : "තොට",
     "Region" : "කළාපය",
     "URL" : "URL",
-    "Host" : "සත්කාරකය",
     "Location" : "ස්ථානය",
     "ownCloud" : "ownCloud",
+    "Host" : "සත්කාරකය",
     "Share" : "බෙදා හදා ගන්න",
     "Name" : "නම",
     "External Storage" : "භාහිර ගබඩාව",
