@@ -3,22 +3,20 @@ OC.L10N.register(
     {
     "Personal" : "தனிப்பட்ட",
     "Grant access" : "அனுமதியை வழங்கல்",
-    "Access granted" : "அனுமதி வழங்கப்பட்டது",
-    "None" : "ஒன்றுமில்லை",
     "Username" : "பயனாளர் பெயர்",
     "Password" : "கடவுச்சொல்",
+    "Save" : "சேமிக்க ",
     "Port" : "துறை ",
     "Region" : "பிரதேசம்",
     "URL" : "URL",
-    "Host" : "ஓம்புனர்",
     "Location" : "இடம்",
     "ownCloud" : "OwnCloud",
+    "Host" : "ஓம்புனர்",
     "Share" : "பகிர்வு",
     "Name" : "பெயர்",
     "External Storage" : "வெளி சேமிப்பு",
     "Folder name" : "கோப்புறை பெயர்",
     "Configuration" : "தகவமைப்பு",
-    "Delete" : "நீக்குக",
-    "Enable User External Storage" : "பயனாளர் வெளி சேமிப்பை இயலுமைப்படுத்துக"
+    "Delete" : "நீக்குக"
 },
 "nplurals=2; plural=(n != 1);");
