@@ -75,6 +75,10 @@ OC.L10N.register(
     "Advanced settings" : "高级选项",
     "Delete" : "删除",
     "Allow users to mount external storage" : "允许用户挂载外部存储",
-    "Allow users to mount the following external storage" : "允许用户挂载以下外部存储"
+    "Allow users to mount the following external storage" : "允许用户挂载以下外部存储",
+    "Disable external storage" : "停用外部存储",
+    "Enable external storage" : "启用外部存储",
+    "OAuth2" : "OAuth2",
+    "Credentials required" : "需要凭据"
 },
 "nplurals=1; plural=0;");
