@@ -3,7 +3,7 @@
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -34,7 +34,6 @@ use phpseclib\Crypt\RSA as RSACrypt;
  * RSA public key authentication
  */
 class RSA extends AuthMechanism {
-
 	const CREATE_KEY_BITS = 1024;
 
 	/** @var IConfig */
@@ -64,7 +63,7 @@ class RSA extends AuthMechanism {
 		if (!$auth->loadKey($privateKey)) {
 			throw new \RuntimeException('unable to load private key');
 		}
-		$storage->setBackendOption('private_key', base64_encode($privateKey));
+		$storage->setBackendOption('private_key', \base64_encode($privateKey));
 		$storage->setBackendOption('public_key_auth', $auth);
 	}
 
@@ -80,5 +79,4 @@ class RSA extends AuthMechanism {
 
 		return $rsa->createKey(self::CREATE_KEY_BITS);
 	}
-
 }
