@@ -3,7 +3,7 @@
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,14 +24,13 @@ namespace OCA\Files_External\Lib\Backend;
 
 use OCA\Files_External\Lib\LegacyDependencyCheckPolyfill;
 use OCP\Files\External\Auth\AuthMechanism;
-use OCP\Files\External\Backend\Backend;
+use OCP\Files\External\Backend\Backend as ExternalBackend;
 use OCP\Files\External\DefinitionParameter;
 use OCP\Files\External\IStorageConfig;
 use OCP\IL10N;
 use OCP\IUser;
 
-class SMB extends Backend {
-
+class SMB extends ExternalBackend {
 	use LegacyDependencyCheckPolyfill;
 
 	public function __construct(IL10N $l) {
@@ -62,5 +61,4 @@ class SMB extends Backend {
 			$storage->setBackendOption('user', $domain.'\\'.$user);
 		}
 	}
-
 }
