@@ -4,7 +4,7 @@
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -31,7 +31,7 @@ use Sabre\DAV\Client;
  * http://%host/%context/remote.php/webdav/%root
  *
  */
-class OwnCloud extends \OC\Files\Storage\DAV{
+class OwnCloud extends \OC\Files\Storage\DAV {
 	const OC_URL_SUFFIX = 'remote.php/webdav';
 
 	public function __construct($params) {
@@ -39,31 +39,30 @@ class OwnCloud extends \OC\Files\Storage\DAV{
 		// (owncloud install path on host)
 		$host = $params['host'];
 		// strip protocol
-		if (substr($host, 0, 8) == "https://") {
-			$host = substr($host, 8);
+		if (\substr($host, 0, 8) == "https://") {
+			$host = \substr($host, 8);
 			$params['secure'] = true;
-		} else if (substr($host, 0, 7) == "http://") {
-			$host = substr($host, 7);
+		} elseif (\substr($host, 0, 7) == "http://") {
+			$host = \substr($host, 7);
 			$params['secure'] = false;
 		}
 		$contextPath = '';
-		$hostSlashPos = strpos($host, '/');
-		if ($hostSlashPos !== false){
-			$contextPath = substr($host, $hostSlashPos);
-			$host = substr($host, 0, $hostSlashPos);
+		$hostSlashPos = \strpos($host, '/');
+		if ($hostSlashPos !== false) {
+			$contextPath = \substr($host, $hostSlashPos);
+			$host = \substr($host, 0, $hostSlashPos);
 		}
 
-		if (substr($contextPath, -1) !== '/'){
+		if (\substr($contextPath, -1) !== '/') {
 			$contextPath .= '/';
 		}
 
-		if (isset($params['root'])){
+		if (isset($params['root'])) {
 			$root = $params['root'];
-			if (substr($root, 0, 1) !== '/'){
+			if (\substr($root, 0, 1) !== '/') {
 				$root = '/' . $root;
 			}
-		}
-		else{
+		} else {
 			$root = '/';
 		}
 
