@@ -10,7 +10,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -34,11 +34,14 @@
 
 $application = new \OCA\Files_Sharing\AppInfo\Application();
 $application->registerMountProviders();
+$application->registerNotifier();
+$application->registerEvents();
 
+// TODO: move to "Hooks" class
 $eventDispatcher = \OC::$server->getEventDispatcher();
 $eventDispatcher->addListener(
 	'OCA\Files::loadAdditionalScripts',
-	function() {
+	function () {
 		\OCP\Util::addScript('files_sharing', 'share');
 		\OCP\Util::addScript('files_sharing', 'sharetabview');
 		if (\OC::$server->getConfig()->getAppValue('files_sharing', 'incoming_server2server_share_enabled', 'yes') === 'yes') {
@@ -50,8 +53,8 @@ $eventDispatcher->addListener(
 
 // \OCP\Util::addStyle('files_sharing', 'sharetabview');
 
-\OC::$server->getActivityManager()->registerExtension(function() {
-		return new \OCA\Files_Sharing\Activity(
+\OC::$server->getActivityManager()->registerExtension(function () {
+	return new \OCA\Files_Sharing\Activity(
 			\OC::$server->query('L10NFactory'),
 			\OC::$server->getURLGenerator(),
 			\OC::$server->getActivityManager()
@@ -59,8 +62,7 @@ $eventDispatcher->addListener(
 });
 
 $config = \OC::$server->getConfig();
-if (class_exists('OCA\Files\App') && $config->getAppValue('core', 'shareapi_enabled', 'yes') === 'yes') {
-
+if (\class_exists('OCA\Files\App') && $config->getAppValue('core', 'shareapi_enabled', 'yes') === 'yes') {
 	\OCA\Files\App::getNavigationManager()->add(function () {
 		$l = \OC::$server->getL10N('files_sharing');
 		return [
@@ -73,7 +75,6 @@ if (class_exists('OCA\Files\App') && $config->getAppValue('core', 'shareapi_enab
 	});
 
 	if (\OCP\Util::isSharingDisabledForUser() === false) {
-
 		\OCA\Files\App::getNavigationManager()->add(function () {
 			$l = \OC::$server->getL10N('files_sharing');
 			return [
