@@ -26,6 +26,9 @@ OC.L10N.register(
     "For more info, please ask the person who sent this link." : "لمزيد من المعلومات، يرجى سؤال الشخص الذي أرسل هذا الرابط",
     "Download" : "تحميل",
     "Download %s" : "تحميل %s",
-    "Direct link" : "رابط مباشر"
+    "Direct link" : "رابط مباشر",
+    "Pending" : "قيد الانتظار",
+    "Accept" : "قبول",
+    "Declined" : "رفض"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
