@@ -8,6 +8,7 @@ OC.L10N.register(
     "Password" : "Lozinka",
     "Name" : "Ime",
     "Expiration date" : "Datum isteka",
-    "Download" : "Preuzmite"
+    "Download" : "Preuzmite",
+    "Pending" : "Na čekanju"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
