@@ -45,6 +45,10 @@ OC.L10N.register(
     "Add to your ownCloud" : "Afegiu a ownCloud",
     "Download" : "Baixa",
     "Download %s" : "Baixa %s",
-    "Direct link" : "Enllaç directe"
+    "Direct link" : "Enllaç directe",
+    "Pending" : "Pendent",
+    "Accept" : "Acceptar",
+    "Decline" : "Denegar",
+    "Declined" : "Denegat"
 },
 "nplurals=2; plural=(n != 1);");
