@@ -8,6 +8,7 @@ OC.L10N.register(
     "Password" : "Cyfrinair",
     "Name" : "Enw",
     "Expiration date" : "Dyddiad dod i ben",
-    "Download" : "Llwytho i lawr"
+    "Download" : "Llwytho i lawr",
+    "Pending" : "I ddod"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
