@@ -113,6 +113,21 @@ OC.L10N.register(
     "Add to your ownCloud" : "Agregue a su ownCloud",
     "Download" : "Descargar",
     "Download %s" : "Descargar %s",
-    "Direct link" : "Enlace directo"
+    "Direct link" : "Enlace directo",
+    "No permission to create share" : "Permisos insuficientes para crear un compartido",
+    "Pending" : "Pendiente",
+    "Accept" : "Aceptar",
+    "Decline" : "Denegar",
+    "Declined" : "Denegado",
+    "An error occurred while updating share state: {message}" : "Un error ha ocurrido mientras se trataba de actualizar el estado: {message}",
+    "Accept Share" : "Aceptar compartido",
+    "Decline Share" : "No aceptar compartido",
+    "Only recipient can change accepted state" : "Solo el receptor puede cambiar el cambio de estado.",
+    "File sharing" : "Compartir Archivos",
+    "State" : "Estado",
+    "The group is blacklisted for sharing" : "El grupo está en la lista negra de compartir",
+    "Files Sharing" : "Compartir archivos",
+    "Exclude groups from receiving shares." : "Excluir grupos de recibir compartidos",
+    "These groups will not receive shares. Members of the group can still send and receive shares outside of the group." : "Estos grupos no pueden recibir compartidos. Los miembros del grupo todavía pueden enviar y recibir compartidos fuera del grupo."
 },
 "nplurals=2; plural=(n != 1);");
