@@ -113,6 +113,17 @@ OC.L10N.register(
     "Add to your ownCloud" : "Bæta í þitt eigið ownCloud",
     "Download" : "Niðurhal",
     "Download %s" : "Sækja %s",
-    "Direct link" : "Beinn tengill"
+    "Direct link" : "Beinn tengill",
+    "No permission to create share" : "Þú hefur ekki heimild til að búa til sameign",
+    "Pending" : "Í bið",
+    "Accept" : "Samþykkja",
+    "Decline" : "Hafna",
+    "Declined" : "Hafnað",
+    "Accept Share" : "Samþykkja sameign",
+    "Decline Share" : "Hafna sameign",
+    "File sharing" : "Skráadeiling",
+    "State" : "Staða",
+    "Files Sharing" : "Deiling skráa",
+    "Exclude groups from receiving shares." : "Undanskilja hópa frá því að taka á móti sameignum."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
