@@ -25,6 +25,7 @@ OC.L10N.register(
     "For more info, please ask the person who sent this link." : "សម្រាប់​ព័ត៌មាន​បន្ថែម សូម​សួរ​អ្នក​ដែល​ផ្ញើ​តំណ​នេះ។",
     "Download" : "ទាញយក",
     "Download %s" : "ទាញយក %s",
-    "Direct link" : "តំណ​ផ្ទាល់"
+    "Direct link" : "តំណ​ផ្ទាល់",
+    "Pending" : "កំពុង​រង់ចាំ"
 },
 "nplurals=1; plural=0;");
