@@ -9,6 +9,7 @@ OC.L10N.register(
     "Shared with you" : "Споделено со тебе",
     "Shared with others" : "Сподели со останатите",
     "Shared by link" : "Споделено со врска",
+    "Uploading..." : "Подигнувам...",
     "Nothing shared with you yet" : "Сеуште ништо не е споделено со вас",
     "Nothing shared yet" : "Уште ништо не е споделено",
     "No shared links" : "Нема споделени врски/линкови",
@@ -18,6 +19,7 @@ OC.L10N.register(
     "Add remote share" : "Додади оддалечно споделување",
     "You can upload into this folder" : "Можете да прикачите во оваа папка",
     "Invalid ownCloud url" : "Неисправен ownCloud url",
+    "Share" : "Сподели",
     "Shared by" : "Споделено од",
     "Sharing" : "Споделување",
     "A file or folder has been <strong>shared</strong>" : "Датотека или фолдер беше <strong>споделен</strong>",
@@ -33,14 +35,13 @@ OC.L10N.register(
     "Shared via public link" : "Споделено со јавна врска/линк",
     "Shared by %2$s" : "Споделено од %2$s",
     "Shares" : "Споделувања",
-    "Accept" : "Прифати",
-    "Decline" : "Одбиј",
     "This share is password-protected" : "Ова споделување е заштитено со лозинка",
     "The password is wrong. Try again." : "Лозинката е грешна. Обиди се повторно.",
     "Password" : "Лозинка",
     "No entries found in this folder" : "Нема ништо во оваа папка",
     "Name" : "Име",
     "Share time" : "Сподели време",
+    "Expiration date" : "Рок на траење",
     "Sorry, this link doesn’t seem to work anymore." : "Извенете, но овој линк изгледа дека повеќе не функционира.",
     "Reasons might be:" : "Причината може да биде:",
     "the item was removed" : "предметот беше одстранет",
@@ -51,16 +52,36 @@ OC.L10N.register(
     "Download" : "Преземи",
     "Download %s" : "Преземи %s",
     "Direct link" : "Директна врска",
-    "Federated Cloud Sharing" : "Федерирано клауд споделување",
-    "Open documentation" : "Отвори ја документацијата",
-    "Federated Cloud" : "Федериран клауд",
-    "Your Federated Cloud ID:" : "Вашиот федериран Cloud ID:",
-    "Share it:" : "Сподели го:",
-    "Add to your website" : "Додади на твојот веб сајт",
-    "Share with me via ownCloud" : "Сподели со мене преку ownCloud",
-    "HTML Code:" : "HTML код:",
-    "Shared by %2$s" : "Споделено од %2$s",
-    "Shared via link by %2$s" : "Споделено со врска/линк од %2$s",
-    "Shared with group %3$s by %2$s" : "Споделено со група %3$s од %2$s"
+    "Group sharing is disabled by the administrator" : "Споделување со групи е оневозможено од администраторот",
+    "Anonymous upload" : "Анонимно прикачување",
+    "Uploaded files" : "Подигнати датотеки",
+    "Click to select files or use drag & drop to upload" : "Кликнете за да изберете датотеки или користете drag & drop за да испратите",
+    "Cannot remove all permissions" : "Не може да се отстранат сите дозволи",
+    "No permission to create share" : "Нема дозвола да се создаде споделување",
+    "Not allowed to create a federated share with the same user server" : "Не е дозволено да креирате федерален удел со истиот кориснички сервер",
+    "Files and folders others share with you will show up here" : "Датотеките и папките што другите ќе ги споделат со вас ќе се појават тука",
+    "Files and folders you share will show up here" : "Датотеките и папките што ги споделувате ќе се појават тука",
+    "Files and folders you share by link will show up here" : "Датотеките и папките што ги споделувате со линк ќе се појават тука",
+    "No expiration date set" : "Не е утврден датумот на истекување",
+    "Share API is disabled" : "АПИ за споделување е оневозможено",
+    "Wrong share ID, share doesn't exist" : "Погрешено споделен ИД, споделувањето не постои",
+    "Could not delete share" : "Не можеше да се избрише акцијата",
+    "Please specify a file or folder path" : "Ве молиме наведете патека на датотека или папка",
+    "Wrong path, file/folder doesn't exist" : "Погрешна патека, датотека/папка не постои",
+    "Please specify a valid user" : "Наведете валиден корисник",
+    "Please specify a valid group" : "Ве молиме наведете валидна група",
+    "Public link sharing is disabled by the administrator" : "Споделување со јавни линкови е оневозможено од администраторот",
+    "Public upload disabled by the administrator" : "Јавно прикачување е оневозможено од администраторот",
+    "Invalid date, date format must be YYYY-MM-DD" : "Невалиден датум, формат на датумот мора да биде YYYY-MM-DD",
+    "You received a new remote share from %s" : "Добивте ново далечинско споделување од %s",
+    "The mountpoint name contains invalid characters." : "Името на монтираната точка содржи невалидни знаци.",
+    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Дали сакате да додадете далечински пристап на {name} од {owner}@{remote}?",
+    "No ownCloud installation (7 or higher) found at {remote}" : "Не е пронајдена ownCloud инсталација (верзија 7 или поголема) на {remote}",
+    "A file or folder was shared from <strong>another server</strong>" : "Датотека или директориум е споделена со <strong>надворешен сервер</strong>",
+    "A public shared file or folder was <strong>downloaded</strong>" : "Јавно споделена датотека или директориум е <strong>превземен</strong>",
+    "Pending" : "Во очекување",
+    "Accept" : "Прифати",
+    "Decline" : "Одбиј",
+    "Declined" : "Одбиен"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
