@@ -61,6 +61,9 @@ OC.L10N.register(
     "Add to your ownCloud" : "Adaugă propriul tău ownCloud",
     "Download" : "Descarcă",
     "Download %s" : "Descarcă %s",
-    "Direct link" : "Legătură directă"
+    "Direct link" : "Legătură directă",
+    "Pending" : "În așteptare",
+    "Accept" : "Accept",
+    "Decline" : "Refuză"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
