@@ -4,7 +4,7 @@
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Roeland Jago Douma <rullzer@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -119,7 +119,7 @@ class Remote {
 	/**
 	 * List accepted remote shares
 	 *
-	 * @param array $params 
+	 * @param array $params
 	 * @return \OC_OCS_Result
 	 */
 	public static function getShares($params) {
@@ -134,7 +134,7 @@ class Remote {
 
 		$shares = $externalManager->getAcceptedShares();
 
-		$shares = array_map('self::extendShareInfo', $shares);
+		$shares = \array_map('self::extendShareInfo', $shares);
 	
 		return new \OC_OCS_Result($shares);
 	}
