@@ -7,7 +7,7 @@
  * @author Tom Needham <tom@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -40,8 +40,9 @@ use OCP\IUser;
 use OCP\IUserManager;
 use OCP\IUserSession;
 use OCP\Share;
+use OCA\Files_Sharing\SharingBlacklist;
 
-class ShareesController extends OCSController  {
+class ShareesController extends OCSController {
 
 	/** @var IGroupManager */
 	protected $groupManager;
@@ -107,6 +108,9 @@ class ShareesController extends OCSController  {
 	 */
 	protected $additionalInfoField;
 
+	/** @var SharingBlacklist */
+	protected $sharingBlacklist;
+
 	/**
 	 * @param IGroupManager $groupManager
 	 * @param IUserManager $userManager
@@ -127,7 +131,8 @@ class ShareesController extends OCSController  {
 			IUserSession $userSession,
 			IURLGenerator $urlGenerator,
 			ILogger $logger,
-			\OCP\Share\IManager $shareManager) {
+			\OCP\Share\IManager $shareManager,
+			SharingBlacklist $sharingBlacklist) {
 		parent::__construct($appName, $request);
 
 		$this->groupManager = $groupManager;
@@ -139,6 +144,7 @@ class ShareesController extends OCSController  {
 		$this->request = $request;
 		$this->logger = $logger;
 		$this->shareManager = $shareManager;
+		$this->sharingBlacklist = $sharingBlacklist;
 		$this->additionalInfoField = $this->config->getAppValue('core', 'user_additional_info_field', '');
 	}
 
@@ -167,12 +173,12 @@ class ShareesController extends OCSController  {
 			}
 		}
 
-		if (!$this->shareeEnumeration || sizeof($users) < $this->limit) {
+		if (!$this->shareeEnumeration || \sizeof($users) < $this->limit) {
 			$this->reachedEndFor[] = 'users';
 		}
 
 		$foundUserById = false;
-		$lowerSearch = strtolower($search);
+		$lowerSearch = \strtolower($search);
 		foreach ($users as $uid => $user) {
 			/* @var $user IUser */
 			$entry = [
@@ -189,14 +195,14 @@ class ShareesController extends OCSController  {
 
 			if (
 				// Check if the uid is the same
-				strtolower($uid) === $lowerSearch
+				\strtolower($uid) === $lowerSearch
 				// Check if exact display name
-				|| strtolower($user->getDisplayName()) === $lowerSearch
+				|| \strtolower($user->getDisplayName()) === $lowerSearch
 				// Check if exact first email
-				|| strtolower($user->getEMailAddress()) === $lowerSearch
+				|| \strtolower($user->getEMailAddress()) === $lowerSearch
 				// Check for exact search term matches (when mail attributes configured as search terms + no enumeration)
-				|| in_array($lowerSearch, array_map('strtolower', $user->getSearchTerms()))) {
-				if (strtolower($uid) === $lowerSearch) {
+				|| \in_array($lowerSearch, \array_map('strtolower', $user->getSearchTerms()))) {
+				if (\strtolower($uid) === $lowerSearch) {
 					$foundUserById = true;
 				}
 				$this->result['exact']['users'][] = $entry;
@@ -214,7 +220,7 @@ class ShareesController extends OCSController  {
 
 				if ($this->shareWithGroupOnly) {
 					// Only add, if we have a common group
-					$commonGroups = array_intersect($userGroups, $this->groupManager->getUserGroupIds($user));
+					$commonGroups = \array_intersect($userGroups, $this->groupManager->getUserGroupIds($user));
 					$addUser = !empty($commonGroups);
 				}
 
@@ -230,7 +236,7 @@ class ShareesController extends OCSController  {
 					if ($additionalInfo !== null) {
 						$entry['value']['shareWithAdditionalInfo'] = $additionalInfo;
 					}
-					array_push($this->result['exact']['users'], $entry);
+					\array_push($this->result['exact']['users'], $entry);
 				}
 			}
 		}
@@ -249,7 +255,7 @@ class ShareesController extends OCSController  {
 	protected function getAdditionalUserInfo(IUser $user) {
 		if ($this->additionalInfoField === 'email') {
 			return $user->getEMailAddress();
-		} else if ($this->additionalInfoField === 'id') {
+		} elseif ($this->additionalInfoField === 'id') {
 			return $user->getUID();
 		}
 		return null;
@@ -262,9 +268,11 @@ class ShareesController extends OCSController  {
 		$this->result['groups'] = $this->result['exact']['groups'] = [];
 
 		$groups = $this->groupManager->search($search, $this->limit, $this->offset, 'sharing');
-		$groupIds = array_map(function (IGroup $group) { return $group->getGID(); }, $groups);
+		$groupIds = \array_map(function (IGroup $group) {
+			return $group->getGID();
+		}, $groups);
 
-		if (!$this->shareeEnumeration || sizeof($groups) < $this->limit) {
+		if (!$this->shareeEnumeration || \sizeof($groups) < $this->limit) {
 			$this->reachedEndFor[] = 'groups';
 		}
 
@@ -272,18 +280,20 @@ class ShareesController extends OCSController  {
 		if (!empty($groups) && ($this->shareWithMembershipGroupOnly || $this->shareeEnumerationGroupMembers)) {
 			// Intersect all the groups that match with the groups this user is a member of
 			$userGroups = $this->groupManager->getUserGroups($this->userSession->getUser(), 'sharing');
-			$userGroups = array_map(function (IGroup $group) { return $group->getGID(); }, $userGroups);
-			$groupIds = array_intersect($groupIds, $userGroups);
+			$userGroups = \array_map(function (IGroup $group) {
+				return $group->getGID();
+			}, $userGroups);
+			$groupIds = \array_intersect($groupIds, $userGroups);
 		}
 
-		$lowerSearch = strtolower($search);
+		$lowerSearch = \strtolower($search);
 		foreach ($groups as $group) {
 			// FIXME: use a more efficient approach
 			$gid = $group->getGID();
-			if (!in_array($gid, $groupIds)) {
+			if (!\in_array($gid, $groupIds) || $this->sharingBlacklist->isGroupBlacklisted($group)) {
 				continue;
 			}
-			if (strtolower($gid) === $lowerSearch || strtolower($group->getDisplayName()) === $lowerSearch) {
+			if (\strtolower($gid) === $lowerSearch || \strtolower($group->getDisplayName()) === $lowerSearch) {
 				$this->result['exact']['groups'][] = [
 					'label' => $group->getDisplayName(),
 					'value' => [
@@ -306,8 +316,9 @@ class ShareesController extends OCSController  {
 			// On page one we try if the search result has a direct hit on the
 			// user id and if so, we add that to the exact match list
 			$group = $this->groupManager->get($search);
-			if ($group instanceof IGroup && (!$this->shareWithMembershipGroupOnly || in_array($group->getGID(), $userGroups))) {
-				array_push($this->result['exact']['groups'], [
+			if ($group instanceof IGroup && !$this->sharingBlacklist->isGroupBlacklisted($group) &&
+					(!$this->shareWithMembershipGroupOnly || \in_array($group->getGID(), $userGroups))) {
+				\array_push($this->result['exact']['groups'], [
 					'label' => $group->getDisplayName(),
 					'value' => [
 						'shareType' => Share::SHARE_TYPE_GROUP,
@@ -329,12 +340,11 @@ class ShareesController extends OCSController  {
 	protected function getRemote($search) {
 		$this->result['remotes'] = [];
 		// Fetch remote search properties from app config
-		$searchProperties = explode(',', $this->config->getAppValue('dav', 'remote_search_properties', 'CLOUD,FN'));
+		$searchProperties = \explode(',', $this->config->getAppValue('dav', 'remote_search_properties', 'CLOUD,FN'));
 		// Search in contacts
 		$addressBookContacts = $this->contactsManager->search($search, $searchProperties, [], $this->limit, $this->offset);
 		$foundRemoteById = false;
 		foreach ($addressBookContacts as $contact) {
-
 			if (isset($contact['isLocalSystemBook'])) {
 				// We only want remote users
 				continue;
@@ -346,16 +356,15 @@ class ShareesController extends OCSController  {
 
 			// we can have multiple cloud domains, always convert to an array
 			$cloudIds = $contact['CLOUD'];
-			if (!is_array($cloudIds)) {
+			if (!\is_array($cloudIds)) {
 				$cloudIds = [$cloudIds];
 			}
 
-			$lowerSearch = strtolower($search);
+			$lowerSearch = \strtolower($search);
 			foreach ($cloudIds as $cloudId) {
 				list(, $serverUrl) = $this->splitUserRemote($cloudId);
 
-
-				if (strtolower($cloudId) === $lowerSearch) {
+				if (\strtolower($cloudId) === $lowerSearch) {
 					$foundRemoteById = true;
 					// Save this as an exact match and continue with next CLOUD
 					$this->result['exact']['remotes'][] = [
@@ -371,20 +380,20 @@ class ShareesController extends OCSController  {
 
 				// CLOUD matching is done above
 				unset($searchProperties['CLOUD']);
-				foreach($searchProperties as $property) {
+				foreach ($searchProperties as $property) {
 					// do we even have this property for this contact/
-					if(!isset($contact[$property])) {
+					if (!isset($contact[$property])) {
 						// Skip this property since our contact doesnt have it
 						continue;
 					}
 					// check if we have a match
 					$values = $contact[$property];
-					if(!is_array($values)) {
+					if (!\is_array($values)) {
 						$values = [$values];
 					}
-					foreach($values as $value) {
+					foreach ($values as $value) {
 						// check if we have an exact match
-						if(strtolower($value) === $lowerSearch) {
+						if (\strtolower($value) === $lowerSearch) {
 							$this->result['exact']['remotes'][] = [
 								'label' => $contact['FN'],
 								'value' => [
@@ -409,7 +418,6 @@ class ShareesController extends OCSController  {
 						'server' => $serverUrl,
 					],
 				];
-
 			}
 		}
 
@@ -418,8 +426,7 @@ class ShareesController extends OCSController  {
 			$this->result['remotes'] = [];
 		}
 
-
-		if (!$foundRemoteById && substr_count($search, '@') >= 1 && $this->offset === 0
+		if (!$foundRemoteById && \substr_count($search, '@') >= 1 && $this->offset === 0
 			// if an exact local user is found, only keep the remote entry if
 			// its domain does not matches the trusted domains
 			// (if it does, it is a user whose local login domain matches the ownCloud
@@ -447,35 +454,35 @@ class ShareesController extends OCSController  {
 	 * @throws \Exception
 	 */
 	public function splitUserRemote($address) {
-		if (strpos($address, '@') === false) {
+		if (\strpos($address, '@') === false) {
 			throw new \Exception('Invalid Federated Cloud ID');
 		}
 
 		// Find the first character that is not allowed in user names
-		$id = str_replace('\\', '/', $address);
-		$posSlash = strpos($id, '/');
-		$posColon = strpos($id, ':');
+		$id = \str_replace('\\', '/', $address);
+		$posSlash = \strpos($id, '/');
+		$posColon = \strpos($id, ':');
 
 		if ($posSlash === false && $posColon === false) {
-			$invalidPos = strlen($id);
-		} else if ($posSlash === false) {
+			$invalidPos = \strlen($id);
+		} elseif ($posSlash === false) {
 			$invalidPos = $posColon;
-		} else if ($posColon === false) {
+		} elseif ($posColon === false) {
 			$invalidPos = $posSlash;
 		} else {
-			$invalidPos = min($posSlash, $posColon);
+			$invalidPos = \min($posSlash, $posColon);
 		}
 
 		// Find the last @ before $invalidPos
 		$pos = $lastAtPos = 0;
 		while ($lastAtPos !== false && $lastAtPos <= $invalidPos) {
 			$pos = $lastAtPos;
-			$lastAtPos = strpos($id, '@', $pos + 1);
+			$lastAtPos = \strpos($id, '@', $pos + 1);
 		}
 
 		if ($pos !== false) {
-			$user = substr($id, 0, $pos);
-			$remote = substr($id, $pos + 1);
+			$user = \substr($id, 0, $pos);
+			$remote = \substr($id, $pos + 1);
 			$remote = $this->fixRemoteURL($remote);
 			if (!empty($user) && !empty($remote)) {
 				return [$user, $remote];
@@ -498,11 +505,11 @@ class ShareesController extends OCSController  {
 	 * @return string
 	 */
 	protected function fixRemoteURL($remote) {
-		$remote = str_replace('\\', '/', $remote);
-		if ($fileNamePosition = strpos($remote, '/index.php')) {
-			$remote = substr($remote, 0, $fileNamePosition);
+		$remote = \str_replace('\\', '/', $remote);
+		if ($fileNamePosition = \strpos($remote, '/index.php')) {
+			$remote = \substr($remote, 0, $fileNamePosition);
 		}
-		$remote = rtrim($remote, '/');
+		$remote = \rtrim($remote, '/');
 
 		return $remote;
 	}
@@ -518,7 +525,6 @@ class ShareesController extends OCSController  {
 	 * @return array|DataResponse
 	 */
 	public function search($search = '', $itemType = null, $page = 1, $perPage = 200) {
-
 		if ($perPage <= 0) {
 			return [ 'statuscode' => Http::STATUS_BAD_REQUEST,
 				'message' => 'Invalid perPage argument'];
@@ -538,18 +544,17 @@ class ShareesController extends OCSController  {
 
 		$shareTypes[] = Share::SHARE_TYPE_REMOTE;
 
-		if (isset($_GET['shareType']) && is_array($_GET['shareType'])) {
-			$shareTypes = array_intersect($shareTypes, $_GET['shareType']);
-			sort($shareTypes);
-
-		} else if (isset($_GET['shareType']) && is_numeric($_GET['shareType'])) {
-			$shareTypes = array_intersect($shareTypes, [(int) $_GET['shareType']]);
-			sort($shareTypes);
+		if (isset($_GET['shareType']) && \is_array($_GET['shareType'])) {
+			$shareTypes = \array_intersect($shareTypes, $_GET['shareType']);
+			\sort($shareTypes);
+		} elseif (isset($_GET['shareType']) && \is_numeric($_GET['shareType'])) {
+			$shareTypes = \array_intersect($shareTypes, [(int) $_GET['shareType']]);
+			\sort($shareTypes);
 		}
 
-		if (in_array(Share::SHARE_TYPE_REMOTE, $shareTypes) && !$this->isRemoteSharingAllowed($itemType)) {
+		if (\in_array(Share::SHARE_TYPE_REMOTE, $shareTypes) && !$this->isRemoteSharingAllowed($itemType)) {
 			// Remove remote shares from type array, because it is not allowed.
-			$shareTypes = array_diff($shareTypes, [Share::SHARE_TYPE_REMOTE]);
+			$shareTypes = \array_diff($shareTypes, [Share::SHARE_TYPE_REMOTE]);
 		}
 
 		$this->shareWithGroupOnly = $this->config->getAppValue('core', 'shareapi_only_share_with_group_members', 'no') === 'yes';
@@ -599,23 +604,23 @@ class ShareesController extends OCSController  {
 		}
 
 		// Get users
-		if (in_array(Share::SHARE_TYPE_USER, $shareTypes)) {
+		if (\in_array(Share::SHARE_TYPE_USER, $shareTypes)) {
 			$this->getUsers($search);
 		}
 
 		// Get groups
-		if (in_array(Share::SHARE_TYPE_GROUP, $shareTypes)) {
+		if (\in_array(Share::SHARE_TYPE_GROUP, $shareTypes)) {
 			$this->getGroups($search);
 		}
 
 		// Get remote
-		if (in_array(Share::SHARE_TYPE_REMOTE, $shareTypes)) {
+		if (\in_array(Share::SHARE_TYPE_REMOTE, $shareTypes)) {
 			$this->getRemote($search);
 		}
 
 		$response = new DataResponse(['data' => $this->result]);
 
-		if (sizeof($this->reachedEndFor) < 3) {
+		if (\sizeof($this->reachedEndFor) < 3) {
 			$response->addHeader('Link', $this->getPaginationLink($page, [
 				'search' => $search,
 				'itemType' => $itemType,
@@ -641,7 +646,7 @@ class ShareesController extends OCSController  {
 			$url = $this->urlGenerator->getAbsoluteURL('/ocs/v1.php/apps/files_sharing/api/v1/sharees') . '?';
 		}
 		$params['page'] = $page + 1;
-		$link = '<' . $url . http_build_query($params) . '>; rel="next"';
+		$link = '<' . $url . \http_build_query($params) . '>; rel="next"';
 
 		return $link;
 	}
@@ -661,18 +666,18 @@ class ShareesController extends OCSController  {
 	 * @return true if one match was found, false otherwise
 	 */
 	protected function isInstanceDomain($target) {
-		if (strpos($target, '/') !== false) {
+		if (\strpos($target, '/') !== false) {
 			// not a proper email-like format with domain name
 			return false;
 		}
-		$parts = explode('@', $target);
-		if (count($parts) === 1) {
+		$parts = \explode('@', $target);
+		if (\count($parts) === 1) {
 			// no "@" sign
 			return false;
 		}
-		$domainName = $parts[count($parts) - 1];
+		$domainName = $parts[\count($parts) - 1];
 		$trustedDomains = $this->config->getSystemValue('trusted_domains', []);
 
-		return in_array($domainName, $trustedDomains, true);
+		return \in_array($domainName, $trustedDomains, true);
 	}
 }
