@@ -13,7 +13,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -53,6 +53,8 @@ use OCP\IUserManager;
 use OCP\Share;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Template;
+use Symfony\Component\EventDispatcher\EventDispatcher;
+use Symfony\Component\EventDispatcher\GenericEvent;
 
 /**
  * Class ShareController
@@ -79,8 +81,12 @@ class ShareController extends Controller {
 	protected $previewManager;
 	/** @var IRootFolder */
 	protected $rootFolder;
+	/** @var EventDispatcher */
+	protected $eventDispatcher;
 
 	/**
+	 * ShareController constructor.
+	 *
 	 * @param string $appName
 	 * @param IRequest $request
 	 * @param IConfig $config
@@ -88,10 +94,11 @@ class ShareController extends Controller {
 	 * @param IUserManager $userManager
 	 * @param ILogger $logger
 	 * @param OCP\Activity\IManager $activityManager
-	 * @param \OCP\Share\IManager $shareManager
+	 * @param Share\IManager $shareManager
 	 * @param ISession $session
 	 * @param IPreview $previewManager
 	 * @param IRootFolder $rootFolder
+	 * @param EventDispatcher $eventDispatcher
 	 */
 	public function __construct($appName,
 								IRequest $request,
@@ -103,7 +110,8 @@ class ShareController extends Controller {
 								\OCP\Share\IManager $shareManager,
 								ISession $session,
 								IPreview $previewManager,
-								IRootFolder $rootFolder) {
+								IRootFolder $rootFolder,
+								EventDispatcher $eventDispatcher) {
 		parent::__construct($appName, $request);
 
 		$this->config = $config;
@@ -115,6 +123,7 @@ class ShareController extends Controller {
 		$this->session = $session;
 		$this->previewManager = $previewManager;
 		$this->rootFolder = $rootFolder;
+		$this->eventDispatcher = $eventDispatcher;
 	}
 
 	/**
@@ -127,7 +136,7 @@ class ShareController extends Controller {
 	public function showAuthenticate($token) {
 		$share = $this->shareManager->getShareByToken($token);
 
-		if($this->linkShareAuth($share)) {
+		if ($this->linkShareAuth($share)) {
 			return new RedirectResponse($this->urlGenerator->linkToRoute('files_sharing.sharecontroller.showShare', ['token' => $token]));
 		}
 
@@ -154,7 +163,7 @@ class ShareController extends Controller {
 
 		$authenticate = $this->linkShareAuth($share, $password);
 
-		if($authenticate === true) {
+		if ($authenticate === true) {
 			return new RedirectResponse($this->urlGenerator->linkToRoute('files_sharing.sharecontroller.showShare', ['token' => $token]));
 		}
 
@@ -182,7 +191,7 @@ class ShareController extends Controller {
 			}
 		} else {
 			// not authenticated ?
-			if ( ! $this->session->exists('public_link_authenticated')
+			if (! $this->session->exists('public_link_authenticated')
 				|| $this->session->get('public_link_authenticated') !== (string)$share->getId()) {
 				return false;
 			}
@@ -204,7 +213,7 @@ class ShareController extends Controller {
 		$itemType = $itemSource = $uidOwner = '';
 		$token = $share;
 		$exception = null;
-		if($share instanceof \OCP\Share\IShare) {
+		if ($share instanceof \OCP\Share\IShare) {
 			try {
 				$token = $share->getToken();
 				$uidOwner = $share->getSharedBy();
@@ -223,7 +232,16 @@ class ShareController extends Controller {
 			'errorCode' => $errorCode,
 			'errorMessage' => $errorMessage,
 		]);
-		if(!is_null($exception)) {
+
+		if ($share instanceof \OCP\Share\IShare) {
+			$cloneShare = clone $share;
+			$publicShareLinkAccessEvent = new GenericEvent(null,
+				['shareObject' => $cloneShare, 'errorCode' => $errorCode,
+					'errorMessage' => $errorMessage]);
+			$this->eventDispatcher->dispatch('share.linkaccess', $publicShareLinkAccessEvent);
+		}
+
+		if ($exception !== null) {
 			throw $exception;
 		}
 	}
@@ -239,6 +257,8 @@ class ShareController extends Controller {
 	}
 
 	/**
+	 * Renders and displays the public link page template
+	 *
 	 * @PublicPage
 	 * @NoCSRFRequired
 	 *
@@ -314,7 +334,7 @@ class ShareController extends Controller {
 			 */
 			$freeSpace = $share->getNode()->getStorage()->free_space($share->getNode()->getInternalPath());
 			if ($freeSpace < \OCP\Files\FileInfo::SPACE_UNLIMITED) {
-				$freeSpace = max($freeSpace, 0);
+				$freeSpace = \max($freeSpace, 0);
 			} else {
 				$freeSpace = (INF > 0) ? INF: PHP_INT_MAX; // work around https://bugs.php.net/bug.php?id=69188
 			}
@@ -348,12 +368,14 @@ class ShareController extends Controller {
 		$shareTmpl['previewMaxX'] = $this->config->getSystemValue('preview_max_x', 1024);
 		$shareTmpl['previewMaxY'] = $this->config->getSystemValue('preview_max_y', 1024);
 		if ($shareTmpl['previewSupported']) {
-			$shareTmpl['previewImage'] = $this->urlGenerator->linkToRouteAbsolute( 'core_ajax_public_preview',
+			$shareTmpl['previewImage'] = $this->urlGenerator->linkToRouteAbsolute('core_ajax_public_preview',
 				['x' => 200, 'y' => 200, 'file' => $shareTmpl['directory_path'], 't' => $shareTmpl['dirToken']]);
 		} else {
 			$shareTmpl['previewImage'] = $this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('core', 'favicon-fb.png'));
 		}
 
+		$this->eventDispatcher->dispatch('OCA\Files_Sharing::loadAdditionalScripts');
+
 		$csp = new OCP\AppFramework\Http\ContentSecurityPolicy();
 		$csp->addAllowedFrameDomain('\'self\'');
 		$response = new TemplateResponse($this->appName, 'public', $shareTmpl, 'base');
@@ -390,9 +412,9 @@ class ShareController extends Controller {
 		}
 
 		$files_list = $files;
-		if (!is_null($files)) { // download selected files
+		if ($files !== null) { // download selected files
 			// in case we get only a single file
-			if (!is_array($files_list)) {
+			if (!\is_array($files_list)) {
 				$files_list = [(string)$files_list];
 			}
 		}
@@ -441,7 +463,7 @@ class ShareController extends Controller {
 					->setAffectedUser($share->getShareOwner())
 					->setObject('files', $node->getId(), $userFolder->getRelativePath($node->getPath()));
 				$this->activityManager->publish($event);
-			} else if (!empty($files_list)) {
+			} elseif (!empty($files_list)) {
 				/** @var \OCP\Files\Folder $node */
 
 				// Subset of files is downloaded
@@ -485,10 +507,10 @@ class ShareController extends Controller {
 		 */
 		if (!empty($downloadStartSecret)
 			&& !isset($downloadStartSecret[32])
-			&& preg_match('!^[a-zA-Z0-9]+$!', $downloadStartSecret) === 1) {
+			&& \preg_match('!^[a-zA-Z0-9]+$!', $downloadStartSecret) === 1) {
 
 			// FIXME: set on the response once we use an actual app framework response
-			setcookie('ocDownloadStarted', $downloadStartSecret, time() + 20, '/');
+			\setcookie('ocDownloadStarted', $downloadStartSecret, \time() + 20, '/');
 		}
 
 		$this->emitAccessShareHook($share);
@@ -503,7 +525,7 @@ class ShareController extends Controller {
 		}
 
 		// download selected files
-		if (!is_null($files) && $files !== '') {
+		if ($files !== null && $files !== '') {
 			// FIXME: The exit is required here because otherwise the AppFramework is trying to add headers as well
 			// after dispatching the request which results in a "Cannot modify header information" notice.
 			OC_Files::get($originalSharePath, $files_list, $server_params);
@@ -511,7 +533,7 @@ class ShareController extends Controller {
 		} else {
 			// FIXME: The exit is required here because otherwise the AppFramework is trying to add headers as well
 			// after dispatching the request which results in a "Cannot modify header information" notice.
-			OC_Files::get(dirname($originalSharePath), basename($originalSharePath), $server_params);
+			OC_Files::get(\dirname($originalSharePath), \basename($originalSharePath), $server_params);
 			exit();
 		}
 	}
