@@ -10,7 +10,7 @@
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -106,7 +106,6 @@ class Manager {
 	 * @return Mount|null
 	 */
 	public function addShare($remote, $token, $password, $name, $owner, $accepted=false, $user = null, $remoteId = -1) {
-
 		$user = $user ? $user : $this->uid;
 		$accepted = $accepted ? 1 : 0;
 		$name = Filesystem::normalizePath('/' . $name);
@@ -118,7 +117,7 @@ class Manager {
 			// using the original share item name.
 			$tmpMountPointName = '{{TemporaryMountPointName#' . $name . '}}';
 			$mountPoint = $tmpMountPointName;
-			$hash = md5($tmpMountPointName);
+			$hash = \md5($tmpMountPointName);
 			$data = [
 				'remote'		=> $remote,
 				'share_token'	=> $token,
@@ -136,7 +135,7 @@ class Manager {
 			while (!$this->connection->insertIfNotExist('*PREFIX*share_external', $data, ['user', 'mountpoint_hash'])) {
 				// The external share already exists for the user
 				$data['mountpoint'] = $tmpMountPointName . '-' . $i;
-				$data['mountpoint_hash'] = md5($data['mountpoint']);
+				$data['mountpoint_hash'] = \md5($data['mountpoint']);
 				$i++;
 			}
 			return null;
@@ -144,7 +143,7 @@ class Manager {
 
 		$mountPoint = Files::buildNotExistingFileName('/', $name);
 		$mountPoint = Filesystem::normalizePath('/' . $mountPoint);
-		$hash = md5($mountPoint);
+		$hash = \md5($mountPoint);
 
 		$query = $this->connection->prepare('
 				INSERT INTO `*PREFIX*share_external`
@@ -186,13 +185,12 @@ class Manager {
 	 * @return bool True if the share could be accepted, false otherwise
 	 */
 	public function acceptShare($id) {
-
 		$share = $this->getShare($id);
 
 		if ($share) {
 			$mountPoint = Files::buildNotExistingFileName('/', $share['name']);
 			$mountPoint = Filesystem::normalizePath('/' . $mountPoint);
-			$hash = md5($mountPoint);
+			$hash = \md5($mountPoint);
 
 			$acceptShare = $this->connection->prepare('
 				UPDATE `*PREFIX*share_external`
@@ -203,12 +201,12 @@ class Manager {
 			$acceptShare->execute([1, $mountPoint, $hash, $id, $this->uid]);
 
 			$this->eventDispatcher->dispatch(
-				AcceptShare::class,	new AcceptShare($share)
+				AcceptShare::class, new AcceptShare($share)
 			);
 
 			$event = new GenericEvent(null, ['sharedItem' => $share['name'], 'shareAcceptedFrom' => $share['owner'],
 				'remoteUrl' => $share['remote']]);
-			$this->eventDispatcher->dispatch('remoteshare.accepted',$event);
+			$this->eventDispatcher->dispatch('remoteshare.accepted', $event);
 			\OC_Hook::emit('OCP\Share', 'federated_share_added', ['server' => $share['remote']]);
 
 			$this->processNotification($id);
@@ -225,7 +223,6 @@ class Manager {
 	 * @return bool True if the share could be declined, false otherwise
 	 */
 	public function declineShare($id) {
-
 		$share = $this->getShare($id);
 
 		if ($share) {
@@ -240,7 +237,7 @@ class Manager {
 
 			$event = new GenericEvent(null, ['sharedItem' => $share['name'], 'shareAcceptedFrom' => $share['owner'],
 				'remoteUrl' => $share['remote']]);
-			$this->eventDispatcher->dispatch('remoteshare.declined',$event);
+			$this->eventDispatcher->dispatch('remoteshare.declined', $event);
 
 			$this->processNotification($id);
 			return true;
@@ -268,7 +265,7 @@ class Manager {
 	 */
 	protected function stripPath($path) {
 		$prefix = '/' . $this->uid . '/files';
-		return rtrim(substr($path, strlen($prefix)), '/');
+		return \rtrim(\substr($path, \strlen($prefix)), '/');
 	}
 
 	public function getMount($data) {
@@ -304,8 +301,8 @@ class Manager {
 	public function setMountPoint($source, $target) {
 		$source = $this->stripPath($source);
 		$target = $this->stripPath($target);
-		$sourceHash = md5($source);
-		$targetHash = md5($target);
+		$sourceHash = \md5($source);
+		$targetHash = \md5($target);
 
 		$query = $this->connection->prepare('
 			UPDATE `*PREFIX*share_external`
@@ -319,12 +316,11 @@ class Manager {
 	}
 
 	public function removeShare($mountPoint) {
-
 		$mountPointObj = $this->mountManager->find($mountPoint);
 		$id = $mountPointObj->getStorage()->getCache()->getId('');
 
 		$mountPoint = $this->stripPath($mountPoint);
-		$hash = md5($mountPoint);
+		$hash = \md5($mountPoint);
 
 		$getShare = $this->connection->prepare('
 			SELECT `remote`, `share_token`, `remote_id`
@@ -348,7 +344,7 @@ class Manager {
 		');
 		$result = (bool)$query->execute([$hash, $this->uid]);
 
-		if($result) {
+		if ($result) {
 			$this->removeReShares($id);
 			$event = new GenericEvent(null, ['user' => $this->uid, 'targetmount' => $mountPoint]);
 			$this->eventDispatcher->dispatch('\OCA\Files_Sharing::unshareEvent', $event);
@@ -359,7 +355,7 @@ class Manager {
 
 	/**
 	 * remove re-shares from share table and mapping in the federated_reshares table
-	 * 
+	 *
 	 * @param $mountPointId
 	 */
 	protected function removeReShares($mountPointId) {
@@ -369,7 +365,6 @@ class Manager {
 			->where($selectQuery->expr()->eq('file_source', $query->createNamedParameter($mountPointId)));
 		$select = $selectQuery->getSQL();
 
-
 		$query->delete('federated_reshares')
 			->where($query->expr()->in('share_id', $query->createFunction('(' . $select . ')')));
 		$query->execute();
@@ -395,7 +390,7 @@ class Manager {
 
 		if ($result) {
 			$shares = $getShare->fetchAll();
-			foreach($shares as $share) {
+			foreach ($shares as $share) {
 				$this->eventDispatcher->dispatch(
 					DeclineShare::class,
 					new DeclineShare($share)
@@ -441,7 +436,7 @@ class Manager {
 		          FROM `*PREFIX*share_external` 
 				  WHERE `user` = ?';
 		$parameters = [$this->uid];
-		if (!is_null($accepted)) {
+		if ($accepted !== null) {
 			$query .= ' AND `accepted` = ?';
 			$parameters[] = (int) $accepted;
 		}
