@@ -6,7 +6,7 @@
  * @author Roeland Jago Douma <rullzer@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -59,7 +59,6 @@ class MountProvider implements IMountProvider {
 		$this->logger = $logger;
 	}
 
-
 	/**
 	 * Get all mountpoints applicable for the user and check for shares where we need to update the etags
 	 *
@@ -72,8 +71,10 @@ class MountProvider implements IMountProvider {
 		$shares = $this->shareManager->getAllSharedWith($user->getUID(), $requiredShareTypes, null);
 		
 		// filter out excluded shares and group shares that includes self
-		$shares = array_filter($shares, function (\OCP\Share\IShare $share) use ($user) {
-			return $share->getPermissions() > 0 && $share->getShareOwner() !== $user->getUID();
+		$shares = \array_filter($shares, function (\OCP\Share\IShare $share) use ($user) {
+			return $share->getPermissions() > 0
+				&& $share->getShareOwner() !== $user->getUID()
+				&& $share->getState() === \OCP\Share::STATE_ACCEPTED;
 		});
 
 		$superShares = $this->buildSuperShares($shares, $user);
@@ -100,7 +101,7 @@ class MountProvider implements IMountProvider {
 		}
 
 		// array_filter removes the null values from the array
-		return array_filter($mounts);
+		return \array_filter($mounts);
 	}
 
 	/**
@@ -123,7 +124,7 @@ class MountProvider implements IMountProvider {
 		$result = [];
 		// sort by stime, the super share will be based on the least recent share
 		foreach ($tmp as &$tmp2) {
-			@usort($tmp2, function($a, $b) {
+			@\usort($tmp2, function ($a, $b) {
 				if ($a->getShareTime() <= $b->getShareTime()) {
 					return -1;
 				}
@@ -132,7 +133,7 @@ class MountProvider implements IMountProvider {
 			$result[] = $tmp2;
 		}
 
-		return array_values($result);
+		return \array_values($result);
 	}
 
 	/**
@@ -152,7 +153,7 @@ class MountProvider implements IMountProvider {
 
 		/** @var \OCP\Share\IShare[] $shares */
 		foreach ($groupedShares as $shares) {
-			if (count($shares) === 0) {
+			if (\count($shares) === 0) {
 				continue;
 			}
 
