@@ -1,4 +1,10 @@
-<form action="<?php p($_['URL']); ?>" method="post">
+<?php
+	/** @var $_ array */
+	/** @var $l \OCP\IL10N */
+	style('files_sharing', 'authenticate');
+	script('files_sharing', 'authenticate');
+?>
+<form method="post">
 	<fieldset>
 		<?php if (!isset($_['wrongpw'])): ?>
 			<div class="warning-info"><?php p($l->t('This share is password-protected')); ?></div>
@@ -8,12 +14,13 @@
 		<?php endif; ?>
 		<p>
 			<label for="password" class="infield"><?php p($l->t('Password')); ?></label>
+			<input type="hidden" name="requesttoken" value="<?php p($_['requesttoken']) ?>" />
 			<input type="password" name="password" id="password"
 				placeholder="<?php p($l->t('Password')); ?>" value=""
 				autocomplete="off" autocapitalize="off" autocorrect="off"
 				autofocus />
-			<img class="svg" id="password-icon" src="<?php print_unescaped(image_path('', 'actions/password.svg')); ?>" alt=""/>
-			<input type="submit" value="" class="svg icon-confirm" />
+			<input type="submit" id="password-submit" 
+				class="svg icon-confirm input-button-inline" value="" disabled="disabled" />
 		</p>
 	</fieldset>
 </form>
