@@ -7,7 +7,7 @@
  * @author Roeland Jago Douma <rullzer@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,52 +26,59 @@
 \OC_Util::checkLoggedIn();
 \OC::$server->getSession()->close();
 
-if(!\OC_App::isEnabled('files_trashbin')){
+if (!\OC_App::isEnabled('files_trashbin')) {
 	exit;
 }
 
-$file = array_key_exists('file', $_GET) ? (string) $_GET['file'] : '';
-$maxX = array_key_exists('x', $_GET) ? (int) $_GET['x'] : '44';
-$maxY = array_key_exists('y', $_GET) ? (int) $_GET['y'] : '44';
-$scalingUp = array_key_exists('scalingup', $_GET) ? (bool) $_GET['scalingup'] : true;
+$file = \array_key_exists('file', $_GET) ? (string) $_GET['file'] : '';
+$maxX = \array_key_exists('x', $_GET) ? (int) $_GET['x'] : '44';
+$maxY = \array_key_exists('y', $_GET) ? (int) $_GET['y'] : '44';
+$scalingUp = \array_key_exists('scalingup', $_GET) ? (bool) $_GET['scalingup'] : true;
 
-if($file === '') {
+if ($file === '') {
 	\OC_Response::setStatus(400); //400 Bad Request
 	\OCP\Util::writeLog('core-preview', 'No file parameter was passed', \OCP\Util::DEBUG);
 	exit;
 }
 
-if($maxX === 0 || $maxY === 0) {
+if ($maxX === 0 || $maxY === 0) {
 	\OC_Response::setStatus(400); //400 Bad Request
 	\OCP\Util::writeLog('core-preview', 'x and/or y set to 0', \OCP\Util::DEBUG);
 	exit;
 }
 
-try{
-	$preview = new \OC\Preview(\OC_User::getUser(), 'files_trashbin/files', $file);
-	$view = new \OC\Files\View('/'.\OC_User::getUser(). '/files_trashbin/files');
-	if ($view->is_dir($file)) {
+try {
+	$userFolder = \OC::$server->getRootFolder()->getUserFolder(\OC_User::getUser());
+	/** @var \OCP\Files\Folder $trashFolder */
+	$trashFolder = $userFolder->getParent()->get('files_trashbin/files');
+	/** @var \OCP\Files\File | \OCP\Files\IPreviewNode $file */
+	$file = $trashFolder->get($file);
+
+	if ($file->getType() === \OCP\Files\FileInfo::TYPE_FOLDER) {
 		$mimetype = 'httpd/unix-directory';
 	} else {
-		$pathInfo = pathinfo(ltrim($file, '/'));
+		$pathInfo = \pathinfo(\ltrim($file->getName(), '/'));
 		$fileName = $pathInfo['basename'];
 		// if in root dir
 		if ($pathInfo['dirname'] === '.') {
 			// cut off the .d* suffix
-			$i = strrpos($fileName, '.');
+			$i = \strrpos($fileName, '.');
 			if ($i !== false) {
-				$fileName = substr($fileName, 0, $i);
+				$fileName = \substr($fileName, 0, $i);
 			}
 		}
 		$mimetype = \OC::$server->getMimeTypeDetector()->detectPath($fileName);
 	}
-	$preview->setMimetype($mimetype);
-	$preview->setMaxX($maxX);
-	$preview->setMaxY($maxY);
-	$preview->setScalingUp($scalingUp);
 
-	$preview->showPreview();
-}catch(\Exception $e) {
+	$image = $file->getThumbnail([
+		'x' => $maxX,
+		'y' => $maxY,
+		'scalingup' => $scalingUp,
+		'mimeType' => $mimetype
+	]);
+
+	$image->show();
+} catch (\Exception $e) {
 	\OC_Response::setStatus(500);
 	\OCP\Util::writeLog('core', $e->getmessage(), \OCP\Util::DEBUG);
 }
