@@ -5,15 +5,17 @@ OC.L10N.register(
     "Couldn't restore %s" : "Nelze obnovit %s",
     "Deleted files" : "Odstraněné soubory",
     "Restore" : "Obnovit",
+    "Delete" : "Smazat",
     "Delete permanently" : "Trvale odstranit",
     "Error" : "Chyba",
+    "This operation is forbidden" : "Tato operace je zakázána",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte prosím logy nebo kontaktujte svého správce systému",
     "restored" : "obnoveno",
     "No deleted files" : "Žádné smazané soubory",
     "You will be able to recover deleted files from here" : "Odtud budete moci obnovovat odstraněné soubory",
-    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
+    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
     "Select all" : "Vybrat vše",
     "Name" : "Název",
-    "Deleted" : "Smazáno",
-    "Delete" : "Smazat"
+    "Deleted" : "Smazáno"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
