@@ -3,7 +3,7 @@
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -46,7 +46,7 @@ class Expiration {
 	/** @var bool */
 	private $canPurgeToSaveSpace;
 
-	public function __construct(IConfig $config,ITimeFactory $timeFactory){
+	public function __construct(IConfig $config, ITimeFactory $timeFactory) {
 		$this->timeFactory = $timeFactory;
 		$this->retentionObligation = $config->getSystemValue('trashbin_retention_obligation', 'auto');
 
@@ -59,7 +59,7 @@ class Expiration {
 	 * Is trashbin expiration enabled
 	 * @return bool
 	 */
-	public function isEnabled(){
+	public function isEnabled() {
 		return $this->retentionObligation !== 'disabled';
 	}
 
@@ -69,7 +69,7 @@ class Expiration {
 	 * @param bool $quotaExceeded
 	 * @return bool
 	 */
-	public function isExpired($timestamp, $quotaExceeded = false){
+	public function isExpired($timestamp, $quotaExceeded = false) {
 		// No expiration if disabled
 		if (!$this->isEnabled()) {
 			return false;
@@ -118,12 +118,12 @@ class Expiration {
 		return $maxAge;
 	}
 
-	private function parseRetentionObligation(){
-		$splitValues = explode(',', $this->retentionObligation);
+	private function parseRetentionObligation() {
+		$splitValues = \explode(',', $this->retentionObligation);
 		if (!isset($splitValues[0])) {
 			$minValue = self::DEFAULT_RETENTION_OBLIGATION;
 		} else {
-			$minValue = trim($splitValues[0]);
+			$minValue = \trim($splitValues[0]);
 		}
 
 		if (!isset($splitValues[1]) && $minValue === 'auto') {
@@ -131,7 +131,7 @@ class Expiration {
 		} elseif (!isset($splitValues[1])) {
 			$maxValue = self::DEFAULT_RETENTION_OBLIGATION;
 		} else {
-			$maxValue = trim($splitValues[1]);
+			$maxValue = \trim($splitValues[1]);
 		}
 
 		if ($minValue === 'auto' && $maxValue === 'auto') {
@@ -141,13 +141,13 @@ class Expiration {
 			$this->canPurgeToSaveSpace = true;
 		} elseif ($minValue !== 'auto' && $maxValue === 'auto') {
 			// Keep for X days but delete anytime if space needed
-			$this->minAge = intval($minValue);
+			$this->minAge = \intval($minValue);
 			$this->maxAge = self::NO_OBLIGATION;
 			$this->canPurgeToSaveSpace = true;
 		} elseif ($minValue === 'auto' && $maxValue !== 'auto') {
 			// Delete anytime if space needed, Delete all older than max automatically
 			$this->minAge = self::NO_OBLIGATION;
-			$this->maxAge = intval($maxValue);
+			$this->maxAge = \intval($maxValue);
 			$this->canPurgeToSaveSpace = true;
 		} elseif ($minValue !== 'auto' && $maxValue !== 'auto') {
 			// Delete all older than max OR older than min if space needed
@@ -157,8 +157,8 @@ class Expiration {
 				$maxValue = $minValue;
 			}
 
-			$this->minAge = intval($minValue);
-			$this->maxAge = intval($maxValue);
+			$this->minAge = \intval($minValue);
+			$this->maxAge = \intval($maxValue);
 			$this->canPurgeToSaveSpace = false;
 		}
 	}
