@@ -15,10 +15,10 @@
  * @author Sjors van der Pluijm <sjors@desjors.nl>
  * @author Steven Bühner <buehner@me.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Victor Dubiniuk <dubiniuk@owncloud.com>
+ * @author Viktar Dubiniuk <dubiniuk@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -41,13 +41,41 @@ use OC\Files\Filesystem;
 use OC\Files\View;
 use OCA\Files_Trashbin\AppInfo\Application;
 use OCA\Files_Trashbin\Command\Expire;
+use OCP\Encryption\Keys\IStorage;
 use OCP\Files\NotFoundException;
 use OCP\User;
+use Symfony\Component\EventDispatcher\GenericEvent;
+use OCP\Files\Folder;
+use OCP\Files\IRootFolder;
+use OCP\IURLGenerator;
+use Symfony\Component\EventDispatcher\EventDispatcher;
 
 class Trashbin {
 
-	// unit: percentage; 50% of available disk space/quota
-	const DEFAULTMAXSIZE = 50;
+	/**
+	 * @var IURLGenerator
+	 */
+	private $urlGenerator;
+
+	/**
+	 * @var IRootFolder
+	 */
+	private $rootFolder;
+
+	/**
+	 * @var EventDispatcher
+	 */
+	private $eventDispatcher;
+
+	public function __construct(
+		IRootFolder $rootFolder,
+		IUrlGenerator $urlGenerator,
+		EventDispatcher $eventDispatcher
+	) {
+		$this->rootFolder = $rootFolder;
+		$this->urlGenerator = $urlGenerator;
+		$this->eventDispatcher = $eventDispatcher;
+	}
 
 	/**
 	 * Whether versions have already be rescanned during this PHP request
@@ -144,11 +172,23 @@ class Trashbin {
 		}
 	}
 
+	/**
+	 * Sets up the trashbin for the given user
+	 *
+	 * @param string $user user id
+	 * @return bool true if trashbin is setup and usable, false otherwise
+	 */
 	private static function setUpTrash($user) {
 		$view = new View('/' . $user);
 		if (!$view->is_dir('files_trashbin')) {
 			$view->mkdir('files_trashbin');
 		}
+
+		if (!$view->isUpdatable('files_trashbin')) {
+			// no trashbin access or denied
+			return false;
+		}
+
 		if (!$view->is_dir('files_trashbin/files')) {
 			$view->mkdir('files_trashbin/files');
 		}
@@ -158,8 +198,9 @@ class Trashbin {
 		if (!$view->is_dir('files_trashbin/keys')) {
 			$view->mkdir('files_trashbin/keys');
 		}
-	}
 
+		return true;
+	}
 
 	/**
 	 * copy file to owners trash
@@ -173,10 +214,10 @@ class Trashbin {
 	private static function copyFilesToUser($sourcePath, $owner, $targetPath, $user, $timestamp) {
 		self::setUpTrash($owner);
 
-		$targetFilename = basename($targetPath);
-		$targetLocation = dirname($targetPath);
+		$targetFilename = \basename($targetPath);
+		$targetLocation = \dirname($targetPath);
 
-		$sourceFilename = basename($sourcePath);
+		$sourceFilename = \basename($sourcePath);
 
 		$view = new View('/');
 
@@ -200,9 +241,9 @@ class Trashbin {
 	public static function copyBackupForOwner($ownerPath, $owner, $timestamp) {
 		self::setUpTrash($owner);
 
-		$targetFilename = basename($ownerPath);
-		$targetLocation = dirname($ownerPath);
-		$source = $owner . '/files/' . ltrim($ownerPath, '/');
+		$targetFilename = \basename($ownerPath);
+		$targetLocation = \dirname($ownerPath);
+		$source = $owner . '/files/' . \ltrim($ownerPath, '/');
 		$target = $owner . '/files_trashbin/files/' . $targetFilename . '.d' . $timestamp;
 
 		$view = new View('/');
@@ -227,7 +268,6 @@ class Trashbin {
 		}
 	}
 
-
 	/**
 	 * move file to the trash bin
 	 *
@@ -237,32 +277,39 @@ class Trashbin {
 	public static function move2trash($file_path) {
 		// get the user for which the filesystem is setup
 		$root = Filesystem::getRoot();
-		list(, $user) = explode('/', $root);
+		list(, $user) = \explode('/', $root);
 		list($owner, $ownerPath) = self::getUidAndFilename($file_path);
 
 		// if no owner found (ex: ext storage + share link), will use the current user's trashbin then
-		if (is_null($owner)) {
+		if ($owner === null) {
 			$owner = $user;
 			$ownerPath = $file_path;
 		}
 
 		$ownerView = new View('/' . $owner);
 		// file has been deleted in between
-		if (is_null($ownerPath) || $ownerPath === '' || !$ownerView->file_exists('/files/' . $ownerPath)) {
+		if ($ownerPath === null || $ownerPath === '' || !$ownerView->file_exists('/files/' . $ownerPath)) {
 			return true;
 		}
 
-		self::setUpTrash($user);
+		if (!self::setUpTrash($user)) {
+			// trashbin not usable for user (ex: guest), switch to owner only
+			$user = $owner;
+			if (!self::setUpTrash($owner)) {
+				// nothing to do as no trash is available anywheree
+				return true;
+			}
+		}
 		if ($owner !== $user) {
 			// also setup for owner
 			self::setUpTrash($owner);
 		}
 
-		$path_parts = pathinfo($ownerPath);
+		$path_parts = \pathinfo($ownerPath);
 
 		$filename = $path_parts['basename'];
 		$location = $path_parts['dirname'];
-		$timestamp = time();
+		$timestamp = \time();
 
 		$trashPath = '/files_trashbin/files/' . $filename . '.d' . $timestamp;
 
@@ -329,11 +376,12 @@ class Trashbin {
 	 * @param string $owner owner user id
 	 * @param string $ownerPath path relative to the owner's home storage
 	 * @param integer $timestamp when the file was deleted
+	 * @param IStorage|null $sourceStorage
 	 * @param bool $forceCopy true to only make a copy of the versions into the trashbin
+	 * @throws Exceptions\CopyRecursiveException
 	 */
 	private static function retainVersions($filename, $owner, $ownerPath, $timestamp, $sourceStorage = null, $forceCopy = false) {
 		if (\OCP\App::isEnabled('files_versions') && !empty($ownerPath)) {
-
 			$copyKeysResult = false;
 
 			/**
@@ -349,13 +397,12 @@ class Trashbin {
 
 			if ($rootView->is_dir($owner . '/files_versions/' . $ownerPath)) {
 				if ($owner !== $user || $forceCopy) {
-					self::copy_recursive($owner . '/files_versions/' . $ownerPath, $owner . '/files_trashbin/versions/' . basename($ownerPath) . '.d' . $timestamp, $rootView);
+					self::copy_recursive($owner . '/files_versions/' . $ownerPath, $owner . '/files_trashbin/versions/' . \basename($ownerPath) . '.d' . $timestamp, $rootView);
 				}
 				if (!$forceCopy) {
 					self::move($rootView, $owner . '/files_versions/' . $ownerPath, $user . '/files_trashbin/versions/' . $filename . '.d' . $timestamp);
 				}
-			} else if ($versions = \OCA\Files_Versions\Storage::getVersions($owner, $ownerPath)) {
-
+			} elseif ($versions = \OCA\Files_Versions\Storage::getVersions($owner, $ownerPath)) {
 				foreach ($versions as $v) {
 					if ($owner !== $user || $forceCopy) {
 						self::copy($rootView, $owner . '/files_versions' . $v['path'] . '.v' . $v['version'], $owner . '/files_trashbin/versions/' . $v['name'] . '.v' . $v['version'] . '.d' . $timestamp);
@@ -367,7 +414,8 @@ class Trashbin {
 			}
 
 			if ($copyKeysResult === true) {
-				$sourceStorage->deleteAllFileKeys($filename);
+				$filePath = $rootView->getAbsolutePath('/files/' . $ownerPath);
+				$sourceStorage->deleteAllFileKeys($filePath);
 			}
 		}
 	}
@@ -494,9 +542,7 @@ class Trashbin {
 	 * @return false|null
 	 */
 	private static function restoreVersions(View $view, $file, $filename, $uniqueFilename, $location, $timestamp) {
-
 		if (\OCP\App::isEnabled('files_versions')) {
-
 			$user = User::getUser();
 			$rootView = new View('/');
 
@@ -517,7 +563,7 @@ class Trashbin {
 
 			if ($view->is_dir('/files_trashbin/versions/' . $file)) {
 				$rootView->rename(Filesystem::normalizePath($user . '/files_trashbin/versions/' . $file), Filesystem::normalizePath($owner . '/files_versions/' . $ownerPath));
-			} else if ($versions = self::getVersionsFromTrash($versionedFile, $timestamp, $user)) {
+			} elseif ($versions = self::getVersionsFromTrash($versionedFile, $timestamp, $user)) {
 				foreach ($versions as $v) {
 					if ($timestamp) {
 						$rootView->rename($user . '/files_trashbin/versions/' . $versionedFile . '.v' . $v . '.d' . $timestamp, $owner . '/files_versions/' . $ownerPath . '.v' . $v);
@@ -539,7 +585,7 @@ class Trashbin {
 
 		// Array to store the relative path in (after the file is deleted, the view won't be able to relativise the path anymore)
 		$filePaths = [];
-		foreach($fileInfos as $fileInfo){
+		foreach ($fileInfos as $fileInfo) {
 			$filePaths[] = $view->getRelativePath($fileInfo->getPath());
 		}
 		unset($fileInfos); // save memory
@@ -548,7 +594,7 @@ class Trashbin {
 		\OC_Hook::emit('\OCP\Trashbin', 'preDeleteAll', ['paths' => $filePaths]);
 
 		// Single-File Hooks
-		foreach($filePaths as $path){
+		foreach ($filePaths as $path) {
 			self::emitTrashbinPreDelete($path);
 		}
 
@@ -561,7 +607,7 @@ class Trashbin {
 		\OC_Hook::emit('\OCP\Trashbin', 'deleteAll', ['paths' => $filePaths]);
 
 		// Single-File Hooks
-		foreach($filePaths as $path){
+		foreach ($filePaths as $path) {
 			self::emitTrashbinPostDelete($path);
 		}
 
@@ -575,7 +621,7 @@ class Trashbin {
 	 * wrapper function to emit the 'preDelete' hook of \OCP\Trashbin before a file is deleted
 	 * @param string $path
 	 */
-	protected static function emitTrashbinPreDelete($path){
+	protected static function emitTrashbinPreDelete($path) {
 		\OC_Hook::emit('\OCP\Trashbin', 'preDelete', ['path' => $path]);
 	}
 
@@ -583,7 +629,7 @@ class Trashbin {
 	 * wrapper function to emit the 'delete' hook of \OCP\Trashbin after a file has been deleted
 	 * @param string $path
 	 */
-	protected static function emitTrashbinPostDelete($path){
+	protected static function emitTrashbinPostDelete($path) {
 		\OC_Hook::emit('\OCP\Trashbin', 'delete', ['path' => $path]);
 	}
 
@@ -636,7 +682,7 @@ class Trashbin {
 			if ($view->is_dir('files_trashbin/versions/' . $file)) {
 				$size += self::calculateSize(new View('/' . $user . '/files_trashbin/versions/' . $file));
 				$view->unlink('files_trashbin/versions/' . $file);
-			} else if ($versions = self::getVersionsFromTrash($filename, $timestamp, $user)) {
+			} elseif ($versions = self::getVersionsFromTrash($filename, $timestamp, $user)) {
 				foreach ($versions as $v) {
 					if ($timestamp) {
 						$size += $view->filesize('/files_trashbin/versions/' . $filename . '.v' . $v . '.d' . $timestamp);
@@ -664,8 +710,6 @@ class Trashbin {
 
 		if ($timestamp) {
 			$filename = $filename . '.d' . $timestamp;
-		} else {
-			$filename = $filename;
 		}
 
 		$target = Filesystem::normalizePath('files_trashbin/files/' . $filename);
@@ -683,61 +727,14 @@ class Trashbin {
 		return $query->execute([$uid]);
 	}
 
-	/**
-	 * calculate remaining free space for trash bin
-	 *
-	 * @param integer $trashbinSize current size of the trash bin
-	 * @param string $user
-	 * @return int available free space for trash bin
-	 */
-	private static function calculateFreeSpace($trashbinSize, $user) {
-		$softQuota = true;
-		$userObject = \OC::$server->getUserManager()->get($user);
-		if(is_null($userObject)) {
-			return 0;
-		}
-		$quota = \OC_Util::getUserQuota($userObject);
-		if ($quota === \OCP\Files\FileInfo::SPACE_UNLIMITED) {
-			$quota = Filesystem::free_space('/');
-			$softQuota = false;
-			// inf or unknown free space
-			if ($quota < 0) {
-				$quota = PHP_INT_MAX;
-			}
-		} else {
-			$quota = \OCP\Util::computerFileSize($quota);
-		}
-
-		// calculate available space for trash bin
-		// subtract size of files and current trash bin size from quota
-		if ($softQuota) {
-			$userFolder = \OC::$server->getUserFolder($user);
-			if(is_null($userFolder)) {
-				return 0;
-			}
-			$free = $quota - $userFolder->getSize(); // remaining free space for user
-			if ($free > 0) {
-				$availableSpace = ($free * self::DEFAULTMAXSIZE / 100) - $trashbinSize; // how much space can be used for versions
-			} else {
-				$availableSpace = $free - $trashbinSize;
-			}
-		} else {
-			$availableSpace = $quota;
-		}
-
-		return $availableSpace;
-	}
-
 	/**
 	 * resize trash bin if necessary after a new file was added to ownCloud
 	 *
 	 * @param string $user user id
 	 */
 	public static function resizeTrash($user) {
-
 		$size = self::getTrashbinSize($user);
-
-		$freeSpace = self::calculateFreeSpace($size, $user);
+		$freeSpace = self::getQuota()->calculateFreeSpace($size, $user);
 
 		if ($freeSpace < 0) {
 			self::scheduleExpire($user);
@@ -751,7 +748,7 @@ class Trashbin {
 	 */
 	public static function expire($user) {
 		$trashBinSize = self::getTrashbinSize($user);
-		$availableSpace = self::calculateFreeSpace($trashBinSize, $user);
+		$availableSpace = self::getQuota()->calculateFreeSpace($trashBinSize, $user);
 
 		$dirContent = Helper::getTrashFiles('/', $user, 'mtime');
 
@@ -761,7 +758,15 @@ class Trashbin {
 		$availableSpace += $delSize;
 
 		// delete files from trash until we meet the trash bin size limit again
-		self::deleteFiles(array_slice($dirContent, $count), $user, $availableSpace);
+		self::deleteFiles(\array_slice($dirContent, $count), $user, $availableSpace);
+	}
+
+	/**
+	 * @return Quota
+	 */
+	protected static function getQuota() {
+		$application = new Application();
+		return $application->getContainer()->query('Quota');
 	}
 
 	/**
@@ -794,7 +799,13 @@ class Trashbin {
 			foreach ($files as $file) {
 				if ($availableSpace < 0 && $expiration->isExpired($file['mtime'], true)) {
 					$tmp = self::delete($file['name'], $user, $file['mtime']);
-					\OCP\Util::writeLog('files_trashbin', 'remove "' . $file['name'] . '" (' . $tmp . 'B) to meet the limit of trash bin size (50% of available quota)', \OCP\Util::INFO);
+					$message = \sprintf(
+						'remove "%s" (%dB) to meet the limit of trash bin size (%d%% of available quota)',
+						$file['name'],
+						$tmp,
+						self::getQuota()->getPurgeLimit()
+					);
+					\OCP\Util::writeLog('files_trashbin', $message, \OCP\Util::INFO);
 					$availableSpace += $tmp;
 					$size += $tmp;
 				} else {
@@ -887,7 +898,7 @@ class Trashbin {
 		//force rescan of versions, local storage may not have updated the cache
 		if (!self::$scannedVersions) {
 			/** @var \OC\Files\Storage\Storage $storage */
-			list($storage,) = $view->resolvePath('/');
+			list($storage, ) = $view->resolvePath('/');
 			$storage->getScanner()->scan('files_trashbin/versions');
 			self::$scannedVersions = true;
 		}
@@ -895,19 +906,19 @@ class Trashbin {
 		if ($timestamp) {
 			// fetch for old versions
 			$matches = $view->searchRaw($filename . '.v%.d' . $timestamp);
-			$offset = -strlen($timestamp) - 2;
+			$offset = -\strlen($timestamp) - 2;
 		} else {
 			$matches = $view->searchRaw($filename . '.v%');
 		}
 
-		if (is_array($matches)) {
+		if (\is_array($matches)) {
 			foreach ($matches as $ma) {
 				if ($timestamp) {
-					$parts = explode('.v', substr($ma['path'], 0, $offset));
-					$versions[] = (end($parts));
+					$parts = \explode('.v', \substr($ma['path'], 0, $offset));
+					$versions[] = (\end($parts));
 				} else {
-					$parts = explode('.v', $ma);
-					$versions[] = (end($parts));
+					$parts = \explode('.v', $ma);
+					$versions[] = (\end($parts));
 				}
 			}
 		}
@@ -923,11 +934,11 @@ class Trashbin {
 	 * @return string with unique extension
 	 */
 	private static function getUniqueFilename($location, $filename, View $view) {
-		$ext = pathinfo($filename, PATHINFO_EXTENSION);
-		$name = pathinfo($filename, PATHINFO_FILENAME);
+		$ext = \pathinfo($filename, PATHINFO_EXTENSION);
+		$name = \pathinfo($filename, PATHINFO_FILENAME);
 		$l = \OC::$server->getL10N('files_trashbin');
 
-		$location = '/' . trim($location, '/');
+		$location = '/' . \trim($location, '/');
 
 		// if extension is not empty we set a dot in front of it
 		if ($ext !== '') {
@@ -956,7 +967,7 @@ class Trashbin {
 	 */
 	private static function calculateSize($view) {
 		$root = \OC::$server->getConfig()->getSystemValue('datadirectory') . $view->getAbsolutePath('');
-		if (!file_exists($root)) {
+		if (!\file_exists($root)) {
 			return 0;
 		}
 		$iterator = new \RecursiveIteratorIterator(new \RecursiveDirectoryIterator($root), \RecursiveIteratorIterator::CHILD_FIRST);
@@ -970,7 +981,7 @@ class Trashbin {
 		$iterator->rewind();
 		while ($iterator->valid()) {
 			$path = $iterator->current();
-			$relpath = substr($path, strlen($root) - 1);
+			$relpath = \substr($path, \strlen($root) - 1);
 			if (!$view->is_dir($relpath)) {
 				$size += $view->filesize($relpath);
 			}
@@ -991,6 +1002,25 @@ class Trashbin {
 		return isset($fileInfo['size']) ? $fileInfo['size'] : 0;
 	}
 
+	/**
+	 * Register listeners
+	 */
+	public function registerListeners() {
+		$this->eventDispatcher->addListener(
+			'files.resolvePrivateLink',
+			function (GenericEvent $event) {
+				$uid = $event->getArgument('uid');
+				$fileId = $event->getArgument('fileid');
+
+				$link = $this->resolvePrivateLink($uid, $fileId);
+
+				if ($link !== null) {
+					$event->setArgument('resolvedWebLink', $link);
+				}
+			}
+		);
+	}
+
 	/**
 	 * register hooks
 	 */
@@ -1007,6 +1037,36 @@ class Trashbin {
 		\OCP\Util::connectHook('OC_Filesystem', 'post_rename', 'OCA\Files_Trashbin\Storage', 'postRenameHook');
 	}
 
+	/**
+	 * Resolves web URL that points to the trashbin view of the given file
+	 *
+	 * @param string $uid user id
+	 * @param string $fileId file id
+	 * @return string|null view URL or null if the file is not found or not accessible
+	 */
+	public function resolvePrivateLink($uid, $fileId) {
+		if ($this->rootFolder->nodeExists($uid . '/files_trashbin/files/')) {
+			$baseFolder = $this->rootFolder->get($uid . '/files_trashbin/files/');
+			$files = $baseFolder->getById($fileId);
+			if (!empty($files)) {
+				$params['view'] = 'trashbin';
+				$file = \current($files);
+				if ($file instanceof Folder) {
+					// set the full path to enter the folder
+					$params['dir'] = $baseFolder->getRelativePath($file->getPath());
+				} else {
+					// set parent path as dir
+					$params['dir'] = $baseFolder->getRelativePath($file->getParent()->getPath());
+					// and scroll to the entry
+					$params['scrollto'] = $file->getName();
+				}
+				return $this->urlGenerator->linkToRoute('files.view.index', $params);
+			}
+		}
+
+		return null;
+	}
+
 	/**
 	 * check if trash bin is empty for a given user
 	 *
@@ -1014,10 +1074,9 @@ class Trashbin {
 	 * @return bool
 	 */
 	public static function isEmpty($user) {
-
 		$view = new View('/' . $user . '/files_trashbin');
 		if ($view->is_dir('/files') && $dh = $view->opendir('/files')) {
-			while ($file = readdir($dh)) {
+			while ($file = \readdir($dh)) {
 				if (!Filesystem::isIgnoredDir($file)) {
 					return false;
 				}
