@@ -4,8 +4,9 @@ OC.L10N.register(
     "Could not revert: %s" : "Não foi possível reverter: %s",
     "Versions" : "Versões",
     "Failed to revert {file} to revision {timestamp}." : "Falhou a recuperação do ficheiro {file} para a revisão {timestamp}.",
-    "More versions..." : "Mais versões...",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
+    "Restore" : "Restaurar",
     "No other versions available" : "Não existem versões mais antigas",
-    "Restore" : "Restaurar"
+    "More versions..." : "Mais versões..."
 },
 "nplurals=2; plural=(n != 1);");
