@@ -2,7 +2,7 @@
 /**
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -44,7 +44,7 @@ class Expiration {
 	/** @var bool */
 	private $canPurgeToSaveSpace;
 
-	public function __construct(IConfig $config,ITimeFactory $timeFactory){
+	public function __construct(IConfig $config, ITimeFactory $timeFactory) {
 		$this->timeFactory = $timeFactory;
 		$this->retentionObligation = $config->getSystemValue('versions_retention_obligation', 'auto');
 
@@ -57,14 +57,14 @@ class Expiration {
 	 * Is versions expiration enabled
 	 * @return bool
 	 */
-	public function isEnabled(){
+	public function isEnabled() {
 		return $this->retentionObligation !== 'disabled';
 	}
 
 	/**
 	 * Is default expiration active
 	 */
-	public function shouldAutoExpire(){
+	public function shouldAutoExpire() {
 		return $this->minAge === self::NO_OBLIGATION
 				|| $this->maxAge === self::NO_OBLIGATION;
 	}
@@ -75,7 +75,7 @@ class Expiration {
 	 * @param bool $quotaExceeded
 	 * @return bool
 	 */
-	public function isExpired($timestamp, $quotaExceeded = false){
+	public function isExpired($timestamp, $quotaExceeded = false) {
 		// No expiration if disabled
 		if (!$this->isEnabled()) {
 			return false;
@@ -116,7 +116,7 @@ class Expiration {
 	 * Get maximal retention obligation as a timestamp
 	 * @return int
 	 */
-	public function getMaxAgeAsTimestamp(){
+	public function getMaxAgeAsTimestamp() {
 		$maxAge = false;
 		if ($this->isEnabled() && $this->maxAge !== self::NO_OBLIGATION) {
 			$time = $this->timeFactory->getTime();
@@ -126,26 +126,26 @@ class Expiration {
 	}
 
 	/**
-	* Read versions_retention_obligation, validate it 
+	* Read versions_retention_obligation, validate it
 	* and set private members accordingly
 	*/
-	private function parseRetentionObligation(){
-		$splitValues = explode(',', $this->retentionObligation);
+	private function parseRetentionObligation() {
+		$splitValues = \explode(',', $this->retentionObligation);
 		if (!isset($splitValues[0])) {
 			$minValue = 'auto';
 		} else {
-			$minValue = trim($splitValues[0]);
+			$minValue = \trim($splitValues[0]);
 		}
 
 		if (!isset($splitValues[1])) {
 			$maxValue = 'auto';
 		} else {
-			$maxValue = trim($splitValues[1]);
+			$maxValue = \trim($splitValues[1]);
 		}
 
 		$isValid = true;
 		// Validate
-		if (!ctype_digit($minValue) && $minValue !== 'auto') {
+		if (!\ctype_digit($minValue) && $minValue !== 'auto') {
 			$isValid = false;
 			\OC::$server->getLogger()->warning(
 					$minValue . ' is not a valid value for minimal versions retention obligation. Check versions_retention_obligation in your config.php. Falling back to auto.',
@@ -153,7 +153,7 @@ class Expiration {
 			);
 		}
 
-		if (!ctype_digit($maxValue) && $maxValue !== 'auto') {
+		if (!\ctype_digit($maxValue) && $maxValue !== 'auto') {
 			$isValid = false;
 			\OC::$server->getLogger()->warning(
 					$maxValue . ' is not a valid value for maximal versions retention obligation. Check versions_retention_obligation in your config.php. Falling back to auto.',
@@ -161,12 +161,11 @@ class Expiration {
 			);
 		}
 
-		if (!$isValid){
+		if (!$isValid) {
 			$minValue = 'auto';
 			$maxValue = 'auto';
 		}
 
-
 		if ($minValue === 'auto' && $maxValue === 'auto') {
 			// Default: Delete anytime if space needed
 			$this->minAge = self::NO_OBLIGATION;
@@ -174,13 +173,13 @@ class Expiration {
 			$this->canPurgeToSaveSpace = true;
 		} elseif ($minValue !== 'auto' && $maxValue === 'auto') {
 			// Keep for X days but delete anytime if space needed
-			$this->minAge = intval($minValue);
+			$this->minAge = \intval($minValue);
 			$this->maxAge = self::NO_OBLIGATION;
 			$this->canPurgeToSaveSpace = true;
 		} elseif ($minValue === 'auto' && $maxValue !== 'auto') {
 			// Delete anytime if space needed, Delete all older than max automatically
 			$this->minAge = self::NO_OBLIGATION;
-			$this->maxAge = intval($maxValue);
+			$this->maxAge = \intval($maxValue);
 			$this->canPurgeToSaveSpace = true;
 		} elseif ($minValue !== 'auto' && $maxValue !== 'auto') {
 			// Delete all older than max OR older than min if space needed
@@ -190,8 +189,8 @@ class Expiration {
 				$maxValue = $minValue;
 			}
 
-			$this->minAge = intval($minValue);
-			$this->maxAge = intval($maxValue);
+			$this->minAge = \intval($minValue);
+			$this->maxAge = \intval($maxValue);
 			$this->canPurgeToSaveSpace = false;
 		}
 	}
