@@ -20,30 +20,11 @@
  *
  */
 
-use OCA\Notifications\App;
-use OCA\Notifications\Handler;
 use OCP\Util;
 
-\OC::$server->getNotificationManager()->registerApp(function() {
-	return new App(
-		new Handler(
-			\OC::$server->getDatabaseConnection(),
-			\OC::$server->getNotificationManager()
-		)
-	);
-});
-\OC::$server->getNotificationManager()->registerNotifier(
-	function() {
-		return new \OCA\Notifications\Notifier();
-	}, function () {
-	$l = \OC::$server->getL10N('notifications');
-	return [
-		'id' => 'notifications',
-		'name' => $l->t('Admin notifications'),
-	];
-
-});
-
+$application = new \OCA\Notifications\AppInfo\Application();
+$application->setupConsumerAndNotifier();
+$application->setupSymfonyEventListeners();
 // Only display the app on index.php except for public shares
 $request = \OC::$server->getRequest();
 if (\OC::$server->getUserSession() !== null && \OC::$server->getUserSession()->getUser() !== null
