@@ -10,7 +10,7 @@
  * @author Tom Needham <tom@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -32,6 +32,7 @@ namespace OCA\Provisioning_API;
 use OC\OCS\Result;
 use OC_Helper;
 use OCP\API;
+use OCP\Files\FileInfo;
 use OCP\Files\NotFoundException;
 use OCP\IGroup;
 use OCP\IGroupManager;
@@ -64,7 +65,7 @@ class Users {
 								IGroupManager $groupManager,
 								IUserSession $userSession,
 								ILogger $logger,
-								\OC\Authentication\TwoFactorAuth\Manager $twoFactorAuthManager ) {
+								\OC\Authentication\TwoFactorAuth\Manager $twoFactorAuthManager) {
 		$this->userManager = $userManager;
 		$this->groupManager = $groupManager;
 		$this->userSession = $userSession;
@@ -91,28 +92,28 @@ class Users {
 		// Admin? Or SubAdmin?
 		$uid = $user->getUID();
 		$subAdminManager = $this->groupManager->getSubAdmin();
-		if($this->groupManager->isAdmin($uid)){
+		if ($this->groupManager->isAdmin($uid)) {
 			$users = $this->userManager->search($search, $limit, $offset);
-		} else if ($subAdminManager->isSubAdmin($user)) {
+		} elseif ($subAdminManager->isSubAdmin($user)) {
 			$subAdminOfGroups = $subAdminManager->getSubAdminsGroups($user);
 			foreach ($subAdminOfGroups as $key => $group) {
 				$subAdminOfGroups[$key] = $group->getGID();
 			}
 
-			if($offset === null) {
+			if ($offset === null) {
 				$offset = 0;
 			}
 
 			$users = [];
 			foreach ($subAdminOfGroups as $group) {
-				$users = array_merge($users, $this->groupManager->displayNamesInGroup($group, $search));
+				$users = \array_merge($users, $this->groupManager->displayNamesInGroup($group, $search));
 			}
 
-			$users = array_slice($users, $offset, $limit);
+			$users = \array_slice($users, $offset, $limit);
 		} else {
 			return new Result(null, API::RESPOND_UNAUTHORISED);
 		}
-		$users = array_keys($users);
+		$users = \array_keys($users);
 
 		return new Result([
 			'users' => $users
@@ -134,22 +135,22 @@ class Users {
 			return new Result(null, API::RESPOND_UNAUTHORISED);
 		}
 
-		if($this->userManager->userExists($userId)) {
+		if ($this->userManager->userExists($userId)) {
 			$this->logger->error('Failed addUser attempt: User already exists.', ['app' => 'ocs_api']);
 			return new Result(null, 102, 'User already exists');
 		}
 
-		if(is_array($groups)) {
+		if (\is_array($groups)) {
 			foreach ($groups as $group) {
-				if(!$this->groupManager->groupExists($group)){
+				if (!$this->groupManager->groupExists($group)) {
 					return new Result(null, 104, 'group '.$group.' does not exist');
 				}
-				if(!$isAdmin && !$subAdminManager->isSubAdminofGroup($user, $this->groupManager->get($group))) {
+				if (!$isAdmin && !$subAdminManager->isSubAdminofGroup($user, $this->groupManager->get($group))) {
 					return new Result(null, 105, 'insufficient privileges for group '. $group);
 				}
 			}
 		} else {
-			if(!$isAdmin) {
+			if (!$isAdmin) {
 				return new Result(null, 106, 'no group specified (required for subadmins)');
 			}
 		}
@@ -158,7 +159,7 @@ class Users {
 			$newUser = $this->userManager->createUser($userId, $password);
 			$this->logger->info('Successful addUser call with userid: '.$userId, ['app' => 'ocs_api']);
 
-			if (is_array($groups)) {
+			if (\is_array($groups)) {
 				foreach ($groups as $group) {
 					$this->groupManager->get($group)->addUser($newUser);
 					$this->logger->info('Added userid '.$userId.' to group '.$group, ['app' => 'ocs_api']);
@@ -194,23 +195,24 @@ class Users {
 
 		// Check if the target user exists
 		$targetUserObject = $this->userManager->get($userId);
-		if($targetUserObject === null) {
+		if ($targetUserObject === null) {
 			return new Result(null, API::RESPOND_NOT_FOUND, 'The requested user could not be found');
 		}
 
 		// Admin? Or SubAdmin?
-		if($this->groupManager->isAdmin($currentLoggedInUser->getUID())
+		if ($this->groupManager->isAdmin($currentLoggedInUser->getUID())
 			|| $this->groupManager->getSubAdmin()->isUserAccessible($currentLoggedInUser, $targetUserObject)) {
 			$data['enabled'] = $targetUserObject->isEnabled() ? 'true' : 'false';
 		} else {
 			// Check they are looking up themselves
-			if($currentLoggedInUser->getUID() !== $userId) {
+			if ($currentLoggedInUser->getUID() !== $userId) {
 				return new Result(null, API::RESPOND_UNAUTHORISED);
 			}
 		}
 
 		// Find the data
 		$data['quota'] = $this->fillStorageInfo($userId);
+		$data['quota']['definition'] = $targetUserObject->getQuota();
 		$data['email'] = $targetUserObject->getEMailAddress();
 		$data['displayname'] = $targetUserObject->getDisplayName();
 		$data['home'] = $targetUserObject->getHome();
@@ -236,24 +238,24 @@ class Users {
 		}
 
 		$targetUser = $this->userManager->get($targetUserId);
-		if($targetUser === null) {
+		if ($targetUser === null) {
 			return new Result(null, 997);
 		}
 
-		if($targetUserId === $currentLoggedInUser->getUID()) {
+		if ($targetUserId === $currentLoggedInUser->getUID()) {
 			// Editing self (display, email)
 			$permittedFields[] = 'display';
 			$permittedFields[] = 'email';
 			$permittedFields[] = 'password';
 			$permittedFields[] = 'two_factor_auth_enabled';
 			// If admin they can edit their own quota
-			if($this->groupManager->isAdmin($currentLoggedInUser->getUID())) {
+			if ($this->groupManager->isAdmin($currentLoggedInUser->getUID())) {
 				$permittedFields[] = 'quota';
 			}
 		} else {
 			// Check if admin / subadmin
 			$subAdminManager = $this->groupManager->getSubAdmin();
-			if($subAdminManager->isUserAccessible($currentLoggedInUser, $targetUser)
+			if ($subAdminManager->isUserAccessible($currentLoggedInUser, $targetUser)
 			|| $this->groupManager->isAdmin($currentLoggedInUser->getUID())) {
 				// They have permissions over the user
 				$permittedFields[] = 'display';
@@ -267,32 +269,26 @@ class Users {
 			}
 		}
 		// Check if permitted to edit this field
-		if(!in_array($parameters['_put']['key'], $permittedFields)) {
+		if (!\in_array($parameters['_put']['key'], $permittedFields)) {
 			return new Result(null, 997);
 		}
 		// Process the edit
-		switch($parameters['_put']['key']) {
+		switch ($parameters['_put']['key']) {
 			case 'display':
 				$targetUser->setDisplayName($parameters['_put']['value']);
 				break;
 			case 'quota':
 				$quota = $parameters['_put']['value'];
-				if($quota !== 'none' and $quota !== 'default') {
-					if (is_numeric($quota)) {
-						$quota = floatval($quota);
+				if ($quota !== 'none' && $quota !== 'default') {
+					if (\is_numeric($quota)) {
+						$quota = \floatval($quota);
 					} else {
 						$quota = Util::computerFileSize($quota);
 					}
 					if ($quota === false) {
 						return new Result(null, 103, "Invalid quota value {$parameters['_put']['value']}");
 					}
-					if($quota === 0) {
-						$quota = 'default';
-					}else if($quota === -1) {
-						$quota = 'none';
-					} else {
-						$quota = Util::humanFileSize($quota);
-					}
+					$quota = Util::humanFileSize($quota);
 				}
 				$targetUser->setQuota($quota);
 				break;
@@ -311,7 +307,7 @@ class Users {
 				}
 				break;
 			case 'email':
-				if(filter_var($parameters['_put']['value'], FILTER_VALIDATE_EMAIL)) {
+				if (\filter_var($parameters['_put']['value'], FILTER_VALIDATE_EMAIL)) {
 					$targetUser->setEMailAddress($parameters['_put']['value']);
 				} else {
 					return new Result(null, 102);
@@ -337,18 +333,18 @@ class Users {
 
 		$targetUser = $this->userManager->get($parameters['userid']);
 
-		if($targetUser === null || $targetUser->getUID() === $currentLoggedInUser->getUID()) {
+		if ($targetUser === null || $targetUser->getUID() === $currentLoggedInUser->getUID()) {
 			return new Result(null, 101);
 		}
 
 		// If not permitted
 		$subAdminManager = $this->groupManager->getSubAdmin();
-		if(!$this->groupManager->isAdmin($currentLoggedInUser->getUID()) && !$subAdminManager->isUserAccessible($currentLoggedInUser, $targetUser)) {
+		if (!$this->groupManager->isAdmin($currentLoggedInUser->getUID()) && !$subAdminManager->isUserAccessible($currentLoggedInUser, $targetUser)) {
 			return new Result(null, 997);
 		}
 
 		// Go ahead with the delete
-		if($targetUser->delete()) {
+		if ($targetUser->delete()) {
 			return new Result(null, 100);
 		} else {
 			return new Result(null, 101);
@@ -384,13 +380,13 @@ class Users {
 		}
 
 		$targetUser = $this->userManager->get($parameters['userid']);
-		if($targetUser === null || $targetUser->getUID() === $currentLoggedInUser->getUID()) {
+		if ($targetUser === null || $targetUser->getUID() === $currentLoggedInUser->getUID()) {
 			return new Result(null, 101);
 		}
 
 		// If not permitted
 		$subAdminManager = $this->groupManager->getSubAdmin();
-		if(!$this->groupManager->isAdmin($currentLoggedInUser->getUID()) && !$subAdminManager->isUserAccessible($currentLoggedInUser, $targetUser)) {
+		if (!$this->groupManager->isAdmin($currentLoggedInUser->getUID()) && !$subAdminManager->isUserAccessible($currentLoggedInUser, $targetUser)) {
 			return new Result(null, 997);
 		}
 
@@ -411,11 +407,11 @@ class Users {
 		}
 
 		$targetUser = $this->userManager->get($parameters['userid']);
-		if($targetUser === null) {
+		if ($targetUser === null) {
 			return new Result(null, API::RESPOND_NOT_FOUND);
 		}
 
-		if($targetUser->getUID() === $loggedInUser->getUID() || $this->groupManager->isAdmin($loggedInUser->getUID())) {
+		if ($targetUser->getUID() === $loggedInUser->getUID() || $this->groupManager->isAdmin($loggedInUser->getUID())) {
 			// Self lookup or admin lookup
 			return new Result([
 				'groups' => $this->groupManager->getUserGroupIds($targetUser, 'management')
@@ -424,13 +420,13 @@ class Users {
 			$subAdminManager = $this->groupManager->getSubAdmin();
 
 			// Looking up someone else
-			if($subAdminManager->isUserAccessible($loggedInUser, $targetUser)) {
+			if ($subAdminManager->isUserAccessible($loggedInUser, $targetUser)) {
 				// Return the group that the method caller is subadmin of for the user in question
 				$getSubAdminsGroups = $subAdminManager->getSubAdminsGroups($loggedInUser);
 				foreach ($getSubAdminsGroups as $key => $group) {
 					$getSubAdminsGroups[$key] = $group->getGID();
 				}
-				$groups = array_intersect(
+				$groups = \array_intersect(
 					$getSubAdminsGroups,
 					$this->groupManager->getUserGroupIds($targetUser)
 				);
@@ -440,7 +436,6 @@ class Users {
 				return new Result(null, 997);
 			}
 		}
-
 	}
 
 	/**
@@ -485,13 +480,12 @@ class Users {
 			return new Result(null, 102);
 		}
 
-		// Check they're an admin or subadmin of the group
-		if(!$this->canUserManageGroup($user, $group)) {
+		if (!$this->groupManager->isAdmin($user->getUID())) {
 			return new Result(null, 104);
 		}
 
 		$targetUser = $this->userManager->get($parameters['userid']);
-		if($targetUser === null) {
+		if ($targetUser === null) {
 			return new Result(null, 103);
 		}
 
@@ -517,22 +511,22 @@ class Users {
 		}
 
 		$group = $this->groupManager->get($group);
-		if($group === null) {
+		if ($group === null) {
 			return new Result(null, 102);
 		}
 
-		if(!$this->canUserManageGroup($loggedInUser, $group)) {
+		if (!$this->canUserManageGroup($loggedInUser, $group)) {
 			return new Result(null, 104);
 		}
 
 		$targetUser = $this->userManager->get($parameters['userid']);
-		if($targetUser === null) {
+		if ($targetUser === null) {
 			return new Result(null, 103);
 		}
 		// Check they aren't removing themselves from 'admin' or their 'subadmin; group
-		if($parameters['userid'] === $loggedInUser->getUID()) {
-			if($this->groupManager->isAdmin($loggedInUser->getUID())) {
-				if($group->getGID() === 'admin') {
+		if ($parameters['userid'] === $loggedInUser->getUID()) {
+			if ($this->groupManager->isAdmin($loggedInUser->getUID())) {
+				if ($group->getGID() === 'admin') {
 					return new Result(null, 105, 'Cannot remove yourself from the admin group');
 				}
 			} else {
@@ -543,7 +537,7 @@ class Users {
 					$subAdminGroups[$key] = $group->getGID();
 				}
 
-				if(in_array($group->getGID(), $subAdminGroups, true)) {
+				if (\in_array($group->getGID(), $subAdminGroups, true)) {
 					return new Result(null, 105, 'Cannot remove yourself from this group as you are a SubAdmin');
 				}
 			}
@@ -565,15 +559,15 @@ class Users {
 		$user = $this->userManager->get($parameters['userid']);
 
 		// Check if the user exists
-		if($user === null) {
+		if ($user === null) {
 			return new Result(null, 101, 'User does not exist');
 		}
 		// Check if group exists
-		if($group === null) {
+		if ($group === null) {
 			return new Result(null, 102, 'Group:'.$_POST['groupid'].' does not exist');
 		}
 		// Check if trying to make subadmin of admin group
-		if(strtolower($_POST['groupid']) === 'admin') {
+		if (\strtolower($_POST['groupid']) === 'admin') {
 			return new Result(null, 103, 'Cannot create subadmins for admin group');
 		}
 
@@ -584,7 +578,7 @@ class Users {
 			return new Result(null, 100);
 		}
 		// Go
-		if($subAdminManager->createSubAdmin($user, $group)) {
+		if ($subAdminManager->createSubAdmin($user, $group)) {
 			return new Result(null, 100);
 		} else {
 			return new Result(null, 103, 'Unknown error occurred');
@@ -603,20 +597,20 @@ class Users {
 		$subAdminManager = $this->groupManager->getSubAdmin();
 
 		// Check if the user exists
-		if($user === null) {
+		if ($user === null) {
 			return new Result(null, 101, 'User does not exist');
 		}
 		// Check if the group exists
-		if($group === null) {
+		if ($group === null) {
 			return new Result(null, 101, 'Group does not exist');
 		}
 		// Check if they are a subadmin of this said group
-		if(!$subAdminManager->isSubAdminofGroup($user, $group)) {
+		if (!$subAdminManager->isSubAdminofGroup($user, $group)) {
 			return new Result(null, 102, 'User is not a subadmin of this group');
 		}
 
 		// Go
-		if($subAdminManager->deleteSubAdmin($user, $group)) {
+		if ($subAdminManager->deleteSubAdmin($user, $group)) {
 			return new Result(null, 100);
 		} else {
 			return new Result(null, 103, 'Unknown error occurred');
@@ -632,7 +626,7 @@ class Users {
 	public function getUserSubAdminGroups($parameters) {
 		$user = $this->userManager->get($parameters['userid']);
 		// Check if the user exists
-		if($user === null) {
+		if ($user === null) {
 			return new Result(null, 101, 'User does not exist');
 		}
 
@@ -642,7 +636,7 @@ class Users {
 			$groups[$key] = $group->getGID();
 		}
 
-		if(!$groups) {
+		if (!$groups) {
 			return new Result(null, 102, 'Unknown error occurred');
 		} else {
 			return new Result($groups);
@@ -668,6 +662,7 @@ class Users {
 		} catch (NotFoundException $ex) {
 			$data = [];
 		}
+
 		return $data;
 	}
 }
