@@ -1,19 +1,28 @@
 OC.L10N.register(
     "systemtags",
     {
-    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
-    "%1$s assigned system tag %3$s" : "%1$s blev tilldelad systemtagg %3$s",
-    "%1$s unassigned system tag %3$s" : "%1$s unassigned system tag %3$s",
-    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
-    "%1$s deleted system tag %2$s" : "%1$s raderade systemtagg %2$s",
-    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
-    "%1$s assigned system tag %3$s to %2$s" : "%1$s tilldelade systemtagg %3$s till %2$s",
-    "%s (invisible)" : "%s (osynlig)",
     "Tags" : "Taggar",
     "Tagged files" : "Taggade filer",
     "Select tags to filter by" : "Välj taggar att filtrera med",
     "Please select tags to filter by" : "Vänligen välj taggar att filtrera med",
     "No files found for the selected tags" : "Inga filer hittade för de valda taggarna",
+    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
+    "You assigned system tag %3$s" : "Du tilldelade systemtagg %3$s",
+    "%1$s assigned system tag %3$s" : "%1$s blev tilldelad systemtagg %3$s",
+    "You unassigned system tag %3$s" : "Du tog bort tilldelning av systemtag %3$s",
+    "%1$s unassigned system tag %3$s" : "%1$s tog bort tilldelad systemtagg %3$s",
+    "You created system tag %2$s" : "Du skapade systemtagg %2$s",
+    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
+    "You deleted system tag %2$s" : "Du tog bort systemtagg %2$s",
+    "%1$s deleted system tag %2$s" : "%1$s raderade systemtagg %2$s",
+    "You updated system tag %3$s to %2$s" : "Du uppdaterade systemtagg %3$s till %2$s",
+    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
+    "You assigned system tag %3$s to %2$s" : "Du tilldelade systemtagg %3$s till %2$s",
+    "%1$s assigned system tag %3$s to %2$s" : "%1$s tilldelade systemtagg %3$s till %2$s",
+    "You unassigned system tag %3$s from %2$s" : "Du tog bort tilldelad systemtagg %3$s från %2$s",
+    "%1$s unassigned system tag %3$s from %2$s" : "%1$s tog bort tilldelad systemtagg %3$s från %2$s",
+    "%s (restricted)" : "%s (begränsad)",
+    "%s (invisible)" : "%s (osynlig)",
     "No files in here" : "Inga filer kunde hittas",
     "No entries found in this folder" : "nga Filer hittades i denna mapp",
     "Name" : "Namn",
