@@ -2,7 +2,7 @@
 /**
  * @author Joas Schilling <coding@schilljs.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -114,9 +114,9 @@ class ListConfigs extends Base {
 		$configs = [];
 		foreach ($keys as $key) {
 			if ($noSensitiveValues) {
-				$value = $this->systemConfig->getFilteredValue($key, serialize(null));
+				$value = $this->systemConfig->getFilteredValue($key, \serialize(null));
 			} else {
-				$value = $this->systemConfig->getValue($key, serialize(null));
+				$value = $this->systemConfig->getValue($key, \serialize(null));
 			}
 
 			if ($value !== 'N;') {
