@@ -3,7 +3,7 @@
  * @author Joas Schilling <coding@schilljs.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -67,7 +67,7 @@ class ListModules extends Base {
 	 */
 	protected function writeModuleList(InputInterface $input, OutputInterface $output, $items) {
 		if ($input->getOption('output') === self::OUTPUT_FORMAT_PLAIN) {
-			array_walk($items, function(&$item) {
+			\array_walk($items, function (&$item) {
 				if (!$item['default']) {
 					$item = $item['displayName'];
 				} else {
