@@ -3,7 +3,7 @@
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -75,7 +75,7 @@ class SignApp extends Command {
 		$path = $input->getOption('path');
 		$privateKeyPath = $input->getOption('privateKey');
 		$keyBundlePath = $input->getOption('certificate');
-		if(is_null($path) || is_null($privateKeyPath) || is_null($keyBundlePath)) {
+		if ($path === null || $privateKeyPath === null || $keyBundlePath === null) {
 			$documentationUrl = $this->urlGenerator->linkToDocs('developer-code-integrity');
 			$output->writeln('This command requires the --path, --privateKey and --certificate.');
 			$output->writeln('Example: ./occ integrity:sign-app --path="/Users/lukasreschke/Programming/myapp/" --privateKey="/Users/lukasreschke/private/myapp.key" --certificate="/Users/lukasreschke/public/mycert.crt"');
@@ -86,13 +86,13 @@ class SignApp extends Command {
 		$privateKey = $this->fileAccessHelper->file_get_contents($privateKeyPath);
 		$keyBundle = $this->fileAccessHelper->file_get_contents($keyBundlePath);
 
-		if($privateKey === false) {
-			$output->writeln(sprintf('Private key "%s" does not exists.', $privateKeyPath));
+		if ($privateKey === false) {
+			$output->writeln(\sprintf('Private key "%s" does not exists.', $privateKeyPath));
 			return null;
 		}
 
-		if($keyBundle === false) {
-			$output->writeln(sprintf('Certificate "%s" does not exists.', $keyBundlePath));
+		if ($keyBundle === false) {
+			$output->writeln(\sprintf('Certificate "%s" does not exists.', $keyBundlePath));
 			return null;
 		}
 
@@ -104,7 +104,7 @@ class SignApp extends Command {
 		try {
 			$this->checker->writeAppSignature($path, $x509, $rsa);
 			$output->writeln('Successfully signed "'.$path.'"');
-		} catch (\Exception $e){
+		} catch (\Exception $e) {
 			$output->writeln('Error: ' . $e->getMessage());
 			return 1;
 		}
