@@ -3,7 +3,7 @@
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -69,7 +69,7 @@ class SignCore extends Command {
 		$privateKeyPath = $input->getOption('privateKey');
 		$keyBundlePath = $input->getOption('certificate');
 		$path = $input->getOption('path');
-		if(is_null($privateKeyPath) || is_null($keyBundlePath) || is_null($path)) {
+		if ($privateKeyPath === null || $keyBundlePath === null || $path === null) {
 			$output->writeln('--privateKey, --certificate and --path are required.');
 			return null;
 		}
@@ -77,13 +77,13 @@ class SignCore extends Command {
 		$privateKey = $this->fileAccessHelper->file_get_contents($privateKeyPath);
 		$keyBundle = $this->fileAccessHelper->file_get_contents($keyBundlePath);
 
-		if($privateKey === false) {
-			$output->writeln(sprintf('Private key "%s" does not exists.', $privateKeyPath));
+		if ($privateKey === false) {
+			$output->writeln(\sprintf('Private key "%s" does not exists.', $privateKeyPath));
 			return null;
 		}
 
-		if($keyBundle === false) {
-			$output->writeln(sprintf('Certificate "%s" does not exists.', $keyBundlePath));
+		if ($keyBundle === false) {
+			$output->writeln(\sprintf('Certificate "%s" does not exists.', $keyBundlePath));
 			return null;
 		}
 
@@ -96,7 +96,7 @@ class SignCore extends Command {
 		try {
 			$this->checker->writeCoreSignature($x509, $rsa, $path);
 			$output->writeln('Successfully signed "core"');
-		} catch (\Exception $e){
+		} catch (\Exception $e) {
 			$output->writeln('Error: ' . $e->getMessage());
 			return 1;
 		}
