@@ -3,7 +3,7 @@
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -31,7 +31,6 @@ use Symfony\Component\Console\Output\OutputInterface;
 use UnexpectedValueException;
 
 class CreateJs extends Command {
-
 	protected function configure() {
 		$this
 			->setName('l10n:createjs')
@@ -62,7 +61,7 @@ class CreateJs extends Command {
 			$languages= $this->getAllLanguages($path);
 		}
 
-		foreach($languages as $lang) {
+		foreach ($languages as $lang) {
 			$this->writeFiles($app, $path, $lang, $output);
 		}
 	}
@@ -70,16 +69,16 @@ class CreateJs extends Command {
 	private function getAllLanguages($path) {
 		$result = [];
 		foreach (new DirectoryIterator("$path/l10n") as $fileInfo) {
-			if($fileInfo->isDot()) {
+			if ($fileInfo->isDot()) {
 				continue;
 			}
-			if($fileInfo->isDir()) {
+			if ($fileInfo->isDir()) {
 				continue;
 			}
-			if($fileInfo->getExtension() !== 'php') {
+			if ($fileInfo->getExtension() !== 'php') {
 				continue;
 			}
-			$result[]= substr($fileInfo->getBasename(), 0, -4);
+			$result[]= \substr($fileInfo->getBasename(), 0, -4);
 		}
 
 		return $result;
@@ -93,33 +92,33 @@ class CreateJs extends Command {
 
 	private function writeJsFile($app, $path, $lang, OutputInterface $output, $translations, $plurals) {
 		$jsFile = "$path/l10n/$lang.js";
-		if (file_exists($jsFile)) {
+		if (\file_exists($jsFile)) {
 			$output->writeln("File already exists: $jsFile");
 			return;
 		}
 		$content = "OC.L10N.register(\n    \"$app\",\n    {\n    ";
 		$jsTrans = [];
 		foreach ($translations as $id => $val) {
-			if (is_array($val)) {
-				$val = '[ ' . join(',', $val) . ']';
+			if (\is_array($val)) {
+				$val = '[ ' . \join(',', $val) . ']';
 			}
 			$jsTrans[] = "\"$id\" : \"$val\"";
 		}
-		$content .= join(",\n    ", $jsTrans);
+		$content .= \join(",\n    ", $jsTrans);
 		$content .= "\n},\n\"$plurals\");\n";
 
-		file_put_contents($jsFile, $content);
+		\file_put_contents($jsFile, $content);
 		$output->writeln("Javascript translation file generated: $jsFile");
 	}
 
 	private function writeJsonFile($path, $lang, OutputInterface $output, $translations, $plurals) {
 		$jsFile = "$path/l10n/$lang.json";
-		if (file_exists($jsFile)) {
+		if (\file_exists($jsFile)) {
 			$output->writeln("File already exists: $jsFile");
 			return;
 		}
 		$content = ['translations' => $translations, 'pluralForm' => $plurals];
-		file_put_contents($jsFile, json_encode($content));
+		\file_put_contents($jsFile, \json_encode($content));
 		$output->writeln("Json translation file generated: $jsFile");
 	}
 
@@ -127,7 +126,7 @@ class CreateJs extends Command {
 		$phpFile = "$path/l10n/$lang.php";
 		$TRANSLATIONS = [];
 		$PLURAL_FORMS = '';
-		if (!file_exists($phpFile)) {
+		if (!\file_exists($phpFile)) {
 			throw new UnexpectedValueException("PHP translation file <$phpFile> does not exist.");
 		}
 		require $phpFile;
