@@ -2,7 +2,7 @@
 /**
  * @author Robin Appelman <icewind@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -51,13 +51,13 @@ class ImportCertificate extends Base {
 	protected function execute(InputInterface $input, OutputInterface $output) {
 		$path = $input->getArgument('path');
 
-		if (!file_exists($path)) {
+		if (!\file_exists($path)) {
 			$output->writeln('<error>certificate not found</error>');
 			return;
 		}
 
-		$certData = file_get_contents($path);
-		$name = basename($path);
+		$certData = \file_get_contents($path);
+		$name = \basename($path);
 
 		$this->certificateManager->addCertificate($certData, $name);
 	}
