@@ -2,7 +2,7 @@
 /**
  * @author Christoph Wurst <christoph@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -53,12 +53,11 @@ class Disable extends Base {
 	protected function execute(InputInterface $input, OutputInterface $output) {
 		$uid = $input->getArgument('uid');
 		$user = $this->userManager->get($uid);
-		if (is_null($user)) {
+		if ($user === null) {
 			$output->writeln("<error>Invalid UID</error>");
 			return;
 		}
 		$this->manager->disableTwoFactorAuthentication($user);
 		$output->writeln("Two-factor authentication disabled for user $uid");
 	}
-
 }
