@@ -5,7 +5,7 @@
  * @author Joas Schilling <coding@schilljs.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -54,18 +54,22 @@ class Delete extends Command {
 	}
 
 	protected function execute(InputInterface $input, OutputInterface $output) {
-		$user = $this->userManager->get($input->getArgument('uid'));
-		if (is_null($user)) {
-			$output->writeln('<error>User does not exist</error>');
+		$uid = $input->getArgument('uid');
+		$user = $this->userManager->get($uid);
+		if ($user === null) {
+			$output->writeln("<error>User with uid '$uid' does not exist</error>");
 			return 1;
 		}
 
+		$uid = $user->getUID();
+		$displayName = $user->getDisplayName();
+		$email = $user->getEMailAddress();
 		if ($user->delete()) {
-			$output->writeln('<info>The specified user was deleted</info>');
-			return;
+			$output->writeln("<info>User with uid '$uid', display name '$displayName', email '$email' was deleted</info>");
+			return 0;
 		}
 
-		$output->writeln('<error>The specified user could not be deleted. Please check the logs.</error>');
+		$output->writeln("<error>User with uid '$uid', display name '$displayName', email '$email' could not be deleted. Please check the logs.</error>");
 		return 1;
 	}
 }
