@@ -5,7 +5,7 @@
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Pierre Ozoux <pierre@ozoux.net>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -55,13 +55,13 @@ class LastSeen extends Command {
 
 	protected function execute(InputInterface $input, OutputInterface $output) {
 		$user = $this->userManager->get($input->getArgument('uid'));
-		if(is_null($user)) {
+		if ($user === null) {
 			$output->writeln('<error>User does not exist</error>');
 			return;
 		}
 
 		$lastLogin = $user->getLastLogin();
-		if($lastLogin === 0) {
+		if ($lastLogin === 0) {
 			$output->writeln('User ' . $user->getUID() .
 				' has never logged in, yet.');
 		} else {
