@@ -4,6 +4,7 @@ namespace OC\Migrations;
 use OC\User\AccountMapper;
 use OC\User\AccountTermMapper;
 use OC\User\Database;
+use OC\User\Sync\AllUsersIterator;
 use OC\User\SyncService;
 use OCP\Migration\ISimpleMigration;
 use OCP\Migration\IOutput;
@@ -19,12 +20,12 @@ class Version20170221114437 implements ISimpleMigration {
 		$logger = \OC::$server->getLogger();
 		$connection = \OC::$server->getDatabaseConnection();
 		$accountMapper = new AccountMapper($config, $connection, new AccountTermMapper($connection));
-		$syncService = new SyncService($accountMapper, $backend, $config, $logger);
+		$syncService = new SyncService($config, $logger, $accountMapper);
 
 		// insert/update known users
 		$out->info("Insert new users ...");
 		$out->startProgress($backend->countUsers());
-		$syncService->run(function () use ($out) {
+		$syncService->run($backend, new AllUsersIterator($backend), function () use ($out) {
 			$out->advance();
 		});
 		$out->finishProgress();
