@@ -11,7 +11,6 @@
 var oc_debug;
 var oc_webroot;
 
-var oc_current_user = document.getElementsByTagName('head')[0].getAttribute('data-user');
 var oc_requesttoken = document.getElementsByTagName('head')[0].getAttribute('data-requesttoken');
 
 window.oc_config = window.oc_config || {};
@@ -82,7 +81,7 @@ var OC = {
 	 * @type String
 	 * @deprecated use {@link OC.getCurrentUser} instead
 	 */
-	currentUser: (typeof oc_current_user !== 'undefined') ? oc_current_user : false,
+	currentUser: (typeof oc_user !== 'undefined') ? oc_user.uid : false,
 	config: window.oc_config,
 	appConfig: window.oc_appconfig || {},
 	theme: window.oc_defaults || {},
@@ -322,12 +321,13 @@ var OC = {
 	 * @since 9.0.0
 	 */
 	getCurrentUser: function () {
-		if (_.isUndefined(this._currentUserDisplayName)) {
-			this._currentUserDisplayName = document.getElementsByTagName('head')[0].getAttribute('data-user-displayname');
+		if (!_.isUndefined(window.oc_user)) {
+			return oc_user;
 		}
 		return {
-			uid: this.currentUser,
-			displayName: this._currentUserDisplayName
+			uid: null,
+			displayName: null,
+			email: null
 		};
 	},
 
@@ -1663,6 +1663,15 @@ function initCore() {
 	}
 }
 
+/**
+ * Disable the use of globalEval in jQuery 2.1.4.
+ * This is required for API compatibility, yet should not be available all the
+ * same.
+ *
+ * @see https://github.com/jquery/jquery/issues/2432 for further details.
+ */
+$.fn.globalEval = function(){};
+
 $(document).ready(initCore);
 
 /**
