@@ -6,16 +6,8 @@ OC.L10N.register(
     "Invalid image" : "Nevažeća datoteka",
     "No temporary profile picture available, try again" : "Trenutna slika profila nije dostupna, pokušajte ponovo",
     "Couldn't reset password because the token is invalid" : "Nemoguće resetiranje lozinke jer znak nije validan.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Slanje emaila resetovanja nije moguće. Osigurajte se da vam je ispravno korisničko ime.",
     "%s password reset" : "%s lozinka resetovana",
     "Couldn't send reset email. Please contact your administrator." : "Slanje emaila resetovanja nije moguće. Molim kontaktirajte administratora.",
-    "Error loading tags" : "Greška pri učitavanju oznaka",
-    "Tag already exists" : "Oznaka već postoji",
-    "Error deleting tag(s)" : "Greška pri brisanju znaka(ova)",
-    "Error tagging" : "Greška pri označavanju",
-    "Error untagging" : "Greška pri uklanjanju oznaka",
-    "Error favoriting" : "Greška pri dodavanju u favorite",
-    "Error unfavoriting" : "Greška pri uklanjanju iz favorita",
     "Couldn't send mail to following users: %s " : "Nemoguće slanje emaila slijedećim korisnicima: %s",
     "Turned on maintenance mode" : "Upaljen modus održavanja",
     "Turned off maintenance mode" : "Ugašen modus održavanja",
@@ -95,22 +87,20 @@ OC.L10N.register(
     "Error" : "Greška",
     "Error while sharing" : "Greška pri dijeljenju",
     "Error while unsharing" : "Ggreška pri prestanku dijeljenja",
-    "Error setting expiration date" : "Pogrešno postavljanje datuma isteka",
     "The public link will expire no later than {days} days after it is created" : "Javna veza ističe najkasnije {days} dana nakon što je kreirana",
     "Set expiration date" : "Postavite datum isteka",
     "Expiration" : "Istek",
     "Expiration date" : "Datum isteka",
-    "Choose a password for the public link" : "Izaberite lozinku za javnu vezu",
-    "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
-    "Share link" : "Podijelite vezu",
     "Link" : "Veza",
-    "Password protect" : "Zaštitita lozinkom",
+    "Edit" : "Izmjeni",
+    "Choose a password for the public link" : "Izaberite lozinku za javnu vezu",
     "Password" : "Lozinka",
+    "Name" : "Ime",
     "Allow editing" : "Dozvolite izmjenu",
-    "Email link to person" : "Pošaljite osobi vezu e-poštom",
-    "Send" : "Pošalji",
+    "Save" : "Spremi",
     "Sending ..." : "Slanje...",
     "Email sent" : "E-pošta poslana",
+    "Email link to person" : "Pošaljite osobi vezu e-poštom",
     "Shared with you and the group {group} by {owner}" : "Dijeljeno s vama i grupom {group} vlasnika {owner}",
     "Shared with you by {owner}" : "Podijeljeno sa vama od {owner}",
     "group" : "grupa",
@@ -124,6 +114,7 @@ OC.L10N.register(
     "delete" : "izbriši",
     "access control" : "Kontrola pristupa",
     "Share" : "Podijeli",
+    "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
     "Warning" : "Upozorenje",
     "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
@@ -159,7 +150,6 @@ OC.L10N.register(
     "Message: %s" : "Poruka: %s",
     "File: %s" : "Datoteka: %s",
     "Line: %s" : "Red: %s",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vaš direktorij podataka i datoteke vjerojatno se mogu pristupiti s interneta jer .htaccess datoteka ne radi.",
     "Create an <strong>admin account</strong>" : "Kreirajte <strong>administracioni račun</strong>",
     "Username" : "Korisničko ime",
     "Storage & database" : "Pohrana & baza podataka",
