@@ -240,6 +240,66 @@ OC.L10N.register(
     "Start update" : "Inicia l'actualització",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitar que s'esgoti el temps d'espera en instalacions grans, pots en el seu lloc fer córrer la següent comanda en el directori d'instalació. ",
     "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància %s està actualment en manteniment i podria trigar una estona.",
-    "This page will refresh itself when the %s instance is available again." : "Aquesta pàgina s'actualitzarà automàticament quan la instància %s estigui disponible de nou."
+    "This page will refresh itself when the %s instance is available again." : "Aquesta pàgina s'actualitzarà automàticament quan la instància %s estigui disponible de nou.",
+    "Could not reset password because the token is invalid" : "No es pot actualitzar la contrassenya perquè l'identificador és invàlid",
+    "Could not reset password because the token expired" : "No es pot actualitzar la contrassenya perquè l'identificador ha expirat",
+    "Could not reset password because the token does not match" : "No es pot actualitzar la contrassenya perquè els identificadors no coincideixen",
+    "Checking updates of apps" : "Comprobant actualitzacions de les aplicacions",
+    "Dismiss" : "Ignora",
+    "Expiration date is required" : "Data de venciment requerida",
+    "Remove link" : "Borrar l'enllaç",
+    "Create public link" : "Crear un enllaç públic",
+    "Copy to clipboard" : "Copia al porta-papers",
+    "There are currently no link shares, you can create one" : "Actualment no hi cap enllaç a les xarxes, en pots crear un",
+    "Anyone with the link has access to the file/folder" : "Qualsevol podrà accedir a l'arxiu o carpeta amb aquest link",
+    "Choose a password" : "Introdueix una contrasenya",
+    "Password required" : "Es requereix de contrasenya ",
+    "Remove password" : "Borra contrasenya",
+    "Send link via email" : "Enviar enllaç via e-mail",
+    "Sending" : "Enviant",
+    "Public Links" : "Enllaços públics",
+    "invisible" : "invisible",
+    "Delete {link}" : "Borrar {link}",
+    "Share to Twitter. Opens in a new window." : "Compartir a Twitter. Obrirà una nova finestra",
+    "Menu" : "Menú",
+    "Username or email" : "nom d'usuari o email",
+    "Read only" : "Només lectura",
+    "Read & Write" : "Lectura i Escriptura",
+    "You took too long to login, please try again now" : "Has tardat massa en registrar-te, si us plau, intenta-ho de nou",
+    "Password changed successfully" : "Contrasenya actualitzada correctament",
+    "Choose an expiration date" : "Escull una data de venciment",
+    "Social share" : "Xarxes Socials",
+    "An error occured" : "Ha fallat",
+    "Send copy to self" : "Enviar-me copia",
+    "Add personal message" : "Afegir comentari personal",
+    "Could not unshare" : "No es pot descompartir",
+    "No search results in other folders" : "No s'ha trobat res en altres carpetes",
+    "Cancel login" : "Cancel·lar l'accés",
+    "An error occurred while verifying the token" : "Detectat un problema al verificar l'identificador",
+    "Update needed" : "Actualització necessària",
+    "An error occurred. Please contact your admin." : "Error. Contacte amb el teu administrador.",
+    "Please select a file." : "Si us plau, selecciona un fitxer",
+    "%s password changed successfully" : "%scontrassenya actualitzada correctament",
+    "[%d / %d]: %s" : "[%d/%d]:%s",
+    "{fileName} link" : "{filename} enllaç",
+    "Copied!" : "Copiat",
+    "Not supported!" : "No està suportat!",
+    "Edit link share: {name}" : "Edita l'enllaç compartit: {name}",
+    "Create link share: {name}" : "Crea un enllaç compartit: {name}",
+    "Share to Facebook. Opens in a new window." : "Compartir a Facbook. Obrirà una nova finestra",
+    "Share to Diaspora. Opens in a new window." : "Compartir a Diaspora. Obrirà una nova finestra",
+    "Share to Google+. Opens in a new window." : "Compartir a Google+. Obrirà una nova finestra",
+    "Share via email. Opens your mail client." : "Compartir via email. Obrirà el teu gestor de correu",
+    "Owner: {owner}" : "Propietari:{owner}",
+    "new" : "Nou",
+    "Updating to {version}" : "Actualitzant a la versió {version}",
+    "An error occurred." : "Ha fallat",
+    "An internal error occurred." : "Error intern",
+    "You are trying to access a private link. Please log in first." : "Estàs accedint a un enllaç privat. Necessites registrar-te primer.",
+    "Couldn't send mail to following recipient(s): %s " : "No s'ha pugut enviar l'email al(s) destinatari(s): %s",
+    "Imprint" : "Imprint",
+    "Link name" : "Nom de l'enllaç",
+    "Download / View" : "Descarregar / Veure",
+    "Download / View / Upload" : "Descarregar / Veure / Pujar"
 },
 "nplurals=2; plural=(n != 1);");
