@@ -334,6 +334,45 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Da du eine große Instanz von Owncloud besitzt, nutze bitte den Updater über die Kommandozeile.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Für weitere Hilfen, schaue bitte in die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese %s-Instanz befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
-    "This page will refresh itself when the %s instance is available again." : "Diese Seite aktualisiert sich automatisch, wenn die %s-Instanz wieder verfügbar ist."
+    "This page will refresh itself when the %s instance is available again." : "Diese Seite aktualisiert sich automatisch, wenn die %s-Instanz wieder verfügbar ist.",
+    "Could not reset password because the token is invalid" : "Das Passwort konnte aufgrund eines ungültigen Tokens nicht zurückgesetzt werden",
+    "Could not reset password because the token expired" : "Das Passwort konnte nicht zurückgesetzt werden, da der Token abgelaufen ist",
+    "Could not reset password because the token does not match" : "Das Passwort konnte aufgrund eines nicht übereinstimmenden Tokens nicht zurückgesetzt werden",
+    "Copy to clipboard" : "In Zwischenablage kopieren",
+    "Choose a password" : "Ein Passwort wählen",
+    "Upload only" : "Nur Hochladen",
+    "Sending" : "Senden",
+    "Menu" : "Menü",
+    "Read only" : "Schreibgeschützt",
+    "Read & Write" : "Lesen & Schreiben",
+    "Email notification not sent" : "Mail-Benachrichtigung wurde nicht versendet",
+    "You took too long to login, please try again now" : "Sie haben zu lange benötigt, um sich einzuloggen. Bitte versuchen Sie es jetzt erneut.",
+    "Choose an expiration date" : "Wähle ein Ablaufdatum",
+    "An error occured" : "Ein Fehler ist aufgetreten",
+    "Send copy to self" : "Sende dir selbst ein Kopie",
+    "Add personal message" : "Füge eine persönliche Nachricht an",
+    "Error adding {addItem}: {addItem} already exists" : "Fehler beim Hinzufügen von {addItem},  {addItem} existiert schon.",
+    "federated" : "verbunden zu anderer Instanz",
+    "Link name" : "Name des Links",
+    "Owner: {owner}" : "Besitzer: {owner}",
+    "Email notification was sent!" : "Mail-Benachrichtigung wurde versendet!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Bitte wende dich an den Serveradministrator, sollte dieser Fehler mehrfach auftreten und füge deiner Anfrage die unten stehenden technischen Details bei.",
+    "You are trying to access a private link. Please log in first." : "Du versuchst auf einen privaten Link zuzugreifen. Bitte erst anmelden.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Es scheint, dass diese Installation viele Dateien und / oder Benutzer verwaltet. Um einen reibungslosen Upgrade-Prozess sicherzustellen, bitte die Kommandozeile benutzen (php occ upgrade).",
+    "Couldn't send mail to following recipient(s): %s " : "Konnte die Mail an folgende Empfänger nicht senden: %s ",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Von mehreren Empfängern Dateien empfangen, ohne den Inhalt des Ordners preiszugeben.",
+    "Download / View" : "Herunterladen / Ansehen",
+    "Recipients can view or download contents." : "Empfänger können Inhalte sehen und herunterladen.",
+    "Download / View / Upload" : "Herunterladen / Ansehen / Hochladen",
+    "Recipients can view, download, edit, delete and upload contents." : "Empfänger können Inhalte sehen, herunterladen, ändern, löschen und hochladen.",
+    "An error occured while sending email" : "Beim Versenden der E-Mail ist ein Fehler aufgetreten",
+    "{sharee} (federated)" : "Von {sharee} (verbunden zu anderer Instanz)",
+    "Personal note from the sender: %s." : "Persönliche Notiz des Absenders: 1%s .",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Automatische Aktualisierung ist in der Konfiguration deaktiviert. Zur Aktualisierung der Instanz bitte die Kommandozeile benutzen (php occ upgrade).",
+    "Imprint" : "Impressum",
+    "E-Mail sent" : "E-Mail gesendet",
+    "Privacy Policy" : "Datenschutzerklärung",
+    "Sharing is not allowed" : "Teilen nicht erlaubt",
+    "Personal note from the sender: <br> %s." : "Persönliche Notiz vom Absender: <br>%s."
 },
 "nplurals=2; plural=(n != 1);");
