@@ -334,6 +334,14 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Παρακαλώ χρησιμοποιήστε την ενημέρωση μέσω γραμμής εντολών διότι έχετε μεγάλη εγκατάσταση.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Για βοήθεια, δείτε στην  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Αυτή %s η εγκατάσταση είναι σε κατάσταση συντήρησης, η οποία μπορεί να διαρκέσει κάποιο χρόνο.",
-    "This page will refresh itself when the %s instance is available again." : "Αυτή η σελίδα θα ανανεωθεί από μόνη της όταν η %s εγκατάσταση είναι διαθέσιμη ξανά."
+    "This page will refresh itself when the %s instance is available again." : "Αυτή η σελίδα θα ανανεωθεί από μόνη της όταν η %s εγκατάσταση είναι διαθέσιμη ξανά.",
+    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
+    "Choose a password" : "Επιλογή συνθηματικού",
+    "Upload only" : "Μόνο μεταφόρτωση",
+    "Sending" : "Αποστολή",
+    "Menu" : "Μενού",
+    "Link name" : "Όνομα συνδέσμου",
+    "Imprint" : "Αποτύπωμα",
+    "Add personal message" : "Προσθήκη προσωπικού μηνύματος"
 },
 "nplurals=2; plural=(n != 1);");
