@@ -334,6 +334,45 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Por favor utilice la actualización mediante la linea de comandos porque tiene pendiente una gran actualización.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para ayuda, mirar  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> la documentación</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, por lo que puede llevar un tiempo.",
-    "This page will refresh itself when the %s instance is available again." : "La página se refrescará cuando la instalación %s vuelva a estar disponible."
+    "This page will refresh itself when the %s instance is available again." : "La página se refrescará cuando la instalación %s vuelva a estar disponible.",
+    "Could not reset password because the token is invalid" : "No se pudo restablecer la contraseña porque el vale de identificación no es válido",
+    "Could not reset password because the token expired" : "No se pudo restablecer la contraseña porque vale de identificación ha caducado",
+    "Could not reset password because the token does not match" : "No se pudo restablecer la contraseña porque el vale de identificación no coincide",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Choose a password" : "Elige una contraseña",
+    "Upload only" : "Sólo descarga",
+    "Sending" : "Enviando",
+    "Menu" : "Menú",
+    "Read only" : "Sólo leer",
+    "Read & Write" : "Leer y Escribir",
+    "Email notification not sent" : "No se ha enviado la notificación por correo electrónico",
+    "You took too long to login, please try again now" : "Ha tardado demasiado en logearse, por favor intentelo de nuevo",
+    "Choose an expiration date" : "Elija fecha de expiración",
+    "An error occured" : "Ha ocurrido un error",
+    "Send copy to self" : "Enviarme una copia a mi mismo",
+    "Add personal message" : "Añadir un mensaje personal.",
+    "Error adding {addItem}: {addItem} already exists" : "Error añadiendo {addItem}: {addItem} Ya existe.",
+    "federated" : "Federado",
+    "Recipients can view, download, edit, delete and upload contents." : "Se puede ver, descargar, editar, borrar y subir contenido.",
+    "Link name" : "Nombre del enlace",
+    "Download / View" : "Descargar / Ver",
+    "Download / View / Upload" : "Descargar / Ver / Subir",
+    "Owner: {owner}" : "Propietario: {owner}",
+    "Email notification was sent!" : "¡Se ha enviado una notificación por correo electrónico!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Por favor, ponte en contacto con el administrador del servidor si este error aparece más veces, e incluye los detalles técnicos en tu informe a continuación.",
+    "You are trying to access a private link. Please log in first." : "Estás intentando acceder a un enlace privado. Por favor, inicia sesión primero.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Parece que su instalación tiene demasiados host, archivos o usuarios. Para garantizar una actualización suave, por favor use la actualización por linea de comandos (occ upgrade)",
+    "Couldn't send mail to following recipient(s): %s " : "No se puede enviar un correo electrónico a los siguientes receptores: %s ",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Recibir archivos de multiples origenes sin revelar el contenido de la carpeta.",
+    "Recipients can view or download contents." : "Se puede ver o descargar el contenido",
+    "An error occured while sending email" : "Un error ocurrió mientras se enviaba el correo",
+    "{sharee} (federated)" : "{sharee} (federado)",
+    "Personal note from the sender: %s." : "Nota personal del origen: %s.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "La actualización autómatica ha sido deshabilitada en config.php. Para actualizar use la linea de comandos (occ upgrade).",
+    "Imprint" : "Imprimir",
+    "E-Mail sent" : "E-Mail enviado",
+    "Privacy Policy" : "Política de privacidad",
+    "Sharing is not allowed" : "No se permite compartir",
+    "Personal note from the sender: <br> %s." : "Nota personal del remitente: <br> %s."
 },
 "nplurals=2; plural=(n != 1);");
