@@ -203,6 +203,61 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia duzula.",
     "Start update" : "Hasi eguneraketa",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handien itxarote-denbora saihesteko, ondoko komandoa exekuta dezakezu instalazio direktoriotik:",
-    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean."
+    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean.",
+    "No valid crop data provided" : "Ebaketarako datu baliogabea",
+    "Crop is not square" : "Ebaketa ez da karratua",
+    "Could not reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
+    "Could not reset password because the token expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
+    "Could not reset password because the token does not match" : "Ezin izan da pasahitza berrezarri tokena ez datorrelako bat",
+    "Preparing update" : "Eguneraketa prestatzen",
+    "Create public link" : "Esteka publikoa sortu",
+    "Copy to clipboard" : "Kopiatu arbelera",
+    "Anyone with the link has access to the file/folder" : "Esteka duen edonork atzitu dezake fitxategi/karpeta",
+    "Filename" : "Fitxategiaren izena",
+    "User and Groups" : "Erabiltzaile eta Taldeak",
+    "Menu" : "Menua",
+    "Invalid file provided" : "Baliogabeko fitxategia",
+    "File is too big" : "Fitxategia handiegia da",
+    "Collaborative tags" : "Kolaboraziorako etiketak",
+    "Please select a file." : "Mesedez, hautatu fitxategia.",
+    "An error occurred. Please contact your admin." : "Errore bat gertatu da. Mesedez jarri harremanetan zure administratzailearekin.",
+    "%s password changed successfully" : "%s pasahitza behar bezala aldatu da",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Konponketa abisua:",
+    "Repair error: " : "Konponketa errorea:",
+    "Checking updates of apps" : "Aplikazioentzat eguneraketak baieztatzen",
+    "%s (3rdparty)" : "%s (3garrena)",
+    "%s (incompatible)" : "%s (bateraezina)",
+    "Following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
+    "Already up to date" : "Dagoeneko martxan",
+    "Mo" : "Al",
+    "Tu" : "Ar",
+    "We" : "Az",
+    "Th" : "Og",
+    "Fr" : "Ol",
+    "Dismiss" : "Baztertu",
+    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
+    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
+    "Updating database schema" : "Datu-base eskema eguneratzen",
+    "Error adding {addItem}: {addItem} already exists" : "{addItem} gehitzean errorea: {addItem} dagoeneko bada",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Datu-base eskema eguneratu daiteken baieztatzen (dabu-base tamainaren arabera denbora luzea eraman dezake honek)",
+    "Reset log level" : "Log maila berrezarri",
+    "Starting code integrity check" : "Kode osotasun baieztapena hasten",
+    "Finished code integrity check" : "Kode osotasun baieztapena amaituta",
+    "Copied!" : "Kopiatua!",
+    "Not supported!" : "Euskarririk ez!",
+    "Imprint" : "Imprint",
+    "Password required" : "Pasahitza beharrezkoa",
+    "Remove password" : "Pasahitza ezabatu",
+    "Couldn't send mail to following recipient(s): %s " : "Ezin izan da ondorengo helbidetara posta mezurik bidali: %s",
+    "Remove link" : "Esteka ezabatu",
+    "Choose a password" : "Aukeratu pasahitza",
+    "Link name" : "Estekaren izena",
+    "Upload only" : "Kargatu bakarrik",
+    "Download / View" : "Deskargatu / Ikusi",
+    "Download / View / Upload" : "Deskargatu / Ikusi / Kargatu",
+    "Maintenance mode is kept active" : "Mantentze-modua aktibo dago",
+    "Set log level to debug" : "Log maila arazketa gisa jarri",
+    "Problem loading page, reloading in 5 seconds" : "Arazoa orria kargatzen, 5 segundo barru birkargatuko da"
 },
 "nplurals=2; plural=(n != 1);");
