@@ -307,6 +307,52 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Käytä komentorivipäivitintä, koska käyttämäsi ownCloud on sen verran suuri.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Apua saat <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaatiosta</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
-    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä."
+    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä.",
+    "Expiration date is required" : "Vanhenemispäivä vaaditaan",
+    "Remove link" : "Poista linkki",
+    "Create public link" : "Luo julkinen linkki",
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Anyone with the link has access to the file/folder" : "Kenellä tahansa linkin omaavalla on pääsy tiedostoon/kansioon",
+    "Password required" : "Salasana vaaditaan",
+    "Remove password" : "Poista salasana",
+    "User and Groups" : "Käyttäjät ja ryhmät",
+    "Public Links" : "Julkiset linkit",
+    "Delete {link}" : "Poista {link}",
+    "Menu" : "Valikko",
+    "Read only" : "Vain luku",
+    "Read & Write" : "Luku ja kirjoitus",
+    "Email notification not sent" : "Sähköposti-ilmoitusta ei lähetetty",
+    "You took too long to login, please try again now" : "Kirjautumisessa kesti liian kauan. Yritä uudelleen nyt",
+    "Password changed successfully" : "Salasana vaihdettu onnistuneesti",
+    "Social share" : "Sosiaalinen jako",
+    "Link name" : "Linkin nimi",
+    "Owner: {owner}" : "Omistaja: {owner}",
+    "Email notification was sent!" : "Sähköposti-ilmoitus lähetetty!",
+    "You are trying to access a private link. Please log in first." : "Yrität käyttää yksityistä linkkiä. Kirjaudu sisään ensin.",
+    "Imprint" : "Tiedot",
+    "Could not reset password because the token is invalid" : "Salasanaa ei voitu palauttaa koska valtuutuslinkki on virheellinen",
+    "Could not reset password because the token expired" : "Salasanaa ei voitu nollata koska valtuutuslinkki on vanhentunut",
+    "Could not reset password because the token does not match" : "Salasanaa ei voitu nollata koska valtuutuslinkki ei täsmää",
+    "%s password changed successfully" : "%s salasana vaihdettiin onnistuneesti",
+    "{fileName} link" : "{fileName} linkki",
+    "Edit link share: {name}" : "Muokkaa jakolinkkiä: {name}",
+    "Create link share: {name}" : "Luo jakolinkki: {name}",
+    "Sending" : "Lähetetään",
+    "There are currently no link shares, you can create one" : "Jakolinkkejä ei nyt ole. Voit luoda uuden.",
+    "Couldn't send mail to following recipient(s): %s " : "Ei voitu lähettää sähköpostia seuraaville vastaanottajille: %s",
+    "Choose an expiration date" : "Valitse vanhenemispäivä",
+    "Choose a password" : "Valitse salasana",
+    "Download / View" : "Lataa / Näytä",
+    "Download / View / Upload" : "Lataa / Näytä / Lähetä",
+    "Send copy to self" : "Lähetä kopio itsellesi",
+    "Add personal message" : "Lisää henkilökohtainen viesti",
+    "Upload only" : "Vain lähetys",
+    "Privacy Policy" : "Tietosuojalauseke",
+    "Recipients can view or download contents." : "Vastaanottaja voi katsoa tai ladata sisältöä.",
+    "Recipients can view, download, edit, delete and upload contents." : "Vastaanottaja voi katsoa, ladata, muokata, poistaa ja lähettää sisältöä.",
+    "An error occured while sending email" : "Tapahtui virhe lähetettäessä sähköpostia",
+    "E-Mail sent" : "Sähköposti lähetetty",
+    "Personal note from the sender: <br> %s." : "Henkilökohtainen viesti lähettäjältä: <br> %s.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Automaattiset päivitykset on poistettu käytöstä config.php:ssä. Päivittääksesi asennuksesi, ole hyvä ja käytä päivittäjää komentoriviltä (occ upgrade)"
 },
 "nplurals=2; plural=(n != 1);");
