@@ -236,6 +236,9 @@ OC.L10N.register(
     "Start update" : "Iniciar a actualización",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera nas instalacións grandes, no seu lugar pode executar a seguinte orde desde o directorio de instalación:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
-    "This page will refresh itself when the %s instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia de %s estea dispoñíbel de novo."
+    "This page will refresh itself when the %s instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia de %s estea dispoñíbel de novo.",
+    "Copy to clipboard" : "Copiar ao portapapeis",
+    "Menu" : "Menú",
+    "Imprint" : "Impresión"
 },
 "nplurals=2; plural=(n != 1);");
