@@ -334,6 +334,32 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "יש להשתמש בעדכון על בסיס שורת פקודה כיוון שמדובר בעדכון גדול.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "לעזרה, ניתן לצפות ב<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">מסמכי התיעוד</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "הפעלה %s זו כרגע במצב אחזקה, שתמשך זמן מה.",
-    "This page will refresh itself when the %s instance is available again." : "עמוד זה ירענן את עצמו כשהפעלת %s תהיה זמינה שוב."
+    "This page will refresh itself when the %s instance is available again." : "עמוד זה ירענן את עצמו כשהפעלת %s תהיה זמינה שוב.",
+    "Could not reset password because the token is invalid" : "לא ניתן לאפס את הסיסמא שכן חתימת הייצוג אינה חוקית",
+    "Could not reset password because the token expired" : "לא ניתן לאפס את הסיסמא שכן תוקף חתימת הייצוג עבר",
+    "Could not reset password because the token does not match" : "לא ניתן לאפס את הסיסמא שכן חתימת הייצוג אינה מתאימה",
+    "Copy to clipboard" : "העתקה ללוח הגזירים",
+    "Choose a password" : "בחירת סיסמא",
+    "Upload only" : "העלאה בלבד",
+    "Sending" : "שולח",
+    "Menu" : "תפריט",
+    "Read only" : "קריאה בלבד",
+    "Read & Write" : "קריאה וכתיבה",
+    "Email notification not sent" : "לא נשלחה הודעה בדוא״ל",
+    "You took too long to login, please try again now" : "לקח לך יותר מדי זמן להיכנס, נא לנסות שוב עכשיו",
+    "Choose an expiration date" : "נא לבחור תאריך תפוגה",
+    "An error occured" : "אירעה שגיאה",
+    "Send copy to self" : "שליחת עותק אלי",
+    "Add personal message" : "הוספת הודעה פרטית",
+    "Error adding {addItem}: {addItem} already exists" : "שגיאה בהוספת {addItem}:‏ {addItem} כבר קיים",
+    "Link name" : "שם קישור",
+    "Owner: {owner}" : "בעלים: {owner}",
+    "Email notification was sent!" : "נשלחה הודעה בדוא״ל!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "נא ליצור קשר עם מנהל השרת שלך אם שגיאה זו מופיעה שוב מספר פעמים ולכלול בדיווח את הפרטים הטכניים שלהלן.",
+    "You are trying to access a private link. Please log in first." : "הנך מנסה לגשת לקישור פרטי. יש להתחבר תחילה.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "נראה שההרצה שלך יכולה לארח מספר רב של קבצים ו/או משתמשים. להבטחת תהליך שדרוג חלק, מומלץ להשתמש בעדכון המבוסס על שורת פקודה (שדרוג occ).",
+    "Couldn't send mail to following recipient(s): %s " : "נא ניתן לשלוח דוא״ל לנמענים הבאים: %s",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "עדכון אוטומטי מנוטרל בקובץ config.php. לשדרוג ההרצה שלך, יש להשתמש בעדכון המבוסס על שורת פקודה (שדרוג occ).",
+    "Imprint" : "חותמת"
 },
 "nplurals=2; plural=(n != 1);");
