@@ -300,6 +300,74 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Kérjük, a frissítéshez a parancssort használja, mert nagyobb frissítést készül telepíteni.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Segítségért keresse fel a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentációt</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Ez a %s folyamat éppen karbantartó üzemmódban van, ami eltarthat egy darabig.",
-    "This page will refresh itself when the %s instance is available again." : "Ez az oldal frissíteni fogja magát amint a(z) %s példány ismét elérhető."
+    "This page will refresh itself when the %s instance is available again." : "Ez az oldal frissíteni fogja magát amint a(z) %s példány ismét elérhető.",
+    "Could not reset password because the token is invalid" : "Nem sikerült a jelszót visszaállítani, mert a token érvénytelen",
+    "Could not reset password because the token expired" : "Nem sikerült a jelszót visszaállítani, mert a token lejárt",
+    "Could not reset password because the token does not match" : "Nem sikerült a jelszót visszaállítani, mert a token nem egyezik",
+    "Expiration date is required" : "A lejárat dátuma szükséges",
+    "Remove link" : "Hivatkozás eltávolítása",
+    "Create public link" : "Publikus hivatkozás létrehozása",
+    "Copy to clipboard" : "Másold a vágólapra",
+    "There are currently no link shares, you can create one" : "Jelenleg nincs egy hivatkozás sem megosztva, létrehozhatsz egyet",
+    "Anyone with the link has access to the file/folder" : "Bárki a hivatkozással hozzáférhet a fájlhoz/mappához",
+    "Password required" : "Jelszó szükséges",
+    "Remove password" : "Jelszó eltávolítása",
+    "User and Groups" : "Felhasználó és Csoportok",
+    "Public Links" : "Publikus Hivatkozások",
+    "restricted" : "korlátozott",
+    "Delete {link}" : "Törlés {link}",
+    "Share to Twitter. Opens in a new window." : "Megosztás Twitter-en. Új ablakban jelenik meg.",
+    "Menu" : "Menü",
+    "Read only" : "Csak olvasható",
+    "Read & Write" : "Írás és olvasás",
+    "Email notification not sent" : "E-mail értesítést nem küldtünk",
+    "You took too long to login, please try again now" : "Túl sokáig tartott belépni, próbáld újra",
+    "Password changed successfully" : "A jelszó sikeresen megváltozott",
+    "Social share" : "Közösségi megosztás",
+    "Cancel login" : "Bejelentkezés megszakítása",
+    "An error occurred while verifying the token" : "Egy hiba merült fel a token érvényesítése közben",
+    "Error adding {addItem}: {addItem} already exists" : "Hiba történt egy {addItem} hozzáadása esetén: az {addItem} már létezik",
+    "federated" : "egyesített",
+    "Two-step verification" : "Kétlépcsős azonosítás",
+    "Link name" : "Link neve",
+    "%s password changed successfully" : "%s jelszó sikeresen megváltozott",
+    "{fileName} link" : "{fileName} hivatkozás",
+    "Copied!" : "Másolva!",
+    "Not supported!" : "Nem támogatott!",
+    "Press ⌘-C to copy." : "Használd a ⌘-C másoláshoz.",
+    "Press Ctrl-C to copy." : "Használd a Ctrl+C másoláshoz.",
+    "Edit link share: {name}" : "Megosztási hivatkozás szerkesztése: {name}",
+    "Create link share: {name}" : "Megosztási hivatkozás létrehozása: {name}",
+    "Share to Facebook. Opens in a new window." : "Megosztás Facebook-on. Új ablakban jelenik meg.",
+    "Share to Diaspora. Opens in a new window." : "Megosztás a Diaspora-n. Új ablakban jelenik meg.",
+    "Share to Google+. Opens in a new window." : "Megosztás Google+ -on. Új ablakban jelenik meg.",
+    "Share via email. Opens your mail client." : "Megosztás E-mailben. A levelező kliensedben jelenik meg.",
+    "Owner: {owner}" : "Tulajdonos: {owner}",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Határozd meg a port számát a hosztnév mellett (pl.: localhost: 5432).",
+    "Email notification was sent!" : "E-mail értesítést küldött!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Kérjük, lépjen kapcsolatba a szerver rendszergazdájával, ha ez a hiba többször megjelenik újra, és tartalmazza az alábbi technikai részleteket a jelentésben.",
+    "You are trying to access a private link. Please log in first." : "Egy privát hivatkozáshoz próbál hozzáférni. Kérjük, elsőként jelentkezzen be.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Úgy néz ki, hogy a kiszolgáló talán sok fájlt és/vagy felhasználót szolgál ki. Ahhoz, hogy a frissítés simán végbemenjen, kérjük, hogy használja a parancssor-ból a frissítőt  (occ upgrade). ",
+    "{sharee} (federated)" : "{sharee} (federated)",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "A kiterjesztett biztonság engedélyezve lett a fiókján. Kérjük a hitelesítéshez használjon egy második faktort.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Az automatikus frissítés ki van kapcsolva a config.php -ban. A frissítéshez, használja a parancssori frissítőt (occ upgrade).",
+    "Please authenticate using the selected factor." : "Kérjük a bejelentkezéshez használja a kiválasztott faktort.",
+    "Sending" : "Küldés",
+    "Imprint" : "Impresszum",
+    "Couldn't send mail to following recipient(s): %s " : "Email küldese sikertelen a következő(k)nek: %s",
+    "Choose an expiration date" : "Lejárati dátum választása",
+    "Choose a password" : "Válasszon jelszót",
+    "Send copy to self" : "Másolatküldés önmagának",
+    "Add personal message" : "Személyes üzenet hozzáadása",
+    "Upload only" : "Csak feltöltés",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Fájlok fogadása többszörös fogadóktól a mappa tartalmának felfedése nélkül",
+    "Download / View" : "Letöltés / Megjelenítés",
+    "Recipients can view or download contents." : "Fogadók letölthetnek és megjeleníthetnek tartalmakat.",
+    "Download / View / Upload" : "Letöltés / Megjelenítés / Feltöltés",
+    "Recipients can view, download, edit, delete and upload contents." : "Fogadók megjeleníthetnek, letölthetnek, módosíthatnak, törölhetnek és feltölthetnek tartalmakat.",
+    "An error occured while sending email" : "Hiba az email küldése során",
+    "E-Mail sent" : "Email elküldve",
+    "Personal note from the sender: %s." : "Személyes megjegyzés %s küldőnek.",
+    "Privacy Policy" : "Adatvédelmi szabályzat"
 },
 "nplurals=2; plural=(n != 1);");
