@@ -334,6 +334,38 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
-    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný."
+    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný.",
+    "Could not reset password because the token is invalid" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er ógilt",
+    "Could not reset password because the token expired" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er útrunnið",
+    "Could not reset password because the token does not match" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið samsvarar ekki",
+    "Copy to clipboard" : "Afrita á klippispjald",
+    "Choose a password" : "Veldu lykilorð",
+    "Upload only" : "Einungis innsending",
+    "Sending" : "Sending",
+    "Menu" : "Valmynd",
+    "Read only" : "Skrifvarið",
+    "Read & Write" : "Les- & skrifanlegt",
+    "Email notification not sent" : "Tilkynning í tölvupósti ekki send",
+    "You took too long to login, please try again now" : "Þú varst of lengi að skrá þig inn, reyndu núna aftur",
+    "Choose an expiration date" : "Veldu lokadagsetningu",
+    "An error occured" : "Villa kom upp",
+    "Send copy to self" : "Senda afrit til sjálfs þín",
+    "Add personal message" : "Bættu við persónulegum skilaboðum",
+    "Error adding {addItem}: {addItem} already exists" : "Villa við að bæta við {addItem}: {addItem} er þegar til",
+    "federated" : "skýjasamband (federated)",
+    "Link name" : "Heiti tengils",
+    "Owner: {owner}" : "Eigandi: {owner}",
+    "Email notification was sent!" : "Tilkynning var send í tölvupósti!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Hafðu samband við kerfisstjóra ef þessi villa birtist oft aftur, láttu þá tæknilegu upplýsingarnar hér að neðan fylgja með.",
+    "You are trying to access a private link. Please log in first." : "Þú ert að reyna að tengjast einkatengli. Skráðu þig fyrst inn.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Það lítur út fyrir að tilvikið þitt hýsi mjög margar skrár og/eða notendur. Til að uppfærslan gangi sem best fyrir sig, ættirðu að nota uppfærslutólið af skipanalínu (occ upgrade).",
+    "Couldn't send mail to following recipient(s): %s " : "Gat ekki sent póst á eftirfarandi notendur: %s ",
+    "{sharee} (federated)" : "{sharee} (federated)",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Sjálfvirkar uppfærslur eru gerðar óvirkar í config.php. Til að uppfæra tilvikið þitt ættirðu að nota uppfærslutólið af skipanalínu (occ upgrade).",
+    "Imprint" : "Prenta",
+    "Download / View" : "Sækja / Skoða",
+    "Download / View / Upload" : "Sækja / Skoða / Senda inn",
+    "Recipients can view or download contents." : "Viðtakendur geta skoðað eða sótt efni.",
+    "Recipients can view, download, edit, delete and upload contents." : "Viðtakendur geta skoðað, sótt, breytt, eytt eða sent inn efni."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
