@@ -332,6 +332,30 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "현재 인스턴스 크기가 크기 때문에 명령행 업데이터를 사용하십시오.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "도움말을 보려면 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">문서</a>를 참조하십시오.",
     "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
-    "This page will refresh itself when the %s instance is available again." : "%s 인스턴스를 다시 사용할 수 있으면 자동으로 새로 고칩니다."
+    "This page will refresh itself when the %s instance is available again." : "%s 인스턴스를 다시 사용할 수 있으면 자동으로 새로 고칩니다.",
+    "Could not reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없음",
+    "Could not reset password because the token expired" : "토큰이 만료되었기 때문에 암호를 초기화할 수 없음",
+    "Could not reset password because the token does not match" : "토큰이 일치하지 않기 때문에 암호를 초기화할 수 없음",
+    "Copy to clipboard" : "클립보드로 복사",
+    "Anyone with the link has access to the file/folder" : "링크가 있는 모든 사용자는 파일/폴더에 접근할 수 있습니다",
+    "Choose a password" : "암호 지정",
+    "Upload only" : "업로드만",
+    "Sending" : "보내는 중",
+    "Menu" : "메뉴",
+    "Read only" : "읽기 전용",
+    "Read & Write" : "읽기 및 쓰기",
+    "Email notification not sent" : "이메일 알림을 보내지 못했습니다",
+    "You took too long to login, please try again now" : "로그인이 너무 오래 걸렸습니다. 다시 시도하십시오",
+    "Error adding {addItem}: {addItem} already exists" : "{addItem} 추가 오류: {addItem} 항목이 이미 존재함",
+    "federated" : "연합",
+    "Link name" : "링크 이름",
+    "Owner: {owner}" : "소유자: {owner}",
+    "Email notification was sent!" : "이메일 알림을 보냈습니다!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "이 오류가 여러 번 발생하면 아래의 기술 정보를 포함해서 서버 관리자에게 연락하십시오.",
+    "You are trying to access a private link. Please log in first." : "비공개 링크에 접근을 시도하셨습니다. 먼저 로그인해 주십시오.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "인스턴스에 너무 많은 파일이나 사용자가 있는 것 같습니다. 업그레이드를 순조롭게 진행하려면 명령행 업데이트 도구(occ upgrade)를 사용하십시오.",
+    "{sharee} (federated)" : "{sharee}(연합)",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "config.php에서 자동 업데이트가 비활성화되어 있습니다. 인스턴스를 업그레이드하려면 명령줄 업데이트(occ upgrade)를 사용하십시오.",
+    "Imprint" : "법적 고지"
 },
 "nplurals=1; plural=0;");
