@@ -332,6 +332,44 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Vennligst bruk kommandolinje-oppdatering fordi du har en stor instans.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "For hjelp, se  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentasjonen</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instansen er for øyeblikket i vedlikeholdsmodus, noe som kan vare en stund.",
-    "This page will refresh itself when the %s instance is available again." : "Denne siden vil bli lastet på nytt når %s-instansen er tilgjengelig igjen."
+    "This page will refresh itself when the %s instance is available again." : "Denne siden vil bli lastet på nytt når %s-instansen er tilgjengelig igjen.",
+    "Could not reset password because the token is invalid" : "Klarte ikke å tilbakestille passordet fordi token er ugyldig.",
+    "Could not reset password because the token expired" : "Klarte ikke å tilbakestille passordet fordi token er utløpt.",
+    "Could not reset password because the token does not match" : "Klarte ikke å tilbakestille passordet fordi token ikke matcher.",
+    "Copy to clipboard" : "Kopier til utklippstavlen",
+    "Anyone with the link has access to the file/folder" : "Alle med linken har tilgang til filen/mappen",
+    "Choose a password" : "Velg passord",
+    "Upload only" : "Bare last opp",
+    "Sending" : "Sender",
+    "Menu" : "Meny",
+    "Read only" : "Kun lese",
+    "Read & Write" : "Les & Skriv",
+    "Email notification not sent" : "E-postvarsling ikke sendt",
+    "You took too long to login, please try again now" : "Du tok for lang tid til å logge inn, prøv igjen nå",
+    "Choose an expiration date" : "Velg en utløpsdato",
+    "An error occured" : "En feil oppstod",
+    "Send copy to self" : "Send kopi til deg selv",
+    "Add personal message" : "Legg til personlig melding",
+    "Error adding {addItem}: {addItem} already exists" : "Feil ved å legge til {addItem}: {addItem} eksisterer allerede",
+    "federated" : "Forent",
+    "Link name" : "Navn på link",
+    "Owner: {owner}" : "Eier: {owner}",
+    "Email notification was sent!" : "E-postvarsling ble sendt!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Ta kontakt med serveradministratoren hvis denne feilen vises flere ganger, inkluder de tekniske detaljene nedenfor i rapporten.",
+    "You are trying to access a private link. Please log in first." : "Du prøver å få tilgang til en privat lenke. Vennligst logg inn først. ",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Det ser ut som instansen inneholder mange filer og/eller brukere. Bruk kommandolinje-oppdatering (occ upgrade) for å sikre en smidig oppgradering.",
+    "Couldn't send mail to following recipient(s): %s " : "Kunne ikke sende e-post til følgende mottaker (e): %s",
+    "{sharee} (federated)" : "{sharee} (federated)",
+    "Personal note from the sender: %s." : "Personlig notat fra avsenderen: %s.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Automatisk oppdatering er deaktivert i config.php. Bruk kommandolinje-oppdatering (occ upgrade) for å oppgradere instansen.",
+    "Imprint" : "Avtrykk",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Motta filer fra andre uten å avsløre innholdet i mappen.",
+    "Download / View" : "Last ned / Se",
+    "Recipients can view or download contents." : "Mottakere kan se og laste ned innhold.",
+    "Download / View / Upload" : "Last ned / Se / Last opp",
+    "Recipients can view, download, edit, delete and upload contents." : "Mottakere kan se, laste ned, redigere, slette og laste opp innhold.",
+    "An error occured while sending email" : "Det oppstod en feil ved sending av epost",
+    "E-Mail sent" : "E-post sendt",
+    "Privacy Policy" : "Personvern regler"
 },
 "nplurals=2; plural=(n != 1);");
