@@ -315,6 +315,37 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Ver venleg og bruk kommando linje forbedring fordi du har ein stor førekomst",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "For hjelp, sjå <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentasjon</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s førekomst er i forbetrings modus som kan ta ei stund.",
-    "This page will refresh itself when the %s instance is available again." : "Denne sida vil lastast på ny når %s førekomsten er tilgjengeleg att."
+    "This page will refresh itself when the %s instance is available again." : "Denne sida vil lastast på ny når %s førekomsten er tilgjengeleg att.",
+    "Could not reset password because the token is invalid" : "Kunne ikkje nullstille passord fordi pollett er  ugyldig",
+    "Could not reset password because the token expired" : "Kunne ikkje nullstille passord fordi pollet er utgått",
+    "Could not reset password because the token does not match" : "Kunne ikkje nullstille passord fordi pollett stemmer ikkje",
+    "Expiration date is required" : "Utløp dato er krevd",
+    "Remove link" : "Fjern lenke",
+    "Create public link" : "Opprett offentleg lenke",
+    "Copy to clipboard" : "Kopier til utklippstavle",
+    "There are currently no link shares, you can create one" : "Det er ikkje nokon delt lenke, du kan opprette ei",
+    "Anyone with the link has access to the file/folder" : "Alle med lenke har tilgang til fil eller mappe",
+    "Password required" : "Passord påkrevd",
+    "Filename" : "Filnavn",
+    "Remove password" : "Fjern passord",
+    "User and Groups" : "Brukar og grupper",
+    "Public Links" : "Offentlege lenker",
+    "Delete {link}" : "Fjern {link}",
+    "Menu" : "Meny",
+    "Read only" : "Kun les",
+    "Read & Write" : "Les og skriv",
+    "Email notification not sent" : "E-post varsel er ikkje sendt!",
+    "Password changed successfully" : "Passord er endra",
+    "Social share" : "Deling",
+    "%s password changed successfully" : "%spassord er endra",
+    "{fileName} link" : "{fileName} lenke",
+    "Edit link share: {name}" : "Endre delt lenke: {name}",
+    "Create link share: {name}" : "Opprett delt lenke: (name)",
+    "Owner: {owner}" : "Eigar: {owner}",
+    "Email notification was sent!" : "E-post varsel er sendt!",
+    "You are trying to access a private link. Please log in first." : "Ver venleg å logge inn for å få tilgang til privat lenke.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Din instans har mange filer og/enn brukarar. For å sikre god oppgradering ver venleg å bruk kommandolinje oppdatering (occ upgrade).",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Automatisk oppgradering er skrudd av i config.php. For å oppgradere ver venleg å bruke kommando linje oppdatering (occ upgrade).",
+    "Imprint" : "Impressum"
 },
 "nplurals=2; plural=(n != 1);");
