@@ -329,6 +329,33 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Ze względu na rozmiar Twojej instalacji użyj programu do aktualizacji z linii poleceń.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Aby uzyskać pomoc, zajrzyj do <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentacji</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Ta %s instancja jest obecnie w trybie serwisowym, co może potrwać chwilę.",
-    "This page will refresh itself when the %s instance is available again." : "Strona odświeży się gdy instancja %s będzie ponownie dostępna."
+    "This page will refresh itself when the %s instance is available again." : "Strona odświeży się gdy instancja %s będzie ponownie dostępna.",
+    "Could not reset password because the token is invalid" : "Nie można zresetować hasła: nieprawidłowy token.",
+    "Could not reset password because the token expired" : "Nie można zresetować hasła: token wygasł.",
+    "Could not reset password because the token does not match" : "Nie można zresetować hasła: nieprawidłowy token.",
+    "Copy to clipboard" : "Skopiuj do schowka",
+    "Choose a password" : "Wprowadź hasło",
+    "Menu" : "Menu",
+    "Email notification not sent" : "Powiadomienie email nie zostało wysłane",
+    "Link name" : "Nazwa linku",
+    "Email notification was sent!" : "Powiadomienie email zostało wysłane",
+    "Sending" : "Wysyłanie",
+    "Imprint" : "Stopka",
+    "Owner: {owner}" : "Właściciel: {owner}",
+    "You are trying to access a private link. Please log in first." : "Próbujesz dostępu do prywatnego linku. Proszę się najpierw zalogować.",
+    "Couldn't send mail to following recipient(s): %s " : "Nie udało się wysłać wiadomości do odbiorcy(ów): %s ",
+    "Choose an expiration date" : "Wybierz datę wygaśnięcia",
+    "Send copy to self" : "Wyślij kopię do siebie",
+    "Add personal message" : "Dodaj własną wiadomość",
+    "Upload only" : "Tylko wysyłanie",
+    "Error adding {addItem}: {addItem} already exists" : "Błąd dodawania {addItem}: {addItem} już istnieje",
+    "Download / View" : "Pobieranie / Podgląd",
+    "Recipients can view or download contents." : "Odbiorcy mogą otwierać lub pobierać zawartość.",
+    "Download / View / Upload" : "Pobieranie / Podgląd / Wysyłanie",
+    "Recipients can view, download, edit, delete and upload contents." : "Odbiorcy mogą otwierać, pobierać, zmieniać, kasować i wysyłać zawartość.",
+    "An error occured while sending email" : "Wystąpił błąd przy wysyłaniu wiadomości email",
+    "E-Mail sent" : "Wiadomość e-mail została wysłana",
+    "federated" : "stowarzyszona",
+    "Personal note from the sender: %s." : "Własna informacja od nadawcy: %s."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
