@@ -334,6 +334,45 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Por favor, use a atualização de linha de comando, porque você tem um grande exemplo.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
-    "This page will refresh itself when the %s instance is available again." : "Esta página será atualizada automaticamente quando esta instância %s estiver disponível novamente."
+    "This page will refresh itself when the %s instance is available again." : "Esta página será atualizada automaticamente quando esta instância %s estiver disponível novamente.",
+    "Could not reset password because the token is invalid" : "Não foi possível redefinir a senha porque o token é inválido",
+    "Could not reset password because the token expired" : "Não foi possível redefinir a senha porque o token expirou",
+    "Could not reset password because the token does not match" : "Não foi possível redefinir a senha porque o token não corresponde",
+    "Copy to clipboard" : "Copiar para área de transferência",
+    "Choose a password" : "Escolha uma senha",
+    "Upload only" : "Somente enviar",
+    "Sending" : "Enviando",
+    "Menu" : "Menu",
+    "Read only" : "Somente leitura",
+    "Read & Write" : "Ler & Escrever",
+    "Email notification not sent" : "Notificação de e-mail não enviada",
+    "You took too long to login, please try again now" : "Você demorou muito para se logar, tente novamente agora",
+    "Choose an expiration date" : "Escolha uma data de validade",
+    "An error occured" : "Ocorreu um erro",
+    "Send copy to self" : "Enviar cópia para si mesmo",
+    "Add personal message" : "Adicionar mensagem pessoal",
+    "Error adding {addItem}: {addItem} already exists" : "Erro ao adicionar {addItem}: {addItem} já existe",
+    "federated" : "federado",
+    "Link name" : "Nome do link",
+    "Download / View" : "Baixar/Visualizar",
+    "Recipients can view, download, edit, delete and upload contents." : "Os destinatários podem visualizar, baixar, editar, excluir e fazer upload de conteúdo.",
+    "Download / View / Upload" : "Baixar / Visualizar / Enviar",
+    "An error occured while sending email" : "Ocorreu um erro ao enviar e-mail",
+    "Owner: {owner}" : "Proprietário: {owner}",
+    "Email notification was sent!" : "Notificação de e-mail foi enviada!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Entre em contato com o administrador do servidor se este erro reaparecer várias vezes e inclua os detalhes técnicos abaixo no seu relatório.",
+    "You are trying to access a private link. Please log in first." : "Você está tentando acessar um linque privado. Por favor, faça o login primeiro.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Parece que sua instância pode hospedar muitos arquivos e/ou usuários. Para garantir um processo de atualização suave, use o atualizador da linha de comando (atualização do occ).",
+    "Couldn't send mail to following recipient(s): %s " : "Não foi possível enviar email para o(s) seguinte(s) destinatário(s): %s ",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Receber arquivos de vários destinatários sem revelar o conteúdo da pasta.",
+    "Recipients can view or download contents." : "Os destinatários podem visualizar ou baixar o conteúdo.",
+    "{sharee} (federated)" : "{sharee} (federated)",
+    "Personal note from the sender: %s." : "Nota pessoal do remetente: %s.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "A atualização automática está desativada no config.php. Para atualizar sua instância, use o atualizador da linha de comando (atualização do occ).",
+    "Imprint" : "Impressão",
+    "E-Mail sent" : "E-mail enviado",
+    "Privacy Policy" : "Política de Privacidade",
+    "Sharing is not allowed" : "Não é permitido o compartilhamento",
+    "Personal note from the sender: <br> %s." : "Nota pessoal do remetente: <br> %s."
 },
 "nplurals=2; plural=(n > 1);");
