@@ -334,6 +334,45 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Пожалуйста, используйте обновление через командную строку, так как данная установка имеет большой размер.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Для помощи, ознакомьтесь с  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацией</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
-    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен."
+    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен.",
+    "Could not reset password because the token is invalid" : "Не удалось сбросить пароль, так как токен неправильный",
+    "Could not reset password because the token expired" : "Не удалось сбросить пароль, так как токен устарел",
+    "Could not reset password because the token does not match" : "Не удалось сбросить пароль, так как токен не соответствует",
+    "Copy to clipboard" : "Скопировать в буфер обмена",
+    "Choose a password" : "Выберите пароль",
+    "Upload only" : "Только закачка",
+    "Sending" : "Отправка",
+    "Menu" : "Меню",
+    "Read only" : "Только чтение",
+    "Read & Write" : "Чтение и запись",
+    "Email notification not sent" : "Уведомление почтой не было отправлено",
+    "You took too long to login, please try again now" : "Ваш вход занял слишком много времени, пожалуйста попробуйте ещё раз сейчас",
+    "Choose an expiration date" : "Выберите срок действия",
+    "An error occured" : "Произошла ошибка",
+    "Send copy to self" : "Отправить копию себе",
+    "Add personal message" : "Добавить личное сообщение",
+    "Error adding {addItem}: {addItem} already exists" : "Ошибка при добавлении {addItem}: {addItem} уже существует",
+    "federated" : "федеративный",
+    "Link name" : "Имя ссылки",
+    "Recipients can view, download, edit, delete and upload contents." : "Получатели могут просматривать, скачивать, править, удалять и закачивать содержимое.",
+    "Download / View" : "Скачивание / Просмотр",
+    "Download / View / Upload" : "Скачивание / Просмотр / Закачка",
+    "Owner: {owner}" : "Владелец: {owner}",
+    "Email notification was sent!" : "Уведомление почтой было отправлено!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Если эта ошибка будет повторяться, то пожалуйста свяжитесь с администратором этого сервера, и приложите к сообщению технические подробности, приведённые ниже.",
+    "You are trying to access a private link. Please log in first." : "Вы пытаетесь получить доступ по личной ссылке. Пожалуйста, сначала войдите.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Возможно, что ваш экземпляр может содержать много файлов и/или пользователей. Чтобы обеспечить плавный процесс обновления, используйте обновление через командную строку(occ upgrade).",
+    "Couldn't send mail to following recipient(s): %s " : "Не удалось отправить почту следующим получателям: %s ",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Получение файлов от многих получателей без раскрытия содержимого каталога.",
+    "Recipients can view or download contents." : "Получатели могут просматривать или скачивать содержимое.",
+    "{sharee} (federated)" : "{sharee} (федеративный)",
+    "Personal note from the sender: %s." : "Личное замечание от отправителя: %s.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Автоматическое обновление отключается в config.php. Для обновления вашего экземпляра, пожалуйста, используйте командную строку(occ upgrade).",
+    "Imprint" : "Штамп",
+    "An error occured while sending email" : "При отправке письма произошла ошибка",
+    "E-Mail sent" : "Письмо отправлено",
+    "Privacy Policy" : "Политика конфиденциальности",
+    "Sharing is not allowed" : "Предоставление доступа не разрешено",
+    "Personal note from the sender: <br> %s." : "Личная заметка от отправителя: <br> %s."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
