@@ -334,6 +334,44 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Ju lutemi, përdorni përditësuesin e rreshtit të urdhrave, sepse keni një instalim të madh.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Për ndihmë, shihni  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentimin</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Kjo instancë %s hëpërhë gjendet nën mënyrën mirëmbajtje, çka mund të zgjasë ca.",
-    "This page will refresh itself when the %s instance is available again." : "Kjo faqe do të rifreskohet vetiu, sapo instanca %s të jetë sërish gati."
+    "This page will refresh itself when the %s instance is available again." : "Kjo faqe do të rifreskohet vetiu, sapo instanca %s të jetë sërish gati.",
+    "Could not reset password because the token is invalid" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i është i pavlefshëm",
+    "Could not reset password because the token expired" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i ka skaduar",
+    "Could not reset password because the token does not match" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i nuk përputhet",
+    "Copy to clipboard" : "Kopjoje në të papastër",
+    "Choose a password" : "Zgjidhni një fjalëkalim",
+    "Upload only" : "Vetëm ngarkim",
+    "Sending" : "Po dërgohet",
+    "Menu" : "Menu",
+    "Read only" : "Vetëm për lexim",
+    "Read & Write" : "Lexim & Shkrim",
+    "Email notification not sent" : "Njoftimi me email s’u dërgua",
+    "You took too long to login, please try again now" : "U vonuat shumë me hyrjen, ju lutemi, riprovoni tani",
+    "Choose an expiration date" : "Zgjidhni një datë skadimi",
+    "An error occured" : "Ndodhi një gabim",
+    "Send copy to self" : "Dërgojini vetes një kopje",
+    "Add personal message" : "Shtoni mesazh personal",
+    "Error adding {addItem}: {addItem} already exists" : "Gabim në shtimin e {addItem}: {addItem} ekziston tashmë",
+    "federated" : "i federuar",
+    "Link name" : "Emër lidhjeje",
+    "Recipients can view, download, edit, delete and upload contents." : "Marrësit mund të shohin shkarkojnë, përpunojnë, fshijnë dhe ngarkojnë lëndë.",
+    "Download / View" : "Të shkarkojë / Të shohë",
+    "Download / View / Upload" : "Të shkarkojë / Të shohë / Të ngarkojë",
+    "An error occured while sending email" : "Ndodhi një gabim gjatë dërgimit të email-it",
+    "Owner: {owner}" : "I zoti: {owner}",
+    "Email notification was sent!" : "Njoftimi me email u dërgua!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Ju lutemi, nëse ky gabim rishfaqet shumë herë, lidhuni me përgjegjësin e shërbyesit dhe në njoftimin tuaj përfshini hollësitë teknike të mëposhtme.",
+    "You are trying to access a private link. Please log in first." : "Po provoni të hapni një lidhje private. Ju lutemi, më parë bëni hyrjen.",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Duket sikur instanca juaj mund të strehojë shumë kartela dhe/ose përdorues. Për të garantuar një proces të rrjedhshëm përmirësimi, ju lutemi, përdorni përpunuesin për rresht urdhrash (occ upgrade).",
+    "Couldn't send mail to following recipient(s): %s " : "S’u dërgua dot postë te marrësi(t) vijues: %s ",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Merr kartela prej të tjerësh pa e zbuluar lëndën e dosjes.",
+    "Recipients can view or download contents." : "Marrësit mund të shohin dhe shkarkojnë lëndë.",
+    "{sharee} (federated)" : "{sharee} (i federuar)",
+    "Personal note from the sender: %s." : "Shënim personal nga dërguesi: %s.",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Përditësimi i vetvetishëm është i çaktivizuar te config.php. Që të përmirësoni instancën tuaj, ju lutemi, përdorni përditësuesin për rresht urdhrash (occ upgrade).",
+    "Imprint" : "Imprint",
+    "E-Mail sent" : "Email-i u dërgua",
+    "Privacy Policy" : "Rregulla Privatësie",
+    "Personal note from the sender: <br> %s." : "Shënim personal nga dërguesi: <br> %s."
 },
 "nplurals=2; plural=(n != 1);");
