@@ -50,12 +50,13 @@ OC.L10N.register(
     "Error" : "வழு",
     "Error while sharing" : "பகிரும் போதான வழு",
     "Error while unsharing" : "பகிராமல் உள்ளப்போதான வழு",
-    "Error setting expiration date" : "காலாவதியாகும் திகதியை குறிப்பிடுவதில் வழு",
     "Set expiration date" : "காலாவதி தேதியை குறிப்பிடுக",
     "Expiration date" : "காலவதியாகும் திகதி",
-    "Resharing is not allowed" : "மீள்பகிர்வதற்கு அனுமதி இல்லை ",
-    "Password protect" : "கடவுச்சொல்லை பாதுகாத்தல்",
+    "Edit" : "தொகுக்க",
+    "Remove" : "அகற்றுக",
     "Password" : "கடவுச்சொல்",
+    "Name" : "பெயர்",
+    "Save" : "சேமிக்க ",
     "Shared with you and the group {group} by {owner}" : "உங்களுடனும் குழுவுக்கிடையிலும் {குழு} பகிரப்பட்டுள்ளது {உரிமையாளர்}",
     "Shared with you by {owner}" : "உங்களுடன் பகிரப்பட்டுள்ளது {உரிமையாளர்}",
     "group" : "குழு",
@@ -65,6 +66,7 @@ OC.L10N.register(
     "delete" : "நீக்குக",
     "access control" : "கட்டுப்பாடான அணுகல்",
     "Share" : "பகிர்வு",
+    "Resharing is not allowed" : "மீள்பகிர்வதற்கு அனுமதி இல்லை ",
     "Warning" : "எச்சரிக்கை",
     "Delete" : "நீக்குக",
     "Rename" : "பெயர்மாற்றம்",
@@ -91,7 +93,6 @@ OC.L10N.register(
     "Log in" : "புகுபதிகை",
     "Use the following link to reset your password: {link}" : "உங்கள் கடவுச்சொல்லை மீளமைக்க பின்வரும் இணைப்பை பயன்படுத்தவும் : {இணைப்பு}",
     "New password" : "புதிய கடவுச்சொல்",
-    "Reset password" : "மீளமைத்த கடவுச்சொல்",
-    "Shared with you and the group {group} by {owner}" : "உங்களுடனும் குழுவுக்கிடையிலும் {குழு} பகிரப்பட்டுள்ளது {உரிமையாளர்}"
+    "Reset password" : "மீளமைத்த கடவுச்சொல்"
 },
 "nplurals=2; plural=(n != 1);");
