@@ -334,6 +334,45 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "กรุณาใช้คำสั่งการอัพเดทเพราะเหตุผลบางอย่าง",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : " สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">เอกสาร</a>",
     "This %s instance is currently in maintenance mode, which may take a while." : "%s กำลังอยู่ในโหมดการบำรุงรักษาซึ่งอาจใช้เวลาสักครู่",
-    "This page will refresh itself when the %s instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อ %s สามารถใช้ได้อีกครั้ง"
+    "This page will refresh itself when the %s instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อ %s สามารถใช้ได้อีกครั้ง",
+    "Could not reset password because the token is invalid" : "ไม่สามารถรีเซ็ตรหัสผ่านเนื่องจากโทเค็นไม่ถูกต้อง",
+    "Could not reset password because the token expired" : "ไม่สามารถรีเซ็ตรหัสผ่านเนื่องจากโทเค็นหมดอายุแล้ว",
+    "Could not reset password because the token does not match" : "ไม่สามารถรีเซ็ตรหัสผ่านเนื่องจากโทเค็นไม่ตรงกัน",
+    "Copy to clipboard" : "คัดลอกไปที่คลิปบอร์ด",
+    "Choose a password" : "เลือกรหัสผ่าน",
+    "Upload only" : "อัพโหลดเท่านั้น",
+    "Sending" : "กำลังส่ง",
+    "Menu" : "เมนู",
+    "Read only" : "อ่านอย่างเดียว",
+    "Read & Write" : "อ่านและเขียน",
+    "Email notification not sent" : "ไม่ได้ส่งการแจ้งเตือนทางอีเมล",
+    "You took too long to login, please try again now" : "คุณใช้เวลาลงชื่อเข้าใช้นานเกินไป โปรดลองอีกครั้ง",
+    "Choose an expiration date" : "เลือกวันหมดอายุ",
+    "An error occured" : "เกิดข้อผิดพลาด",
+    "Send copy to self" : "ส่งสำเนาให้กับตัวเอง",
+    "Add personal message" : "เพิ่มข้อความส่วนตัว",
+    "Error adding {addItem}: {addItem} already exists" : "เกิดข้อผิดพลาดขณะกำลังเพิ่ม {addItem}: {addItem} ที่มีอยู่แล้ว",
+    "federated" : "สหพันธ์",
+    "Link name" : "ชื่อลิงก์",
+    "Recipients can view, download, edit, delete and upload contents." : "ผู้รับสามารถดู ดาวน์โหลด แก้ไข ลบและอัพโหลดเนื้อหาได้",
+    "Download / View" : "ดาวน์โหลดหรือดู",
+    "Download / View / Upload" : "ดาวน์โหลด ดู หรืออัพโหลด",
+    "An error occured while sending email" : "เกิดข้อผิดพลาดขณะส่งอีเมล",
+    "Owner: {owner}" : "เจ้าของ: {owner}",
+    "Email notification was sent!" : "ส่งการแจ้งเตือนทางอีเมลแล้ว!",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "โปรดติดต่อผู้ดูแลระบบเซิร์ฟเวอร์หากเกิดข้อผิดพลาดนี้อีก และกรอกรายละเอียดในรายงานของคุณ",
+    "You are trying to access a private link. Please log in first." : "คุณกำลังพยายามเข้าถึงลิงก์ส่วนตัว โปรดเข้าสู่ระบบก่อน",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "ดูเหมือนว่าอินสแตนซ์ของคุณอาจมีโฮสต์ ไฟล์หรือผู้ใช้จำนวนมากเพื่อให้แน่ใจว่ากระบวนการอัพเกรดทำงานได้ปกติดี โปรดใช้คำสั่งอัพเดท (occ upgrade)",
+    "Couldn't send mail to following recipient(s): %s " : "ไม่สามารถส่งจดหมายไปยังผู้รับต่อไปนี้: %s",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "รับไฟล์จากผู้รับหลายรายโดยไม่ต้องเปิดเผยเนื้อหาของโฟลเดอร์",
+    "Recipients can view or download contents." : "ผู้รับสามารถดูหรือดาวน์โหลดเนื้อหา",
+    "{sharee} (federated)" : "{sharee} (ร่วมเป็นสหพันธ์แล้ว)",
+    "Personal note from the sender: %s." : "บันทึกส่วนบุคคลจากผู้ส่ง: %s",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "การอัพเดทโดยอัตโนมัติถูกปิดใช้งานใน config.php เพื่ออัพเกรดอินสแตนซ์ของคุณโปรดใช้คำสั่งอัพเดท (occ upgrade)",
+    "Imprint" : "ประทับ",
+    "E-Mail sent" : "ส่งอิีเมล",
+    "Privacy Policy" : "นโยบายส่วนบุคคล",
+    "Sharing is not allowed" : "ไม่อนุญาตให้แชร์",
+    "Personal note from the sender: <br> %s." : "บันทึกส่วนบุคคลจากผู้ส่ง: <br>%s"
 },
 "nplurals=1; plural=0;");
