@@ -301,6 +301,13 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "Просимо запустити процес оновлення з командного рядка, оскільки ви маєте багато даних.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "За допомогою зверніться до <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документації</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Цей %s знаходиться в режимі технічного обслуговування, яке може зайняти деякий час.",
-    "This page will refresh itself when the %s instance is available again." : "Ця сторінка автоматично перезавантажиться коли екземпляр %s стане знову доступний."
+    "This page will refresh itself when the %s instance is available again." : "Ця сторінка автоматично перезавантажиться коли екземпляр %s стане знову доступний.",
+    "Remove link" : "Видалити посилання",
+    "Copy to clipboard" : "Копіювати в буфер обміну",
+    "Anyone with the link has access to the file/folder" : "Будь хто з цім посиланням має доступ до файлу/теки",
+    "Menu" : "Меню",
+    "Link name" : "Ім'я посилання",
+    "Imprint" : "Відбиток",
+    "%s password changed successfully" : "%s пароль змінено успішно"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
