@@ -332,6 +332,39 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance." : "请使用命令行更新。",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "该 %s 实例当前处于维护模式，这将进行一些时间。",
-    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时这个页面将刷新。"
+    "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时这个页面将刷新。",
+    "Could not reset password because the token is invalid" : "无法重置密码，因为该令牌无效。",
+    "Could not reset password because the token expired" : "无法重置密码，因为该令牌已过期。",
+    "Could not reset password because the token does not match" : "因令牌不符无法重置密码",
+    "Copy to clipboard" : "复制到剪贴板 ",
+    "Anyone with the link has access to the file/folder" : "任何查看此链接的人都可以访问文件、文件夹",
+    "Upload only" : "仅上传",
+    "Sending" : "发送中",
+    "Menu" : "菜单",
+    "Link name" : "链接名称",
+    "Owner: {owner}" : "所有者：{owner}",
+    "You are trying to access a private link. Please log in first." : "您在尝试访问私有链接，请先登录。",
+    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "您的实例可能包含较多文件和/或用户，为保证更新过程流畅，请使用命令行更新工具 (occ upgrade)。",
+    "Couldn't send mail to following recipient(s): %s " : "无法发送邮件到下列收件人: %s ",
+    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "自动更新在 config.php 中被禁用，请使用命令行更新工具 (occ upgrade) 升级您的实例。",
+    "Imprint" : "版本说明",
+    "Email notification was sent!" : "电子邮件通知已发送！",
+    "Email notification not sent" : "电子邮件通知未发送",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "如果此错误多次复现请联系服务器管理员，并在报告中包含以下技术细节。",
+    "You took too long to login, please try again now" : "你的登录花费时间过长，请重试一次。",
+    "Choose an expiration date" : "选择过期日期",
+    "Choose a password" : "选择一个密码",
+    "Download / View" : "下载 / 查看",
+    "Download / View / Upload" : "下载 / 查看 / 上传",
+    "Send copy to self" : "发送副本给自己。",
+    "Add personal message" : "增加个人信息",
+    "Privacy Policy" : "隐私政策",
+    "Error adding {addItem}: {addItem} already exists" : "添加{addItem}时发生错误：{addItem}已经存在",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "从多个接收者处接收文件而不暴露文件夹中的内容。",
+    "Recipients can view or download contents." : "接收者可查看或下载内容。",
+    "Recipients can view, download, edit, delete and upload contents." : "接收者可查看、下载、编辑、删除以及上传内容。",
+    "An error occured while sending email" : "发送电子邮件时发生错误",
+    "E-Mail sent" : "邮件已发送",
+    "Sharing is not allowed" : "禁止分享"
 },
 "nplurals=1; plural=0;");
