@@ -278,6 +278,49 @@ OC.L10N.register(
     "Start update" : "開始升級",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在大型安裝上，為了避免升級請求逾時，你也可以在安裝目錄執行下列指令：",
     "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，需要一段時間恢復。",
-    "This page will refresh itself when the %s instance is available again." : "%s 安裝恢復可用之後，本頁會自動重新整理"
+    "This page will refresh itself when the %s instance is available again." : "%s 安裝恢復可用之後，本頁會自動重新整理",
+    "Expiration date is required" : "需要過期日期",
+    "Remove link" : "移除連結",
+    "Copy to clipboard" : "複製到剪貼簿",
+    "Choose a password" : "選擇密碼",
+    "Password required" : "需要密碼",
+    "Public Links" : "公共連結",
+    "Menu" : "選單",
+    "Link name" : "連結名稱",
+    "Imprint" : "法律聲明",
+    "Could not reset password because the token is invalid" : "無法重設密碼，因為令牌無效",
+    "Could not reset password because the token expired" : "無法重設密碼，因為令牌過期",
+    "Could not reset password because the token does not match" : "無法重設密碼，因為令牌不符",
+    "%s password changed successfully" : "%s 密碼修改成功",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Dismiss" : "忽略",
+    "Delete {link}" : "刪除 {link}",
+    "{fileName} link" : "{fileName} 連結",
+    "Copied!" : "已複製！",
+    "Not supported!" : "不支援！",
+    "Press ⌘-C to copy." : "按下 ⌘-C 以複製",
+    "Press Ctrl-C to copy." : "按下 Ctrl-C 以複製",
+    "Sending" : "傳送中",
+    "User and Groups" : "使用者及群組",
+    "Username or email" : "使用者名稱或電子郵件",
+    "Create public link" : "建立公開連結",
+    "Remove password" : "移除密碼",
+    "Couldn't send mail to following recipient(s): %s " : "無法發送郵件給以下人員：%s",
+    "Choose an expiration date" : "選擇到期日期",
+    "Social share" : "社群分享",
+    "Download / View" : "下載 / 檢視",
+    "Download / View / Upload" : "下載 / 檢視 / 上傳",
+    "Share to Twitter. Opens in a new window." : "分享到 Twitter。開啟新視窗。",
+    "Share to Facebook. Opens in a new window." : "分享到 Facebook。開啟新視窗。",
+    "Share to Diaspora. Opens in a new window." : "分享到 Diaspora。開啟新視窗。",
+    "Share to Google+. Opens in a new window." : "分享到 Google+。開啟新視窗。",
+    "Share via email. Opens your mail client." : "分享到電子郵件。開啟郵件客戶端。",
+    "Add personal message" : "新增個人訊息",
+    "Updating to {version}" : "更新至 {version}",
+    "Cancel login" : "取消登入",
+    "An error occurred while verifying the token" : "驗證令牌時發生錯誤",
+    "Upload only" : "僅上傳",
+    "Two-step verification" : "兩步驟驗證",
+    "Update needed" : "需要更新"
 },
 "nplurals=1; plural=0;");
