@@ -168,6 +168,9 @@ OC.L10N.register(
     "Storage unauthorized. %s" : "Almacenamientu desautorizáu. %s",
     "Storage incomplete configuration. %s" : "Configuración d'almacenamientu incompleta. %s",
     "Storage connection error. %s" : "Fallu de conexón al almacenamientu. %s",
-    "Storage connection timeout. %s" : "Tiempu escosao de conexón al almacenamientu. %s"
+    "Storage connection timeout. %s" : "Tiempu escosao de conexón al almacenamientu. %s",
+    "A safe home for all your data" : "Un llar seguru pa tolos sos datos",
+    "Imprint" : "Imprint",
+    "__language_name__" : "Asturianu"
 },
 "nplurals=2; plural=(n != 1);");
