@@ -171,6 +171,9 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Непълна конфигруацията на дисково устройство. %s",
     "Storage connection error. %s" : "Грешка при свързване с дисково пространство. %s",
     "Storage is temporarily not available" : "Съхраняването е временно деактивирано",
-    "Storage connection timeout. %s" : "Престъпен времеви лимит за свързване с дисково устройство. %s"
+    "Storage connection timeout. %s" : "Престъпен времеви лимит за свързване с дисково устройство. %s",
+    "A safe home for all your data" : "Сигурен дом за цялата всичките Ви данни",
+    "Imprint" : "Imprint",
+    "__language_name__" : "Български"
 },
 "nplurals=2; plural=(n != 1);");
