@@ -11,6 +11,7 @@ OC.L10N.register(
     "Search" : "Suche",
     "Help" : "Hilfe",
     "Settings" : "Einstellungen",
-    "Users" : "Benutzer"
+    "Users" : "Benutzer",
+    "__language_name__" : "Deutsch (Österreich)"
 },
 "nplurals=2; plural=(n != 1);");
