@@ -174,6 +174,17 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
     "Storage connection error. %s" : "Storage connection error. %s",
     "Storage is temporarily not available" : "Storage is temporarily not available",
-    "Storage connection timeout. %s" : "Storage connection timeout. %s"
+    "Storage connection timeout. %s" : "Storage connection timeout. %s",
+    "Help & Tips" : "Help & Tips",
+    "Additional" : "Additional",
+    "A safe home for all your data" : "A safe home for all your data",
+    "User Authentication" : "User Authentication",
+    "The username must be at least 3 characters long" : "The username must be at least 3 characters long",
+    "File cannot be read" : "File cannot be read",
+    "Workflows & Tags" : "Workflows & Tags",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s is not supported and %s will not work properly on this platform. Use it at your own risk! ",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "Sharing %s failed, could not find %s, check spelling and server availability.",
+    "Imprint" : "Imprint",
+    "__language_name__" : "English (British English)"
 },
 "nplurals=2; plural=(n != 1);");
