@@ -123,6 +123,9 @@ OC.L10N.register(
     "Please upgrade your database version" : "Palun uuenda oma andmebaasi versiooni",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Palun veendu, et andmete kataloogis sisaldub fail \".ocdata\" ",
-    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
+    "A safe home for all your data" : "Turvaline kodu kõigile sinu andmetele",
+    "Imprint" : "Impressum",
+    "__language_name__" : "Eesti"
 },
 "nplurals=2; plural=(n != 1);");
