@@ -154,6 +154,10 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Tallennustilan puutteellinen määritys. %s",
     "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
     "Storage is temporarily not available" : "Tallennustila ei juuri nyt ole käytettävissä",
-    "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s"
+    "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
+    "A safe home for all your data" : "Turvallinen koti tiedoillesi",
+    "Imprint" : "Tiedot",
+    "__language_name__" : "_kielen_nimi_",
+    "Privacy Policy" : "Tietosuojalauseke"
 },
 "nplurals=2; plural=(n != 1);");
