@@ -176,6 +176,16 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Configuration de l'espace de stockage incomplète. %s",
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
     "Storage is temporarily not available" : "Espace de stockage temporairement indisponible",
-    "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s"
+    "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
+    "A safe home for all your data" : "Un endroit sûr pour toutes vos données",
+    "User Authentication" : "Autentification de l'utilisateur",
+    "The username must be at least 3 characters long" : "Le nom d'utilisateur doit comporter au moins 3 caractères",
+    "File cannot be read" : "Le fichier ne peut être lu",
+    "Workflows & Tags" : "Flux et étiquettes",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%sn'est pas supporté et %sne fonctionnera pas correctement sur cette plateforme. Utilisez le à vos propres risques!",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "Le partage de %s a échoué, impossible de trouver %s. Veuillez vérifier l'orthographe ainsi que la disponibilité du serveur.",
+    "Imprint" : "Mentions légales",
+    "Privacy Policy" : "Politique de confidentialité",
+    "__language_name__" : "Français"
 },
 "nplurals=2; plural=(n > 1);");
