@@ -20,6 +20,7 @@ OC.L10N.register(
     "Help" : "Adjuta",
     "Settings" : "Configurationes",
     "Users" : "Usatores",
-    "web services under your control" : "servicios web sub tu controlo"
+    "web services under your control" : "servicios web sub tu controlo",
+    "__language_name__" : "Interlingua"
 },
 "nplurals=2; plural=(n != 1);");
