@@ -177,6 +177,9 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "設定が未完了のストレージです。 %s",
     "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
     "Storage is temporarily not available" : "ストレージが一時的に利用できません",
-    "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s"
+    "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
+    "A safe home for all your data" : "あなたの持っているデータすべての安全な保存先",
+    "Imprint" : "インプリント",
+    "__language_name__" : "Japanese (日本語)"
 },
 "nplurals=1; plural=0;");
