@@ -40,6 +40,7 @@ OC.L10N.register(
     "web services under your control" : "សេវាកម្ម​វេប​ក្រោម​ការ​ការ​បញ្ជា​របស់​អ្នក",
     "Application is not enabled" : "មិន​បាន​បើក​កម្មវិធី",
     "Authentication error" : "កំហុស​ការ​ផ្ទៀង​ផ្ទាត់​ភាព​ត្រឹម​ត្រូវ",
-    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់"
+    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់",
+    "__language_name__" : "__language_name__"
 },
 "nplurals=1; plural=0;");
