@@ -6,10 +6,6 @@ OC.L10N.register(
     "PHP %s or higher is required." : "PHP %s oder méi nei ass néideg.",
     "PHP with a version lower than %s is required." : "PHP mat enger Versioun %s oder méi kleng ass néideg.",
     "Following databases are supported: %s" : "Dës Datebanke ginn ënnerstëtzt: %s",
-    "Help" : "Hëllef",
-    "Personal" : "Perséinlech",
-    "Users" : "Benotzer",
-    "Admin" : "Admin",
     "Unknown filetype" : "Onbekannten Fichier Typ",
     "Invalid image" : "Ongülteg d'Bild",
     "today" : "haut",
@@ -21,10 +17,26 @@ OC.L10N.register(
     "_%n year ago_::_%n years ago_" : ["%n Joer hier","%n Joer hier"],
     "_%n hour ago_::_%n hours ago_" : ["%n Stonn hier","%n Stonnen hier"],
     "seconds ago" : "Sekonnen hir",
+    "None" : "Keng",
+    "Username" : "Benotzernumm",
+    "Password" : "Passwuert",
+    "File name contains at least one invalid character" : "Den Numm vum Fichier entält min. een ongültegz Zeechen",
+    "Apps" : "Applikatiounen",
+    "General" : "Allgemeng",
+    "Security" : "Sécherheet",
+    "Encryption" : "Verschlësselung",
+    "Sharing" : "Gedeelt",
+    "Search" : "Sichen",
+    "Updates" : "Updates",
+    "%s shared »%s« with you" : "Den/D' %s huet »%s« mat dir gedeelt",
+    "A valid username must be provided" : "Et muss e gültegen Benotzernumm ugi ginn",
+    "A valid password must be provided" : "Et muss e gültegt Passwuert ugi ginn",
+    "Help" : "Hëllef",
+    "Settings" : "Astellungen",
+    "Users" : "Benotzer",
     "web services under your control" : "Web-Servicer ënnert denger Kontroll",
     "Authentication error" : "Authentifikatioun's Fehler",
-    "%s shared »%s« with you" : "Den/D' %s huet »%s« mat dir gedeelt",
-    "Apps" : "Applikatiounen",
-    "Data directory (%s) is invalid" : "Daten-Dossier (%s) ass ongëlteg"
+    "Imprint" : "Impressum",
+    "__language_name__" : "__language_name__"
 },
 "nplurals=2; plural=(n != 1);");
