@@ -42,6 +42,7 @@ OC.L10N.register(
     "web services under your control" : "tīmekļa servisi tavā varā",
     "Application is not enabled" : "Lietotne nav aktivēta",
     "Authentication error" : "Autentifikācijas kļūda",
-    "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu."
+    "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu.",
+    "__language_name__" : "__valodas_nosaukums__"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
