@@ -10,6 +10,7 @@ OC.L10N.register(
     "Settings" : "Tetapan",
     "Users" : "Pengguna",
     "web services under your control" : "Perkhidmatan web di bawah kawalan anda",
-    "Authentication error" : "Ralat pengesahan"
+    "Authentication error" : "Ralat pengesahan",
+    "__language_name__" : "_nama_bahasa_"
 },
 "nplurals=1; plural=0;");
