@@ -177,6 +177,16 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Ikke komplett oppsett for lager. %s",
     "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
     "Storage is temporarily not available" : "Lagring er for tiden ikke tilgjengelig",
-    "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s"
+    "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s",
+    "A safe home for all your data" : "Et trygt hjem for alle dine data",
+    "User Authentication" : "Bruker autentisering",
+    "The username must be at least 3 characters long" : "Brukernavn må være minst tre tegn langt",
+    "File cannot be read" : "Fil kan ikke leses",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%ser ikke støttet og %svil ikke fungere tilstrekkelig på denne platformen. Bruk på egen risiko.",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "Deling %s mislyktes, kunne ikke finne %s, kontroller input og server tilgjengelighet.",
+    "Imprint" : "Avtrykk",
+    "__language_name__" : "__language_name__",
+    "Privacy Policy" : "Personvern regler",
+    "The username can not be longer than 64 characters" : "Brukernavn kan ikke være lengre en 64 tegn"
 },
 "nplurals=2; plural=(n != 1);");
