@@ -177,6 +177,13 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Incomplete opslagconfiguratie. %s",
     "Storage connection error. %s" : "Opslagverbindingsfout. %s",
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
-    "Storage connection timeout. %s" : "Opslagverbinding time-out. %s"
+    "Storage connection timeout. %s" : "Opslagverbinding time-out. %s",
+    "A safe home for all your data" : "Een veilig thuis voor al uw gegevens",
+    "User Authentication" : "Gebruiker authenticatie",
+    "File cannot be read" : "Bestand kan niet worden gelezen",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s wordt niet ondersteund en %s zal niet goed werken op dit platform. Gebruik het op uw eigen risico!",
+    "Imprint" : "afdruk",
+    "__language_name__" : "Nederlands",
+    "Privacy Policy" : "Privacybeleid"
 },
 "nplurals=2; plural=(n != 1);");
