@@ -159,6 +159,9 @@ OC.L10N.register(
     "Storage unauthorized. %s" : "Espaci d'emmagazinatge pas autorizat. %s",
     "Storage incomplete configuration. %s" : "Configuracion de l'espaci d'emmagazinatge incompleta. %s",
     "Storage connection error. %s" : "Error de connexion a l'espaci d'emmagazinatge. %s",
-    "Storage is temporarily not available" : "Espaci d'emmagazinatge temporàriament indisponible"
+    "Storage is temporarily not available" : "Espaci d'emmagazinatge temporàriament indisponible",
+    "A safe home for all your data" : "Un endrech segur per totas vòstras donadas",
+    "Imprint" : "Mencions",
+    "__language_name__" : "Occitan-lengadocian"
 },
 "nplurals=2; plural=(n > 1);");
