@@ -12,6 +12,8 @@ OC.L10N.register(
     "Sharing" : "ਸਾਂਝ",
     "Search" : "ਖੋਜ",
     "Help" : "ਮਦਦ",
-    "Settings" : "ਸੈਟਿੰਗ"
+    "Settings" : "ਸੈਟਿੰਗ",
+    "Imprint" : "ਛਾਪ",
+    "__language_name__" : "__ਭਾਸ਼ਾ_ਨਾਂ__"
 },
 "nplurals=2; plural=(n != 1);");
