@@ -178,6 +178,15 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Incompleta configuração de armazenamento. %s",
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
-    "Storage connection timeout. %s" : "Tempo limite de conexão de armazenamento. %s"
+    "Storage connection timeout. %s" : "Tempo limite de conexão de armazenamento. %s",
+    "A safe home for all your data" : "Um lugar seguro para todos os seus dados",
+    "The username must be at least 3 characters long" : "O nome de usuário deve ter pelo menos 3 caracteres",
+    "File cannot be read" : "O arquivo não pode ser lido",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco. ",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "O compartilhamento  %s falhou, não foi possível encontrar %s, verifique o que foi digitado e a disponibilidade do servidor.",
+    "Imprint" : "Imprimir",
+    "The username can not be longer than 64 characters" : "O nome de usuário não pode ter mais de 64 caracteres",
+    "Privacy Policy" : "Política de Privacidade",
+    "__language_name__" : "__language_name__"
 },
 "nplurals=2; plural=(n > 1);");
