@@ -177,6 +177,10 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
     "Storage connection error. %s" : "Erro de ligação ao armazenamento. %s",
     "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
-    "Storage connection timeout. %s" : "Tempo de ligação ao armazenamento expirou. %s"
+    "Storage connection timeout. %s" : "Tempo de ligação ao armazenamento expirou. %s",
+    "A safe home for all your data" : "Um local seguro para todos os seus dados",
+    "Imprint" : "Marca",
+    "__language_name__" : "__language_name__",
+    "Privacy Policy" : "Política de Privacidade"
 },
 "nplurals=2; plural=(n != 1);");
