@@ -178,6 +178,15 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Неполная конфигурация хранилища.  %s",
     "Storage connection error. %s" : "Ошибка подключения к хранилищу. %s",
     "Storage is temporarily not available" : "Хранилище временно не доступно",
-    "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s"
+    "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
+    "A safe home for all your data" : "Безопасный дом для всех ваших данных",
+    "The username must be at least 3 characters long" : "Имя пользователя должно быть не менее 3 символов в длину",
+    "File cannot be read" : "Невозможно прочитать файл",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s не поддерживается и %s не будет работать правильно на этой платформе. Используйте на свой страх и риск! ",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "Не удалось предоставить доступ к %s, не удалось найти %s, проверьте написание и доступность сервера.",
+    "Imprint" : "Штамп",
+    "The username can not be longer than 64 characters" : "Имя пользователя не может быть длиннее 64 символов",
+    "Privacy Policy" : "Политика конфиденциальности",
+    "__language_name__" : "Русский"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
