@@ -177,6 +177,11 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Nepopolna nastavitev shrambe. %s",
     "Storage connection error. %s" : "Napaka povezave do shrambe. %s",
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
-    "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s"
+    "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
+    "A safe home for all your data" : "Varno mesto za vse pomembne podatke",
+    "User Authentication" : "Overitev uporabnika",
+    "File cannot be read" : "Datoteke ni mogoče prebrati",
+    "Imprint" : "Natis",
+    "__language_name__" : "Slovenščina"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
