@@ -178,6 +178,15 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Formësim jo i plotë i depozitës. %s",
     "Storage connection error. %s" : "Gabim lidhje te depozita. %s",
     "Storage is temporarily not available" : "Depozita është përkohësisht jashtë pune",
-    "Storage connection timeout. %s" : "Mbarim kohe lidhjeje për depozitën. %s"
+    "Storage connection timeout. %s" : "Mbarim kohe lidhjeje për depozitën. %s",
+    "A safe home for all your data" : "Një shtëpi e sigurt për krejt të dhënat tuaja",
+    "The username must be at least 3 characters long" : "Emri i përdoruesit duhet të jetë e pakta 3 shenja i gjatë",
+    "File cannot be read" : "Kartela s’lexohet dot",
+    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s nuk mbulohet dhe %s s’do të funksionojë si duhet në këtë platformë. Qari dhe zarari, i juaji! ",
+    "Sharing %s failed, could not find %s, check spelling and server availability." : "Ndarja me të tjerët e %s dështoi, s’u gjet dot %s, kontrollori i drejtshkrimit dhe shërbyesi në punë.",
+    "Imprint" : "Imprint",
+    "The username can not be longer than 64 characters" : "Emri i përdoruesit s’mund të jetë më i gjatë se 64 shenja",
+    "Privacy Policy" : "Rregulla Privatësie",
+    "__language_name__" : "Shqip"
 },
 "nplurals=2; plural=(n != 1);");
