@@ -141,6 +141,8 @@ OC.L10N.register(
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Промените дозволе у 0770 како директоријуми не би могли бити излистани од стране других корисника.",
     "Check the value of \"datadirectory\" in your configuration" : "Проверите податак за \"datadirectory\" у вашој конфигурацији",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Проверите да ли директоријум података садржи фајл „.ocdata“ у свом основном директоријуму.",
-    "Could not obtain lock type %d on \"%s\"." : "Не могу да остварим закључаност %d за „%s“."
+    "Could not obtain lock type %d on \"%s\"." : "Не могу да остварим закључаност %d за „%s“.",
+    "Imprint" : "Жиг",
+    "__language_name__" : "Српски"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
