@@ -19,6 +19,7 @@ OC.L10N.register(
     "Help" : "Pomoć",
     "Settings" : "Podešavanja",
     "Users" : "Korisnici",
-    "Authentication error" : "Greška pri autentifikaciji"
+    "Authentication error" : "Greška pri autentifikaciji",
+    "Imprint" : "Žig"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
