@@ -135,6 +135,36 @@ OC.L10N.register(
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra rättigheterna till 0770 så att katalogen inte kan listas utav andra användare.",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Vänligen kontrollera att datakatalogen innehåller filen \".ocdata\" i rooten.",
     "Could not obtain lock type %d on \"%s\"." : "Kan inte hämta låstyp %d på \"%s\".",
-    "Storage is temporarily not available" : "Lagring är temporärt inte tillgänglig"
+    "Storage is temporarily not available" : "Lagring är temporärt inte tillgänglig",
+    "Help & Tips" : "Hjälp och text",
+    "Additional" : "Ytterligare",
+    "A safe home for all your data" : "En säker lagringsplats för all din data",
+    "User Authentication" : "Användarautentisering",
+    "Workflows & Tags" : "Arbetsflöden och taggar",
+    "Username contains whitespace at the beginning or at the end" : "Användarnamnet innehåller ett blankslag vid början eller slutet",
+    "Login canceled by app" : "Inloggningen avbröts av appen",
+    "User disabled" : "Användare inaktiverad",
+    "Your Data directory is readable by other users" : "Din datamapp är läsbar för andra användare",
+    "Your Data directory must be an absolute path" : "Din datamapp måste ha en absolut sökväg",
+    "Your Data directory  is invalid" : "Din datamapp är ogiltig",
+    "Storage unauthorized. %s" : "Lagring obehörig. %s",
+    "Storage connection error. %s" : "Anslutningsfel till lagring. %s",
+    "Storage connection timeout. %s" : "Anslutningstiden överskreds till lagring. %s",
+    "Avatar image is not square" : "Avatarbilden är inte fyrkantig",
+    "Sharing %s failed, because you can not share with yourself" : "Delningen %s misslyckades då du inte kan dela med dig själv",
+    "Sharing %s failed, because this item is already shared with user %s" : "Delningen %s misslyckades då objektet redan är delat med användaren %s",
+    "Sharing failed, because the user %s is the original sharer" : "Delning misslyckades då användaren %s är ursprungsdelaren",
+    "Cannot increase permissions of %s" : "Kan inte öka behörigheterna för %s",
+    "Files can't be shared with delete permissions" : "Filer utan rättigheter kan inte delars",
+    "Files can't be shared with create permissions" : "Filer utan rättigheter för skapa kan inte delas",
+    "File is currently busy, please try again later" : "Filen är för närvarande upptagen, försök igen senare",
+    "%s via %s" : "%s via %s",
+    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulen %s finns inte. Aktiveraden i dina programinställningar eller kontakta din administratör.",
+    "%s enter the database username and name." : "%s ange användarnamn och lösenord för servern",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort inställningen open_basedir i din php.ini-fil eller byt till 64-bitars PHP.",
+    "Cannot clear expiration date. Shares are required to have an expiration date." : "Kan inte rensa utgångsdatum. Delningar måste ha en utgångsdatum.",
+    "Expiration date is in the past" : "Utgångsdatumet är från det förflutna",
+    "Imprint" : "Imprint",
+    "__language_name__" : "__language_name__"
 },
 "nplurals=2; plural=(n != 1);");
