@@ -168,6 +168,9 @@ OC.L10N.register(
     "Storage unauthorized. %s" : "Depolamaya erişim izni yok. %s",
     "Storage incomplete configuration. %s" : "Depolamada tamamlanmamış yapılandırma. %s",
     "Storage connection error. %s" : "Depolama bağlantı hatası. %s",
-    "Storage connection timeout. %s" : "Depolama bağlantı zaman aşımı. %s"
+    "Storage connection timeout. %s" : "Depolama bağlantı zaman aşımı. %s",
+    "A safe home for all your data" : "Verileriniz için güvenli bir yuva",
+    "Imprint" : "İzlenim",
+    "__language_name__" : "Türkçe"
 },
 "nplurals=2; plural=(n > 1);");
