@@ -18,6 +18,7 @@ OC.L10N.register(
     "Help" : "ياردەم",
     "Settings" : "تەڭشەكلەر",
     "Users" : "ئىشلەتكۈچىلەر",
-    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى"
+    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
+    "__language_name__" : "ئۇيغۇرچە"
 },
 "nplurals=1; plural=0;");
