@@ -162,6 +162,9 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
     "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
     "Storage is temporarily not available" : "Сховище тимчасове недоступне",
-    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s"
+    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
+    "A safe home for all your data" : "Безпечне місце для усієї вашої інформації.",
+    "Imprint" : "Відбиток",
+    "__language_name__" : "__language_name__"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
