@@ -11,7 +11,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -56,6 +56,7 @@ class AppManager implements IAppManager {
 		'authentication',
 		'logging',
 		'prevent_group_restriction',
+		'theme',
 	];
 
 	/** @var \OCP\IUserSession */
@@ -116,14 +117,14 @@ class AppManager implements IAppManager {
 			$values = $this->appConfig->getValues(false, 'enabled');
 
 			$alwaysEnabledApps = $this->getAlwaysEnabledApps();
-			foreach($alwaysEnabledApps as $appId) {
+			foreach ($alwaysEnabledApps as $appId) {
 				$values[$appId] = 'yes';
 			}
 
-			$this->installedAppsCache = array_filter($values, function ($value) {
+			$this->installedAppsCache = \array_filter($values, function ($value) {
 				return $value !== 'no';
 			});
-			ksort($this->installedAppsCache);
+			\ksort($this->installedAppsCache);
 		}
 		return $this->installedAppsCache;
 	}
@@ -134,7 +135,7 @@ class AppManager implements IAppManager {
 	 * @return string[]
 	 */
 	public function getInstalledApps() {
-		return array_keys($this->getInstalledAppsValues());
+		return \array_keys($this->getInstalledAppsValues());
 	}
 
 	/**
@@ -145,10 +146,10 @@ class AppManager implements IAppManager {
 	 */
 	public function getEnabledAppsForUser(IUser $user = null) {
 		$apps = $this->getInstalledAppsValues();
-		$appsForUser = array_filter($apps, function ($enabled) use ($user) {
+		$appsForUser = \array_filter($apps, function ($enabled) use ($user) {
 			return $this->checkAppForUser($enabled, $user);
 		});
-		return array_keys($appsForUser);
+		return \array_keys($appsForUser);
 	}
 
 	/**
@@ -162,7 +163,7 @@ class AppManager implements IAppManager {
 		if ($this->isAlwaysEnabled($appId)) {
 			return true;
 		}
-		if (is_null($user) && !is_null($this->userSession)) {
+		if ($user === null && $this->userSession !== null) {
 			$user = $this->userSession->getUser();
 		}
 		$installedApps = $this->getInstalledAppsValues();
@@ -181,24 +182,24 @@ class AppManager implements IAppManager {
 	private function checkAppForUser($enabled, $user) {
 		if ($enabled === 'yes') {
 			return true;
-		} elseif (is_null($user)) {
+		} elseif ($user === null) {
 			return false;
 		} else {
-			if(empty($enabled)){
+			if (empty($enabled)) {
 				return false;
 			}
 
-			$groupIds = json_decode($enabled);
+			$groupIds = \json_decode($enabled);
 
-			if (!is_array($groupIds)) {
-				$jsonError = json_last_error();
-				\OC::$server->getLogger()->warning('AppManger::checkAppForUser - can\'t decode group IDs: ' . print_r($enabled, true) . ' - json error code: ' . $jsonError, ['app' => 'lib']);
+			if (!\is_array($groupIds)) {
+				$jsonError = \json_last_error();
+				\OC::$server->getLogger()->warning('AppManager::checkAppForUser - can\'t decode group IDs: ' . \print_r($enabled, true) . ' - json error code: ' . $jsonError, ['app' => 'lib']);
 				return false;
 			}
 
 			$userGroups = $this->groupManager->getUserGroupIds($user);
 			foreach ($userGroups as $groupId) {
-				if (array_search($groupId, $groupIds) !== false) {
+				if (\array_search($groupId, $groupIds) !== false) {
 					return true;
 				}
 			}
@@ -224,9 +225,14 @@ class AppManager implements IAppManager {
 	 * @throws \Exception
 	 */
 	public function enableApp($appId) {
-		if($this->getAppPath($appId) === false) {
+		if ($this->getAppPath($appId) === false) {
 			throw new \Exception("$appId can't be enabled since it is not installed.");
 		}
+
+		if (!Installer::isInstalled($appId)) {
+			Installer::installShippedApp($appId);
+		}
+
 		$this->canEnableTheme($appId);
 
 		$this->installedAppsCache[$appId] = 'yes';
@@ -247,11 +253,14 @@ class AppManager implements IAppManager {
 		$info = $this->getAppInfo($appId);
 		if (
 			isset($info['types'])
-			&& is_array($info['types'])
-			&& in_array('theme', $info['types'])
+			&& \is_array($info['types'])
+			&& \in_array('theme', $info['types'])
 		) {
 			$apps = $this->getInstalledApps();
 			foreach ($apps as $installedAppId) {
+				if ($installedAppId === $appId) {
+					continue;
+				}
 				if ($this->isTheme($installedAppId)) {
 					throw new AppManagerException("$appId can't be enabled until $installedAppId is disabled.");
 				}
@@ -266,7 +275,7 @@ class AppManager implements IAppManager {
 	 * @return bool
 	 */
 	protected function isTheme($appId) {
-		return \OC_App::isType($appId,'theme');
+		return \OC_App::isType($appId, 'theme');
 	}
 
 	/**
@@ -279,18 +288,22 @@ class AppManager implements IAppManager {
 	public function enableAppForGroups($appId, $groups) {
 		$info = $this->getAppInfo($appId);
 		if (!empty($info['types'])) {
-			$protectedTypes = array_intersect($this->protectedAppTypes, $info['types']);
+			$protectedTypes = \array_intersect($this->protectedAppTypes, $info['types']);
 			if (!empty($protectedTypes)) {
 				throw new \Exception("$appId can't be enabled for groups.");
 			}
 		}
 
-		$groupIds = array_map(function ($group) {
+		if (!Installer::isInstalled($appId)) {
+			Installer::installShippedApp($appId);
+		}
+
+		$groupIds = \array_map(function ($group) {
 			/** @var \OCP\IGroup $group */
 			return $group->getGID();
 		}, $groups);
-		$this->installedAppsCache[$appId] = json_encode($groupIds);
-		$this->appConfig->setValue($appId, 'enabled', json_encode($groupIds));
+		$this->installedAppsCache[$appId] = \json_encode($groupIds);
+		$this->appConfig->setValue($appId, 'enabled', \json_encode($groupIds));
 		$this->dispatcher->dispatch(ManagerEvent::EVENT_APP_ENABLE_FOR_GROUPS, new ManagerEvent(
 			ManagerEvent::EVENT_APP_ENABLE_FOR_GROUPS, $appId, $groups
 		));
@@ -339,7 +352,7 @@ class AppManager implements IAppManager {
 			$appDbVersion = $this->appConfig->getValue($appId, 'installed_version');
 			if ($appDbVersion
 				&& isset($appInfo['version'])
-				&& version_compare($appInfo['version'], $appDbVersion, '>')
+				&& \version_compare($appInfo['version'], $appDbVersion, '>')
 				&& \OC_App::isAppCompatible($ocVersion, $appInfo)
 			) {
 				$appsToUpgrade[] = $appInfo;
@@ -396,21 +409,21 @@ class AppManager implements IAppManager {
 	 */
 	public function isShipped($appId) {
 		$this->loadShippedJson();
-		return in_array($appId, $this->shippedApps);
+		return \in_array($appId, $this->shippedApps);
 	}
 
 	private function isAlwaysEnabled($appId) {
 		$alwaysEnabled = $this->getAlwaysEnabledApps();
-		return in_array($appId, $alwaysEnabled);
+		return \in_array($appId, $alwaysEnabled);
 	}
 
 	private function loadShippedJson() {
-		if (is_null($this->shippedApps)) {
+		if ($this->shippedApps === null) {
 			$shippedJson = \OC::$SERVERROOT . '/core/shipped.json';
-			if (!file_exists($shippedJson)) {
+			if (!\file_exists($shippedJson)) {
 				throw new \Exception("File not found: $shippedJson");
 			}
-			$content = json_decode(file_get_contents($shippedJson), true);
+			$content = \json_decode(\file_get_contents($shippedJson), true);
 			$this->shippedApps = $content['shippedApps'];
 			$this->alwaysEnabled = $content['alwaysEnabled'];
 		}
@@ -490,7 +503,7 @@ class AppManager implements IAppManager {
 		}
 
 		$appsFolder = OC_App::getInstallPath();
-		return $appsFolder !== null && is_writable($appsFolder) && is_readable($appsFolder);
+		return $appsFolder !== null && \is_writable($appsFolder) && \is_readable($appsFolder);
 	}
 
 	/**
@@ -503,7 +516,7 @@ class AppManager implements IAppManager {
 	 * @since 10.0.5
 	 */
 	public function getAppPath($appId) {
-		if (trim($appId) === '') {
+		if (\trim($appId) === '') {
 			return false;
 		}
 		if (($appRoot = $this->findAppInDirectories($appId)) !== false) {
@@ -523,7 +536,16 @@ class AppManager implements IAppManager {
 	 */
 	public function getAppWebPath($appId) {
 		if (($appRoot = $this->findAppInDirectories($appId)) !== false) {
-			return \OC::$WEBROOT . $appRoot['url'];
+			$ocWebRoot = $this->getOcWebRoot();
+			// consider all relative ../ in the app web path as an adjustment
+			// for oC web root
+			while (\strpos($appRoot['url'], '../') === 0) {
+				$appRoot['url'] = \substr($appRoot['url'], 3);
+				$ocWebRoot = \dirname($ocWebRoot);
+			}
+			$trimmedOcWebRoot = \rtrim($ocWebRoot, '/');
+			$trimmedAppRoot = \ltrim($appRoot['url'], '/');
+			return "$trimmedOcWebRoot/$trimmedAppRoot";
 		}
 		return false;
 	}
@@ -547,7 +569,7 @@ class AppManager implements IAppManager {
 		if (!isset($this->appDirs[$appId])) {
 			$possibleAppRoots = [];
 			foreach ($this->getAppRoots() as $appRoot) {
-				if (is_dir($appRoot['path'] . '/' . $appId)) {
+				if (\is_dir($appRoot['path'] . '/' . $appId)) {
 					$possibleAppRoots[] = $appRoot;
 				}
 			}
@@ -555,8 +577,8 @@ class AppManager implements IAppManager {
 			$versionToLoad = [];
 			foreach ($possibleAppRoots as $possibleAppRoot) {
 				$version = $this->getAppVersionByPath($possibleAppRoot['path'] . '/' . $appId);
-				if (empty($versionToLoad) || version_compare($version, $versionToLoad['version'], '>')) {
-					$versionToLoad = array_merge($possibleAppRoot, ['version' => $version]);
+				if (empty($versionToLoad) || \version_compare($version, $versionToLoad['version'], '>')) {
+					$versionToLoad = \array_merge($possibleAppRoot, ['version' => $version]);
 					$versionToLoad['path'] .= '/' . $appId;
 					$versionToLoad['url'] .= '/' . $appId;
 				}
@@ -579,12 +601,21 @@ class AppManager implements IAppManager {
 		$this->appDirs[$appId] = $appData;
 	}
 
+	/**
+	 * Get OC web root
+	 * Wrapper for easy mocking
+	 * @return string
+	 */
+	protected function getOcWebRoot() {
+		return \OC::$WEBROOT;
+	}
+
 	/**
 	 * Get apps roots as an array of path and url
 	 * Wrapper for easy mocking
 	 * @return string[][]
 	 */
-	protected function getAppRoots(){
+	protected function getAppRoots() {
 		return \OC::$APPSROOTS;
 	}
 
