@@ -4,7 +4,7 @@
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -34,7 +34,6 @@ use RegexIterator;
 use SplFileInfo;
 
 class CodeChecker extends BasicEmitter {
-
 	const CLASS_EXTENDS_NOT_ALLOWED = 1000;
 	const CLASS_IMPLEMENTS_NOT_ALLOWED = 1001;
 	const STATIC_CALL_NOT_ALLOWED = 1002;
@@ -75,15 +74,15 @@ class CodeChecker extends BasicEmitter {
 	public function analyseFolder($folder) {
 		$errors = [];
 
-		$excludes = array_map(function($item) use ($folder) {
+		$excludes = \array_map(function ($item) use ($folder) {
 			return $folder . '/' . $item;
 		}, ['vendor', '3rdparty', '.git', 'l10n', 'tests', 'test']);
 
 		$iterator = new RecursiveDirectoryIterator($folder, RecursiveDirectoryIterator::SKIP_DOTS);
-		$iterator = new RecursiveCallbackFilterIterator($iterator, function($item) use ($folder, $excludes){
+		$iterator = new RecursiveCallbackFilterIterator($iterator, function ($item) use ($folder, $excludes) {
 			/** @var SplFileInfo $item */
-			foreach($excludes as $exclude) {
-				if (substr($item->getPath(), 0, strlen($exclude)) === $exclude) {
+			foreach ($excludes as $exclude) {
+				if (\substr($item->getPath(), 0, \strlen($exclude)) === $exclude) {
 					return false;
 				}
 			}
@@ -97,19 +96,18 @@ class CodeChecker extends BasicEmitter {
 			$this->emit('CodeChecker', 'analyseFileBegin', [$file->getPathname()]);
 			$fileErrors = $this->analyseFile($file);
 			$this->emit('CodeChecker', 'analyseFileFinished', [$file->getPathname(), $fileErrors]);
-			$errors = array_merge($fileErrors, $errors);
+			$errors = \array_merge($fileErrors, $errors);
 		}
 
 		return $errors;
 	}
 
-
 	/**
 	 * @param string $file
 	 * @return array
 	 */
 	public function analyseFile($file) {
-		$code = file_get_contents($file);
+		$code = \file_get_contents($file);
 		$statements = $this->parser->parse($code);
 
 		$visitor = new NodeVisitor($this->checkList);
