@@ -14,7 +14,7 @@
  * @author Thomas Tanghus <thomas@tanghus.net>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -53,7 +53,6 @@ use OCP\Security\ISecureRandom;
  * @property mixed[] server
  */
 class Request implements \ArrayAccess, \Countable, IRequest {
-
 	const USER_AGENT_IE = '/(MSIE)|(Trident)/';
 	const USER_AGENT_IE_8 = '/MSIE 8.0/';
 	// Microsoft Edge User Agent from https://msdn.microsoft.com/en-us/library/hh869301(v=vs.85).aspx
@@ -129,30 +128,29 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 		$this->config = $config;
 		$this->csrfTokenManager = $csrfTokenManager;
 
-		if(!array_key_exists('method', $vars)) {
+		if (!\array_key_exists('method', $vars)) {
 			$vars['method'] = 'GET';
 		}
 
-		foreach($this->allowedKeys as $name) {
+		foreach ($this->allowedKeys as $name) {
 			$this->items[$name] = isset($vars[$name])
 				? $vars[$name]
 				: [];
 		}
 
-		$this->items['parameters'] = array_merge(
+		$this->items['parameters'] = \array_merge(
 			$this->items['get'],
 			$this->items['post'],
 			$this->items['urlParams'],
 			$this->items['params']
 		);
-
 	}
 	/**
 	 * @param array $parameters
 	 */
 	public function setUrlParameters(array $parameters) {
 		$this->items['urlParams'] = $parameters;
-		$this->items['parameters'] = array_merge(
+		$this->items['parameters'] = \array_merge(
 			$this->items['parameters'],
 			$this->items['urlParams']
 		);
@@ -163,7 +161,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 * @return int
 	 */
 	public function count() {
-		return count(array_keys($this->items['parameters']));
+		return \count(\array_keys($this->items['parameters']));
 	}
 
 	/**
@@ -238,13 +236,13 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	* @return mixed|null
 	*/
 	public function __get($name) {
-		switch($name) {
+		switch ($name) {
 			case 'put':
 			case 'patch':
 			case 'get':
 			case 'post':
-				if($this->method !== strtoupper($name)) {
-					throw new \LogicException(sprintf('%s cannot be accessed in a %s request.', $name, $this->method));
+				if ($this->method !== \strtoupper($name)) {
+					throw new \LogicException(\sprintf('%s cannot be accessed in a %s request.', $name, $this->method));
 				}
 				return $this->getContent();
 			case 'files':
@@ -259,7 +257,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 			case 'parameters':
 			case 'params':
 				return $this->getContent();
-			default;
+			default:
 				return isset($this[$name])
 					? $this[$name]
 					: null;
@@ -271,7 +269,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 * @return bool
 	 */
 	public function __isset($name) {
-		if (in_array($name, $this->allowedKeys, true)) {
+		if (\in_array($name, $this->allowedKeys, true)) {
 			return true;
 		}
 		return isset($this->items['parameters'][$name]);
@@ -293,17 +291,16 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 * @return string
 	 */
 	public function getHeader($name) {
-
-		$name = strtoupper(str_replace(['-'], ['_'],$name));
+		$name = \strtoupper(\str_replace(['-'], ['_'], $name));
 		if (isset($this->server['HTTP_' . $name])) {
 			return $this->server['HTTP_' . $name];
 		}
 
 		// There's a few headers that seem to end up in the top-level
 		// server array.
-		switch($name) {
-			case 'CONTENT_TYPE' :
-			case 'CONTENT_LENGTH' :
+		switch ($name) {
+			case 'CONTENT_TYPE':
+			case 'CONTENT_LENGTH':
 				if (isset($this->server[$name])) {
 					return $this->server[$name];
 				}
@@ -391,8 +388,8 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	protected function getContent() {
 		// If the content can't be parsed into an array then return a stream resource.
 		if ($this->method === 'PUT'
-			&& strpos($this->getHeader('Content-Type'), 'application/x-www-form-urlencoded') === false
-			&& strpos($this->getHeader('Content-Type'), 'application/json') === false
+			&& \strpos($this->getHeader('Content-Type'), 'application/x-www-form-urlencoded') === false
+			&& \strpos($this->getHeader('Content-Type'), 'application/json') === false
 		) {
 			if ($this->content === false) {
 				throw new \LogicException(
@@ -401,7 +398,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 				);
 			}
 			$this->content = false;
-			return fopen($this->inputStream, 'rb');
+			return \fopen($this->inputStream, 'rb');
 		} else {
 			$this->decodeContent();
 			return $this->items['parameters'];
@@ -418,40 +415,38 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 		$params = [];
 
 		// 'application/json' must be decoded manually.
-		if (strpos($this->getHeader('Content-Type'), 'application/json') !== false) {
-			$params = json_decode(file_get_contents($this->inputStream), true);
-			if(is_array($params) && count($params) > 0) {
+		if (\strpos($this->getHeader('Content-Type'), 'application/json') !== false) {
+			$params = \json_decode(\file_get_contents($this->inputStream), true);
+			if (\is_array($params) && \count($params) > 0) {
 				$this->items['params'] = $params;
-				if($this->method === 'POST') {
+				if ($this->method === 'POST') {
 					$this->items['post'] = $params;
 				}
 			}
 
-		// Handle application/x-www-form-urlencoded for methods other than GET
+			// Handle application/x-www-form-urlencoded for methods other than GET
 		// or post correctly
-		} elseif($this->method !== 'GET'
+		} elseif ($this->method !== 'GET'
 				&& $this->method !== 'POST'
-				&& strpos($this->getHeader('Content-Type'), 'application/x-www-form-urlencoded') !== false) {
-
-			parse_str(file_get_contents($this->inputStream), $params);
-			if(is_array($params)) {
+				&& \strpos($this->getHeader('Content-Type'), 'application/x-www-form-urlencoded') !== false) {
+			\parse_str(\file_get_contents($this->inputStream), $params);
+			if (\is_array($params)) {
 				$this->items['params'] = $params;
 			}
 		}
 
-		if (is_array($params)) {
-			$this->items['parameters'] = array_merge($this->items['parameters'], $params);
+		if (\is_array($params)) {
+			$this->items['parameters'] = \array_merge($this->items['parameters'], $params);
 		}
 		$this->contentDecoded = true;
 	}
 
-
 	/**
 	 * Checks if the CSRF check was correct
 	 * @return bool true if CSRF check passed
 	 */
 	public function passesCSRFCheck() {
-		if($this->csrfTokenManager === null) {
+		if ($this->csrfTokenManager === null) {
 			return false;
 		}
 
@@ -483,21 +478,21 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 */
 	public function getId() {
 		// allow clients to provide a request id
-		if(isset($this->server['HTTP_X_REQUEST_ID'])) {
+		if (isset($this->server['HTTP_X_REQUEST_ID'])) {
 			$reqId = $this->server['HTTP_X_REQUEST_ID'];
-			if (strlen($reqId) > 19
-				&& strlen($reqId) < 200
-				&& preg_match('%^[a-zA-Z0-9-+/_=.:]+$%', $reqId)) {
+			if (\strlen($reqId) > 19
+				&& \strlen($reqId) < 200
+				&& \preg_match('%^[a-zA-Z0-9-+/_=.:]+$%', $reqId)) {
 				return $this->server['HTTP_X_REQUEST_ID'];
 			} else {
 				throw new \InvalidArgumentException('X-Request-ID must be 20-200 bytes of chars, numbers and -+/_=.:');
 			}
 		}
-		if(isset($this->server['UNIQUE_ID'])) {
+		if (isset($this->server['UNIQUE_ID'])) {
 			return $this->server['UNIQUE_ID'];
 		}
 
-		if(empty($this->requestId)) {
+		if (empty($this->requestId)) {
 			$validChars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
 			$this->requestId = $this->secureRandom->generate(20, $validChars);
 		}
@@ -516,17 +511,17 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 		$remoteAddress = isset($this->server['REMOTE_ADDR']) ? $this->server['REMOTE_ADDR'] : '';
 		$trustedProxies = $this->config->getSystemValue('trusted_proxies', []);
 
-		if(is_array($trustedProxies) && in_array($remoteAddress, $trustedProxies)) {
+		if (\is_array($trustedProxies) && \in_array($remoteAddress, $trustedProxies)) {
 			$forwardedForHeaders = $this->config->getSystemValue('forwarded_for_headers', [
 				'HTTP_X_FORWARDED_FOR'
 				// only have one default, so we cannot ship an insecure product out of the box
 			]);
 
-			foreach($forwardedForHeaders as $header) {
-				if(isset($this->server[$header])) {
-					foreach(explode(',', $this->server[$header]) as $IP) {
-						$IP = trim($IP);
-						if (filter_var($IP, FILTER_VALIDATE_IP) !== false) {
+			foreach ($forwardedForHeaders as $header) {
+				if (isset($this->server[$header])) {
+					foreach (\explode(',', $this->server[$header]) as $IP) {
+						$IP = \trim($IP);
+						if (\filter_var($IP, FILTER_VALIDATE_IP) !== false) {
 							return $IP;
 						}
 					}
@@ -545,7 +540,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	private function isOverwriteCondition($type = '') {
 		$regex = '/' . $this->config->getSystemValue('overwritecondaddr', '')  . '/';
 		$remoteAddr = isset($this->server['REMOTE_ADDR']) ? $this->server['REMOTE_ADDR'] : '';
-		return $regex === '//' || preg_match($regex, $remoteAddr) === 1
+		return $regex === '//' || \preg_match($regex, $remoteAddr) === 1
 		|| $type !== 'protocol';
 	}
 
@@ -555,17 +550,17 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 * @return string Server protocol (http or https)
 	 */
 	public function getServerProtocol() {
-		if($this->config->getSystemValue('overwriteprotocol') !== ''
+		if ($this->config->getSystemValue('overwriteprotocol') !== ''
 			&& $this->isOverwriteCondition('protocol')) {
 			return $this->config->getSystemValue('overwriteprotocol');
 		}
 
 		if (isset($this->server['HTTP_X_FORWARDED_PROTO'])) {
-			if (strpos($this->server['HTTP_X_FORWARDED_PROTO'], ',') !== false) {
-				$parts = explode(',', $this->server['HTTP_X_FORWARDED_PROTO']);
-				$proto = strtolower(trim($parts[0]));
+			if (\strpos($this->server['HTTP_X_FORWARDED_PROTO'], ',') !== false) {
+				$parts = \explode(',', $this->server['HTTP_X_FORWARDED_PROTO']);
+				$proto = \strtolower(\trim($parts[0]));
 			} else {
-				$proto = strtolower($this->server['HTTP_X_FORWARDED_PROTO']);
+				$proto = \strtolower($this->server['HTTP_X_FORWARDED_PROTO']);
 			}
 
 			// Verify that the protocol is always HTTP or HTTPS
@@ -589,7 +584,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 * @return string HTTP protocol. HTTP/2, HTTP/1.1 or HTTP/1.0.
 	 */
 	public function getHttpProtocol() {
-		$claimedProtocol = strtoupper($this->server['SERVER_PROTOCOL']);
+		$claimedProtocol = \strtoupper($this->server['SERVER_PROTOCOL']);
 
 		$validProtocols = [
 			'HTTP/1.0',
@@ -597,7 +592,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 			'HTTP/2',
 		];
 
-		if(in_array($claimedProtocol, $validProtocols, true)) {
+		if (\in_array($claimedProtocol, $validProtocols, true)) {
 			return $claimedProtocol;
 		}
 
@@ -611,14 +606,14 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 */
 	public function getRequestUri() {
 		$uri = isset($this->server['REQUEST_URI']) ? $this->server['REQUEST_URI'] : '';
-		if($this->config->getSystemValue('overwritewebroot') !== '' && $this->isOverwriteCondition()) {
-			$uri = $this->getScriptName() . substr($uri, strlen($this->server['SCRIPT_NAME']));
+		if ($this->config->getSystemValue('overwritewebroot') !== '' && $this->isOverwriteCondition()) {
+			$uri = $this->getScriptName() . \substr($uri, \strlen($this->server['SCRIPT_NAME']));
 		} else {
-			$components = parse_url($uri);
+			$components = \parse_url($uri);
 			if ($components === false) {
 				// due to https://bugs.php.net/bug.php?id=70942 we have to add a
 				// fake schema and host to successfully extract path, query and fragment
-				$components = parse_url("http://localhost$uri");
+				$components = \parse_url("http://localhost$uri");
 			}
 			$uri = $components['path'];
 			if (isset($components['query'])) {
@@ -639,37 +634,38 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	public function getRawPathInfo() {
 		$requestUri = isset($this->server['REQUEST_URI']) ? $this->server['REQUEST_URI'] : '';
 		// remove too many leading slashes - can be caused by reverse proxy configuration
-		if (strpos($requestUri, '/') === 0) {
-			$requestUri = '/' . ltrim($requestUri, '/');
+		if (\strpos($requestUri, '/') === 0) {
+			$requestUri = '/' . \ltrim($requestUri, '/');
 		}
 
-		$requestUri = preg_replace('%/{2,}%', '/', $requestUri);
+		$requestUri = \preg_replace('%/{2,}%', '/', $requestUri);
 
 		// Remove the query string from REQUEST_URI
-		if ($pos = strpos($requestUri, '?')) {
-			$requestUri = substr($requestUri, 0, $pos);
+		if ($pos = \strpos($requestUri, '?')) {
+			$requestUri = \substr($requestUri, 0, $pos);
 		}
 
 		$scriptName = $this->server['SCRIPT_NAME'];
+		$scriptName = \preg_replace('%/{2,}%', '/', $scriptName);
 		$pathInfo = $requestUri;
 
 		// strip off the script name's dir and file name
 		// FIXME: Sabre does not really belong here
 		list($path, $name) = \Sabre\HTTP\URLUtil::splitPath($scriptName);
 		if (!empty($path)) {
-			if($path === $pathInfo || strpos($pathInfo, $path.'/') === 0) {
-				$pathInfo = substr($pathInfo, strlen($path));
+			if ($path === $pathInfo || \strpos($pathInfo, $path.'/') === 0) {
+				$pathInfo = \substr($pathInfo, \strlen($path));
 			} else {
 				throw new \Exception("The requested uri($requestUri) cannot be processed by the script '$scriptName')");
 			}
 		}
-		if (strpos($pathInfo, '/'.$name) === 0) {
-			$pathInfo = substr($pathInfo, strlen($name) + 1);
+		if (\strpos($pathInfo, '/'.$name) === 0) {
+			$pathInfo = \substr($pathInfo, \strlen($name) + 1);
 		}
-		if (strpos($pathInfo, $name) === 0) {
-			$pathInfo = substr($pathInfo, strlen($name));
+		if (\strpos($pathInfo, $name) === 0) {
+			$pathInfo = \substr($pathInfo, \strlen($name));
 		}
-		if($pathInfo === false || $pathInfo === '/'){
+		if ($pathInfo === false || $pathInfo === '/') {
 			return '';
 		} else {
 			return $pathInfo;
@@ -683,18 +679,18 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 */
 	public function getPathInfo() {
 		$pathInfo = isset($this->server['PATH_INFO']) ? $this->server['PATH_INFO'] : '';
-		if($pathInfo !== '') {
+		if ($pathInfo !== '') {
 			return $pathInfo;
 		}
 
 		$pathInfo = $this->getRawPathInfo();
 		// following is taken from \Sabre\HTTP\URLUtil::decodePathSegment
-		$pathInfo = rawurldecode($pathInfo);
-		$encoding = mb_detect_encoding($pathInfo, ['UTF-8', 'ISO-8859-1']);
+		$pathInfo = \rawurldecode($pathInfo);
+		$encoding = \mb_detect_encoding($pathInfo, ['UTF-8', 'ISO-8859-1']);
 
-		switch($encoding) {
-			case 'ISO-8859-1' :
-				$pathInfo = utf8_encode($pathInfo);
+		switch ($encoding) {
+			case 'ISO-8859-1':
+				$pathInfo = \utf8_encode($pathInfo);
 		}
 		// end copy
 
@@ -711,9 +707,9 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 		$overwriteWebRoot =  $this->config->getSystemValue('overwritewebroot');
 		if ($overwriteWebRoot !== '' && $this->isOverwriteCondition()) {
 			// FIXME: This code is untestable due to __DIR__, also that hardcoded path is really dangerous
-			$serverRoot = str_replace('\\', '/', substr(__DIR__, 0, -strlen('lib/private/appframework/http/')));
-			$suburi = str_replace('\\', '/', substr(realpath($this->server['SCRIPT_FILENAME']), strlen($serverRoot)));
-			$name = '/' . ltrim($overwriteWebRoot . $suburi, '/');
+			$serverRoot = \str_replace('\\', '/', \substr(__DIR__, 0, -\strlen('lib/private/appframework/http/')));
+			$suburi = \str_replace('\\', '/', \substr(\realpath($this->server['SCRIPT_FILENAME']), \strlen($serverRoot)));
+			$name = '/' . \ltrim($overwriteWebRoot . $suburi, '/');
 		}
 		return $name;
 	}
@@ -728,7 +724,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 			return false;
 		}
 		foreach ($agent as $regex) {
-			if (preg_match($regex, $this->server['HTTP_USER_AGENT'])) {
+			if (\preg_match($regex, $this->server['HTTP_USER_AGENT'])) {
 				return true;
 			}
 		}
@@ -743,23 +739,22 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	public function getInsecureServerHost() {
 		$host = 'localhost';
 		if (isset($this->server['HTTP_X_FORWARDED_HOST'])) {
-			if (strpos($this->server['HTTP_X_FORWARDED_HOST'], ',') !== false) {
-				$parts = explode(',', $this->server['HTTP_X_FORWARDED_HOST']);
-				$host = trim(current($parts));
+			if (\strpos($this->server['HTTP_X_FORWARDED_HOST'], ',') !== false) {
+				$parts = \explode(',', $this->server['HTTP_X_FORWARDED_HOST']);
+				$host = \trim(\current($parts));
 			} else {
 				$host = $this->server['HTTP_X_FORWARDED_HOST'];
 			}
 		} else {
 			if (isset($this->server['HTTP_HOST'])) {
 				$host = $this->server['HTTP_HOST'];
-			} else if (isset($this->server['SERVER_NAME'])) {
+			} elseif (isset($this->server['SERVER_NAME'])) {
 				$host = $this->server['SERVER_NAME'];
 			}
 		}
 		return $host;
 	}
 
-
 	/**
 	 * Returns the server host from the headers, or the first configured
 	 * trusted domain if the host isn't in the trusted list
@@ -798,10 +793,9 @@ class Request implements \ArrayAccess, \Countable, IRequest {
 	 * isn't met
 	 */
 	private function getOverwriteHost() {
-		if($this->config->getSystemValue('overwritehost') !== '' && $this->isOverwriteCondition()) {
+		if ($this->config->getSystemValue('overwritehost') !== '' && $this->isOverwriteCondition()) {
 			return $this->config->getSystemValue('overwritehost');
 		}
 		return null;
 	}
-
 }
