@@ -2,7 +2,7 @@
 /**
  * @author Christoph Wurst <christoph@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -135,7 +135,7 @@ class DefaultToken extends Entity implements IToken {
 	 * @param string $name
 	 */
 	public function setName($name) {
-		if (strlen($name) < 1) {
+		if (\strlen($name) < 1) {
 			throw new \InvalidArgumentException();
 		}
 		parent::setName($name);
@@ -145,10 +145,9 @@ class DefaultToken extends Entity implements IToken {
 	 * @param string $loginName
 	 */
 	public function setLoginName($loginName) {
-		if (strlen($loginName) < 1) {
+		if (\strlen($loginName) < 1) {
 			throw new \InvalidArgumentException();
 		}
 		parent::setLoginName($loginName);
 	}
-
 }
