@@ -8,7 +8,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -82,12 +82,10 @@ class AvatarManager implements IAvatarManager {
 	 */
 	public function getAvatar($userId) {
 		$user = $this->userManager->get($userId);
-		if (is_null($user)) {
+		if ($user === null) {
 			throw new \Exception('user does not exist');
 		}
 
-		$userId = $user->getUID();
-
 		$avatarsFolder = $this->getAvatarFolder($user);
 		return new Avatar($avatarsFolder, $this->l, $user, $this->logger);
 	}
@@ -101,8 +99,8 @@ class AvatarManager implements IAvatarManager {
 	}
 
 	private function buildAvatarPath($userId) {
-		$avatar = substr_replace(substr_replace(md5($userId), '/', 4, 0), '/', 2, 0);
-		return explode('/', $avatar);
+		$avatar = \substr_replace(\substr_replace(\md5($userId), '/', 4, 0), '/', 2, 0);
+		return \explode('/', $avatar);
 	}
 
 	/**
