@@ -2,7 +2,7 @@
 /**
  * @author Robin Appelman <icewind@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -28,7 +28,7 @@ class ClosureJob extends QueuedJob {
 	protected function run($serializedCallable) {
 		$serializer = new Serializer();
 		$callable = $serializer->unserialize($serializedCallable);
-		if (is_callable($callable)) {
+		if (\is_callable($callable)) {
 			$callable();
 		} else {
 			throw new \InvalidArgumentException('Invalid serialized callable');
