@@ -2,7 +2,7 @@
 /**
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -40,7 +40,7 @@ class MySqlTools {
 			if ($rows === false) {
 				return false;
 			}
-			if (strcasecmp($rows['Value'], $val) !== 0) {
+			if (\strcasecmp($rows['Value'], $val) !== 0) {
 				return false;
 			}
 		}
