@@ -3,7 +3,7 @@
  * @author Robin Appelman <icewind@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -45,7 +45,7 @@ class LazyStorageMountInfo extends CachedMountInfo {
 	 */
 	public function getStorageId() {
 		if (!$this->storageId) {
-			if (method_exists($this->mount, 'getStorageNumericId')) {
+			if (\method_exists($this->mount, 'getStorageNumericId')) {
 				$this->storageId = $this->mount->getStorageNumericId();
 			} else {
 				$storage = $this->mount->getStorage();
