@@ -5,7 +5,7 @@
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@ namespace OC\Files\External\Service;
 use OC\Files\Filesystem;
 
 use OCP\Files\Config\IUserMountCache;
+use OCP\IUser;
 use OCP\IUserSession;
 
 use OCP\Files\External\IStorageConfig;
@@ -56,6 +57,7 @@ class UserStoragesService extends StoragesService implements IUserStoragesServic
 		IUserMountCache $userMountCache
 	) {
 		$this->userSession = $userSession;
+		$this->userMountCache = $userMountCache;
 		parent::__construct($backendService, $dbConfig, $userMountCache);
 	}
 
@@ -140,4 +142,22 @@ class UserStoragesService extends StoragesService implements IUserStoragesServic
 	protected function isApplicable(IStorageConfig $config) {
 		return ($config->getApplicableUsers() === [$this->getUser()->getUID()]) && $config->getType() === IStorageConfig::MOUNT_TYPE_PERSONAl;
 	}
+
+	/**
+	 * Deletes the storages mounted to a user
+	 * @param IUser $user
+	 * @return bool
+	 */
+	public function deleteAllMountsForUser(IUser $user) {
+		$getUserMounts = $this->userMountCache->getMountsForUser($user);
+		$result = false;
+		if (\count($getUserMounts) > 0) {
+			foreach ($getUserMounts as $userMount) {
+				$id = $userMount->getStorageId();
+				$this->userMountCache->removeUserStorageMount($id, $user->getUID());
+				$result = true;
+			}
+		}
+		return $result;
+	}
 }
