@@ -2,7 +2,7 @@
 /**
  * @author Robin Appelman <icewind@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -54,9 +54,9 @@ class CacheMountProvider implements IMountProvider {
 	public function getMountsForUser(IUser $user, IStorageFactory $loader) {
 		$cacheBaseDir = $this->config->getSystemValue('cache_path', '');
 		if ($cacheBaseDir !== '') {
-			$cacheDir = rtrim($cacheBaseDir, '/') . '/' . $user->getUID();
-			if (!file_exists($cacheDir)) {
-				mkdir($cacheDir, 0770, true);
+			$cacheDir = \rtrim($cacheBaseDir, '/') . '/' . $user->getUID();
+			if (!\file_exists($cacheDir)) {
+				\mkdir($cacheDir, 0770, true);
 			}
 
 			return [
