@@ -7,7 +7,7 @@
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -78,7 +78,7 @@ class PermissionsMask extends Wrapper {
 	}
 
 	private function isPartFile($path) {
-		return pathinfo($path, PATHINFO_EXTENSION) === 'part';
+		return \pathinfo($path, PATHINFO_EXTENSION) === 'part';
 	}
 
 	public function rename($path1, $path2) {
