@@ -7,7 +7,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -120,7 +120,6 @@ class Encryption extends Wrapper {
 		];
 	}
 
-
 	/**
 	 * Wraps a stream with the provided callbacks
 	 *
@@ -159,8 +158,7 @@ class Encryption extends Wrapper {
 								$signed,
 								$sourceFileOfRename = null,
 								$wrapper =  'OC\Files\Stream\Encryption') {
-
-		$context = stream_context_create([
+		$context = \stream_context_create([
 			'ocencryption' => [
 				'source' => $source,
 				'storage' => $storage,
@@ -196,17 +194,17 @@ class Encryption extends Wrapper {
 	 */
 	protected static function wrapSource($source, $context, $protocol, $class, $mode = 'r+') {
 		try {
-			stream_wrapper_register($protocol, $class);
-			if (@rewinddir($source) === false) {
-				$wrapped = fopen($protocol . '://', $mode, false, $context);
+			\stream_wrapper_register($protocol, $class);
+			if (@\rewinddir($source) === false) {
+				$wrapped = \fopen($protocol . '://', $mode, false, $context);
 			} else {
-				$wrapped = opendir($protocol . '://', $context);
+				$wrapped = \opendir($protocol . '://', $context);
 			}
 		} catch (\BadMethodCallException $e) {
-			stream_wrapper_unregister($protocol);
+			\stream_wrapper_unregister($protocol);
 			throw $e;
 		}
-		stream_wrapper_unregister($protocol);
+		\stream_wrapper_unregister($protocol);
 		return $wrapped;
 	}
 
@@ -221,14 +219,13 @@ class Encryption extends Wrapper {
 		$context = parent::loadContext($name);
 
 		foreach ($this->expectedContextProperties as $property) {
-			if (array_key_exists($property, $context)) {
+			if (\array_key_exists($property, $context)) {
 				$this->{$property} = $context[$property];
 			} else {
 				throw new \BadMethodCallException('Invalid context, "' . $property . '" options not set');
 			}
 		}
 		return $context;
-
 	}
 
 	public function stream_open($path, $mode, $options, &$opened_path) {
@@ -254,7 +251,7 @@ class Encryption extends Wrapper {
 
 		$sharePath = $this->fullPath;
 		if (!$this->storage->file_exists($this->internalPath)) {
-			$sharePath = dirname($sharePath);
+			$sharePath = \dirname($sharePath);
 		}
 
 		$accessList = $this->file->getAccessList($sharePath);
@@ -276,7 +273,6 @@ class Encryption extends Wrapper {
 		}
 
 		return true;
-
 	}
 
 	public function stream_eof() {
@@ -284,10 +280,9 @@ class Encryption extends Wrapper {
 	}
 
 	public function stream_read($count) {
-
 		$result = '';
 
-		$count = min($count, $this->unencryptedSize - $this->position);
+		$count = \min($count, $this->unencryptedSize - $this->position);
 		while ($count > 0) {
 			$remainingLength = $count;
 			// update the cache of the current block
@@ -296,34 +291,32 @@ class Encryption extends Wrapper {
 			$blockPosition = ($this->position % $this->unencryptedBlockSize);
 			// if entire read inside current block then only position needs to be updated
 			if ($remainingLength < ($this->unencryptedBlockSize - $blockPosition)) {
-				$result .= substr($this->cache, $blockPosition, $remainingLength);
+				$result .= \substr($this->cache, $blockPosition, $remainingLength);
 				$this->position += $remainingLength;
 				$count = 0;
-				// otherwise remainder of current block is fetched, the block is flushed and the position updated
+			// otherwise remainder of current block is fetched, the block is flushed and the position updated
 			} else {
-				$result .= substr($this->cache, $blockPosition);
+				$result .= \substr($this->cache, $blockPosition);
 				$this->flush();
 				$this->position += ($this->unencryptedBlockSize - $blockPosition);
 				$count -= ($this->unencryptedBlockSize - $blockPosition);
 			}
 		}
 		return $result;
-
 	}
 
 	public function stream_write($data) {
-
 		$length = 0;
 		// loop over $data to fit it in 6126 sized unencrypted blocks
 		while (isset($data[0])) {
-			$remainingLength = strlen($data);
+			$remainingLength = \strlen($data);
 
 			// set the cache to the current 6126 block
 			$this->readCache();
 
 			// for seekable streams the pointer is moved back to the beginning of the encrypted block
 			// flush will start writing there when the position moves to another block
-			$positionInFile = (int)floor($this->position / $this->unencryptedBlockSize) *
+			$positionInFile = (int)\floor($this->position / $this->unencryptedBlockSize) *
 				$this->util->getBlockSize() + $this->headerSize;
 			$resultFseek = $this->parentStreamSeek($positionInFile);
 
@@ -339,25 +332,25 @@ class Encryption extends Wrapper {
 				// if so, overwrite existing data (if any)
 				// update position and liberate $data
 				if ($remainingLength < ($this->unencryptedBlockSize - $blockPosition)) {
-					$this->cache = substr($this->cache, 0, $blockPosition)
-						. $data . substr($this->cache, $blockPosition + $remainingLength);
+					$this->cache = \substr($this->cache, 0, $blockPosition)
+						. $data . \substr($this->cache, $blockPosition + $remainingLength);
 					$this->position += $remainingLength;
 					$length += $remainingLength;
 					$data = '';
-					// if $data doesn't fit the current block, the fill the current block and reiterate
+				// if $data doesn't fit the current block, the fill the current block and reiterate
 					// after the block is filled, it is flushed and $data is updatedxxx
 				} else {
-					$this->cache = substr($this->cache, 0, $blockPosition) .
-						substr($data, 0, $this->unencryptedBlockSize - $blockPosition);
+					$this->cache = \substr($this->cache, 0, $blockPosition) .
+						\substr($data, 0, $this->unencryptedBlockSize - $blockPosition);
 					$this->flush();
 					$this->position += ($this->unencryptedBlockSize - $blockPosition);
 					$length += ($this->unencryptedBlockSize - $blockPosition);
-					$data = substr($data, $this->unencryptedBlockSize - $blockPosition);
+					$data = \substr($data, $this->unencryptedBlockSize - $blockPosition);
 				}
 			} else {
 				$data = '';
 			}
-			$this->unencryptedSize = max($this->unencryptedSize, $this->position);
+			$this->unencryptedSize = \max($this->unencryptedSize, $this->position);
 		}
 		return $length;
 	}
@@ -367,7 +360,6 @@ class Encryption extends Wrapper {
 	}
 
 	public function stream_seek($offset, $whence = SEEK_SET) {
-
 		$return = false;
 
 		switch ($whence) {
@@ -388,7 +380,7 @@ class Encryption extends Wrapper {
 			return $return;
 		}
 
-		$newFilePosition = floor($newPosition / $this->unencryptedBlockSize)
+		$newFilePosition = \floor($newPosition / $this->unencryptedBlockSize)
 			* $this->util->getBlockSize() + $this->headerSize;
 
 		$oldFilePosition = parent::stream_tell();
@@ -400,15 +392,14 @@ class Encryption extends Wrapper {
 			$return = true;
 		}
 		return $return;
-
 	}
 
 	public function stream_close() {
 		$this->flush('end');
-		$position = (int)floor($this->position/$this->unencryptedBlockSize);
+		$position = (int)\floor($this->position/$this->unencryptedBlockSize);
 		$remainingData = $this->encryptionModule->end($this->fullPath, $position . 'end');
 		if ($this->readOnly === false) {
-			if(!empty($remainingData)) {
+			if (!empty($remainingData)) {
 				parent::stream_write($remainingData);
 			}
 			$this->encryptionStorage->updateUnencryptedSize($this->fullPath, $this->unencryptedSize);
@@ -427,7 +418,7 @@ class Encryption extends Wrapper {
 			// automatically attempted when the file is written to disk -
 			// we are handling that separately here and we don't want to
 			// get into an infinite loop
-			$position = (int)floor($this->position/$this->unencryptedBlockSize);
+			$position = (int)\floor($this->position/$this->unencryptedBlockSize);
 			$encrypted = $this->encryptionModule->encrypt($this->cache, $position . $positionPrefix);
 			$bytesWritten = parent::stream_write($encrypted);
 			$this->writeFlag = false;
@@ -435,8 +426,8 @@ class Encryption extends Wrapper {
 			// If so then update the encrypted filesize
 			// Note that the unencrypted pointer and filesize are NOT yet updated when flush() is called
 			// We recalculate the encrypted filesize as we do not know the context of calling flush()
-			$completeBlocksInFile=(int)floor($this->unencryptedSize/$this->unencryptedBlockSize);
-			if ($completeBlocksInFile === (int)floor($this->position/$this->unencryptedBlockSize)) {
+			$completeBlocksInFile=(int)\floor($this->unencryptedSize/$this->unencryptedBlockSize);
+			if ($completeBlocksInFile === (int)\floor($this->position/$this->unencryptedBlockSize)) {
 				$this->size = $this->util->getBlockSize() * $completeBlocksInFile;
 				$this->size += $bytesWritten;
 				$this->size += $this->headerSize;
@@ -455,9 +446,9 @@ class Encryption extends Wrapper {
 		if ($this->cache === '' && !($this->position === $this->unencryptedSize && ($this->position % $this->unencryptedBlockSize) === 0)) {
 			// Get the data from the file handle
 			$data = parent::stream_read($this->util->getBlockSize());
-			$position = (int)floor($this->position/$this->unencryptedBlockSize);
+			$position = (int)\floor($this->position/$this->unencryptedBlockSize);
 			$numberOfChunks = (int)($this->unencryptedSize / $this->unencryptedBlockSize);
-			if($numberOfChunks === $position) {
+			if ($numberOfChunks === $position) {
 				$position .= 'end';
 			}
 			$this->cache = $this->encryptionModule->decrypt($data, $position);
@@ -500,5 +491,4 @@ class Encryption extends Wrapper {
 	public function dir_opendir($path, $options) {
 		return false;
 	}
-
 }
