@@ -3,7 +3,7 @@
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Robin Appelman <icewind@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -92,10 +92,10 @@ class Client implements IClient {
 		$proxyUserPwd = $this->config->getSystemValue('proxyuserpwd', null);
 		$proxyUri = '';
 
-		if (!is_null($proxyUserPwd)) {
+		if ($proxyUserPwd !== null) {
 			$proxyUri .= $proxyUserPwd . '@';
 		}
-		if (!is_null($proxyHost)) {
+		if ($proxyHost !== null) {
 			$proxyUri .= $proxyHost;
 		}
 
@@ -273,7 +273,6 @@ class Client implements IClient {
 		return new Response($response);
 	}
 
-
 	/**
 	 * Sends a options request
 	 *
