@@ -19,7 +19,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Thomas Tanghus <thomas@tanghus.net>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -86,7 +86,7 @@ class Installer {
 	 * @throws \Exception
 	 * @return integer
 	 */
-	public static function installApp( $data = []) {
+	public static function installApp($data = []) {
 		$l = \OC::$server->getL10N('lib');
 
 		list($extractDir, $path) = self::downloadApp($data);
@@ -95,35 +95,35 @@ class Installer {
 		$appId = OC_App::cleanAppId($info['id']);
 		$appsFolder = OC_App::getInstallPath();
 
-		if ($appsFolder === null || !is_writable($appsFolder)) {
+		if ($appsFolder === null || !\is_writable($appsFolder)) {
 			throw new \Exception('Apps folder is not writable');
 		}
 		$basedir = "$appsFolder/$appId";
 		//check if the destination directory already exists
-		if(is_dir($basedir)) {
+		if (\is_dir($basedir)) {
 			OC_Helper::rmdirr($extractDir);
-			if($data['source']=='http') {
-				unlink($path);
+			if ($data['source']=='http') {
+				\unlink($path);
 			}
 			throw new \Exception($l->t("App directory already exists"));
 		}
 
-		if(!empty($data['pretent'])) {
+		if (!empty($data['pretent'])) {
 			return false;
 		}
 		OC_App::clearAppCache($info['id']);
 
 		//copy the app to the correct place
-		if(@!mkdir($basedir)) {
+		if (@!\mkdir($basedir)) {
 			OC_Helper::rmdirr($extractDir);
-			if($data['source']=='http') {
-				unlink($path);
+			if ($data['source']=='http') {
+				\unlink($path);
 			}
 			throw new \Exception($l->t("Can't create app folder. Please fix permissions. %s", [$basedir]));
 		}
 
 		$extractDir .= '/' . $info['id'];
-		if(!file_exists($extractDir)) {
+		if (!\file_exists($extractDir)) {
 			OC_Helper::rmdirr($basedir);
 			throw new \Exception($l->t("Archive does not contain a directory named %s", $info['id']));
 		}
@@ -137,7 +137,7 @@ class Installer {
 			$ms = new \OC\DB\MigrationService($appId, \OC::$server->getDatabaseConnection());
 			$ms->migrate();
 		} else {
-			if(is_file($basedir.'/appinfo/database.xml')) {
+			if (\is_file($basedir.'/appinfo/database.xml')) {
 				if (\OC::$server->getAppConfig()->getValue($info['id'], 'installed_version') === null) {
 					OC_DB::createDbFromStructure($basedir . '/appinfo/database.xml');
 				} else {
@@ -149,7 +149,7 @@ class Installer {
 		\OC_App::setupBackgroundJobs($info['background-jobs']);
 
 		//run appinfo/install.php
-		if((!isset($data['noinstall']) or $data['noinstall']==false)) {
+		if ((!isset($data['noinstall']) or $data['noinstall']==false)) {
 			self::includeAppScript($basedir . '/appinfo/install.php');
 		}
 
@@ -161,10 +161,10 @@ class Installer {
 		\OC::$server->getConfig()->setAppValue($info['id'], 'enabled', 'no');
 
 		//set remote/public handlers
-		foreach($info['remote'] as $name=>$path) {
+		foreach ($info['remote'] as $name=>$path) {
 			\OC::$server->getConfig()->setAppValue('core', 'remote_'.$name, $info['id'].'/'.$path);
 		}
-		foreach($info['public'] as $name=>$path) {
+		foreach ($info['public'] as $name=>$path) {
 			\OC::$server->getConfig()->setAppValue('core', 'public_'.$name, $info['id'].'/'.$path);
 		}
 
@@ -176,11 +176,11 @@ class Installer {
 	/**
 	 * @brief checks whether or not an app is installed
 	 * @param string $app app
-	 * @returns bool
+	 * @return bool
 	 *
 	 * Checks whether or not an app is installed, i.e. registered in apps table.
 	 */
-	public static function isInstalled( $app ) {
+	public static function isInstalled($app) {
 		return (\OC::$server->getConfig()->getAppValue($app, "installed_version", null) !== null);
 	}
 
@@ -227,18 +227,18 @@ class Installer {
 		$basedir .= '/';
 		$basedir .= $info['id'];
 
-		if($currentDir !== false && is_writable($currentDir)) {
+		if ($currentDir !== false && \is_writable($currentDir)) {
 			$basedir = $currentDir;
 		}
-		if(is_dir("$basedir/.git")) {
+		if (\is_dir("$basedir/.git")) {
 			throw new AppAlreadyInstalledException("App <{$info['id']}> is a git clone - it will not be updated.");
 		}
-		if(is_dir($basedir)) {
+		if (\is_dir($basedir)) {
 			OC_Helper::rmdirr($basedir);
 		}
 
 		$appInExtractDir = $extractDir;
-		if (substr($extractDir, -1) !== '/') {
+		if (\substr($extractDir, -1) !== '/') {
 			$appInExtractDir .= '/';
 		}
 
@@ -257,22 +257,22 @@ class Installer {
 	public static function downloadApp($data = []) {
 		$l = \OC::$server->getL10N('lib');
 
-		if(!isset($data['source'])) {
+		if (!isset($data['source'])) {
 			throw new \Exception($l->t("No source specified when installing app"));
 		}
 
 		//download the file if necessary
-		if($data['source']=='http') {
-			$pathInfo = pathinfo($data['href']);
+		if ($data['source']=='http') {
+			$pathInfo = \pathinfo($data['href']);
 			$extension = isset($pathInfo['extension']) ? '.' . $pathInfo['extension'] : '';
 			$path = \OC::$server->getTempManager()->getTemporaryFile($extension);
-			if(!isset($data['href'])) {
+			if (!isset($data['href'])) {
 				throw new \Exception($l->t("No href specified when installing app from http"));
 			}
 			$client = \OC::$server->getHTTPClientService()->newClient();
 			$client->get($data['href'], ['save_to' => $path]);
 		} else {
-			if(!isset($data['path'])) {
+			if (!isset($data['path'])) {
 				throw new \Exception($l->t("No path specified when installing app from local file"));
 			}
 			$path=$data['path'];
@@ -287,13 +287,13 @@ class Installer {
 		//extract the archive in a temporary folder
 		$extractDir = \OC::$server->getTempManager()->getTemporaryFolder();
 		OC_Helper::rmdirr($extractDir);
-		mkdir($extractDir);
-		if($archive=\OC\Archive\Archive::open($path)) {
+		\mkdir($extractDir);
+		if ($archive=\OC\Archive\Archive::open($path)) {
 			$archive->extract($extractDir);
 		} else {
 			OC_Helper::rmdirr($extractDir);
-			if($data['source']=='http') {
-				unlink($path);
+			if ($data['source']=='http') {
+				\unlink($path);
 			}
 			throw new \Exception($l->t("Failed to open archive when installing app"));
 		}
@@ -316,29 +316,29 @@ class Installer {
 	public static function checkAppsIntegrity($data, $extractDir, $path, $isShipped = false) {
 		$l = \OC::$server->getL10N('lib');
 		//load the info.xml file of the app
-		if(!is_file($extractDir.'/appinfo/info.xml')) {
+		if (!\is_file($extractDir.'/appinfo/info.xml')) {
 			//try to find it in a subdir
-			$dh=opendir($extractDir);
-			if(is_resource($dh)) {
-				while (($folder = readdir($dh)) !== false) {
-					if($folder[0]!='.' and is_dir($extractDir.'/'.$folder)) {
-						if(is_file($extractDir.'/'.$folder.'/appinfo/info.xml')) {
+			$dh=\opendir($extractDir);
+			if (\is_resource($dh)) {
+				while (($folder = \readdir($dh)) !== false) {
+					if ($folder[0]!='.' and \is_dir($extractDir.'/'.$folder)) {
+						if (\is_file($extractDir.'/'.$folder.'/appinfo/info.xml')) {
 							$extractDir.='/'.$folder;
 						}
 					}
 				}
 			}
 		}
-		if(!is_file($extractDir.'/appinfo/info.xml')) {
+		if (!\is_file($extractDir.'/appinfo/info.xml')) {
 			OC_Helper::rmdirr($extractDir);
-			if($data['source'] === 'http') {
-				unlink($path);
+			if ($data['source'] === 'http') {
+				\unlink($path);
 			}
 			throw new \Exception($l->t("App does not provide an info.xml file"));
 		}
 
 		$info = OC_App::getAppInfo($extractDir.'/appinfo/info.xml', true);
-		if(!is_array($info)) {
+		if (!\is_array($info)) {
 			throw new \Exception($l->t('App cannot be installed because appinfo file cannot be read.'));
 		}
 
@@ -347,19 +347,19 @@ class Installer {
 		// whether the application needs to be signed.
 		$appId = OC_App::cleanAppId(isset($data['appdata']['id']) ? $data['appdata']['id'] : '');
 		$appBelongingToId = OC_App::getInternalAppIdByOcs($appId);
-		if(is_string($appBelongingToId)) {
+		if (\is_string($appBelongingToId)) {
 			$previouslySigned = \OC::$server->getConfig()->getAppValue($appBelongingToId, 'signed', 'false');
 		} else {
 			$appBelongingToId = $info['id'];
 			$previouslySigned = 'false';
 		}
-		if (file_exists($extractDir . '/appinfo/signature.json') || $previouslySigned === 'true') {
+		if (\file_exists($extractDir . '/appinfo/signature.json') || $previouslySigned === 'true') {
 			\OC::$server->getConfig()->setAppValue($appBelongingToId, 'signed', 'true');
 			$integrityResult = \OC::$server->getIntegrityCodeChecker()->verifyAppSignature(
 					$appBelongingToId,
 					$extractDir
 			);
-			if($integrityResult !== []) {
+			if ($integrityResult !== []) {
 				$e = new \Exception(
 						$l->t(
 								'Signature could not get checked. Please contact the app developer and check your admin screen.'
@@ -370,27 +370,27 @@ class Installer {
 		}
 
 		// check the code for not allowed calls
-		if(!$isShipped && !Installer::checkCode($extractDir)) {
+		if (!$isShipped && !Installer::checkCode($extractDir)) {
 			OC_Helper::rmdirr($extractDir);
 			throw new \Exception($l->t("App can't be installed because of not allowed code in the App"));
 		}
 
 		// check if the app is compatible with this version of ownCloud
-		if(!OC_App::isAppCompatible(\OCP\Util::getVersion(), $info)) {
+		if (!OC_App::isAppCompatible(\OCP\Util::getVersion(), $info)) {
 			OC_Helper::rmdirr($extractDir);
 			throw new \Exception($l->t("App can't be installed because it is not compatible with this version of ownCloud"));
 		}
 
 		// check if shipped tag is set which is only allowed for apps that are shipped with ownCloud
-		if(!$isShipped && isset($info['shipped']) && ($info['shipped']=='true')) {
+		if (!$isShipped && isset($info['shipped']) && ($info['shipped']=='true')) {
 			OC_Helper::rmdirr($extractDir);
 			throw new \Exception($l->t("App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps"));
 		}
 
 		// check if the ocs version is the same as the version in info.xml/version
-		$version = trim($info['version']);
+		$version = \trim($info['version']);
 
-		if(isset($data['appdata']['version']) && $version<>trim($data['appdata']['version'])) {
+		if (isset($data['appdata']['version']) && $version<>\trim($data['appdata']['version'])) {
 			OC_Helper::rmdirr($extractDir);
 			throw new \Exception($l->t("App can't be installed because the version in info.xml is not the same as the version reported from the app store"));
 		}
@@ -405,14 +405,14 @@ class Installer {
 	 *
 	 * The function will check if the app is already downloaded in the apps repository
 	 */
-	public static function isDownloaded( $name ) {
-		foreach(\OC::$APPSROOTS as $dir) {
+	public static function isDownloaded($name) {
+		foreach (\OC::$APPSROOTS as $dir) {
 			$dirToTest  = $dir['path'];
 			$dirToTest .= '/';
 			$dirToTest .= $name;
 			$dirToTest .= '/';
 
-			if (is_dir($dirToTest)) {
+			if (\is_dir($dirToTest)) {
 				return true;
 			}
 		}
@@ -435,13 +435,12 @@ class Installer {
 	 * this has to be done by the function oc_app_uninstall().
 	 */
 	public static function removeApp($appId) {
-
-		if(Installer::isDownloaded( $appId )) {
+		if (Installer::isDownloaded($appId)) {
 			$appDir = OC_App::getAppPath($appId);
 			if ($appDir === false) {
 				return false;
 			}
-			if(is_dir("$appDir/.git")) {
+			if (\is_dir("$appDir/.git")) {
 				throw new AppAlreadyInstalledException("App <$appId> is a git clone - it will not be deleted.");
 			}
 
@@ -456,16 +455,16 @@ class Installer {
 
 	protected static function getShippedApps() {
 		$shippedApps = [];
-		foreach(\OC::$APPSROOTS as $app_dir) {
-			if($dir = opendir( $app_dir['path'] )) {
-				$nodes = scandir($app_dir['path']);
-				foreach($nodes as $filename) {
-					if( substr( $filename, 0, 1 ) != '.' and is_dir($app_dir['path']."/$filename") ) {
-						if( file_exists( $app_dir['path']."/$filename/appinfo/info.xml" )) {
-							if(!Installer::isInstalled($filename)) {
+		foreach (\OC::$APPSROOTS as $app_dir) {
+			if ($dir = \opendir($app_dir['path'])) {
+				$nodes = \scandir($app_dir['path']);
+				foreach ($nodes as $filename) {
+					if (\substr($filename, 0, 1) != '.' and \is_dir($app_dir['path']."/$filename")) {
+						if (\file_exists($app_dir['path']."/$filename/appinfo/info.xml")) {
+							if (!Installer::isInstalled($filename)) {
 								$info=OC_App::getAppInfo($filename);
 								$enabled = isset($info['default_enable']);
-								if (($enabled || in_array($filename, \OC::$server->getAppManager()->getAlwaysEnabledApps()))
+								if (($enabled || \in_array($filename, \OC::$server->getAppManager()->getAlwaysEnabledApps()))
 									&& \OC::$server->getConfig()->getAppValue($filename, 'enabled') !== 'no') {
 									$shippedApps[] = $filename;
 								}
@@ -473,15 +472,14 @@ class Installer {
 						}
 					}
 				}
-				closedir( $dir );
+				\closedir($dir);
 			}
 		}
 
-
 		// Fix the order - make files first
-		$shippedApps = array_diff($shippedApps,['files', 'dav']);
-		array_unshift($shippedApps, 'dav');
-		array_unshift($shippedApps, 'files');
+		$shippedApps = \array_diff($shippedApps, ['files', 'dav']);
+		\array_unshift($shippedApps, 'dav');
+		\array_unshift($shippedApps, 'files');
 		return $shippedApps;
 	}
 
@@ -497,8 +495,8 @@ class Installer {
 		$errors = [];
 		$appsToInstall = Installer::getShippedApps();
 
-		foreach($appsToInstall as $appToInstall) {
-			if(!Installer::isInstalled($appToInstall)) {
+		foreach ($appsToInstall as $appToInstall) {
+			if (!Installer::isInstalled($appToInstall)) {
 				if ($softErrors) {
 					try {
 						Installer::installShippedApp($appToInstall);
@@ -515,7 +513,6 @@ class Installer {
 		}
 
 		return $errors;
-
 	}
 
 	/**
@@ -524,11 +521,10 @@ class Installer {
 	 * @return integer|false
 	 */
 	public static function installShippedApp($app) {
-
 		\OC::$server->getLogger()->info('Attempting to install shipped app: '.$app);
 
 		$info = OC_App::getAppInfo($app);
-		if (is_null($info)) {
+		if ($info === null) {
 			return false;
 		}
 
@@ -539,7 +535,7 @@ class Installer {
 			$ms = new MigrationService($app, \OC::$server->getDatabaseConnection());
 			$ms->migrate();
 		} else {
-			if(is_file($appPath.'/appinfo/database.xml')) {
+			if (\is_file($appPath.'/appinfo/database.xml')) {
 				\OC::$server->getLogger()->debug('Create app database from schema file');
 				OC_DB::createDbFromStructure($appPath . '/appinfo/database.xml');
 			}
@@ -559,15 +555,15 @@ class Installer {
 		$config = \OC::$server->getConfig();
 
 		$config->setAppValue($app, 'installed_version', OC_App::getAppVersion($app));
-		if (array_key_exists('ocsid', $info)) {
+		if (\array_key_exists('ocsid', $info)) {
 			$config->setAppValue($app, 'ocsid', $info['ocsid']);
 		}
 
 		//set remote/public handlers
-		foreach($info['remote'] as $name=>$path) {
+		foreach ($info['remote'] as $name=>$path) {
 			$config->setAppValue('core', 'remote_'.$name, $app.'/'.$path);
 		}
-		foreach($info['public'] as $name=>$path) {
+		foreach ($info['public'] as $name=>$path) {
 			$config->setAppValue('core', 'public_'.$name, $app.'/'.$path);
 		}
 
@@ -583,7 +579,7 @@ class Installer {
 	 */
 	public static function checkCode($folder) {
 		// is the code checker enabled?
-		if(!\OC::$server->getConfig()->getSystemValue('appcodechecker', false)) {
+		if (!\OC::$server->getConfig()->getSystemValue('appcodechecker', false)) {
 			return true;
 		}
 
@@ -597,7 +593,7 @@ class Installer {
 	 * @param $basedir
 	 */
 	private static function includeAppScript($script) {
-		if ( file_exists($script) ){
+		if (\file_exists($script)) {
 			include $script;
 		}
 	}
