@@ -8,7 +8,7 @@
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -34,7 +34,6 @@ use OCP\L10N\IFactory;
 use OCP\Theme\ITheme;
 use OCP\Theme\IThemeService;
 
-
 /**
  * A factory that generates language instances
  */
@@ -103,7 +102,7 @@ class Factory implements IFactory {
 	public function get($app, $lang = null) {
 		$app = \OC_App::cleanAppId($app);
 		if ($lang !== null) {
-			$lang = str_replace(['\0', '/', '\\', '..'], '', (string) $lang);
+			$lang = \str_replace(['\0', '/', '\\', '..'], '', (string) $lang);
 		}
 		if ($lang === null || !$this->languageExists($app, $lang)) {
 			$lang = $this->findLanguage($app);
@@ -137,9 +136,9 @@ class Factory implements IFactory {
 		 *
 		 * @link https://github.com/owncloud/core/issues/21955
 		 */
-		if(!is_null($this->userSession) && $this->config->getSystemValue('installed', false)) {
-			$userId = !is_null($this->userSession->getUser()) ? $this->userSession->getUser()->getUID() :  null;
-			if(!is_null($userId)) {
+		if ($this->userSession !== null && $this->config->getSystemValue('installed', false)) {
+			$userId = $this->userSession->getUser() !== null ? $this->userSession->getUser()->getUID() :  null;
+			if ($userId !== null) {
 				$userLang = $this->config->getUserValue($userId, 'core', 'lang', null);
 			} else {
 				$userLang = null;
@@ -189,14 +188,14 @@ class Factory implements IFactory {
 
 		$available = ['en']; //english is always available
 		$dir = $this->findL10nDir($app);
-		$available = array_merge($available, $this->findAvailableLanguageFiles($dir));
+		$available = \array_merge($available, $this->findAvailableLanguageFiles($dir));
 
 		// merge with translations from themes
-		$relativePath = substr($dir, strlen($this->serverRoot));
+		$relativePath = \substr($dir, \strlen($this->serverRoot));
 		$themeDir = $this->getActiveThemeDirectory();
 		if ($themeDir !== '') {
 			$themeDir .= $relativePath;
-			$available = array_merge($available, $this->findAvailableLanguageFiles($themeDir));
+			$available = \array_merge($available, $this->findAvailableLanguageFiles($themeDir));
 		}
 
 		$this->availableLanguages[$key] = $available;
@@ -214,7 +213,7 @@ class Factory implements IFactory {
 		}
 
 		$languages = $this->findAvailableLanguages($app);
-		return array_search($lang, $languages) !== false;
+		return \array_search($lang, $languages) !== false;
 	}
 
 	/**
@@ -227,15 +226,15 @@ class Factory implements IFactory {
 			$available = $this->findAvailableLanguages($app);
 
 			// E.g. make sure that 'de' is before 'de_DE'.
-			sort($available);
+			\sort($available);
 
-			$preferences = preg_split('/,\s*/', strtolower($header));
+			$preferences = \preg_split('/,\s*/', \strtolower($header));
 			foreach ($preferences as $preference) {
-				list($preferred_language) = explode(';', $preference);
-				$preferred_language = str_replace('-', '_', $preferred_language);
+				list($preferred_language) = \explode(';', $preference);
+				$preferred_language = \str_replace('-', '_', $preferred_language);
 
 				foreach ($available as $available_language) {
-					if ($preferred_language === strtolower($available_language)) {
+					if ($preferred_language === \strtolower($available_language)) {
 						if ($app === null && !$this->requestLanguage) {
 							$this->requestLanguage = $available_language;
 						}
@@ -245,7 +244,7 @@ class Factory implements IFactory {
 
 				// Fallback from de_De to de
 				foreach ($available as $available_language) {
-					if (substr($preferred_language, 0, 2) === $available_language) {
+					if (\substr($preferred_language, 0, 2) === $available_language) {
 						if ($app === null && !$this->requestLanguage) {
 							$this->requestLanguage = $available_language;
 						}
@@ -274,24 +273,24 @@ class Factory implements IFactory {
 		$languageFiles = [];
 
 		$i18nDir = $this->findL10nDir($app);
-		$transFile = strip_tags($i18nDir) . strip_tags($lang) . '.json';
+		$transFile = \strip_tags($i18nDir) . \strip_tags($lang) . '.json';
 
 		if ((\OC_Helper::isSubDirectory($transFile, $this->serverRoot . '/core/l10n/')
 				|| \OC_Helper::isSubDirectory($transFile, $this->serverRoot . '/lib/l10n/')
 				|| \OC_Helper::isSubDirectory($transFile, $this->serverRoot . '/settings/l10n/')
 				|| \OC_Helper::isSubDirectory($transFile, \OC_App::getAppPath($app) . '/l10n/')
 			)
-			&& file_exists($transFile)) {
+			&& \file_exists($transFile)) {
 			// load the translations file
 			$languageFiles[] = $transFile;
 		}
 
 		// merge with translations from themes
-		$relativePath = substr($transFile, strlen($this->serverRoot));
+		$relativePath = \substr($transFile, \strlen($this->serverRoot));
 		$themeDir = $this->getActiveThemeDirectory();
 		if ($themeDir !== '') {
 			$themeTransFile = $themeDir . $relativePath;
-			if (file_exists($themeTransFile)) {
+			if (\file_exists($themeTransFile)) {
 				$languageFiles[] = $themeTransFile;
 			}
 		}
@@ -306,11 +305,11 @@ class Factory implements IFactory {
 	 * @return string directory
 	 */
 	protected function findL10nDir($app = null) {
-		if (in_array($app, ['core', 'lib', 'settings'])) {
-			if (file_exists($this->serverRoot . '/' . $app . '/l10n/')) {
+		if (\in_array($app, ['core', 'lib', 'settings'])) {
+			if (\file_exists($this->serverRoot . '/' . $app . '/l10n/')) {
 				return $this->serverRoot . '/' . $app . '/l10n/';
 			}
-		} else if ($app && \OC_App::getAppPath($app) !== false) {
+		} elseif ($app && \OC_App::getAppPath($app) !== false) {
 			// Check if the app is in the app folder
 			return \OC_App::getAppPath($app) . '/l10n/';
 		}
@@ -323,12 +322,12 @@ class Factory implements IFactory {
 	 */
 	protected function findAvailableLanguageFiles($dir) {
 		$availableLanguageFiles = [];
-		if (is_dir($dir)) {
-			$files = scandir($dir);
+		if (\is_dir($dir)) {
+			$files = \scandir($dir);
 			if ($files !== false) {
 				foreach ($files as $file) {
-					if (substr($file, -5) === '.json' && substr($file, 0, 4) !== 'l10n') {
-						$availableLanguageFiles[] = substr($file, 0, -5);
+					if (\substr($file, -5) === '.json' && \substr($file, 0, 4) !== 'l10n') {
+						$availableLanguageFiles[] = \substr($file, 0, -5);
 					}
 				}
 			}
@@ -371,8 +370,8 @@ class Factory implements IFactory {
 	 */
 	protected function getActiveAppThemeDirectory() {
 		$theme = $this->themeService->getTheme();
-		if ($theme instanceof ITheme && $theme->getDirectory() !== '' ) {
-			return $this->serverRoot . '/' . $theme->getDirectory();
+		if ($theme instanceof ITheme && $theme->getDirectory() !== '') {
+			return $theme->getBaseDirectory(). '/' . $theme->getDirectory();
 		}
 		return '';
 	}
