@@ -2,7 +2,7 @@
 /**
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,18 +21,20 @@
 
 namespace OC\Repair;
 
+use OCP\IConfig;
+use OCP\ILogger;
 use OCP\Migration\IOutput;
 use OCP\Migration\IRepairStep;
 use Doctrine\DBAL\Platforms\MySqlPlatform;
 use Doctrine\DBAL\Platforms\OraclePlatform;
 use OCP\Files\IMimeTypeLoader;
 use OCP\IDBConnection;
+use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
 
 /**
  * Repairs file cache entry which path do not match the parent-child relationship
  */
 class RepairMismatchFileCachePath implements IRepairStep {
-
 	const CHUNK_SIZE = 10000;
 
 	/** @var IDBConnection */
@@ -53,12 +55,23 @@ class RepairMismatchFileCachePath implements IRepairStep {
 	/** @var bool */
 	protected $countOnly = true;
 
+	/** @var ILogger  */
+	protected $logger;
+
+	/** @var IConfig */
+	protected $config;
+
 	/**
 	 * @param \OCP\IDBConnection $connection
 	 */
-	public function __construct(IDBConnection $connection, IMimeTypeLoader $mimeLoader) {
+	public function __construct(IDBConnection $connection,
+								IMimeTypeLoader $mimeLoader,
+								ILogger $logger,
+								IConfig $config) {
 		$this->connection = $connection;
 		$this->mimeLoader = $mimeLoader;
+		$this->logger = $logger;
+		$this->config = $config;
 	}
 
 	public function getName() {
@@ -94,7 +107,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 	 * @param int $fileId file id of the entry to fix
 	 * @param string $wrongPath wrong path of the entry to fix
 	 * @param int $correctStorageNumericId numeric idea of the correct storage
-	 * @param string $correctPath value to which to set the path of the entry 
+	 * @param string $correctPath value to which to set the path of the entry
 	 * @return bool true for success
 	 */
 	private function fixEntryPath(IOutput $out, $fileId, $wrongPath, $correctStorageNumericId, $correctPath) {
@@ -106,14 +119,14 @@ class RepairMismatchFileCachePath implements IRepairStep {
 		if ($correctPath === '' && $this->connection->getDatabasePlatform() instanceof OraclePlatform) {
 			$qb->andWhere($qb->expr()->isNull('path'));
 		} else {
-			$qb->andWhere($qb->expr()->eq('path_hash', $qb->createNamedParameter(md5($correctPath))));
+			$qb->andWhere($qb->expr()->eq('path_hash', $qb->createNamedParameter(\md5($correctPath))));
 		}
 		$entryExisted = $qb->execute() > 0;
 
 		$qb = $this->connection->getQueryBuilder();
 		$qb->update('filecache')
 			->set('path', $qb->createNamedParameter($correctPath))
-			->set('path_hash', $qb->createNamedParameter(md5($correctPath)))
+			->set('path_hash', $qb->createNamedParameter(\md5($correctPath)))
 			->set('storage', $qb->createNamedParameter($correctStorageNumericId))
 			->where($qb->expr()->eq('fileid', $qb->createNamedParameter($fileId)));
 		$qb->execute();
@@ -213,7 +226,6 @@ class RepairMismatchFileCachePath implements IRepairStep {
 		return $count;
 	}
 
-
 	/**
 	 * Outputs a report about storages with wrong path that need repairing in the file cache
 	 */
@@ -235,7 +247,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 		}
 
 		if (!empty($storageIds)) {
-			$out->warning('The file cache contains entries with invalid path values for the following storage numeric ids: ' . implode(' ', $storageIds));
+			$out->warning('The file cache contains entries with invalid path values for the following storage numeric ids: ' . \implode(' ', $storageIds));
 			$out->warning('Please run `occ files:scan --all --repair` to repair'
 			.'all affected storages or run `occ files:scan userid --repair for '
 			.'each user with affected storages');
@@ -263,7 +275,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 		}
 
 		if (!empty($storageIds)) {
-			$out->warning('The file cache contains entries where the parent id does not point to any existing entry for the following storage numeric ids: ' . implode(' ', $storageIds));
+			$out->warning('The file cache contains entries where the parent id does not point to any existing entry for the following storage numeric ids: ' . \implode(' ', $storageIds));
 			$out->warning('Please run `occ files:scan --all --repair` to repair all affected storages');
 		}
 	}
@@ -305,7 +317,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 				$wrongPath = $row['path'];
 				$correctPath = $row['parentpath'] . '/' . $row['name'];
 				// make sure the target is on a different subtree
-				if (substr($correctPath, 0, strlen($wrongPath)) === $wrongPath) {
+				if (\substr($correctPath, 0, \strlen($wrongPath)) === $wrongPath) {
 					// the path based parent entry is referencing one of its own children,
 					// fix the entry's parent id instead
 					// note: fixEntryParent cannot fail to find the parent entry by path
@@ -344,7 +356,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 			$out->info("Fixed $totalResultsCount file cache entries with wrong path");
 		}
 
-		return array_keys($affectedStorages);
+		return \array_keys($affectedStorages);
 	}
 
 	/**
@@ -371,7 +383,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 		if ($path === '' && $this->connection->getDatabasePlatform() instanceof OraclePlatform) {
 			$qb->andWhere($qb->expr()->isNull('path'));
 		} else {
-			$qb->andWhere($qb->expr()->eq('path_hash', $qb->createNamedParameter(md5($path))));
+			$qb->andWhere($qb->expr()->eq('path_hash', $qb->createNamedParameter(\md5($path))));
 		}
 		$results = $qb->execute();
 		$rows = $results->fetchAll();
@@ -382,7 +394,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 		}
 
 		if ($path !== '') {
-			$parentId = $this->getOrCreateEntry($storageId, dirname($path));
+			$parentId = $this->getOrCreateEntry($storageId, \dirname($path));
 		} else {
 			// root entry missing, create it
 			$parentId = -1;
@@ -392,8 +404,8 @@ class RepairMismatchFileCachePath implements IRepairStep {
 		$values = [
 			'storage' => $qb->createNamedParameter($storageId),
 			'path' => $qb->createNamedParameter($path),
-			'path_hash' => $qb->createNamedParameter(md5($path)),
-			'name' => $qb->createNamedParameter(basename($path)),
+			'path_hash' => $qb->createNamedParameter(\md5($path)),
+			'name' => $qb->createNamedParameter(\basename($path)),
 			'parent' => $qb->createNamedParameter($parentId),
 			'size' => $qb->createNamedParameter(-1),
 			'etag' => $qb->createNamedParameter('zombie'),
@@ -407,10 +419,17 @@ class RepairMismatchFileCachePath implements IRepairStep {
 			$values['fileid'] = $qb->createNamedParameter($reuseFileId);
 		}
 		$qb->insert('filecache')->values($values);
-		$qb->execute();
+		try {
+			$qb->execute();
+		} catch (UniqueConstraintViolationException $e) {
+			// This situation should no happen - need debugging information if it does
+			\OC::$server->getLogger()->logException($e);
+			\OC::$server->getLogger()->error("Filecache repair step tried to insert row that already existed with fileid: {$values['fileid']}");
+			// Skip if the entry already exists
+		}
 
 		// If we reused the fileid then this is the id to return
-		if($reuseFileId !== null) {
+		if ($reuseFileId !== null) {
 			// with Oracle, the trigger gets in the way and does not let us specify
 			// a fileid value on insert
 			if ($this->connection->getDatabasePlatform() instanceof OraclePlatform) {
@@ -447,10 +466,10 @@ class RepairMismatchFileCachePath implements IRepairStep {
 	private function fixEntryParent(IOutput $out, $storageId, $fileId, $path, $wrongParentId, $parentIdExists = false) {
 		if (!$parentIdExists) {
 			// if the parent doesn't exist, let us reuse its id in case there is metadata to salvage
-			$correctParentId = $this->getOrCreateEntry($storageId, dirname($path), $wrongParentId);
+			$correctParentId = $this->getOrCreateEntry($storageId, \dirname($path), $wrongParentId);
 		} else {
 			// parent exists and is the wrong one, so recreating would need a new fileid
-			$correctParentId = $this->getOrCreateEntry($storageId, dirname($path));
+			$correctParentId = $this->getOrCreateEntry($storageId, \dirname($path));
 		}
 
 		$this->connection->beginTransaction();
@@ -472,7 +491,7 @@ class RepairMismatchFileCachePath implements IRepairStep {
 	/**
 	 * Repair entries where the parent id doesn't point to any existing entry
 	 * by finding the actual parent entry matching the entry's path dirname.
-	 * 
+	 *
 	 * @param IOutput $out output
 	 * @param int|null $storageNumericId storage to fix or null for all
 	 * @return int number of results that were fixed
@@ -519,12 +538,13 @@ class RepairMismatchFileCachePath implements IRepairStep {
 	}
 
 	/**
-	 * Run the repair step
+	 * The purpose of this function is to let execute the run method
+	 * irrespective of version. For example when triggered from files:scan
+	 * this repair step shouldn't be blocked.
 	 *
-	 * @param IOutput $out output
+	 * @param IOutput $out
 	 */
-	public function run(IOutput $out) {
-
+	public function doRepair(IOutput $out) {
 		$this->dirMimeTypeId = $this->mimeLoader->getId('httpd/unix-directory');
 		$this->dirMimePartId = $this->mimeLoader->getId('httpd');
 
@@ -558,4 +578,19 @@ class RepairMismatchFileCachePath implements IRepairStep {
 			$out->info('');
 		}
 	}
+
+	/**
+	 * Run the repair step
+	 *
+	 * @param IOutput $out output
+	 */
+	public function run(IOutput $out) {
+		$currentVersion = $this->config->getSystemValue('version', '0.0.0');
+		$versionCompareStatus = \version_compare($currentVersion, '10.0.4', '<');
+		//Execute repair step if version is less than 10.0.4 during upgrade
+		//This is not applicable when called from file scan command
+		if ($versionCompareStatus) {
+			$this->doRepair($out);
+		}
+	}
 }
