@@ -10,7 +10,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -35,7 +35,7 @@ class OCI extends AbstractDatabase {
 
 	public function initialize($config) {
 		parent::initialize($config);
-		if (array_key_exists('dbtablespace', $config)) {
+		if (\array_key_exists('dbtablespace', $config)) {
 			$this->dbtablespace = $config['dbtablespace'];
 		} else {
 			$this->dbtablespace = 'USERS';
@@ -51,19 +51,19 @@ class OCI extends AbstractDatabase {
 
 	public function validate($config) {
 		$errors = [];
-		if(empty($config['dbuser']) && empty($config['dbname'])) {
+		if (empty($config['dbuser']) && empty($config['dbname'])) {
 			$errors[] = $this->trans->t("%s enter the database username and name.", [$this->dbprettyname]);
-		} else if(empty($config['dbuser'])) {
+		} elseif (empty($config['dbuser'])) {
 			$errors[] = $this->trans->t("%s enter the database username.", [$this->dbprettyname]);
-		} else if(empty($config['dbname'])) {
+		} elseif (empty($config['dbname'])) {
 			$errors[] = $this->trans->t("%s enter the database name.", [$this->dbprettyname]);
 		}
 		return $errors;
 	}
 
 	public function setupDatabase($username) {
-		$e_host = addslashes($this->dbHost);
-		$e_dbname = addslashes($this->dbName);
+		$e_host = \addslashes($this->dbHost);
+		$e_dbname = \addslashes($this->dbName);
 		//check if the database user has admin right
 		if ($e_host == '') {
 			$easy_connect_string = $e_dbname; // use dbname as easy connect name
@@ -71,37 +71,37 @@ class OCI extends AbstractDatabase {
 			$easy_connect_string = '//'.$e_host.'/'.$e_dbname;
 		}
 		$this->logger->debug('connect string: ' . $easy_connect_string, ['app' => 'setup.oci']);
-		$connection = @oci_connect($this->dbUser, $this->dbPassword, $easy_connect_string);
-		if(!$connection) {
+		$connection = @\oci_connect($this->dbUser, $this->dbPassword, $easy_connect_string);
+		if (!$connection) {
 			$errorMessage = $this->getLastError();
 			if ($errorMessage) {
 				throw new \OC\DatabaseSetupException($this->trans->t('Oracle connection could not be established'),
-				$errorMessage.' Check environment: ORACLE_HOME='.getenv('ORACLE_HOME')
-							.' ORACLE_SID='.getenv('ORACLE_SID')
-							.' LD_LIBRARY_PATH='.getenv('LD_LIBRARY_PATH')
-							.' NLS_LANG='.getenv('NLS_LANG')
-							.' tnsnames.ora is '.(is_readable(getenv('ORACLE_HOME').'/network/admin/tnsnames.ora')?'':'not ').'readable');
+				$errorMessage.' Check environment: ORACLE_HOME='.\getenv('ORACLE_HOME')
+							.' ORACLE_SID='.\getenv('ORACLE_SID')
+							.' LD_LIBRARY_PATH='.\getenv('LD_LIBRARY_PATH')
+							.' NLS_LANG='.\getenv('NLS_LANG')
+							.' tnsnames.ora is '.(\is_readable(\getenv('ORACLE_HOME').'/network/admin/tnsnames.ora')?'':'not ').'readable');
 			}
 			throw new \OC\DatabaseSetupException($this->trans->t('Oracle username and/or password not valid'),
-					'Check environment: ORACLE_HOME='.getenv('ORACLE_HOME')
-							.' ORACLE_SID='.getenv('ORACLE_SID')
-							.' LD_LIBRARY_PATH='.getenv('LD_LIBRARY_PATH')
-							.' NLS_LANG='.getenv('NLS_LANG')
-							.' tnsnames.ora is '.(is_readable(getenv('ORACLE_HOME').'/network/admin/tnsnames.ora')?'':'not ').'readable');
+					'Check environment: ORACLE_HOME='.\getenv('ORACLE_HOME')
+							.' ORACLE_SID='.\getenv('ORACLE_SID')
+							.' LD_LIBRARY_PATH='.\getenv('LD_LIBRARY_PATH')
+							.' NLS_LANG='.\getenv('NLS_LANG')
+							.' tnsnames.ora is '.(\is_readable(\getenv('ORACLE_HOME').'/network/admin/tnsnames.ora')?'':'not ').'readable');
 		}
 		//check for roles creation rights in oracle
 
 		$query='SELECT count(*) FROM user_role_privs, role_sys_privs'
 			." WHERE user_role_privs.granted_role = role_sys_privs.role AND privilege = 'CREATE ROLE'";
-		$stmt = oci_parse($connection, $query);
+		$stmt = \oci_parse($connection, $query);
 		if (!$stmt) {
 			$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 			$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
 			$this->logger->warning($entry, ['app' => 'setup.oci']);
 		}
-		$result = oci_execute($stmt);
-		if($result) {
-			$row = oci_fetch_row($stmt);
+		$result = \oci_execute($stmt);
+		if ($result) {
+			$row = \oci_fetch_row($stmt);
 
 			if ($row[0] > 0) {
 				//use the admin login data for the new database user
@@ -114,7 +114,7 @@ class OCI extends AbstractDatabase {
 				//oracle passwords are treated as identifiers:
 				//  must start with alphanumeric char
 				//  needs to be shortened to 30 bytes, as the two " needed to escape the identifier count towards the identifier length.
-				$this->dbPassword=substr($this->dbPassword, 0, 30);
+				$this->dbPassword=\substr($this->dbPassword, 0, 30);
 
 				$this->createDBUser($connection);
 			}
@@ -132,41 +132,41 @@ class OCI extends AbstractDatabase {
 		//FIXME check tablespace exists: select * from user_tablespaces
 
 		// the connection to dbname=oracle is not needed anymore
-		oci_close($connection);
+		\oci_close($connection);
 
 		// connect to the oracle database (schema=$this->dbuser) an check if the schema needs to be filled
 		$this->dbUser = $this->config->getSystemValue('dbuser');
 		//$this->dbname = \OC_Config::getValue('dbname');
 		$this->dbPassword = $this->config->getSystemValue('dbpassword');
 
-		$e_host = addslashes($this->dbHost);
-		$e_dbname = addslashes($this->dbName);
+		$e_host = \addslashes($this->dbHost);
+		$e_dbname = \addslashes($this->dbName);
 
 		if ($e_host == '') {
 			$easy_connect_string = $e_dbname; // use dbname as easy connect name
 		} else {
 			$easy_connect_string = '//'.$e_host.'/'.$e_dbname;
 		}
-		$connection = @oci_connect($this->dbUser, $this->dbPassword, $easy_connect_string);
-		if(!$connection) {
+		$connection = @\oci_connect($this->dbUser, $this->dbPassword, $easy_connect_string);
+		if (!$connection) {
 			throw new \OC\DatabaseSetupException($this->trans->t('Oracle username and/or password not valid'),
 					$this->trans->t('You need to enter either an existing account or the administrator.'));
 		}
 		$query = "SELECT count(*) FROM user_tables WHERE table_name = :un";
-		$stmt = oci_parse($connection, $query);
+		$stmt = \oci_parse($connection, $query);
 		$un = $this->tablePrefix.'users';
-		oci_bind_by_name($stmt, ':un', $un);
+		\oci_bind_by_name($stmt, ':un', $un);
 		if (!$stmt) {
 			$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 			$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
-			$this->logger->warning( $entry, ['app' => 'setup.oci']);
+			$this->logger->warning($entry, ['app' => 'setup.oci']);
 		}
-		$result = oci_execute($stmt);
+		$result = \oci_execute($stmt);
 
-		if($result) {
-			$row = oci_fetch_row($stmt);
+		if ($result) {
+			$row = \oci_fetch_row($stmt);
 		}
-		if(!$result or $row[0]==0) {
+		if (!$result or $row[0]==0) {
 			\OC_DB::createDbFromStructure($this->dbDefinitionFile);
 		}
 	}
@@ -178,52 +178,50 @@ class OCI extends AbstractDatabase {
 		$name = $this->dbUser;
 		$password = $this->dbPassword;
 		$query = "SELECT * FROM all_users WHERE USERNAME = :un";
-		$stmt = oci_parse($connection, $query);
+		$stmt = \oci_parse($connection, $query);
 		if (!$stmt) {
 			$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 			$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
 			$this->logger->warning($entry, ['app' => 'setup.oci']);
 		}
-		oci_bind_by_name($stmt, ':un', $name);
-		$result = oci_execute($stmt);
-		if(!$result) {
+		\oci_bind_by_name($stmt, ':un', $name);
+		$result = \oci_execute($stmt);
+		if (!$result) {
 			$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 			$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
 			$this->logger->warning($entry, ['app' => 'setup.oci']);
 		}
 
-		if(! oci_fetch_row($stmt)) {
+		if (! \oci_fetch_row($stmt)) {
 			//user does not exist, so let's create them :)
 			//password must start with alphabetic character in oracle
 			$query = 'CREATE USER '.$name.' IDENTIFIED BY "'.$password.'" DEFAULT TABLESPACE '.$this->dbtablespace;
-			$stmt = oci_parse($connection, $query);
+			$stmt = \oci_parse($connection, $query);
 			if (!$stmt) {
 				$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 				$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
 				$this->logger->warning($entry, ['app' => 'setup.oci']);
-
 			}
 			//oci_bind_by_name($stmt, ':un', $name);
-			$result = oci_execute($stmt);
-			if(!$result) {
+			$result = \oci_execute($stmt);
+			if (!$result) {
 				$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 				$entry .= $this->trans->t('Offending command was: "%s", name: %s, password: %s',
 					[$query, $name, $password]) . '<br />';
 				$this->logger->warning($entry, ['app' => 'setup.oci']);
-
 			}
 		} else { // change password of the existing role
 			$query = "ALTER USER :un IDENTIFIED BY :pw";
-			$stmt = oci_parse($connection, $query);
+			$stmt = \oci_parse($connection, $query);
 			if (!$stmt) {
 				$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 				$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
 				$this->logger->warning($entry, ['app' => 'setup.oci']);
 			}
-			oci_bind_by_name($stmt, ':un', $name);
-			oci_bind_by_name($stmt, ':pw', $password);
-			$result = oci_execute($stmt);
-			if(!$result) {
+			\oci_bind_by_name($stmt, ':un', $name);
+			\oci_bind_by_name($stmt, ':pw', $password);
+			$result = \oci_execute($stmt);
+			if (!$result) {
 				$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 				$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
 				$this->logger->warning($entry, ['app' => 'setup.oci']);
@@ -231,14 +229,14 @@ class OCI extends AbstractDatabase {
 		}
 		// grant necessary roles
 		$query = 'GRANT CREATE SESSION, CREATE TABLE, CREATE SEQUENCE, CREATE TRIGGER, UNLIMITED TABLESPACE TO '.$name;
-		$stmt = oci_parse($connection, $query);
+		$stmt = \oci_parse($connection, $query);
 		if (!$stmt) {
 			$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 			$entry .= $this->trans->t('Offending command was: "%s"', [$query]) . '<br />';
 			$this->logger->warning($entry, ['app' => 'setup.oci']);
 		}
-		$result = oci_execute($stmt);
-		if(!$result) {
+		$result = \oci_execute($stmt);
+		if (!$result) {
 			$entry = $this->trans->t('DB Error: "%s"', [$this->getLastError($connection)]) . '<br />';
 			$entry .= $this->trans->t('Offending command was: "%s", name: %s, password: %s',
 				[$query, $name, $password]) . '<br />';
@@ -252,9 +250,9 @@ class OCI extends AbstractDatabase {
 	 */
 	protected function getLastError($connection = null) {
 		if ($connection) {
-			$error = oci_error($connection);
+			$error = \oci_error($connection);
 		} else {
-			$error = oci_error();
+			$error = \oci_error();
 		}
 		foreach (['message', 'code'] as $key) {
 			if (isset($error[$key])) {
