@@ -7,7 +7,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -28,12 +28,14 @@ namespace OC\Share20;
 
 use OC\Cache\CappedMemoryCache;
 use OC\Files\Mount\MoveableMount;
+use OC\Files\View;
 use OCP\Files\File;
 use OCP\Files\Folder;
 use OCP\Files\IRootFolder;
 use OCP\Files\Mount\IMountManager;
 use OCP\Files\NotFoundException;
 use OCP\IConfig;
+use OCP\IDBConnection;
 use OCP\IGroupManager;
 use OCP\IL10N;
 use OCP\ILogger;
@@ -42,8 +44,11 @@ use OCP\Security\IHasher;
 use OCP\Security\ISecureRandom;
 use OCP\Share\Exceptions\GenericShareException;
 use OCP\Share\Exceptions\ShareNotFound;
+use OCP\Share\Exceptions\TransferSharesException;
 use OCP\Share\IManager;
 use OCP\Share\IProviderFactory;
+use OCP\Share\IShare;
+use Symfony\Component\EventDispatcher\EventDispatcher;
 use Symfony\Component\EventDispatcher\GenericEvent;
 
 /**
@@ -73,7 +78,12 @@ class Manager implements IManager {
 	private $rootFolder;
 	/** @var CappedMemoryCache */
 	private $sharingDisabledForUsersCache;
-
+	/** @var EventDispatcher  */
+	private $eventDispatcher;
+	/** @var  View */
+	private $view;
+	/** @var IDBConnection  */
+	private $connection;
 
 	/**
 	 * Manager constructor.
@@ -99,7 +109,10 @@ class Manager implements IManager {
 			IL10N $l,
 			IProviderFactory $factory,
 			IUserManager $userManager,
-			IRootFolder $rootFolder
+			IRootFolder $rootFolder,
+			EventDispatcher $eventDispatcher,
+			View $view,
+			IDBConnection $connection
 	) {
 		$this->logger = $logger;
 		$this->config = $config;
@@ -112,6 +125,9 @@ class Manager implements IManager {
 		$this->userManager = $userManager;
 		$this->rootFolder = $rootFolder;
 		$this->sharingDisabledForUsersCache = new CappedMemoryCache();
+		$this->eventDispatcher = $eventDispatcher;
+		$this->view = $view;
+		$this->connection = $connection;
 	}
 
 	/**
@@ -138,7 +154,7 @@ class Manager implements IManager {
 	 * @return string[]
 	 */
 	private function splitFullId($id) {
-		return explode(':', $id, 2);
+		return \explode(':', $id, 2);
 	}
 
 	/**
@@ -148,15 +164,6 @@ class Manager implements IManager {
 	 * @throws \Exception
 	 */
 	protected function verifyPassword($password) {
-		if ($password === null) {
-			// No password is set, check if this is allowed.
-			if ($this->shareApiLinkEnforcePassword()) {
-				throw new \InvalidArgumentException('Passwords are enforced for link shares');
-			}
-
-			return;
-		}
-
 		// Let others verify the password
 		$accepted = true;
 		$message = '';
@@ -170,12 +177,29 @@ class Manager implements IManager {
 			throw new \Exception($message);
 		}
 
-		\OC::$server->getEventDispatcher()->dispatch(
+		$this->eventDispatcher->dispatch(
 			'OCP\Share::validatePassword',
 			new GenericEvent(null, ['password' => $password])
 		);
 	}
 
+	/**
+	 * Check if a password must be enforced if the shared has those permissions
+	 * @param int $permissions \OCP\Constants::PERMISSION_* ("|" can be use for sets of permissions)
+	 * @return bool true if the password must be enforced, false otherwise
+	 */
+	protected function passwordMustBeEnforced($permissions) {
+		$roEnforcement = $permissions === \OCP\Constants::PERMISSION_READ && $this->shareApiLinkEnforcePasswordReadOnly();
+		$woEnforcement = $permissions === \OCP\Constants::PERMISSION_CREATE && $this->shareApiLinkEnforcePasswordWriteOnly();
+		// use read & write enforcement for the rest of the cases
+		$rwEnforcement = ($permissions !== \OCP\Constants::PERMISSION_READ && $permissions !== \OCP\Constants::PERMISSION_CREATE) && $this->shareApiLinkEnforcePasswordReadWrite();
+		if ($roEnforcement || $woEnforcement || $rwEnforcement) {
+			return true;
+		} else {
+			return false;
+		}
+	}
+
 	/**
 	 * Check for generic requirements before creating a share
 	 *
@@ -189,16 +213,16 @@ class Manager implements IManager {
 			if (!$this->userManager->userExists($share->getSharedWith())) {
 				throw new \InvalidArgumentException('SharedWith is not a valid user');
 			}
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
+		} elseif ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
 			// We expect a valid group as sharedWith for group shares
 			if (!$this->groupManager->groupExists($share->getSharedWith())) {
 				throw new \InvalidArgumentException('SharedWith is not a valid group');
 			}
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
+		} elseif ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
 			if ($share->getSharedWith() !== null) {
 				throw new \InvalidArgumentException('SharedWith should be empty');
 			}
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_REMOTE) {
+		} elseif ($share->getShareType() === \OCP\Share::SHARE_TYPE_REMOTE) {
 			if ($share->getSharedWith() === null) {
 				throw new \InvalidArgumentException('SharedWith should not be empty');
 			}
@@ -289,7 +313,6 @@ class Manager implements IManager {
 	 * @throws \Exception
 	 */
 	protected function validateExpirationDate(\OCP\Share\IShare $share) {
-
 		$expirationDate = $share->getExpirationDate();
 
 		if ($expirationDate !== null) {
@@ -314,7 +337,7 @@ class Manager implements IManager {
 
 		if ($fullId === null && $expirationDate === null && $this->shareApiLinkDefaultExpireDate()) {
 			$expirationDate = new \DateTime();
-			$expirationDate->setTime(0,0,0);
+			$expirationDate->setTime(0, 0, 0);
 			$expirationDate->add(new \DateInterval('P'.$this->shareApiLinkDefaultExpireDays().'D'));
 		}
 
@@ -363,7 +386,7 @@ class Manager implements IManager {
 			$sharedBy = $this->userManager->get($share->getSharedBy());
 			$sharedWith = $this->userManager->get($share->getSharedWith());
 			// Verify we can share with this user
-			$groups = array_intersect(
+			$groups = \array_intersect(
 					$this->groupManager->getUserGroupIds($sharedBy),
 					$this->groupManager->getUserGroupIds($sharedWith)
 			);
@@ -379,7 +402,7 @@ class Manager implements IManager {
 		 */
 		$provider = $this->factory->getProviderForType(\OCP\Share::SHARE_TYPE_USER);
 		$existingShares = $provider->getSharesByPath($share->getNode());
-		foreach($existingShares as $existingShare) {
+		foreach ($existingShares as $existingShare) {
 			// Ignore if it is the same share
 			try {
 				if ($existingShare->getFullId() === $share->getFullId()) {
@@ -397,7 +420,7 @@ class Manager implements IManager {
 			// The share is already shared with this user via a group share
 			if ($existingShare->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
 				$group = $this->groupManager->get($existingShare->getSharedWith());
-				if (!is_null($group)) {
+				if ($group !== null) {
 					$user = $this->userManager->get($share->getSharedWith());
 
 					if ($group->inGroup($user) && $existingShare->getShareOwner() !== $share->getShareOwner()) {
@@ -424,7 +447,7 @@ class Manager implements IManager {
 		if ($this->shareWithMembershipGroupOnly()) {
 			$sharedBy = $this->userManager->get($share->getSharedBy());
 			$sharedWith = $this->groupManager->get($share->getSharedWith());
-			if (is_null($sharedWith) || !$sharedWith->inGroup($sharedBy)) {
+			if ($sharedWith === null || !$sharedWith->inGroup($sharedBy)) {
 				throw new \Exception('Only sharing within your own groups is allowed');
 			}
 		}
@@ -436,7 +459,7 @@ class Manager implements IManager {
 		 */
 		$provider = $this->factory->getProviderForType(\OCP\Share::SHARE_TYPE_GROUP);
 		$existingShares = $provider->getSharesByPath($share->getNode());
-		foreach($existingShares as $existingShare) {
+		foreach ($existingShares as $existingShare) {
 			try {
 				if ($existingShare->getFullId() === $share->getFullId()) {
 					continue;
@@ -489,7 +512,7 @@ class Manager implements IManager {
 	protected function setLinkParent(\OCP\Share\IShare $share) {
 
 		// No sense in checking if the method is not there.
-		if (method_exists($share, 'setParent')) {
+		if (\method_exists($share, 'setParent')) {
 			$storage = $share->getNode()->getStorage();
 			if ($storage->instanceOfStorage('\OCA\Files_Sharing\ISharedStorage')) {
 				$share->setParent($storage->getShareId());
@@ -504,7 +527,7 @@ class Manager implements IManager {
 		// Make sure that we do not share a path that contains a shared mountpoint
 		if ($path instanceof \OCP\Files\Folder) {
 			$mounts = $this->mountManager->findIn($path->getPath());
-			foreach($mounts as $mount) {
+			foreach ($mounts as $mount) {
 				if ($mount->getStorage()->instanceOfStorage('\OCA\Files_Sharing\ISharedStorage')) {
 					throw new \InvalidArgumentException('Path contains files shared with you');
 				}
@@ -552,7 +575,7 @@ class Manager implements IManager {
 		$storage = $share->getNode()->getStorage();
 		if ($storage->instanceOfStorage('OCA\Files_Sharing\External\Storage')) {
 			$parent = $share->getNode()->getParent();
-			while($parent->getStorage()->instanceOfStorage('OCA\Files_Sharing\External\Storage')) {
+			while ($parent->getStorage()->instanceOfStorage('OCA\Files_Sharing\External\Storage')) {
 				$parent = $parent->getParent();
 			}
 			$share->setShareOwner($parent->getOwner()->getUID());
@@ -563,9 +586,9 @@ class Manager implements IManager {
 		//Verify share type
 		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_USER) {
 			$this->userCreateChecks($share);
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
+		} elseif ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
 			$this->groupCreateChecks($share);
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
+		} elseif ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
 			$this->linkCreateChecks($share);
 			$this->setLinkParent($share);
 
@@ -585,10 +608,14 @@ class Manager implements IManager {
 			$this->validateExpirationDate($share);
 
 			//Verify the password
-			$this->verifyPassword($share->getPassword());
+			if ($this->passwordMustBeEnforced($share->getPermissions()) && $share->getPassword() === null) {
+				throw new \InvalidArgumentException('Passwords are enforced for link shares');
+			} else {
+				$this->verifyPassword($share->getPassword());
+			}
 
 			// If a password is set. Hash it!
-			if ($share->getPassword() !== null) {
+			if (($share->getPassword() !== null) && ($share->getShouldHashPassword() === true)) {
 				$share->setPassword($this->hasher->hash($share->getPassword()));
 			}
 		}
@@ -623,6 +650,9 @@ class Manager implements IManager {
 		];
 		\OC_Hook::emit('OCP\Share', 'pre_shared', $preHookData);
 
+		$beforeEvent = new GenericEvent(null, ['shareData' => $preHookData, 'shareObject' => $share]);
+		$this->eventDispatcher->dispatch('share.beforeCreate', $beforeEvent);
+
 		if ($run === false) {
 			throw new \Exception($error);
 		}
@@ -644,14 +674,119 @@ class Manager implements IManager {
 			'shareWith' => $share->getSharedWith(),
 			'itemTarget' => $share->getTarget(),
 			'fileTarget' => $share->getTarget(),
-			'passwordEnabled' => (!is_null($share->getPassword()) and ($share->getPassword() !== '')),
+			'passwordEnabled' => ($share->getPassword() !== null and ($share->getPassword() !== '')),
 		];
 
 		\OC_Hook::emit('OCP\Share', 'post_shared', $postHookData);
 
+		$afterEvent = new GenericEvent(null, ['shareData' => $postHookData, 'shareObject' => $share]);
+		$this->eventDispatcher->dispatch('share.afterCreate', $afterEvent);
+
 		return $share;
 	}
 
+	/**
+	 * Transfer shares from oldOwner to newOwner. Both old and new owners are uid
+	 *
+	 * finalTarget is of the form "user1/files/transferred from admin on 20180509"
+	 *
+	 * TransferShareException would be thrown when:
+	 *  - oldOwner, newOwner does not exist.
+	 *  - oldOwner and newOwner are same
+	 * NotFoundException would be thrown when finalTarget does not exist in the file
+	 * system
+	 *
+	 * @param IShare $share
+	 * @param string $oldOwner
+	 * @param string $newOwner
+	 * @param string $finalTarget
+	 * @param null|bool $isChild
+	 * @throws TransferSharesException
+	 * @throws NotFoundException
+	 */
+	public function transferShare(IShare $share, $oldOwner, $newOwner, $finalTarget, $isChild = null) {
+		if ($this->userManager->get($oldOwner) === null) {
+			throw new TransferSharesException("The current owner of the share $oldOwner doesn't exist");
+		}
+		if ($this->userManager->get($newOwner) === null) {
+			throw new TransferSharesException("The future owner $newOwner, where the share has to be moved doesn't exist");
+		}
+
+		if ($oldOwner === $newOwner) {
+			throw new TransferSharesException("The current owner of the share and the future owner of the share are same");
+		}
+
+		//If the destination location, i.e finalTarget is not present, then
+		//throw an exception
+		if (!$this->view->file_exists($finalTarget)) {
+			throw new NotFoundException("The target location $finalTarget doesn't exist");
+		}
+
+		if ($isChild === true) {
+			//Set the parent to null so that we don't lose the shares after transfer
+			$builder = $this->connection->getQueryBuilder();
+			$builder->update('share')
+				->set('parent', 'null')
+				->where($builder->expr()->eq('id', $builder->createNamedParameter($share->getId())))
+				->execute();
+		}
+		/**
+		 * If the share was already shared with new owner, then we can delete it
+		 */
+		if ($share->getSharedWith() === $newOwner) {
+			// Unmount the shares before deleting, so we don't try to get the storage later on.
+			$shareMountPoint = $this->mountManager->find('/' . $newOwner . '/files' . $share->getTarget());
+			if ($shareMountPoint) {
+				$this->mountManager->removeMount($shareMountPoint->getMountPoint());
+			}
+
+			$provider = $this->factory->getProviderForType($share->getShareType());
+			//Try to get the children transferred and then delete the parent
+			foreach ($provider->getChildren($share) as $child) {
+				$this->transferShare($child, $oldOwner, $newOwner, $finalTarget, true);
+			}
+			$this->deleteShare($share);
+		} else {
+			$sharedWith = $share->getSharedWith();
+
+			$targetFile = '/' . \rtrim(\basename($finalTarget), '/') . '/' . \ltrim(\basename($share->getTarget()), '/');
+			/**
+			 * Scenario where share is made by old owner to a user different
+			 * from new owner
+			 */
+			if (($sharedWith !== null) && ($sharedWith !== $oldOwner) && ($sharedWith !== $newOwner)) {
+				$sharedBy = $share->getSharedBy();
+				$sharedOwner = $share->getShareOwner();
+				//The origin of the share now has to be the destination user.
+				if ($sharedBy === $oldOwner) {
+					$share->setSharedBy($newOwner);
+				}
+				if ($sharedOwner === $oldOwner) {
+					$share->setShareOwner($newOwner);
+				}
+				if (($sharedBy === $oldOwner) || ($sharedOwner === $oldOwner)) {
+					$share->setTarget($targetFile);
+				}
+			} else {
+				if ($share->getShareOwner() === $oldOwner) {
+					$share->setShareOwner($newOwner);
+				}
+				if ($share->getSharedBy() === $oldOwner) {
+					$share->setSharedBy($newOwner);
+				}
+			}
+
+			/**
+			 * Here we update the target when the share is link
+			 */
+			if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
+				$share->setTarget($targetFile);
+			}
+
+			$this->updateShare($share);
+		}
+	}
+
 	/**
 	 * Update a share
 	 *
@@ -677,7 +812,7 @@ class Manager implements IManager {
 
 		// We can only change the recipient on user shares
 		if ($share->getSharedWith() !== $originalShare->getSharedWith() &&
-		    $share->getShareType() !== \OCP\Share::SHARE_TYPE_USER) {
+			$share->getShareType() !== \OCP\Share::SHARE_TYPE_USER) {
 			throw new \InvalidArgumentException('Can only update recipient on user shares');
 		}
 
@@ -691,18 +826,25 @@ class Manager implements IManager {
 
 		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_USER) {
 			$this->userCreateChecks($share);
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
+		} elseif ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
 			$this->groupCreateChecks($share);
-		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
+		} elseif ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
 			$this->linkCreateChecks($share);
 
 			// Password updated.
-			if ($share->getPassword() !== $originalShare->getPassword()) {
-				//Verify the password
-				$this->verifyPassword($share->getPassword());
+			if ($share->getPassword() !== $originalShare->getPassword() ||
+					$share->getPermissions() !== $originalShare->getPermissions()) {
+				//Verify the password. Permissions must be taken into account in case the password must be enforced
+				if ($this->passwordMustBeEnforced($share->getPermissions()) && $share->getPassword() === null) {
+					throw new \InvalidArgumentException('Passwords are enforced for link shares');
+				} else {
+					$this->verifyPassword($share->getPassword(), $share->getPermissions());
+				}
 
-				// If a password is set. Hash it!
-				if ($share->getPassword() !== null) {
+				// If a password is set. Hash it! (only if the password has changed)
+				if (($share->getPassword() !== null) &&
+						($share->getPassword() !== $originalShare->getPassword()) &&
+						($share->getShouldHashPassword() === true)) {
 					$share->setPassword($this->hasher->hash($share->getPassword()));
 				}
 			}
@@ -721,6 +863,9 @@ class Manager implements IManager {
 		$provider = $this->factory->getProviderForType($share->getShareType());
 		$share = $provider->update($share);
 
+		$shareAfterUpdateEvent = new GenericEvent(null);
+		$shareAfterUpdateEvent->setArgument('shareobject', $share);
+		$update = false;
 		if ($expirationDateUpdated === true) {
 			\OC_Hook::emit('OCP\Share', 'post_set_expiration_date', [
 				'itemType' => $share->getNode() instanceof \OCP\Files\File ? 'file' : 'folder',
@@ -728,6 +873,9 @@ class Manager implements IManager {
 				'date' => $share->getExpirationDate(),
 				'uidOwner' => $share->getSharedBy(),
 			]);
+			$shareAfterUpdateEvent->setArgument('expirationdateupdated', true);
+			$shareAfterUpdateEvent->setArgument('oldexpirationdate', $originalShare->getExpirationDate());
+			$update = true;
 		}
 
 		if ($share->getPassword() !== $originalShare->getPassword()) {
@@ -736,8 +884,10 @@ class Manager implements IManager {
 				'itemSource' => $share->getNode()->getId(),
 				'uidOwner' => $share->getSharedBy(),
 				'token' => $share->getToken(),
-				'disabled' => is_null($share->getPassword()),
+				'disabled' => $share->getPassword() === null,
 			]);
+			$shareAfterUpdateEvent->setArgument('passwordupdate', true);
+			$update = true;
 		}
 
 		if ($share->getPermissions() !== $originalShare->getPermissions()) {
@@ -755,8 +905,21 @@ class Manager implements IManager {
 				'permissions' => $share->getPermissions(),
 				'path' => $userFolder->getRelativePath($share->getNode()->getPath()),
 			]);
+			$shareAfterUpdateEvent->setArgument('permissionupdate', true);
+			$shareAfterUpdateEvent->setArgument('oldpermissions', $originalShare->getPermissions());
+			$shareAfterUpdateEvent->setArgument('path', $userFolder->getRelativePath($share->getNode()->getPath()));
+			$update = true;
 		}
 
+		if ($share->getName() !== $originalShare->getName()) {
+			$shareAfterUpdateEvent->setArgument('sharenameupdated', true);
+			$shareAfterUpdateEvent->setArgument('oldname', $originalShare->getName());
+			$update = true;
+		}
+
+		if ($update === true) {
+			$this->eventDispatcher->dispatch('share.afterupdate', $shareAfterUpdateEvent);
+		}
 		return $share;
 	}
 
@@ -774,7 +937,7 @@ class Manager implements IManager {
 
 		foreach ($provider->getChildren($share) as $child) {
 			$deletedChildren = $this->deleteChildren($child);
-			$deletedShares = array_merge($deletedShares, $deletedChildren);
+			$deletedShares = \array_merge($deletedShares, $deletedChildren);
 
 			$provider->delete($child);
 			$deletedShares[] = $child;
@@ -789,9 +952,9 @@ class Manager implements IManager {
 		$sharedWith = '';
 		if ($shareType === \OCP\Share::SHARE_TYPE_USER) {
 			$sharedWith = $share->getSharedWith();
-		} else if ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
+		} elseif ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
 			$sharedWith = $share->getSharedWith();
-		} else if ($shareType === \OCP\Share::SHARE_TYPE_REMOTE) {
+		} elseif ($shareType === \OCP\Share::SHARE_TYPE_REMOTE) {
 			$sharedWith = $share->getSharedWith();
 		}
 
@@ -801,7 +964,7 @@ class Manager implements IManager {
 			'itemSource' => $share->getNodeId(),
 			'shareType'  => $shareType,
 			'shareWith'  => $sharedWith,
-			'itemparent' => method_exists($share, 'getParent') ? $share->getParent() : '',
+			'itemparent' => \method_exists($share, 'getParent') ? $share->getParent() : '',
 			'uidOwner'   => $share->getSharedBy(),
 			'fileSource' => $share->getNodeId(),
 			'fileTarget' => $share->getTarget()
@@ -817,7 +980,6 @@ class Manager implements IManager {
 	 * @throws \InvalidArgumentException
 	 */
 	public function deleteShare(\OCP\Share\IShare $share) {
-
 		try {
 			$share->getFullId();
 		} catch (\UnexpectedValueException $e) {
@@ -829,6 +991,8 @@ class Manager implements IManager {
 		// Emit pre-hook
 		\OC_Hook::emit('OCP\Share', 'pre_unshare', $hookParams);
 
+		$beforeEvent = new GenericEvent(null, ['shareData' => $hookParams, 'shareObject' => $share]);
+		$this->eventDispatcher->dispatch('share.beforeDelete', $beforeEvent);
 		// Get all children and delete them as well
 		$deletedShares = $this->deleteChildren($share);
 
@@ -840,15 +1004,16 @@ class Manager implements IManager {
 		$deletedShares[] = $share;
 
 		//Format hook info
-		$formattedDeletedShares = array_map('self::formatUnshareHookParams', $deletedShares);
+		$formattedDeletedShares = \array_map('self::formatUnshareHookParams', $deletedShares);
 
 		$hookParams['deletedShares'] = $formattedDeletedShares;
 
 		// Emit post hook
 		\OC_Hook::emit('OCP\Share', 'post_unshare', $hookParams);
+		$afterEvent = new GenericEvent(null, ['shareData' => $hookParams['deletedShares'], 'shareObject' => $share]);
+		$this->eventDispatcher->dispatch('share.afterDelete', $afterEvent);
 	}
 
-
 	/**
 	 * Unshare a file as the recipient.
 	 * This can be different from a regular delete for example when one of
@@ -878,36 +1043,24 @@ class Manager implements IManager {
 			'recipientPath' => $share->getTarget(),
 			'ownerPath' => $share->getNode()->getPath(),
 			'nodeType' => $share->getNodeType()]);
-		\OC::$server->getEventDispatcher()->dispatch('fromself.unshare',$event);
+		$this->eventDispatcher->dispatch('fromself.unshare', $event);
 	}
 
 	/**
 	 * @inheritdoc
 	 */
 	public function moveShare(\OCP\Share\IShare $share, $recipientId) {
-		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
-			throw new \InvalidArgumentException('Can\'t change target of link share');
-		}
-
-		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_USER && $share->getSharedWith() !== $recipientId) {
-			throw new \InvalidArgumentException('Invalid recipient');
-		}
-
-		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
-			$sharedWith = $this->groupManager->get($share->getSharedWith());
-			if (is_null($sharedWith)) {
-				throw new \InvalidArgumentException('Group "' . $share->getSharedWith() . '" does not exist');
-			}
-			$recipient = $this->userManager->get($recipientId);
-			if (!$sharedWith->inGroup($recipient)) {
-				throw new \InvalidArgumentException('Invalid recipient');
-			}
-		}
+		return $this->updateShareForRecipient($share, $recipientId);
+	}
 
+	/**
+	 * @inheritdoc
+	 */
+	public function updateShareForRecipient(\OCP\Share\IShare $share, $recipientId) {
 		list($providerId, ) = $this->splitFullId($share->getFullId());
 		$provider = $this->factory->getProvider($providerId);
 
-		$provider->move($share, $recipientId);
+		return $provider->updateForRecipient($share, $recipientId);
 	}
 
 	/**
@@ -919,7 +1072,7 @@ class Manager implements IManager {
 			throw new \InvalidArgumentException('Array of nodeIDs empty');
 		}
 		// This will ensure that if there are multiple share providers for the same share type, we will execute it in batches
-		$shares = array();
+		$shares = [];
 
 		$providerIdMap = $this->shareTypeToProviderMap($shareTypes);
 
@@ -929,7 +1082,7 @@ class Manager implements IManager {
 			$provider = $this->factory->getProvider($providerId);
 
 			$queriedShares = $provider->getAllSharesBy($userId, $shareTypeArray, $nodeIDs, $reshares);
-			foreach ($queriedShares as $queriedShare){
+			foreach ($queriedShares as $queriedShare) {
 				if ($queriedShare->getShareType() === \OCP\Share::SHARE_TYPE_LINK && $queriedShare->getExpirationDate() !== null &&
 					$queriedShare->getExpirationDate() <= $today
 				) {
@@ -940,7 +1093,7 @@ class Manager implements IManager {
 					}
 					continue;
 				}
-				array_push($shares, $queriedShare);
+				\array_push($shares, $queriedShare);
 			}
 		}
 
@@ -969,7 +1122,7 @@ class Manager implements IManager {
 			$shares2 = [];
 			$today = new \DateTime();
 
-			while(true) {
+			while (true) {
 				$added = 0;
 				foreach ($shares as $share) {
 					// Check if the share is expired and if so delete it
@@ -986,12 +1139,12 @@ class Manager implements IManager {
 					$added++;
 					$shares2[] = $share;
 
-					if (count($shares2) === $limit) {
+					if (\count($shares2) === $limit) {
 						break;
 					}
 				}
 
-				if (count($shares2) === $limit) {
+				if (\count($shares2) === $limit) {
 					break;
 				}
 
@@ -1026,7 +1179,6 @@ class Manager implements IManager {
 		return $provider->getSharedWith($userId, $shareType, $node, $limit, $offset);
 	}
 
-
 	/**
 	 * @inheritdoc
 	 */
@@ -1041,7 +1193,7 @@ class Manager implements IManager {
 			
 			// Obtain all shares for all the supported provider types
 			$queriedShares = $provider->getAllSharedWith($userId, $node);
-			$shares = array_merge($shares, $queriedShares);
+			$shares = \array_merge($shares, $queriedShares);
 		}
 
 		return $shares;
@@ -1092,7 +1244,7 @@ class Manager implements IManager {
 		}
 
 		foreach ($providers as $provider) {
-			$results = array_merge($results, $provider->getSharesByPath($path));
+			$results = \array_merge($results, $provider->getSharesByPath($path));
 		}
 
 		return $results;
@@ -1251,12 +1403,39 @@ class Manager implements IManager {
 	}
 
 	/**
-	 * Is password on public link requires
+	 * Is password on public link requires (fallback to shareApiLinkEnforcePasswordReadOnly)
 	 *
 	 * @return bool
 	 */
 	public function shareApiLinkEnforcePassword() {
-		return $this->config->getAppValue('core', 'shareapi_enforce_links_password', 'no') === 'yes';
+		return $this->shareApiLinkEnforcePasswordReadOnly();
+	}
+
+	/**
+	 * Is password enforced for read-only shares?
+	 *
+	 * @return bool
+	 */
+	public function shareApiLinkEnforcePasswordReadOnly() {
+		return $this->config->getAppValue('core', 'shareapi_enforce_links_password_read_only', 'no') === 'yes';
+	}
+
+	/**
+	 * Is password enforced for read & write shares?
+	 *
+	 * @return bool
+	 */
+	public function shareApiLinkEnforcePasswordReadWrite() {
+		return $this->config->getAppValue('core', 'shareapi_enforce_links_password_read_write', 'no') === 'yes';
+	}
+
+	/**
+	 * Is password enforced for write-only shares?
+	 *
+	 * @return bool
+	 */
+	public function shareApiLinkEnforcePasswordWriteOnly() {
+		return $this->config->getAppValue('core', 'shareapi_enforce_links_password_write_only', 'no') === 'yes';
 	}
 
 	/**
@@ -1323,8 +1502,6 @@ class Manager implements IManager {
 	/**
 	 * Copied from \OC_Util::isSharingDisabledForUser
 	 *
-	 * TODO: Deprecate fuction from OC_Util
-	 *
 	 * @param string $userId
 	 * @return bool
 	 */
@@ -1339,22 +1516,19 @@ class Manager implements IManager {
 
 		if ($this->config->getAppValue('core', 'shareapi_exclude_groups', 'no') === 'yes') {
 			$groupsList = $this->config->getAppValue('core', 'shareapi_exclude_groups_list', '');
-			$excludedGroups = json_decode($groupsList);
-			if (is_null($excludedGroups)) {
-				$excludedGroups = explode(',', $groupsList);
-				$newValue = json_encode($excludedGroups);
+			$excludedGroups = \json_decode($groupsList);
+			if ($excludedGroups === null) {
+				$excludedGroups = \explode(',', $groupsList);
+				$newValue = \json_encode($excludedGroups);
 				$this->config->setAppValue('core', 'shareapi_exclude_groups_list', $newValue);
 			}
 			$user = $this->userManager->get($userId);
 			$usersGroups = $this->groupManager->getUserGroupIds($user);
-			if (!empty($usersGroups)) {
-				$remainingGroups = array_diff($usersGroups, $excludedGroups);
-				// if the user is only in groups which are disabled for sharing then
-				// sharing is also disabled for the user
-				if (empty($remainingGroups)) {
-					$this->sharingDisabledForUsersCache[$userId] = true;
-					return true;
-				}
+			$matchingGroups = \array_intersect($usersGroups, $excludedGroups);
+			if (!empty($matchingGroups)) {
+				// If the user is a member of any of the excluded groups they cannot use sharing
+				$this->sharingDisabledForUsersCache[$userId] = true;
+				return true;
 			}
 		}
 
@@ -1368,5 +1542,4 @@ class Manager implements IManager {
 	public function outgoingServer2ServerSharesAllowed() {
 		return $this->config->getAppValue('files_sharing', 'outgoing_server2server_share_enabled', 'yes') === 'yes';
 	}
-
 }
