@@ -6,7 +6,7 @@
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Roeland Jago Douma <rullzer@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 namespace OC;
 
-
 use OCP\IConfig;
 
 /**
@@ -49,8 +48,16 @@ class SystemConfig {
 		'updater.secret' => true,
 		'ldap_agent_password' => true,
 		'proxyuserpwd' => true,
+		'marketplace.key' => true,
 		'log.condition' => [
+			[
 			'shared_secret' => true,
+			]
+		],
+		'log.conditions' => [
+			[
+			'shared_secret' => true,
+			]
 		],
 		'license-key' => true,
 		'redis' => [
@@ -150,10 +157,23 @@ class SystemConfig {
 			return IConfig::SENSITIVE_VALUE;
 		}
 
-		if (is_array($value)) {
+		if (\is_array($value)) {
 			foreach ($keysToRemove as $keyToRemove => $valueToRemove) {
-				if (isset($value[$keyToRemove])) {
-					$value[$keyToRemove] = $this->removeSensitiveValue($valueToRemove, $value[$keyToRemove]);
+				if ($keyToRemove === 0) {
+					/*
+					 * The 0 key in keysToRemove indicates a possibly repeating
+					 * array of actual entries 0,1,2,3...
+					 * Remove any sensitive values from all actual entries.
+					 */
+					foreach ($value as $valueKey => $valueData) {
+						if (\is_int($valueKey) && ($valueKey >= 0)) {
+							$value[$valueKey] = $this->removeSensitiveValue($valueToRemove, $value[$valueKey]);
+						}
+					}
+				} else {
+					if (isset($value[$keyToRemove])) {
+						$value[$keyToRemove] = $this->removeSensitiveValue($valueToRemove, $value[$keyToRemove]);
+					}
 				}
 			}
 		}
