@@ -11,7 +11,7 @@
  * @author Thomas Tanghus <thomas@tanghus.net>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -126,12 +126,12 @@ class Tags implements \OCP\ITags {
 		$this->includeShared = $includeShared;
 		$this->owners = [$this->user];
 		if ($this->includeShared) {
-			$this->owners = array_merge($this->owners, \OC\Share\Share::getSharedItemsOwners($this->user, $this->type, true));
+			$this->owners = \array_merge($this->owners, \OC\Share\Share::getSharedItemsOwners($this->user, $this->type, true));
 			$this->backend = \OC\Share\Share::getBackend($this->type);
 		}
 		$this->tags = $this->mapper->loadTags($this->owners, $this->type);
 
-		if(count($defaultTags) > 0 && count($this->tags) === 0) {
+		if (\count($defaultTags) > 0 && \count($this->tags) === 0) {
 			$this->addMultiple($defaultTags, true);
 		}
 	}
@@ -142,7 +142,7 @@ class Tags implements \OCP\ITags {
 	* @return boolean.
 	*/
 	public function isEmpty() {
-		return count($this->tags) === 0;
+		return \count($this->tags) === 0;
 	}
 
 	/**
@@ -172,22 +172,21 @@ class Tags implements \OCP\ITags {
 	* @return array
 	*/
 	public function getTags() {
-		if(!count($this->tags)) {
+		if (!\count($this->tags)) {
 			return [];
 		}
 
-		usort($this->tags, function($a, $b) {
-			return strnatcasecmp($a->getName(), $b->getName());
+		\usort($this->tags, function ($a, $b) {
+			return \strnatcasecmp($a->getName(), $b->getName());
 		});
 		$tagMap = [];
 
-		foreach($this->tags as $tag) {
-			if($tag->getName() !== self::TAG_FAVORITE) {
+		foreach ($this->tags as $tag) {
+			if ($tag->getName() !== self::TAG_FAVORITE) {
 				$tagMap[] = $this->tagMap($tag);
 			}
 		}
 		return $tagMap;
-
 	}
 
 	/**
@@ -198,8 +197,8 @@ class Tags implements \OCP\ITags {
 	* @return array An array of Tag objects.
 	*/
 	public function getTagsForUser($user) {
-		return array_filter($this->tags,
-			function($tag) use($user) {
+		return \array_filter($this->tags,
+			function ($tag) use ($user) {
 				return $tag->getOwner() === $user;
 			}
 		);
@@ -217,7 +216,7 @@ class Tags implements \OCP\ITags {
 
 		try {
 			$conn = \OC::$server->getDatabaseConnection();
-			$chunks = array_chunk($objIds, 900, false);
+			$chunks = \array_chunk($objIds, 900, false);
 			foreach ($chunks as $chunk) {
 				$result = $conn->executeQuery(
 					'SELECT `category`, `categoryid`, `objid` ' .
@@ -238,7 +237,7 @@ class Tags implements \OCP\ITags {
 					return false;
 				}
 			}
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 				\OCP\Util::ERROR);
 			return false;
@@ -259,18 +258,18 @@ class Tags implements \OCP\ITags {
 	public function getIdsForTag($tag) {
 		$result = null;
 		$tagId = false;
-		if(is_numeric($tag)) {
+		if (\is_numeric($tag)) {
 			$tagId = $tag;
-		} elseif(is_string($tag)) {
-			$tag = trim($tag);
-			if($tag === '') {
+		} elseif (\is_string($tag)) {
+			$tag = \trim($tag);
+			if ($tag === '') {
 				\OCP\Util::writeLog('core', __METHOD__.', Cannot use empty tag names', \OCP\Util::DEBUG);
 				return false;
 			}
 			$tagId = $this->getTagId($tag);
 		}
 
-		if($tagId === false) {
+		if ($tagId === false) {
 			$l10n = \OC::$server->getL10N('core');
 			throw new \Exception(
 				$l10n->t('Could not find category "%s"', $tag)
@@ -288,14 +287,14 @@ class Tags implements \OCP\ITags {
 				\OCP\Util::writeLog('core', __METHOD__. 'DB error: ' . \OCP\DB::getErrorMessage(), \OCP\Util::ERROR);
 				return false;
 			}
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 				\OCP\Util::ERROR);
 			return false;
 		}
 
-		if(!is_null($result)) {
-			while( $row = $result->fetchRow()) {
+		if ($result !== null) {
+			while ($row = $result->fetchRow()) {
 				$id = (int)$row['objid'];
 
 				if ($this->includeShared) {
@@ -348,13 +347,13 @@ class Tags implements \OCP\ITags {
 	* @return false|int the id of the added tag or false on error.
 	*/
 	public function add($name) {
-		$name = trim($name);
+		$name = \trim($name);
 
-		if($name === '') {
+		if ($name === '') {
 			\OCP\Util::writeLog('core', __METHOD__.', Cannot add an empty tag', \OCP\Util::DEBUG);
 			return false;
 		}
-		if($this->userHasTag($name, $this->user)) {
+		if ($this->userHasTag($name, $this->user)) {
 			\OCP\Util::writeLog('core', __METHOD__.', name: ' . $name. ' exists already', \OCP\Util::DEBUG);
 			return false;
 		}
@@ -362,7 +361,7 @@ class Tags implements \OCP\ITags {
 			$tag = new Tag($this->user, $this->type, $name);
 			$tag = $this->mapper->insert($tag);
 			$this->tags[] = $tag;
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 				\OCP\Util::ERROR);
 			return false;
@@ -379,26 +378,26 @@ class Tags implements \OCP\ITags {
 	* @return bool
 	*/
 	public function rename($from, $to) {
-		$from = trim($from);
-		$to = trim($to);
+		$from = \trim($from);
+		$to = \trim($to);
 
-		if($to === '' || $from === '') {
+		if ($to === '' || $from === '') {
 			\OCP\Util::writeLog('core', __METHOD__.', Cannot use empty tag names', \OCP\Util::DEBUG);
 			return false;
 		}
 
-		if (is_numeric($from)) {
+		if (\is_numeric($from)) {
 			$key = $this->getTagById($from);
 		} else {
 			$key = $this->getTagByName($from);
 		}
-		if($key === false) {
+		if ($key === false) {
 			\OCP\Util::writeLog('core', __METHOD__.', tag: ' . $from. ' does not exist', \OCP\Util::DEBUG);
 			return false;
 		}
 		$tag = $this->tags[$key];
 
-		if($this->userHasTag($to, $tag->getOwner())) {
+		if ($this->userHasTag($to, $tag->getOwner())) {
 			\OCP\Util::writeLog('core', __METHOD__.', A tag named ' . $to. ' already exists for user ' . $tag->getOwner() . '.', \OCP\Util::DEBUG);
 			return false;
 		}
@@ -406,7 +405,7 @@ class Tags implements \OCP\ITags {
 		try {
 			$tag->setName($to);
 			$this->tags[$key] = $this->mapper->update($tag);
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 				\OCP\Util::ERROR);
 			return false;
@@ -424,24 +423,24 @@ class Tags implements \OCP\ITags {
 	* @return bool Returns false on error.
 	*/
 	public function addMultiple($names, $sync=false, $id = null) {
-		if(!is_array($names)) {
+		if (!\is_array($names)) {
 			$names = [$names];
 		}
-		$names = array_map('trim', $names);
-		array_filter($names);
+		$names = \array_map('trim', $names);
+		\array_filter($names);
 
 		$newones = [];
-		foreach($names as $name) {
-			if(!$this->hasTag($name) && $name !== '') {
+		foreach ($names as $name) {
+			if (!$this->hasTag($name) && $name !== '') {
 				$newones[] = new Tag($this->user, $this->type, $name);
 			}
-			if(!is_null($id) ) {
+			if ($id !== null) {
 				// Insert $objectid, $categoryid  pairs if not exist.
 				self::$relations[] = ['objid' => $id, 'tag' => $name];
 			}
 		}
-		$this->tags = array_merge($this->tags, $newones);
-		if($sync === true) {
+		$this->tags = \array_merge($this->tags, $newones);
+		if ($sync === true) {
 			$this->save();
 		}
 
@@ -452,13 +451,13 @@ class Tags implements \OCP\ITags {
 	 * Save the list of tags and their object relations
 	 */
 	protected function save() {
-		if(is_array($this->tags)) {
-			foreach($this->tags as $tag) {
+		if (\is_array($this->tags)) {
+			foreach ($this->tags as $tag) {
 				try {
 					if (!$this->mapper->tagExists($tag)) {
 						$this->mapper->insert($tag);
 					}
-				} catch(\Exception $e) {
+				} catch (\Exception $e) {
 					\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 						\OCP\Util::ERROR);
 				}
@@ -466,17 +465,17 @@ class Tags implements \OCP\ITags {
 
 			// reload tags to get the proper ids.
 			$this->tags = $this->mapper->loadTags($this->owners, $this->type);
-			\OCP\Util::writeLog('core', __METHOD__.', tags: ' . print_r($this->tags, true),
+			\OCP\Util::writeLog('core', __METHOD__.', tags: ' . \print_r($this->tags, true),
 				\OCP\Util::DEBUG);
 			// Loop through temporarily cached objectid/tagname pairs
 			// and save relations.
 			$tags = $this->tags;
 			// For some reason this is needed or array_search(i) will return 0..?
-			ksort($tags);
-			foreach(self::$relations as $relation) {
+			\ksort($tags);
+			foreach (self::$relations as $relation) {
 				$tagId = $this->getTagId($relation['tag']);
 				\OCP\Util::writeLog('core', __METHOD__ . 'catid, ' . $relation['tag'] . ' ' . $tagId, \OCP\Util::DEBUG);
-				if($tagId) {
+				if ($tagId) {
 					try {
 						\OCP\DB::insertIfNotExist(self::RELATION_TABLE,
 							[
@@ -484,7 +483,7 @@ class Tags implements \OCP\ITags {
 								'categoryid' => $tagId,
 								'type' => $this->type,
 							]);
-					} catch(\Exception $e) {
+					} catch (\Exception $e) {
 						\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 							\OCP\Util::ERROR);
 					}
@@ -493,7 +492,7 @@ class Tags implements \OCP\ITags {
 			self::$relations = []; // reset
 		} else {
 			\OCP\Util::writeLog('core', __METHOD__.', $this->tags is not an array! '
-				. print_r($this->tags, true), \OCP\Util::ERROR);
+				. \print_r($this->tags, true), \OCP\Util::ERROR);
 		}
 	}
 
@@ -514,24 +513,24 @@ class Tags implements \OCP\ITags {
 			if (\OCP\DB::isError($result)) {
 				\OCP\Util::writeLog('core', __METHOD__. 'DB error: ' . \OCP\DB::getErrorMessage(), \OCP\Util::ERROR);
 			}
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 				\OCP\Util::ERROR);
 		}
 
-		if(!is_null($result)) {
+		if ($result !== null) {
 			try {
 				$stmt = \OCP\DB::prepare('DELETE FROM `' . self::RELATION_TABLE . '` '
 					. 'WHERE `categoryid` = ?');
-				while( $row = $result->fetchRow()) {
+				while ($row = $result->fetchRow()) {
 					try {
 						$stmt->execute([$row['id']]);
-					} catch(\Exception $e) {
+					} catch (\Exception $e) {
 						\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 							\OCP\Util::ERROR);
 					}
 				}
-			} catch(\Exception $e) {
+			} catch (\Exception $e) {
 				\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 					\OCP\Util::ERROR);
 			}
@@ -543,7 +542,7 @@ class Tags implements \OCP\ITags {
 			if (\OCP\DB::isError($result)) {
 				\OCP\Util::writeLog('core', __METHOD__. ', DB error: ' . \OCP\DB::getErrorMessage(), \OCP\Util::ERROR);
 			}
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__ . ', exception: '
 				. $e->getMessage(), \OCP\Util::ERROR);
 		}
@@ -556,14 +555,14 @@ class Tags implements \OCP\ITags {
 	* @return boolean Returns false on error.
 	*/
 	public function purgeObjects(array $ids) {
-		if(count($ids) === 0) {
+		if (\count($ids) === 0) {
 			// job done ;)
 			return true;
 		}
 		$updates = $ids;
 		try {
 			$query = 'DELETE FROM `' . self::RELATION_TABLE . '` ';
-			$query .= 'WHERE `objid` IN (' . str_repeat('?,', count($ids)-1) . '?) ';
+			$query .= 'WHERE `objid` IN (' . \str_repeat('?,', \count($ids)-1) . '?) ';
 			$query .= 'AND `type`= ?';
 			$updates[] = $this->type;
 			$stmt = \OCP\DB::prepare($query);
@@ -572,7 +571,7 @@ class Tags implements \OCP\ITags {
 				\OCP\Util::writeLog('core', __METHOD__. 'DB error: ' . \OCP\DB::getErrorMessage(), \OCP\Util::ERROR);
 				return false;
 			}
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: ' . $e->getMessage(),
 				\OCP\Util::ERROR);
 			return false;
@@ -588,7 +587,7 @@ class Tags implements \OCP\ITags {
 	public function getFavorites() {
 		try {
 			return $this->getIdsForTag(self::TAG_FAVORITE);
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: ' . $e->getMessage(),
 				\OCP\Util::DEBUG);
 			return [];
@@ -602,7 +601,7 @@ class Tags implements \OCP\ITags {
 	* @return boolean
 	*/
 	public function addToFavorites($objid) {
-		if(!$this->userHasTag(self::TAG_FAVORITE, $this->user)) {
+		if (!$this->userHasTag(self::TAG_FAVORITE, $this->user)) {
 			$this->add(self::TAG_FAVORITE);
 		}
 		return $this->tagAs($objid, self::TAG_FAVORITE);
@@ -626,13 +625,13 @@ class Tags implements \OCP\ITags {
 	* @return boolean Returns false on error.
 	*/
 	public function tagAs($objid, $tag) {
-		if(is_string($tag) && !is_numeric($tag)) {
-			$tag = trim($tag);
-			if($tag === '') {
+		if (\is_string($tag) && !\is_numeric($tag)) {
+			$tag = \trim($tag);
+			if ($tag === '') {
 				\OCP\Util::writeLog('core', __METHOD__.', Cannot add an empty tag', \OCP\Util::DEBUG);
 				return false;
 			}
-			if(!$this->hasTag($tag)) {
+			if (!$this->hasTag($tag)) {
 				$this->add($tag);
 			}
 			$tagId =  $this->getTagId($tag);
@@ -646,7 +645,7 @@ class Tags implements \OCP\ITags {
 					'categoryid' => $tagId,
 					'type' => $this->type,
 				]);
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 				\OCP\Util::ERROR);
 			return false;
@@ -662,9 +661,9 @@ class Tags implements \OCP\ITags {
 	* @return boolean
 	*/
 	public function unTag($objid, $tag) {
-		if(is_string($tag) && !is_numeric($tag)) {
-			$tag = trim($tag);
-			if($tag === '') {
+		if (\is_string($tag) && !\is_numeric($tag)) {
+			$tag = \trim($tag);
+			if ($tag === '') {
 				\OCP\Util::writeLog('core', __METHOD__.', Tag name is empty', \OCP\Util::DEBUG);
 				return false;
 			}
@@ -678,7 +677,7 @@ class Tags implements \OCP\ITags {
 					. 'WHERE `objid` = ? AND `categoryid` = ? AND `type` = ?';
 			$stmt = \OCP\DB::prepare($sql);
 			$stmt->execute([$objid, $tagId, $this->type]);
-		} catch(\Exception $e) {
+		} catch (\Exception $e) {
 			\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 				\OCP\Util::ERROR);
 			return false;
@@ -693,19 +692,19 @@ class Tags implements \OCP\ITags {
 	* @return bool Returns false on error
 	*/
 	public function delete($names) {
-		if(!is_array($names)) {
+		if (!\is_array($names)) {
 			$names = [$names];
 		}
 
-		$names = array_map('trim', $names);
-		array_filter($names);
+		$names = \array_map('trim', $names);
+		\array_filter($names);
 
 		\OCP\Util::writeLog('core', __METHOD__ . ', before: '
-			. print_r($this->tags, true), \OCP\Util::DEBUG);
-		foreach($names as $name) {
+			. \print_r($this->tags, true), \OCP\Util::DEBUG);
+		foreach ($names as $name) {
 			$id = null;
 
-			if (is_numeric($name)) {
+			if (\is_numeric($name)) {
 				$key = $this->getTagById($name);
 			} else {
 				$key = $this->getTagByName($name);
@@ -719,7 +718,7 @@ class Tags implements \OCP\ITags {
 				\OCP\Util::writeLog('core', __METHOD__ . 'Cannot delete tag ' . $name
 					. ': not found.', \OCP\Util::ERROR);
 			}
-			if(!is_null($id) && $id !== false) {
+			if ($id !== null && $id !== false) {
 				try {
 					$sql = 'DELETE FROM `' . self::RELATION_TABLE . '` '
 							. 'WHERE `categoryid` = ?';
@@ -731,7 +730,7 @@ class Tags implements \OCP\ITags {
 							\OCP\Util::ERROR);
 						return false;
 					}
-				} catch(\Exception $e) {
+				} catch (\Exception $e) {
 					\OCP\Util::writeLog('core', __METHOD__.', exception: '.$e->getMessage(),
 						\OCP\Util::ERROR);
 					return false;
@@ -743,12 +742,12 @@ class Tags implements \OCP\ITags {
 
 	// case-insensitive array_search
 	protected function array_searchi($needle, $haystack, $mem='getName') {
-		if(!is_array($haystack)) {
+		if (!\is_array($haystack)) {
 			return false;
 		}
-		return array_search(strtolower($needle), array_map(
-			function($tag) use($mem) {
-				return strtolower(call_user_func([$tag, $mem]));
+		return \array_search(\strtolower($needle), \array_map(
+			function ($tag) use ($mem) {
+				return \strtolower(\call_user_func([$tag, $mem]));
 			}, $haystack)
 		);
 	}
