@@ -4,7 +4,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Tom Needham <tom@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,7 +23,6 @@
 
 namespace OC\User;
 
-
 use OC\DB\QueryBuilder\Literal;
 use OCP\AppFramework\Db\Entity;
 use OCP\AppFramework\Db\Mapper;
@@ -104,7 +103,7 @@ class AccountMapper extends Mapper {
 	 * @return Account[]
 	 */
 	public function getByEmail($email) {
-		if ($email === null || trim($email) === '') {
+		if ($email === null || \trim($email) === '') {
 			throw new \InvalidArgumentException('$email must be defined');
 		}
 		$qb = $this->db->getQueryBuilder();
@@ -125,7 +124,7 @@ class AccountMapper extends Mapper {
 		$qb = $this->db->getQueryBuilder();
 		$qb->select('*')
 			->from($this->getTableName())
-			->where($qb->expr()->eq('lower_user_id', $qb->createNamedParameter(strtolower($uid))));
+			->where($qb->expr()->eq('lower_user_id', $qb->createNamedParameter(\strtolower($uid))));
 
 		return $this->findEntity($qb->getSQL(), $qb->getParameters());
 	}
@@ -154,14 +153,13 @@ class AccountMapper extends Mapper {
 	 * @return Account[]
 	 */
 	public function find($pattern, $limit = null, $offset = null) {
-
 		$allowMedialSearches = $this->config->getSystemValue('accounts.enable_medial_search', true);
 		if ($allowMedialSearches) {
 			$parameter = '%' . $this->db->escapeLikeParameter($pattern) . '%';
-			$loweredParameter = '%' . $this->db->escapeLikeParameter(strtolower($pattern)) . '%';
+			$loweredParameter = '%' . $this->db->escapeLikeParameter(\strtolower($pattern)) . '%';
 		} else {
 			$parameter = $this->db->escapeLikeParameter($pattern) . '%';
-			$loweredParameter = $this->db->escapeLikeParameter(strtolower($pattern)) . '%';
+			$loweredParameter = $this->db->escapeLikeParameter(\strtolower($pattern)) . '%';
 		}
 
 		$qb = $this->db->getQueryBuilder();
@@ -170,10 +168,10 @@ class AccountMapper extends Mapper {
 			->from($this->getTableName(), 'a')
 			->leftJoin('a', 'account_terms', 't', $qb->expr()->eq('a.id', 't.account_id'))
 			->orderBy('display_name')
-			->where($qb->expr()->like('lower_user_id', $qb->createNamedParameter($loweredParameter)))
-			->orWhere($qb->expr()->iLike('display_name', $qb->createNamedParameter($parameter)))
-			->orWhere($qb->expr()->iLike('email', $qb->createNamedParameter($parameter)))
-			->orWhere($qb->expr()->like('t.term', $qb->createNamedParameter($loweredParameter)));
+			->where($qb->expr()->like('lower_user_id', $qb->createPositionalParameter($loweredParameter)))
+			->orWhere($qb->expr()->iLike('display_name', $qb->createPositionalParameter($parameter)))
+			->orWhere($qb->expr()->iLike('email', $qb->createPositionalParameter($parameter)))
+			->orWhere($qb->expr()->like('t.term', $qb->createPositionalParameter($loweredParameter)));
 
 		return $this->findEntities($qb->getSQL(), $qb->getParameters(), $limit, $offset);
 	}
@@ -230,7 +228,7 @@ class AccountMapper extends Mapper {
 		}
 		$stmt = $qb->execute();
 		while ($row = $stmt->fetch()) {
-			$return =$callback($this->mapRowToEntity($row));
+			$return = $callback($this->mapRowToEntity($row));
 			if ($return === false) {
 				break;
 			}
@@ -239,4 +237,37 @@ class AccountMapper extends Mapper {
 		$stmt->closeCursor();
 	}
 
+	/**
+	 * @param string $backend
+	 * @param bool $hasLoggedIn
+	 * @param integer $limit
+	 * @param integer $offset
+	 * @return string[]
+	 */
+	public function findUserIds($backend = null, $hasLoggedIn = null, $limit = null, $offset = null) {
+		$qb = $this->db->getQueryBuilder();
+		$qb->select('user_id')
+			->from($this->getTableName())
+			->orderBy('user_id'); // needed for predictable limit & offset
+
+		if ($backend !== null) {
+			$qb->andWhere($qb->expr()->eq('backend', $qb->createNamedParameter($backend)));
+		}
+		if ($hasLoggedIn === true) {
+			$qb->andWhere($qb->expr()->gt('last_login', new Literal(0)));
+		} elseif ($hasLoggedIn === false) {
+			$qb->andWhere($qb->expr()->eq('last_login', new Literal(0)));
+		}
+		if ($limit !== null) {
+			$qb->setMaxResults($limit);
+		}
+		if ($offset !== null) {
+			$qb->setFirstResult($offset);
+		}
+
+		$stmt = $qb->execute();
+		$rows = $stmt->fetchAll(\PDO::FETCH_COLUMN);
+		$stmt->closeCursor();
+		return $rows;
+	}
 }
