@@ -15,7 +15,7 @@
  * @author Tom Needham <tom@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -33,6 +33,7 @@
  */
 use OCP\API;
 use OCP\AppFramework\Http;
+use OCP\Authentication\Exceptions\AccountCheckException;
 
 /**
  * @author Bart Visscher <bartv@thisnet.nl>
@@ -48,7 +49,7 @@ use OCP\AppFramework\Http;
  * @author Tom Needham <tom@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -121,9 +122,9 @@ class OC_API {
 				$authLevel = API::USER_AUTH,
 				$defaults = [],
 				$requirements = [], $cors = true) {
-		$name = strtolower($method).$url;
-		$name = str_replace(['/', '{', '}'], '_', $name);
-		if(!isset(self::$actions[$name])) {
+		$name = \strtolower($method).$url;
+		$name = \str_replace(['/', '{', '}'], '_', $name);
+		if (!isset(self::$actions[$name])) {
 			$oldCollection = OC::$server->getRouter()->getCurrentCollection();
 			OC::$server->getRouter()->useCollection('ocs');
 			OC::$server->getRouter()->create($name, $url)
@@ -146,17 +147,17 @@ class OC_API {
 		$method = $request->getMethod();
 
 		// Prepare the request variables
-		if($method === 'PUT') {
+		if ($method === 'PUT') {
 			$parameters['_put'] = $request->getParams();
-		} else if($method === 'DELETE') {
+		} elseif ($method === 'DELETE') {
 			$parameters['_delete'] = $request->getParams();
 		}
 		$name = $parameters['_route'];
 		// Foreach registered action
 		$responses = [];
-		foreach(self::$actions[$name] as $action) {
+		foreach (self::$actions[$name] as $action) {
 			// Check authentication and availability
-			if(!self::isAuthorised($action)) {
+			if (!self::isAuthorised($action)) {
 				$responses[] = [
 					'app' => $action['app'],
 					'response' => new \OC\OCS\Result(null, API::RESPOND_UNAUTHORISED, 'Unauthorised'),
@@ -164,7 +165,7 @@ class OC_API {
 				];
 				continue;
 			}
-			if(!is_callable($action['action'])) {
+			if (!\is_callable($action['action'])) {
 				$responses[] = [
 					'app' => $action['app'],
 					'response' => new \OC\OCS\Result(null, API::RESPOND_NOT_FOUND, 'Api method not found'),
@@ -175,7 +176,7 @@ class OC_API {
 			// Run the action
 			$responses[] = [
 				'app' => $action['app'],
-				'response' => call_user_func($action['action'], $parameters),
+				'response' => \call_user_func($action['action'], $parameters),
 				'shipped' => OC_App::isShipped($action['app']),
 			];
 		}
@@ -183,11 +184,14 @@ class OC_API {
 
 		// If CORS is set to active for some method, try to add CORS headers
 		if (self::$actions[$name][0]['cors'] &&
-			!is_null(\OC::$server->getUserSession()->getUser()) &&
-			!is_null(\OC::$server->getRequest()->getHeader('Origin'))) {
+			\OC::$server->getUserSession()->getUser() !== null &&
+			\OC::$server->getRequest()->getHeader('Origin') !== null) {
 			$requesterDomain = \OC::$server->getRequest()->getHeader('Origin');
 			$userId = \OC::$server->getUserSession()->getUser()->getUID();
-			$response = \OC_Response::setCorsHeaders($userId, $requesterDomain, $response);
+			$headers = \OC_Response::setCorsHeaders($userId, $requesterDomain);
+			foreach ($headers as $key => $value) {
+				$response->addHeader($key, \implode(',', $value));
+			}
 		}
 
 		$format = self::requestedFormat();
@@ -214,15 +218,15 @@ class OC_API {
 			'failed' => [],
 		];
 
-		foreach($responses as $response) {
-			if($response['shipped'] || ($response['app'] === 'core')) {
-				if($response['response']->succeeded()) {
+		foreach ($responses as $response) {
+			if ($response['shipped'] || ($response['app'] === 'core')) {
+				if ($response['response']->succeeded()) {
 					$shipped['succeeded'][$response['app']] = $response;
 				} else {
 					$shipped['failed'][$response['app']] = $response;
 				}
 			} else {
-				if($response['response']->succeeded()) {
+				if ($response['response']->succeeded()) {
 					$thirdparty['succeeded'][$response['app']] = $response;
 				} else {
 					$thirdparty['failed'][$response['app']] = $response;
@@ -231,31 +235,31 @@ class OC_API {
 		}
 
 		// Remove any error responses if there is one shipped response that succeeded
-		if(!empty($shipped['failed'])) {
+		if (!empty($shipped['failed'])) {
 			// Which shipped response do we use if they all failed?
 			// They may have failed for different reasons (different status codes)
 			// Which response code should we return?
 			// Maybe any that are not \OCP\API::RESPOND_SERVER_ERROR
 			// Merge failed responses if more than one
 			$data = [];
-			foreach($shipped['failed'] as $failure) {
-				$data = array_merge_recursive($data, $failure['response']->getData());
+			foreach ($shipped['failed'] as $failure) {
+				$data = \array_merge_recursive($data, $failure['response']->getData());
 			}
-			$picked = reset($shipped['failed']);
+			$picked = \reset($shipped['failed']);
 			$code = $picked['response']->getStatusCode();
 			$meta = $picked['response']->getMeta();
 			$headers = $picked['response']->getHeaders();
 			$response = new \OC\OCS\Result($data, $code, $meta['message'], $headers);
 			return $response;
-		} elseif(!empty($shipped['succeeded'])) {
-			$responses = array_merge($shipped['succeeded'], $thirdparty['succeeded']);
-		} elseif(!empty($thirdparty['failed'])) {
+		} elseif (!empty($shipped['succeeded'])) {
+			$responses = \array_merge($shipped['succeeded'], $thirdparty['succeeded']);
+		} elseif (!empty($thirdparty['failed'])) {
 			// Merge failed responses if more than one
 			$data = [];
-			foreach($thirdparty['failed'] as $failure) {
-				$data = array_merge_recursive($data, $failure['response']->getData());
+			foreach ($thirdparty['failed'] as $failure) {
+				$data = \array_merge_recursive($data, $failure['response']->getData());
 			}
-			$picked = reset($thirdparty['failed']);
+			$picked = \reset($thirdparty['failed']);
 			$code = $picked['response']->getStatusCode();
 			$meta = $picked['response']->getMeta();
 			$headers = $picked['response']->getHeaders();
@@ -269,13 +273,13 @@ class OC_API {
 		$codes = [];
 		$header = [];
 
-		foreach($responses as $response) {
-			if($response['shipped']) {
-				$data = array_merge_recursive($response['response']->getData(), $data);
+		foreach ($responses as $response) {
+			if ($response['shipped']) {
+				$data = \array_merge_recursive($response['response']->getData(), $data);
 			} else {
-				$data = array_merge_recursive($data, $response['response']->getData());
+				$data = \array_merge_recursive($data, $response['response']->getData());
 			}
-			$header = array_merge_recursive($header, $response['response']->getHeaders());
+			$header = \array_merge_recursive($header, $response['response']->getHeaders());
 			$codes[] = ['code' => $response['response']->getStatusCode(),
 				'meta' => $response['response']->getMeta()];
 		}
@@ -283,8 +287,8 @@ class OC_API {
 		// Use any non 100 status codes
 		$statusCode = 100;
 		$statusMessage = null;
-		foreach($codes as $code) {
-			if($code['code'] != 100) {
+		foreach ($codes as $code) {
+			if ($code['code'] != 100) {
 				$statusCode = $code['code'];
 				$statusMessage = $code['meta']['message'];
 				break;
@@ -301,7 +305,7 @@ class OC_API {
 	 */
 	private static function isAuthorised($action) {
 		$level = $action['authlevel'];
-		switch($level) {
+		switch ($level) {
 			case API::GUEST_AUTH:
 				// Anyone can access
 				return true;
@@ -311,29 +315,31 @@ class OC_API {
 			case API::SUBADMIN_AUTH:
 				// Check for subadmin
 				$user = self::loginUser();
-				if(!$user) {
+				if (!$user) {
 					return false;
 				} else {
 					$userObject = \OC::$server->getUserSession()->getUser();
-					if($userObject === null) {
+					if ($userObject === null) {
 						return false;
 					}
 					$isSubAdmin = \OC::$server->getGroupManager()->getSubAdmin()->isSubAdmin($userObject);
 					$admin = OC_User::isAdminUser($user);
-					if($isSubAdmin || $admin) {
+					if ($isSubAdmin || $admin) {
 						return true;
 					} else {
 						return false;
 					}
 				}
+				// no break
 			case API::ADMIN_AUTH:
 				// Check for admin
 				$user = self::loginUser();
-				if(!$user) {
+				if (!$user) {
 					return false;
 				} else {
 					return OC_User::isAdminUser($user);
 				}
+				// no break
 			default:
 				// oops looks like invalid level supplied
 				return false;
@@ -345,7 +351,7 @@ class OC_API {
 	 * @return string|false (username, or false on failure)
 	 */
 	private static function loginUser() {
-		if(self::$isLoggedIn === true) {
+		if (self::$isLoggedIn === true) {
 			return \OC_User::getUser();
 		}
 
@@ -358,6 +364,12 @@ class OC_API {
 				// Do not allow access to OCS until the 2FA challenge was solved successfully
 				return false;
 			}
+			try {
+				\OC::$server->getAccountModuleManager()->check($userSession->getUser());
+			} catch (AccountCheckException $ex) {
+				// Deny login if any IAuthModule check fails
+				return false;
+			}
 			if ($userSession->verifyAuthHeaders($request)) {
 				$ocsApiRequest = isset($_SERVER['HTTP_OCS_APIREQUEST']) ? $_SERVER['HTTP_OCS_APIREQUEST'] === 'true' : false;
 				if ($ocsApiRequest) {
@@ -378,13 +390,19 @@ class OC_API {
 		try {
 			if (OC_User::handleApacheAuth()) {
 				self::$logoutRequired = false;
-			} else if ($userSession->tryTokenLogin($request)
+			} elseif ($userSession->tryTokenLogin($request)
 				|| $userSession->tryAuthModuleLogin($request)
 				|| $userSession->tryBasicAuthLogin($request)) {
 				self::$logoutRequired = true;
 			} else {
 				return false;
 			}
+			try {
+				\OC::$server->getAccountModuleManager()->check($userSession->getUser());
+			} catch (AccountCheckException $ex) {
+				// Deny login if any IAuthModule check fails
+				return false;
+			}
 			// initialize the user's filesystem
 			\OC_Util::setupFS(\OC_User::getUser());
 			self::$isLoggedIn = true;
@@ -404,25 +422,25 @@ class OC_API {
 		$request = \OC::$server->getRequest();
 
 		// Send 401 headers if unauthorised
-		if($result->getStatusCode() === API::RESPOND_UNAUTHORISED) {
+		if ($result->getStatusCode() === API::RESPOND_UNAUTHORISED) {
 			// If request comes from JS return dummy auth request
-			if($request->getHeader('X-Requested-With') === 'XMLHttpRequest') {
-				header('WWW-Authenticate: DummyBasic realm="Authorisation Required"');
+			if ($request->getHeader('X-Requested-With') === 'XMLHttpRequest') {
+				\header('WWW-Authenticate: DummyBasic realm="Authorisation Required"');
 			} else {
-				header('WWW-Authenticate: Basic realm="Authorisation Required"');
+				\header('WWW-Authenticate: Basic realm="Authorisation Required"');
 			}
-			header('HTTP/1.0 401 Unauthorized');
+			\header('HTTP/1.0 401 Unauthorized');
 		}
 
-		foreach($result->getHeaders() as $name => $value) {
-			header($name . ': ' . $value);
+		foreach ($result->getHeaders() as $name => $value) {
+			\header($name . ': ' . $value);
 		}
 
 		$meta = $result->getMeta();
 		$data = $result->getData();
 		if (self::isV2($request)) {
 			$statusCode = self::mapStatusCodes($result->getStatusCode());
-			if (!is_null($statusCode)) {
+			if ($statusCode !== null) {
 				$meta['statuscode'] = $statusCode;
 				OC_Response::setStatus($statusCode);
 			}
@@ -437,20 +455,20 @@ class OC_API {
 	 * @param XMLWriter $writer
 	 */
 	private static function toXML($array, $writer) {
-		foreach($array as $k => $v) {
+		foreach ($array as $k => $v) {
 			if ($k[0] === '@') {
-				if (is_array($v)) {
+				if (\is_array($v)) {
 					foreach ($v as $name => $value) {
 						$writer->writeAttribute($name, $value);
 					}
 				} else {
-					$writer->writeAttribute(substr($k, 1), $v);
+					$writer->writeAttribute(\substr($k, 1), $v);
 				}
 				continue;
-			} else if (is_numeric($k)) {
+			} elseif (\is_numeric($k)) {
 				$k = 'element';
 			}
-			if(is_array($v)) {
+			if (\is_array($v)) {
 				$writer->startElement($k);
 				self::toXML($v, $writer);
 				$writer->endElement();
@@ -466,7 +484,7 @@ class OC_API {
 	public static function requestedFormat() {
 		$formats = ['json', 'xml'];
 
-		$format = !empty($_GET['format']) && in_array($_GET['format'], $formats) ? $_GET['format'] : 'xml';
+		$format = !empty($_GET['format']) && \in_array($_GET['format'], $formats) ? $_GET['format'] : 'xml';
 		return $format;
 	}
 
@@ -475,18 +493,18 @@ class OC_API {
 	 * @param string $format
 	 */
 	public static function setContentType($format = null) {
-		$format = is_null($format) ? self::requestedFormat() : $format;
+		$format = $format === null ? self::requestedFormat() : $format;
 		if ($format === 'xml') {
-			header('Content-type: text/xml; charset=UTF-8');
+			\header('Content-type: text/xml; charset=UTF-8');
 			return;
 		}
 
 		if ($format === 'json') {
-			header('Content-Type: application/json; charset=utf-8');
+			\header('Content-Type: application/json; charset=utf-8');
 			return;
 		}
 
-		header('Content-Type: application/octet-stream; charset=utf-8');
+		\header('Content-Type: application/octet-stream; charset=utf-8');
 	}
 
 	/**
@@ -496,7 +514,7 @@ class OC_API {
 	protected static function isV2(\OCP\IRequest $request) {
 		$script = $request->getScriptName();
 
-		return substr($script, -11) === '/ocs/v2.php';
+		return \substr($script, -11) === '/ocs/v2.php';
 	}
 
 	/**
@@ -516,6 +534,8 @@ class OC_API {
 				return null;
 			case 100:
 				return Http::STATUS_OK;
+			case 104:
+				return Http::STATUS_FORBIDDEN;
 		}
 		// any 2xx, 4xx and 5xx will be used as is
 		if ($sc >= 200 && $sc < 600) {
