@@ -27,7 +27,7 @@
  * @author Thomas Tanghus <thomas@tanghus.net>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -65,7 +65,7 @@ class OC_Helper {
 		} else {
 			$url = OC::$server->getURLGenerator()->getAbsoluteURL(OC::$server->getURLGenerator()->linkTo('', 'public.php').'?service='.$service);
 		}
-		return $url . (($add_slash && $service[strlen($service) - 1] != '/') ? '/' : '');
+		return $url . (($add_slash && $service[\strlen($service) - 1] != '/') ? '/' : '');
 	}
 
 	/**
@@ -82,24 +82,24 @@ class OC_Helper {
 		if ($bytes < 1024) {
 			return "$bytes B";
 		}
-		$bytes = round($bytes / 1024, 0);
+		$bytes = \round($bytes / 1024, 0);
 		if ($bytes < 1024) {
 			return "$bytes KB";
 		}
-		$bytes = round($bytes / 1024, 1);
+		$bytes = \round($bytes / 1024, 1);
 		if ($bytes < 1024) {
 			return "$bytes MB";
 		}
-		$bytes = round($bytes / 1024, 1);
+		$bytes = \round($bytes / 1024, 1);
 		if ($bytes < 1024) {
 			return "$bytes GB";
 		}
-		$bytes = round($bytes / 1024, 1);
+		$bytes = \round($bytes / 1024, 1);
 		if ($bytes < 1024) {
 			return "$bytes TB";
 		}
 
-		$bytes = round($bytes / 1024, 1);
+		$bytes = \round($bytes / 1024, 1);
 		return "$bytes PB";
 	}
 
@@ -117,15 +117,15 @@ class OC_Helper {
 		if ($bytes < 1024) {
 			return $bytes . "B";
 		}
-		$bytes = round($bytes / 1024, 1);
+		$bytes = \round($bytes / 1024, 1);
 		if ($bytes < 1024) {
 			return $bytes . "K";
 		}
-		$bytes = round($bytes / 1024, 1);
+		$bytes = \round($bytes / 1024, 1);
 		if ($bytes < 1024) {
 			return $bytes . "M";
 		}
-		$bytes = round($bytes / 1024, 1);
+		$bytes = \round($bytes / 1024, 1);
 		return $bytes . "G";
 	}
 
@@ -139,9 +139,9 @@ class OC_Helper {
 	 * Inspired by: http://www.php.net/manual/en/function.filesize.php#92418
 	 */
 	public static function computerFileSize($str) {
-		$str = strtolower($str);
-		if (is_numeric($str)) {
-			return floatval($str);
+		$str = \strtolower($str);
+		if (\is_numeric($str)) {
+			return \floatval($str);
 		}
 
 		$bytes_array = [
@@ -158,15 +158,15 @@ class OC_Helper {
 			'p' => 1024 * 1024 * 1024 * 1024 * 1024,
 		];
 
-		$bytes = floatval($str);
+		$bytes = \floatval($str);
 
-		if (preg_match('#([kmgtp]?b?)$#si', $str, $matches) && !empty($bytes_array[$matches[1]])) {
+		if (\preg_match('#([kmgtp]?b?)$#si', $str, $matches) && !empty($bytes_array[$matches[1]])) {
 			$bytes *= $bytes_array[$matches[1]];
 		} else {
 			return false;
 		}
 
-		$bytes = round($bytes);
+		$bytes = \round($bytes);
 
 		return $bytes;
 	}
@@ -177,19 +177,19 @@ class OC_Helper {
 	 * @param string $dest target folder
 	 *
 	 */
-	static function copyr($src, $dest) {
-		if (is_dir($src)) {
-			if (!is_dir($dest)) {
-				mkdir($dest);
+	public static function copyr($src, $dest) {
+		if (\is_dir($src)) {
+			if (!\is_dir($dest)) {
+				\mkdir($dest);
 			}
-			$files = scandir($src);
+			$files = \scandir($src);
 			foreach ($files as $file) {
 				if ($file != "." && $file != "..") {
 					self::copyr("$src/$file", "$dest/$file");
 				}
 			}
-		} elseif (file_exists($src) && !\OC\Files\Filesystem::isForbiddenFileOrDir($src)) {
-			copy($src, $dest);
+		} elseif (\file_exists($src) && !\OC\Files\Filesystem::isForbiddenFileOrDir($src)) {
+			\copy($src, $dest);
 		}
 	}
 
@@ -199,8 +199,8 @@ class OC_Helper {
 	 * @param bool $deleteSelf if set to false only the content of the folder will be deleted
 	 * @return bool
 	 */
-	static function rmdirr($dir, $deleteSelf = true) {
-		if (is_dir($dir)) {
+	public static function rmdirr($dir, $deleteSelf = true) {
+		if (\is_dir($dir)) {
 			$files = new RecursiveIteratorIterator(
 				new RecursiveDirectoryIterator($dir, RecursiveDirectoryIterator::SKIP_DOTS),
 				RecursiveIteratorIterator::CHILD_FIRST
@@ -209,32 +209,32 @@ class OC_Helper {
 			foreach ($files as $fileInfo) {
 				/** @var SplFileInfo $fileInfo */
 				if ($fileInfo->isLink()) {
-					unlink($fileInfo->getPathname());
-				} else if ($fileInfo->isDir()) {
-					rmdir($fileInfo->getRealPath());
+					\unlink($fileInfo->getPathname());
+				} elseif ($fileInfo->isDir()) {
+					\rmdir($fileInfo->getRealPath());
 				} else {
-					unlink($fileInfo->getRealPath());
+					\unlink($fileInfo->getRealPath());
 				}
 			}
 			if ($deleteSelf) {
-				rmdir($dir);
+				\rmdir($dir);
 			}
-		} elseif (file_exists($dir)) {
+		} elseif (\file_exists($dir)) {
 			if ($deleteSelf) {
-				unlink($dir);
+				\unlink($dir);
 			}
 		}
 		if (!$deleteSelf) {
 			return true;
 		}
 
-		return !file_exists($dir);
+		return !\file_exists($dir);
 	}
 
 	/**
 	 * @return \OC\Files\Type\TemplateManager
 	 */
-	static public function getFileTemplateManager() {
+	public static function getFileTemplateManager() {
 		if (!self::$templateManager) {
 			self::$templateManager = new \OC\Files\Type\TemplateManager();
 		}
@@ -253,18 +253,18 @@ class OC_Helper {
 	public static function canExecute($name, $path = false) {
 		// path defaults to PATH from environment if not set
 		if ($path === false) {
-			$path = getenv("PATH");
+			$path = \getenv("PATH");
 		}
 		// we look for an executable file of that name
 		$exts = [""];
 		$check_fn = "is_executable";
 		// Default check will be done with $path directories :
-		$dirs = explode(PATH_SEPARATOR, $path);
+		$dirs = \explode(PATH_SEPARATOR, $path);
 		// WARNING : We have to check if open_basedir is enabled :
 		$obd = OC::$server->getIniWrapper()->getString('open_basedir');
 		if ($obd != "none") {
-			$obd_values = explode(PATH_SEPARATOR, $obd);
-			if (count($obd_values) > 0 and $obd_values[0]) {
+			$obd_values = \explode(PATH_SEPARATOR, $obd);
+			if (\count($obd_values) > 0 and $obd_values[0]) {
 				// open_basedir is in effect !
 				// We need to check if the program is in one of these dirs :
 				$dirs = $obd_values;
@@ -272,8 +272,9 @@ class OC_Helper {
 		}
 		foreach ($dirs as $dir) {
 			foreach ($exts as $ext) {
-				if ($check_fn("$dir/$name" . $ext))
+				if ($check_fn("$dir/$name" . $ext)) {
 					return true;
+				}
 			}
 		}
 		return false;
@@ -293,16 +294,16 @@ class OC_Helper {
 		$bufSize = 8192;
 		$result = true;
 		$count = 0;
-		while (!feof($source)) {
-			$buf = fread($source, $bufSize);
-			$bytesWritten = fwrite($target, $buf);
+		while (!\feof($source)) {
+			$buf = \fread($source, $bufSize);
+			$bytesWritten = \fwrite($target, $buf);
 			if ($bytesWritten !== false) {
 				$count += $bytesWritten;
 			}
 			// note: strlen is expensive so only use it when necessary,
 			// on the last block
 			if ($bytesWritten === false
-				|| ($bytesWritten < $bufSize && $bytesWritten < strlen($buf))
+				|| ($bytesWritten < $bufSize && $bytesWritten < \strlen($buf))
 			) {
 				// write error, could be disk full ?
 				$result = false;
@@ -335,9 +336,9 @@ class OC_Helper {
 		if ($path === '/') {
 			$path = '';
 		}
-		if ($pos = strrpos($filename, '.')) {
-			$name = substr($filename, 0, $pos);
-			$ext = substr($filename, $pos);
+		if ($pos = \strrpos($filename, '.')) {
+			$name = \substr($filename, 0, $pos);
+			$ext = \substr($filename, $pos);
 		} else {
 			$name = $filename;
 			$ext = '';
@@ -345,12 +346,12 @@ class OC_Helper {
 
 		$newpath = $path . '/' . $filename;
 		if ($view->file_exists($newpath)) {
-			if (preg_match_all('/\((\d+)\)/', $name, $matches, PREG_OFFSET_CAPTURE)) {
+			if (\preg_match_all('/\((\d+)\)/', $name, $matches, PREG_OFFSET_CAPTURE)) {
 				//Replace the last "(number)" with "(number+1)"
-				$last_match = count($matches[0]) - 1;
+				$last_match = \count($matches[0]) - 1;
 				$counter = $matches[1][$last_match][0] + 1;
 				$offset = $matches[0][$last_match][1];
-				$match_length = strlen($matches[0][$last_match][0]);
+				$match_length = \strlen($matches[0][$last_match][0]);
 			} else {
 				$counter = 2;
 				$match_length = 0;
@@ -359,7 +360,7 @@ class OC_Helper {
 			do {
 				if ($offset) {
 					//Replace the last "(number)" with "(number+1)"
-					$newname = substr_replace($name, '(' . $counter . ')', $offset, $match_length);
+					$newname = \substr_replace($name, '(' . $counter . ')', $offset, $match_length);
 				} else {
 					$newname = $name . ' (' . $counter . ')';
 				}
@@ -379,18 +380,18 @@ class OC_Helper {
 	 * @return bool
 	 */
 	public static function isSubDirectory($sub, $parent) {
-		$realpathSub = realpath($sub);
-		$realpathParent = realpath($parent);
+		$realpathSub = \realpath($sub);
+		$realpathParent = \realpath($parent);
 
 		// realpath() may return false in case the directory does not exist
 		// since we can not be sure how different PHP versions may behave here
 		// we do an additional check whether realpath returned false
-		if($realpathSub === false ||  $realpathParent === false) {
+		if ($realpathSub === false ||  $realpathParent === false) {
 			return false;
 		}
 
 		// Check whether $sub is a subdirectory of $parent
-		if (strpos($realpathSub, $realpathParent) === 0) {
+		if (\strpos($realpathSub, $realpathParent) === 0) {
 			return true;
 		}
 
@@ -413,7 +414,7 @@ class OC_Helper {
 		$case = ($case != MB_CASE_UPPER) ? MB_CASE_LOWER : MB_CASE_UPPER;
 		$ret = [];
 		foreach ($input as $k => $v) {
-			$ret[mb_convert_case($k, $case, $encoding)] = $v;
+			$ret[\mb_convert_case($k, $case, $encoding)] = $v;
 		}
 		return $ret;
 	}
@@ -434,7 +435,7 @@ class OC_Helper {
 		$it = new RecursiveIteratorIterator($aIt);
 
 		while ($it->valid()) {
-			if (((isset($index) AND ($it->key() == $index)) OR (!isset($index))) AND ($it->current() == $needle)) {
+			if (((isset($index) and ($it->key() == $index)) or (!isset($index))) and ($it->current() == $needle)) {
 				return $aIt->key();
 			}
 
@@ -452,10 +453,10 @@ class OC_Helper {
 	 * @return int number of bytes representing
 	 */
 	public static function maxUploadFilesize($dir, $freeSpace = null) {
-		if (is_null($freeSpace) || $freeSpace < 0){
+		if ($freeSpace === null || $freeSpace < 0) {
 			$freeSpace = self::freeSpace($dir);
 		}
-		return min($freeSpace, self::uploadLimit());
+		return \min($freeSpace, self::uploadLimit());
 	}
 
 	/**
@@ -467,7 +468,7 @@ class OC_Helper {
 	public static function freeSpace($dir) {
 		$freeSpace = \OC\Files\Filesystem::free_space($dir);
 		if ($freeSpace < \OCP\Files\FileInfo::SPACE_UNLIMITED) {
-			$freeSpace = max($freeSpace, 0);
+			$freeSpace = \max($freeSpace, 0);
 			return $freeSpace;
 		} else {
 			return (INF > 0)? INF: PHP_INT_MAX; // work around https://bugs.php.net/bug.php?id=69188
@@ -486,9 +487,9 @@ class OC_Helper {
 		if ((int)$upload_max_filesize === 0 and (int)$post_max_size === 0) {
 			return INF;
 		} elseif ((int)$upload_max_filesize === 0 or (int)$post_max_size === 0) {
-			return max($upload_max_filesize, $post_max_size); //only the non 0 value counts
+			return \max($upload_max_filesize, $post_max_size); //only the non 0 value counts
 		} else {
-			return min($upload_max_filesize, $post_max_size);
+			return \min($upload_max_filesize, $post_max_size);
 		}
 	}
 
@@ -499,18 +500,18 @@ class OC_Helper {
 	 * @return bool
 	 */
 	public static function is_function_enabled($function_name) {
-		if (!function_exists($function_name)) {
+		if (!\function_exists($function_name)) {
 			return false;
 		}
 		$ini = \OC::$server->getIniWrapper();
-		$disabled = explode(',', $ini->get('disable_functions'));
-		$disabled = array_map('trim', $disabled);
-		if (in_array($function_name, $disabled)) {
+		$disabled = \explode(',', $ini->get('disable_functions'));
+		$disabled = \array_map('trim', $disabled);
+		if (\in_array($function_name, $disabled)) {
 			return false;
 		}
-		$disabled = explode(',', $ini->get('suhosin.executor.func.blacklist'));
-		$disabled = array_map('trim', $disabled);
-		if (in_array($function_name, $disabled)) {
+		$disabled = \explode(',', $ini->get('suhosin.executor.func.blacklist'));
+		$disabled = \array_map('trim', $disabled);
+		if (\in_array($function_name, $disabled)) {
 			return false;
 		}
 		return true;
@@ -533,16 +534,10 @@ class OC_Helper {
 			// Returns null if nothing is found
 			$result = $exeSniffer->find($program);
 			if (empty($result)) {
-				$paths = getenv('PATH');
-				if (empty($paths)) {
-					$paths = '/usr/local/bin /usr/bin /opt/bin /bin';
-				} else {
-					$paths = str_replace(':',' ',getenv('PATH'));
-				}
-				$command = 'find ' . $paths . ' -name ' . escapeshellarg($program) . ' 2> /dev/null';
-				exec($command, $output, $returnCode);
-				if (count($output) > 0) {
-					$result = escapeshellcmd($output[0]);
+				$command = 'find ' . self::getCleanedPath(\getenv('PATH')) . ' -name ' . \escapeshellarg($program) . ' 2> /dev/null';
+				\exec($command, $output, $returnCode);
+				if (\count($output) > 0) {
+					$result = \escapeshellcmd($output[0]);
 				}
 			}
 		}
@@ -551,6 +546,26 @@ class OC_Helper {
 		return $result;
 	}
 
+	/**
+	 * Return a validated (sanitised) version of the system path
+	 *
+	 * The system path needs to be validated/sanitised before being used, as identified in http://bit.ly/2CEUagp (HackerOne).
+	 * This method filters out of the retrieved system path, only valid path directories, if the path is defined. Otherwise
+	 * it returns a defined set of paths.
+	 *
+	 * @param string $path
+	 * @return string|null
+	 */
+	public static function getCleanedPath($path = '') {
+		$pattern = "((\/[\w\d]*)+)";
+
+		if (\preg_match_all($pattern, $path, $matches) > 0) {
+			return \implode(' ', $matches[0]);
+		}
+
+		return '/usr/local/bin /usr/bin /opt/bin /bin';
+	}
+
 	/**
 	 * Calculate the disc space for the given path
 	 *
@@ -604,7 +619,7 @@ class OC_Helper {
 				$total = $quota;
 			}
 			// prevent division by zero or error codes (negative values)
-			$relative = round(($used / $total) * 10000) / 100;
+			$relative = \round(($used / $total) * 10000) / 100;
 		} else {
 			$relative = 0;
 		}
@@ -612,7 +627,7 @@ class OC_Helper {
 		$ownerId = $storage->getOwner($path);
 		$ownerDisplayName = '';
 		$owner = \OC::$server->getUserManager()->get($ownerId);
-		if($owner) {
+		if ($owner) {
 			$ownerDisplayName = $owner->getDisplayName();
 		}
 
@@ -649,12 +664,11 @@ class OC_Helper {
 				$total = $quota;
 			}
 			// prevent division by zero or error codes (negative values)
-			$relative = round(($used / $total) * 10000) / 100;
+			$relative = \round(($used / $total) * 10000) / 100;
 		} else {
 			$relative = 0;
 		}
 
 		return ['free' => $free, 'used' => $used, 'total' => $total, 'relative' => $relative];
-
 	}
 }
