@@ -19,7 +19,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -37,6 +37,7 @@
  */
 
 use OC\TemplateLayout;
+use OCP\IL10N;
 use OCP\Theme\ITheme;
 
 require_once __DIR__.'/template/functions.php';
@@ -76,13 +77,16 @@ class OC_Template extends \OC\Template\Base {
 	 *                         now, $renderAs can be set to "guest", "user" or
 	 *                         "admin".
 	 * @param bool $registerCall = true
+	 * @param string|null $languageCode optional language used to render the template
 	 */
-	public function __construct( $app, $name, $renderAs = "", $registerCall = true ) {
+	public function __construct($app, $name, $renderAs = "", $registerCall = true, $languageCode = null) {
 		self::initTemplateEngine($renderAs);
 		$requestToken = (OC::$server->getSession() && $registerCall) ? \OCP\Util::callRegister() : '';
 
-		$parts = explode('/', $app); // fix translation when app is something like core/lostpassword
-		$l10n = \OC::$server->getL10N($parts[0]);
+		// fix translation when app is something like core/lostpassword
+		$parts = \explode('/', $app);
+
+		$l10n = \OC::$server->getL10N($parts[0], $languageCode);
 
 		$theme = OC_Util::getTheme();
 		$template = $this->findTemplate($theme, $app, $name);
@@ -98,30 +102,30 @@ class OC_Template extends \OC\Template\Base {
 	 * @throws Exception
 	 */
 	public static function initTemplateEngine($renderAs) {
-		if (self::$initTemplateEngineFirstRun){
+		if (self::$initTemplateEngineFirstRun) {
 
 			//apps that started before the template initialization can load their own scripts/styles
 			//so to make sure this scripts/styles here are loaded first we use OC_Util::addScript() with $prepend=true
 			//meaning the last script/style in this list will be loaded first
-			if (\OC::$server->getSystemConfig()->getValue ('installed', false) && $renderAs !== 'error' && !\OCP\Util::needUpgrade()) {
-				if (\OC::$server->getConfig ()->getAppValue ( 'core', 'backgroundjobs_mode', 'ajax' ) == 'ajax') {
-					OC_Util::addScript ( 'backgroundjobs', null, true );
+			if (\OC::$server->getSystemConfig()->getValue('installed', false) && $renderAs !== 'error' && !\OCP\Util::needUpgrade()) {
+				if (\OC::$server->getConfig()->getAppValue('core', 'backgroundjobs_mode', 'ajax') == 'ajax') {
+					OC_Util::addScript('backgroundjobs', null, true);
 				}
 			}
 
-			OC_Util::addStyle("tooltip",null,true);
-			OC_Util::addStyle('jquery-ui-fixes',null,true);
-			OC_Util::addVendorStyle('jquery-ui/themes/base/jquery-ui',null,true);
-			OC_Util::addStyle("mobile",null,true);
-			OC_Util::addStyle("multiselect",null,true);
-			OC_Util::addStyle("fixes",null,true);
-			OC_Util::addStyle("global",null,true);
-			OC_Util::addStyle("apps",null,true);
-			OC_Util::addStyle("fonts",null,true);
-			OC_Util::addStyle("icons",null,true);
-			OC_Util::addStyle("header",null,true);
-			OC_Util::addStyle("inputs",null,true);
-			OC_Util::addStyle("styles",null,true);
+			OC_Util::addStyle("tooltip", null, true);
+			OC_Util::addStyle('jquery-ui-fixes', null, true);
+			OC_Util::addVendorStyle('jquery-ui/themes/base/jquery-ui', null, true);
+			OC_Util::addStyle("mobile", null, true);
+			OC_Util::addStyle("multiselect", null, true);
+			OC_Util::addStyle("fixes", null, true);
+			OC_Util::addStyle("global", null, true);
+			OC_Util::addStyle("apps", null, true);
+			OC_Util::addStyle("fonts", null, true);
+			OC_Util::addStyle("icons", null, true);
+			OC_Util::addStyle("header", null, true);
+			OC_Util::addStyle("inputs", null, true);
+			OC_Util::addStyle("styles", null, true);
 
 			// avatars
 			if (\OC::$server->getSystemConfig()->getValue('enable_avatars', true) === true) {
@@ -129,8 +133,11 @@ class OC_Template extends \OC\Template\Base {
 				\OC_Util::addScript('placeholder', null, true);
 			}
 
+			OC_Util::addScript('oc-backbone-webdav', null, true);
 			OC_Util::addScript('oc-backbone', null, true);
 			OC_Util::addVendorScript('core', 'backbone/backbone', true);
+			OC_Util::addVendorScript('core', 'select2/select2', true);
+			OC_Util::addVendorStyle('select2/select2', null, true);
 			OC_Util::addVendorScript('snapjs/dist/latest/snap', null, true);
 			OC_Util::addScript('mimetypelist', null, true);
 			OC_Util::addScript('mimetype', null, true);
@@ -152,13 +159,13 @@ class OC_Template extends \OC\Template\Base {
 			// Add the stuff we need always
 			// following logic will import all vendor libraries that are
 			// specified in core/js/core.json
-			$fileContent = file_get_contents(OC::$SERVERROOT . '/core/js/core.json');
-			if($fileContent !== false) {
-				$coreDependencies = json_decode($fileContent, true);
-				foreach(array_reverse($coreDependencies['vendor']) as $vendorLibrary) {
+			$fileContent = \file_get_contents(OC::$SERVERROOT . '/core/js/core.json');
+			if ($fileContent !== false) {
+				$coreDependencies = \json_decode($fileContent, true);
+				foreach (\array_reverse($coreDependencies['vendor']) as $vendorLibrary) {
 					// remove trailing ".js" as addVendorScript will append it
 					OC_Util::addVendorScript(
-							substr($vendorLibrary, 0, strlen($vendorLibrary) - 3),null,true);
+							\substr($vendorLibrary, 0, \strlen($vendorLibrary) - 3), null, true);
 				}
 			} else {
 				throw new \Exception('Cannot read core/js/core.json');
@@ -173,10 +180,8 @@ class OC_Template extends \OC\Template\Base {
 
 			self::$initTemplateEngineFirstRun = false;
 		}
-
 	}
 
-
 	/**
 	 * find the template with the given name
 	 * @param string $name of the template file (without suffix)
@@ -189,15 +194,15 @@ class OC_Template extends \OC\Template\Base {
 	 */
 	protected function findTemplate($theme, $app, $name) {
 		// Check if it is a app template or not.
-		if($app === '' || $app === 'core') {
+		if ($app === '' || $app === 'core') {
 			$dirs = $this->getCoreTemplateDirs($theme, OC::$SERVERROOT);
 		} elseif ($app === 'settings') {
 			$dirs = $this->getSettingsTemplateDirs($theme, OC::$SERVERROOT);
 		} else {
-			$dirs = $this->getAppTemplateDirs($theme, $app, OC::$SERVERROOT, OC_App::getAppPath($app));
+			$dirs = $this->getAppTemplateDirs($theme, $app, OC_App::getAppPath($app));
 		}
 
-		$locator = new \OC\Template\TemplateFileLocator( $dirs );
+		$locator = new \OC\Template\TemplateFileLocator($dirs);
 		$template = $locator->find($name);
 
 		return $template;
@@ -230,14 +235,14 @@ class OC_Template extends \OC\Template\Base {
 	public function fetchPage($additionalParams = null) {
 		$data = parent::fetchPage($additionalParams);
 
-		if( $this->renderAs ) {
+		if ($this->renderAs) {
 			$page = new TemplateLayout($this->renderAs, $this->app);
 
 			// Add custom headers
 			$headers = '';
-			foreach(OC_Util::$headers as $header) {
+			foreach (OC_Util::$headers as $header) {
 				$headers .= '<'.\OCP\Util::sanitizeHTML($header['tag']);
-				foreach($header['attributes'] as $name=>$value) {
+				foreach ($header['attributes'] as $name=>$value) {
 					$headers .= ' '.\OCP\Util::sanitizeHTML($name).'="'.\OCP\Util::sanitizeHTML($value).'"';
 				}
 				if ($header['text'] !== null) {
@@ -263,11 +268,14 @@ class OC_Template extends \OC\Template\Base {
 	 * @param array|null $additionalParams
 	 * @return string returns content of included template
 	 *
-	 * Includes another template. use <?php echo $this->inc('template'); ?> to
-	 * do this.
+	 * Includes another template.
+	 * use <?php print_unescaped($this->inc('template')); ?> to do this.
+	 * use <?php print_unescaped($this->inc('template', ['app'=>'appName'])); ?>
+	 * to include template from a different app.
 	 */
 	public function inc($file, $additionalParams = null) {
-		$template = $this->findTemplate($this->theme, $this->app, $file);
+		$app = (isset($additionalParams['app'])) ? $additionalParams['app'] : $this->app;
+		$template = $this->findTemplate($this->theme, $app, $file);
 		return $this->load($template, $additionalParams);
 	}
 
@@ -278,10 +286,10 @@ class OC_Template extends \OC\Template\Base {
 	 * @param array $parameters Parameters for the template
 	 * @return boolean|null
 	 */
-	public static function printUserPage( $application, $name, $parameters = []) {
-		$content = new OC_Template( $application, $name, "user" );
-		foreach( $parameters as $key => $value ) {
-			$content->assign( $key, $value );
+	public static function printUserPage($application, $name, $parameters = []) {
+		$content = new OC_Template($application, $name, "user");
+		foreach ($parameters as $key => $value) {
+			$content->assign($key, $value);
 		}
 		print $content->printPage();
 	}
@@ -293,10 +301,10 @@ class OC_Template extends \OC\Template\Base {
 	 * @param array $parameters Parameters for the template
 	 * @return bool
 	 */
-	public static function printAdminPage( $application, $name, $parameters = []) {
-		$content = new OC_Template( $application, $name, "admin" );
-		foreach( $parameters as $key => $value ) {
-			$content->assign( $key, $value );
+	public static function printAdminPage($application, $name, $parameters = []) {
+		$content = new OC_Template($application, $name, "admin");
+		foreach ($parameters as $key => $value) {
+			$content->assign($key, $value);
 		}
 		return $content->printPage();
 	}
@@ -308,10 +316,10 @@ class OC_Template extends \OC\Template\Base {
 	 * @param array|string $parameters Parameters for the template
 	 * @return bool
 	 */
-	public static function printGuestPage( $application, $name, $parameters = []) {
-		$content = new OC_Template( $application, $name, "guest" );
-		foreach( $parameters as $key => $value ) {
-			$content->assign( $key, $value );
+	public static function printGuestPage($application, $name, $parameters = []) {
+		$content = new OC_Template($application, $name, "guest");
+		foreach ($parameters as $key => $value) {
+			$content->assign($key, $value);
 		}
 		return $content->printPage();
 	}
@@ -322,18 +330,18 @@ class OC_Template extends \OC\Template\Base {
 		* @param string $hint An optional hint message - needs to be properly escaped
 		* @param int HTTP Status Code
 		*/
-	public static function printErrorPage( $error_msg, $hint = '', $httpStatusCode = null ) {
+	public static function printErrorPage($error_msg, $hint = '', $httpStatusCode = null) {
 		if ($error_msg === $hint) {
 			// If the hint is the same as the message there is no need to display it twice.
 			$hint = '';
 		}
 
 		try {
-			$content = new \OC_Template( '', 'error', 'error', false );
+			$content = new \OC_Template('', 'error', 'error', false);
 			$errors = [['error' => $error_msg, 'hint' => $hint]];
-			$content->assign( 'errors', $errors );
+			$content->assign('errors', $errors);
 			if ($httpStatusCode !== null) {
-				http_response_code((int)$httpStatusCode);
+				\http_response_code((int)$httpStatusCode);
 			}
 			$content->printPage();
 		} catch (\Exception $e) {
@@ -341,8 +349,8 @@ class OC_Template extends \OC\Template\Base {
 			$logger->error("$error_msg $hint", ['app' => 'core']);
 			$logger->logException($e, ['app' => 'core']);
 
-			header(self::getHttpProtocol() . ' 500 Internal Server Error');
-			header('Content-Type: text/plain; charset=utf-8');
+			\header(self::getHttpProtocol() . ' 500 Internal Server Error');
+			\header('Content-Type: text/plain; charset=utf-8');
 			print("$error_msg $hint");
 		}
 		die();
@@ -358,7 +366,7 @@ class OC_Template extends \OC\Template\Base {
 		try {
 			$request = \OC::$server->getRequest();
 			$content = new \OC_Template('', 'exception', 'error', false);
-			$content->assign('errorClass', get_class($exception));
+			$content->assign('errorClass', \get_class($exception));
 			$content->assign('errorMsg', $exception->getMessage());
 			$content->assign('errorCode', $exception->getCode());
 			$content->assign('file', $exception->getFile());
@@ -376,8 +384,8 @@ class OC_Template extends \OC\Template\Base {
 			$logger->logException($exception, ['app' => 'core']);
 			$logger->logException($e, ['app' => 'core']);
 
-			header(self::getHttpProtocol() . ' 500 Internal Server Error');
-			header('Content-Type: text/plain; charset=utf-8');
+			\header(self::getHttpProtocol() . ' 500 Internal Server Error');
+			\header('Content-Type: text/plain; charset=utf-8');
 			print("Internal Server Error\n\n");
 			print("The server encountered an internal error and was unable to complete your request.\n");
 			print("Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report.\n");
@@ -396,13 +404,13 @@ class OC_Template extends \OC\Template\Base {
 	 * @internal Don't use this - use AppFramework\Http\Request->getHttpProtocol instead
 	 */
 	protected static function getHttpProtocol() {
-		$claimedProtocol = strtoupper($_SERVER['SERVER_PROTOCOL']);
+		$claimedProtocol = \strtoupper($_SERVER['SERVER_PROTOCOL']);
 		$validProtocols = [
 			'HTTP/1.0',
 			'HTTP/1.1',
 			'HTTP/2',
 		];
-		if(in_array($claimedProtocol, $validProtocols, true)) {
+		if (\in_array($claimedProtocol, $validProtocols, true)) {
 			return $claimedProtocol;
 		}
 		return 'HTTP/1.1';
