@@ -39,7 +39,7 @@
  * @author Vincent Petry <pvince81@owncloud.com>
  * @author Volkan Gezer <volkangezer@gmail.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -56,6 +56,8 @@
  *
  */
 
+use OCP\Authentication\Exceptions\AccountCheckException;
+use OCP\Files\NoReadAccessException;
 use OCP\IConfig;
 use OCP\IGroupManager;
 use OCP\IUser;
@@ -103,9 +105,9 @@ class OC_Util {
 
 		// instantiate object store implementation
 		$name = $config['class'];
-		if (strpos($name, 'OCA\\') === 0 && substr_count($name, '\\') >= 2) {
-			$segments = explode('\\', $name);
-			OC_App::loadApp(strtolower($segments[1]));
+		if (\strpos($name, 'OCA\\') === 0 && \substr_count($name, '\\') >= 2) {
+			$segments = \explode('\\', $name);
+			OC_App::loadApp(\strtolower($segments[1]));
 		}
 		$config['arguments']['objectstore'] = new $config['class']($config['arguments']);
 		// mount with plain / root object store implementation
@@ -137,7 +139,7 @@ class OC_Util {
 		// If we are not forced to load a specific user we load the one that is logged in
 		if ($user === null) {
 			$user = '';
-		} else if ($user == "" && OC_User::isLoggedIn()) {
+		} elseif ($user == "" && OC_User::isLoggedIn()) {
 			$user = OC_User::getUser();
 		}
 
@@ -187,10 +189,8 @@ class OC_Util {
 			}
 
 			return $storage;
-
 		}, 1);
 
-
 		\OC\Files\Filesystem::addStorageWrapper('oc_encoding', function ($mountPoint, \OCP\Files\Storage $storage, \OCP\Files\Mount\IMountPoint $mount) {
 			if ($mount->getOption('encoding_compatibility', false) && !$storage->instanceOfStorage('\OCA\Files_Sharing\SharedStorage') && !$storage->isLocal()) {
 				return new \OC\Files\Storage\Wrapper\Encoding(['storage' => $storage]);
@@ -209,7 +209,7 @@ class OC_Util {
 				|| $storage->instanceOfStorage('\OC\Files\ObjectStore\HomeObjectStoreStorage')
 			) {
 				/** @var \OC\Files\Storage\Home $storage */
-				if (is_object($storage->getUser())) {
+				if (\is_object($storage->getUser())) {
 					$user = $storage->getUser()->getUID();
 					$quota = OC_Util::getUserQuota($user);
 					if ($quota !== \OCP\Files\FileInfo::SPACE_UNLIMITED) {
@@ -234,28 +234,26 @@ class OC_Util {
 		);
 
 		if (!$isGuest) {
-			$readOnlyGroups = json_decode(\OC::$server->getConfig()->getAppValue(
+			$readOnlyGroups = \json_decode(\OC::$server->getConfig()->getAppValue(
 				'core',
 				'read_only_groups',
 				'[]'
 			), true);
 
-			if (!is_array($readOnlyGroups)) {
+			if (!\is_array($readOnlyGroups)) {
 				$readOnlyGroups = [];
 			}
 
-
-			$userGroups = array_keys(
+			$userGroups = \array_keys(
 				\OC::$server->getGroupManager()->getUserIdGroups($user)
 			);
 
-			$readOnlyGroupMemberships = array_intersect(
+			$readOnlyGroupMemberships = \array_intersect(
 				$readOnlyGroups,
 				$userGroups
 			);
 		}
 
-
 		if ($isGuest === '1' || !empty($readOnlyGroupMemberships)) {
 			\OC\Files\Filesystem::addStorageWrapper(
 				'oc_readonly',
@@ -290,7 +288,6 @@ class OC_Util {
 
 		//if we aren't logged in, there is no use to set up the filesystem
 		if ($user != "") {
-
 			$userDir = '/' . $user . '/files';
 
 			//jail the user into his "home" directory
@@ -303,45 +300,20 @@ class OC_Util {
 	}
 
 	/**
-	 * check if a password is required for each public link
+	 * check if a password is required for each public link.
+	 * This is deprecated due to not reflecting all the possibilities now. Falling back to
+	 * enforce password for read-only links. Note that read & write or write-only options won't
+	 * be considered here
 	 *
 	 * @return boolean
+	 * @deprecated
 	 */
 	public static function isPublicLinkPasswordRequired() {
 		$appConfig = \OC::$server->getAppConfig();
-		$enforcePassword = $appConfig->getValue('core', 'shareapi_enforce_links_password', 'no');
+		$enforcePassword = $appConfig->getValue('core', 'shareapi_enforce_links_password_read_only', 'no');
 		return ($enforcePassword === 'yes') ? true : false;
 	}
 
-	/**
-	 * check if sharing is disabled for the current user
-	 * @param IConfig $config
-	 * @param IGroupManager $groupManager
-	 * @param IUser|null $user
-	 * @return bool
-	 */
-	public static function isSharingDisabledForUser(IConfig $config, IGroupManager $groupManager, $user) {
-		if ($config->getAppValue('core', 'shareapi_exclude_groups', 'no') === 'yes') {
-			$groupsList = $config->getAppValue('core', 'shareapi_exclude_groups_list', '');
-			$excludedGroups = json_decode($groupsList);
-			if (is_null($excludedGroups)) {
-				$excludedGroups = explode(',', $groupsList);
-				$newValue = json_encode($excludedGroups);
-				$config->setAppValue('core', 'shareapi_exclude_groups_list', $newValue);
-			}
-			$usersGroups = $groupManager->getUserGroupIds($user);
-			if (!empty($usersGroups)) {
-				$remainingGroups = array_diff($usersGroups, $excludedGroups);
-				// if the user is only in groups which are disabled for sharing then
-				// sharing is also disabled for the user
-				if (empty($remainingGroups)) {
-					return true;
-				}
-			}
-		}
-		return false;
-	}
-
 	/**
 	 * check if share API enforces a default expire date
 	 *
@@ -370,7 +342,7 @@ class OC_Util {
 		} else {
 			$user = \OC::$server->getUserManager()->get($userId);
 		}
-		if (is_null($user)) {
+		if ($user === null) {
 			return \OCP\Files\FileInfo::SPACE_UNLIMITED;
 		}
 		$userQuota = $user->getQuota();
@@ -391,10 +363,9 @@ class OC_Util {
 	 * @throws \OC\HintException
 	 */
 	public static function copySkeleton($userId, \OCP\Files\Folder $userDirectory) {
-
 		$skeletonDirectory = \OCP\Config::getSystemValue('skeletondirectory', \OC::$SERVERROOT . '/core/skeleton');
 
-		if (!is_dir($skeletonDirectory))  {
+		if (!\is_dir($skeletonDirectory)) {
 			throw new \OC\HintException('The skeleton folder '.$skeletonDirectory.' is not accessible');
 		}
 
@@ -416,21 +387,38 @@ class OC_Util {
 	 * @param string $source
 	 * @param \OCP\Files\Folder $target
 	 * @return void
+	 * @throws NoReadAccessException
 	 */
 	public static function copyr($source, \OCP\Files\Folder $target) {
-		$dir = opendir($source);
-		while (false !== ($file = readdir($dir))) {
+		$dir = @\opendir($source);
+		if ($dir === false) {
+			throw new NoReadAccessException('No read permission for folder ' . $source);
+		}
+		while (($file = \readdir($dir)) !== false) {
 			if (!\OC\Files\Filesystem::isIgnoredDir($file)) {
-				if (is_dir($source . '/' . $file)) {
+				if (\is_dir($source . '/' . $file)) {
 					$child = $target->newFolder($file);
 					self::copyr($source . '/' . $file, $child);
 				} else {
+					$sourceFileHandle = @\fopen($source . '/' . $file, 'r');
+					if ($sourceFileHandle === false) {
+						throw new NoReadAccessException('No read permission for file ' . $file);
+					}
 					$child = $target->newFile($file);
-					stream_copy_to_stream(fopen($source . '/' . $file,'r'), $child->fopen('w'));
+					$targetFileHandle = $child->fopen('w');
+					\stream_copy_to_stream($sourceFileHandle, $targetFileHandle);
+					\fclose($targetFileHandle);
+					\fclose($sourceFileHandle);
+
+					// update cache sizes
+					$cache = $target->getStorage()->getCache();
+					if ($cache instanceof \OC\Files\Cache\Cache) {
+						$cache->correctFolderSize($child->getInternalPath());
+					}
 				}
 			}
 		}
-		closedir($dir);
+		\closedir($dir);
 	}
 
 	/**
@@ -470,10 +458,10 @@ class OC_Util {
 	 */
 	public static function getEditionString() {
 		if (OC_App::isEnabled('enterprise_key')) {
- 			return OC_Util::EDITION_ENTERPRISE;
- 		} else {
-			return OC_Util::EDITION_COMMUNITY;		}
-
+			return OC_Util::EDITION_ENTERPRISE;
+		} else {
+			return OC_Util::EDITION_COMMUNITY;
+		}
 	}
 
 	/**
@@ -527,7 +515,7 @@ class OC_Util {
 	 * @return string the path
 	 */
 	private static function generatePath($application, $directory, $file) {
-		if (is_null($file)) {
+		if ($file === null) {
 			$file = $application;
 			$application = "";
 		}
@@ -551,7 +539,7 @@ class OC_Util {
 
 		// core js files need separate handling
 		if ($application !== 'core' && $file !== null) {
-			self::addTranslations ( $application );
+			self::addTranslations($application);
 		}
 		self::addExternalResource($application, $prepend, $path, "script");
 	}
@@ -577,7 +565,7 @@ class OC_Util {
 	 * @param bool $prepend prepend the Script to the beginning of the list
 	 */
 	public static function addTranslations($application, $languageCode = null, $prepend = false) {
-		if (is_null($languageCode)) {
+		if ($languageCode === null) {
 			$languageCode = \OC::$server->getL10NFactory()->findLanguage($application);
 		}
 		if (!empty($application)) {
@@ -624,19 +612,18 @@ class OC_Util {
 	 * @return void
 	 */
 	private static function addExternalResource($application, $prepend, $path, $type = "script") {
-
 		if ($type === "style") {
-			if (!in_array($path, self::$styles)) {
+			if (!\in_array($path, self::$styles)) {
 				if ($prepend === true) {
-					array_unshift ( self::$styles, $path );
+					\array_unshift(self::$styles, $path);
 				} else {
 					self::$styles[] = $path;
 				}
 			}
 		} elseif ($type === "script") {
-			if (!in_array($path, self::$scripts)) {
+			if (!\in_array($path, self::$scripts)) {
 				if ($prepend === true) {
-					array_unshift ( self::$scripts, $path );
+					\array_unshift(self::$scripts, $path);
 				} else {
 					self::$scripts [] = $path;
 				}
@@ -720,8 +707,8 @@ class OC_Util {
 		}
 
 		// Check if config folder is writable.
-		if(!\OC::$server->getConfig()->isSystemConfigReadOnly()) {
-			if (!is_writable(OC::$configDir) or !is_readable(OC::$configDir)) {
+		if (!\OC::$server->getConfig()->isSystemConfigReadOnly()) {
+			if (!\is_writable(OC::$configDir) or !\is_readable(OC::$configDir)) {
 				$errors[] = [
 					'error' => $l->t('Cannot write into "config" directory'),
 					'hint' => $l->t('This can usually be fixed by '
@@ -733,10 +720,10 @@ class OC_Util {
 
 		// Create root dir.
 		if ($config->getSystemValue('installed', false)) {
-			if (!is_dir($CONFIG_DATADIRECTORY)) {
-				$success = @mkdir($CONFIG_DATADIRECTORY);
+			if (!\is_dir($CONFIG_DATADIRECTORY)) {
+				$success = @\mkdir($CONFIG_DATADIRECTORY);
 				if ($success) {
-					$errors = array_merge($errors, self::checkDataDirectoryPermissions($CONFIG_DATADIRECTORY));
+					$errors = \array_merge($errors, self::checkDataDirectoryPermissions($CONFIG_DATADIRECTORY));
 				} else {
 					$errors[] = [
 						'error' => $l->t('Cannot create "data" directory'),
@@ -745,7 +732,7 @@ class OC_Util {
 							[$urlGenerator->linkToDocs('admin-dir_permissions')])
 					];
 				}
-			} else if (!is_writable($CONFIG_DATADIRECTORY) or !is_readable($CONFIG_DATADIRECTORY)) {
+			} elseif (!\is_writable($CONFIG_DATADIRECTORY) or !\is_readable($CONFIG_DATADIRECTORY)) {
 				//common hint for all file permissions error messages
 				$permissionsHint = $l->t('Permissions can usually be fixed by '
 					. '%sgiving the webserver write access to the root directory%s.',
@@ -755,7 +742,7 @@ class OC_Util {
 					'hint' => $permissionsHint
 				];
 			} else {
-				$errors = array_merge($errors, self::checkDataDirectoryPermissions($CONFIG_DATADIRECTORY));
+				$errors = \array_merge($errors, self::checkDataDirectoryPermissions($CONFIG_DATADIRECTORY));
 			}
 		}
 
@@ -816,52 +803,52 @@ class OC_Util {
 		$iniWrapper = \OC::$server->getIniWrapper();
 		if (!self::runningOnHhvm()) {
 			foreach ($dependencies['classes'] as $class => $module) {
-				if (!class_exists($class)) {
+				if (!\class_exists($class)) {
 					$missingDependencies[] = $module;
 				}
 			}
 			foreach ($dependencies['functions'] as $function => $module) {
-				if (!function_exists($function)) {
+				if (!\function_exists($function)) {
 					$missingDependencies[] = $module;
 				}
 			}
 			foreach ($dependencies['defined'] as $defined => $module) {
-				if (!defined($defined)) {
+				if (!\defined($defined)) {
 					$missingDependencies[] = $module;
 				}
 			}
 			foreach ($dependencies['ini'] as $setting => $expected) {
-				if (is_bool($expected)) {
+				if (\is_bool($expected)) {
 					if ($iniWrapper->getBool($setting) !== $expected) {
 						$invalidIniSettings[] = [$setting, $expected];
 					}
 				}
-				if (is_int($expected)) {
+				if (\is_int($expected)) {
 					if ($iniWrapper->getNumeric($setting) !== $expected) {
 						$invalidIniSettings[] = [$setting, $expected];
 					}
 				}
-				if (is_string($expected)) {
-					if (strtolower($iniWrapper->getString($setting)) !== strtolower($expected)) {
+				if (\is_string($expected)) {
+					if (\strtolower($iniWrapper->getString($setting)) !== \strtolower($expected)) {
 						$invalidIniSettings[] = [$setting, $expected];
 					}
 				}
 			}
 		}
 
-		foreach($missingDependencies as $missingDependency) {
+		foreach ($missingDependencies as $missingDependency) {
 			$errors[] = [
 				'error' => $l->t('PHP module %s not installed.', [$missingDependency]),
 				'hint' => $moduleHint
 			];
 			$webServerRestart = true;
 		}
-		foreach($invalidIniSettings as $setting) {
-			if(is_bool($setting[1])) {
+		foreach ($invalidIniSettings as $setting) {
+			if (\is_bool($setting[1])) {
 				$setting[1] = ($setting[1]) ? 'on' : 'off';
 			}
 			$errors[] = [
-				'error' => $l->t('PHP setting "%s" is not set to "%s".', [$setting[0], var_export($setting[1], true)]),
+				'error' => $l->t('PHP setting "%s" is not set to "%s".', [$setting[0], \var_export($setting[1], true)]),
 				'hint' =>  $l->t('Adjusting this setting in php.ini will make ownCloud run again')
 			];
 			$webServerRestart = true;
@@ -875,7 +862,7 @@ class OC_Util {
 		 * TODO: Should probably be implemented in the above generic dependency
 		 *       check somehow in the long-term.
 		 */
-		if($iniWrapper->getBool('mbstring.func_overload') !== null &&
+		if ($iniWrapper->getBool('mbstring.func_overload') !== null &&
 			$iniWrapper->getBool('mbstring.func_overload') === true) {
 			$errors[] = [
 				'error' => $l->t('mbstring.func_overload is set to "%s" instead of the expected value "0"', [$iniWrapper->getString('mbstring.func_overload')]),
@@ -883,8 +870,8 @@ class OC_Util {
 			];
 		}
 
-		if(function_exists('xml_parser_create') &&
-			version_compare('2.7.0', LIBXML_DOTTED_VERSION) === 1) {
+		if (\function_exists('xml_parser_create') &&
+			\version_compare('2.7.0', LIBXML_DOTTED_VERSION) === 1) {
 			$errors[] = [
 				'error' => $l->t('libxml2 2.7.0 is at least required. Currently %s is installed.', [LIBXML_DOTTED_VERSION]),
 				'hint' => $l->t('To fix this issue update your libxml2 version and restart your web server.')
@@ -905,10 +892,10 @@ class OC_Util {
 			];
 		}
 
-		$errors = array_merge($errors, self::checkDatabaseVersion());
+		$errors = \array_merge($errors, self::checkDatabaseVersion());
 
 		// Cache the result of this function
-		\OC::$server->getSession()->set('checkServer_succeeded', count($errors) == 0);
+		\OC::$server->getSession()->set('checkServer_succeeded', \count($errors) == 0);
 
 		return $errors;
 	}
@@ -929,7 +916,7 @@ class OC_Util {
 				$data = $result->fetchRow();
 				if (isset($data['server_version'])) {
 					$version = $data['server_version'];
-					if (version_compare($version, '9.0.0', '<')) {
+					if (\version_compare($version, '9.0.0', '<')) {
 						$errors[] = [
 							'error' => $l->t('PostgreSQL >= 9 required'),
 							'hint' => $l->t('Please upgrade your database version')
@@ -956,12 +943,12 @@ class OC_Util {
 		$errors = [];
 		$permissionsModHint = $l->t('Please change the permissions to 0770 so that the directory'
 			. ' cannot be listed by other users.');
-		$perms = substr(decoct(@fileperms($dataDirectory)), -3);
-		if (substr($perms, -1) != '0') {
-			chmod($dataDirectory, 0770);
-			clearstatcache();
-			$perms = substr(decoct(@fileperms($dataDirectory)), -3);
-			if (substr($perms, 2, 1) != '0') {
+		$perms = \substr(\decoct(@\fileperms($dataDirectory)), -3);
+		if (\substr($perms, -1) != '0') {
+			\chmod($dataDirectory, 0770);
+			\clearstatcache();
+			$perms = \substr(\decoct(@\fileperms($dataDirectory)), -3);
+			if (\substr($perms, 2, 1) != '0') {
 				$errors[] = [
 					'error' => $l->t('Your Data directory is readable by other users'),
 					'hint' => $permissionsModHint
@@ -987,7 +974,7 @@ class OC_Util {
 				'hint' => $l->t('Check the value of "datadirectory" in your configuration')
 			];
 		}
-		if (!file_exists($dataDirectory . '/.ocdata')) {
+		if (!\file_exists($dataDirectory . '/.ocdata')) {
 			$errors[] = [
 				'error' => $l->t('Your Data directory  is invalid'),
 				'hint' => $l->t('Please check that the data directory contains a file' .
@@ -1005,11 +992,12 @@ class OC_Util {
 	 */
 	public static function checkLoggedIn() {
 		// Check if we are a user
-		if (!OC_User::isLoggedIn()) {
-			header('Location: ' . \OC::$server->getURLGenerator()->linkToRoute(
+		$userSession = \OC::$server->getUserSession();
+		if (!$userSession->isLoggedIn()) {
+			\header('Location: ' . \OC::$server->getURLGenerator()->linkToRoute(
 						'core.login.showLoginForm',
 						[
-							'redirect_url' => urlencode(\OC::$server->getRequest()->getRequestUri()),
+							'redirect_url' => \urlencode(\OC::$server->getRequest()->getRequestUri()),
 						]
 					)
 			);
@@ -1017,7 +1005,14 @@ class OC_Util {
 		}
 		// Redirect to index page if 2FA challenge was not solved yet
 		if (\OC::$server->getTwoFactorAuthManager()->needsSecondFactor()) {
-			header('Location: ' . \OCP\Util::linkToAbsolute('', 'index.php'));
+			\header('Location: ' . \OCP\Util::linkToAbsolute('', 'index.php'));
+			exit();
+		}
+		// Redirect to index page if any IAuthModule check fails
+		try {
+			\OC::$server->getAccountModuleManager()->check($userSession->getUser());
+		} catch (AccountCheckException $ex) {
+			\header('Location: ' . \OCP\Util::linkToAbsolute('', 'index.php'));
 			exit();
 		}
 	}
@@ -1030,7 +1025,7 @@ class OC_Util {
 	public static function checkAdminUser() {
 		OC_Util::checkLoggedIn();
 		if (!OC_User::isAdminUser(OC_User::getUser())) {
-			header('Location: ' . \OCP\Util::linkToAbsolute('', 'index.php'));
+			\header('Location: ' . \OCP\Util::linkToAbsolute('', 'index.php'));
 			exit();
 		}
 	}
@@ -1043,7 +1038,6 @@ class OC_Util {
 	 * @return bool
 	 */
 	public static function rememberLoginAllowed() {
-
 		$apps = OC_App::getEnabledApps();
 
 		foreach ($apps as $app) {
@@ -1051,7 +1045,6 @@ class OC_Util {
 			if (isset($appInfo['rememberlogin']) && $appInfo['rememberlogin'] === 'false') {
 				return false;
 			}
-
 		}
 		return true;
 	}
@@ -1065,12 +1058,12 @@ class OC_Util {
 		OC_Util::checkLoggedIn();
 		$userObject = \OC::$server->getUserSession()->getUser();
 		$isSubAdmin = false;
-		if($userObject !== null) {
+		if ($userObject !== null) {
 			$isSubAdmin = \OC::$server->getGroupManager()->getSubAdmin()->isSubAdmin($userObject);
 		}
 
 		if (!$isSubAdmin) {
-			header('Location: ' . \OCP\Util::linkToAbsolute('', 'index.php'));
+			\header('Location: ' . \OCP\Util::linkToAbsolute('', 'index.php'));
 			exit();
 		}
 		return true;
@@ -1087,25 +1080,25 @@ class OC_Util {
 		$urlGenerator = \OC::$server->getURLGenerator();
 		// Deny the redirect if the URL contains a @
 		// This prevents unvalidated redirects like ?redirect_url=:user@domain.com
-		if (isset($_REQUEST['redirect_url']) && strpos($_REQUEST['redirect_url'], '@') === false) {
-			$location = $urlGenerator->getAbsoluteURL(urldecode($_REQUEST['redirect_url']));
+		if (isset($_REQUEST['redirect_url']) && \strpos($_REQUEST['redirect_url'], '@') === false) {
+			$location = $urlGenerator->getAbsoluteURL(\urldecode($_REQUEST['redirect_url']));
 		} else {
 			$defaultPage = \OC::$server->getAppConfig()->getValue('core', 'defaultpage');
 			if ($defaultPage) {
 				$location = $urlGenerator->getAbsoluteURL($defaultPage);
 			} else {
 				$appId = 'files';
-				$defaultApps = explode(',', \OCP\Config::getSystemValue('defaultapp', 'files'));
+				$defaultApps = \explode(',', \OCP\Config::getSystemValue('defaultapp', 'files'));
 				// find the first app that is enabled for the current user
 				foreach ($defaultApps as $defaultApp) {
-					$defaultApp = OC_App::cleanAppId(strip_tags($defaultApp));
+					$defaultApp = OC_App::cleanAppId(\strip_tags($defaultApp));
 					if (static::getAppManager()->isEnabledForUser($defaultApp)) {
 						$appId = $defaultApp;
 						break;
 					}
 				}
 
-				if(getenv('front_controller_active') === 'true') {
+				if (\getenv('front_controller_active') === 'true') {
 					$location = $urlGenerator->getAbsoluteURL('/apps/' . $appId . '/');
 				} else {
 					$location = $urlGenerator->getAbsoluteURL('/index.php/apps/' . $appId . '/');
@@ -1122,7 +1115,7 @@ class OC_Util {
 	 */
 	public static function redirectToDefaultPage() {
 		$location = self::getDefaultPageUrl();
-		header('Location: ' . $location);
+		\header('Location: ' . $location);
 		exit();
 	}
 
@@ -1133,7 +1126,7 @@ class OC_Util {
 	 */
 	public static function getInstanceId() {
 		$id = \OC::$server->getSystemConfig()->getValue('instanceid', null);
-		if (is_null($id)) {
+		if ($id === null) {
 			// We need to guarantee at least one letter in instanceid so it can be used as the session_name
 			$id = 'oc' . \OC::$server->getSecureRandom()->generate(10, \OCP\Security\ISecureRandom::CHAR_LOWER.\OCP\Security\ISecureRandom::CHAR_DIGITS);
 			\OC::$server->getSystemConfig()->setValue('instanceid', $id);
@@ -1151,13 +1144,13 @@ class OC_Util {
 	 * @return string|array an array of sanitized strings or a single sanitized string, depends on the input parameter.
 	 */
 	public static function sanitizeHTML($value) {
-		if (is_array($value)) {
-			$value = array_map(function($value) {
+		if (\is_array($value)) {
+			$value = \array_map(function ($value) {
 				return self::sanitizeHTML($value);
 			}, $value);
 		} else {
 			// Specify encoding for PHP<5.4
-			$value = htmlspecialchars((string)$value, ENT_QUOTES, 'UTF-8');
+			$value = \htmlspecialchars((string)$value, ENT_QUOTES, 'UTF-8');
 		}
 		return $value;
 	}
@@ -1173,15 +1166,14 @@ class OC_Util {
 	 * @return string
 	 */
 	public static function encodePath($component) {
-		$encoded = rawurlencode($component);
-		$encoded = str_replace('%2F', '/', $encoded);
+		$encoded = \rawurlencode($component);
+		$encoded = \str_replace('%2F', '/', $encoded);
 		return $encoded;
 	}
 
-
 	public function createHtaccessTestFile(\OCP\IConfig $config) {
 		// php dev server does not support htaccess
-		if (php_sapi_name() === 'cli-server') {
+		if (\php_sapi_name() === 'cli-server') {
 			return false;
 		}
 		if (\OC::$CLI) {
@@ -1196,17 +1188,17 @@ class OC_Util {
 		// creating a test file
 		$testFile = $config->getSystemValue('datadirectory', OC::$SERVERROOT . '/data') . '/' . $fileName;
 
-		if (file_exists($testFile)) {// already running this test, possible recursive call
+		if (\file_exists($testFile)) {// already running this test, possible recursive call
 			return false;
 		}
 
-		$fp = @fopen($testFile, 'w');
+		$fp = @\fopen($testFile, 'w');
 		if (!$fp) {
 			throw new OC\HintException('Can\'t create test file to check for working .htaccess file.',
 				'Make sure it is possible for the webserver to write to ' . $testFile);
 		}
-		fwrite($fp, $testContent);
-		fclose($fp);
+		\fwrite($fp, $testContent);
+		\fclose($fp);
 	}
 
 	/**
@@ -1217,7 +1209,7 @@ class OC_Util {
 	 */
 	public static function isSetLocaleWorking() {
 		\Patchwork\Utf8\Bootup::initLocale();
-		if ('' === basename('§')) {
+		if (\basename('§') === '') {
 			return false;
 		}
 		return true;
@@ -1232,7 +1224,7 @@ class OC_Util {
 		$reflection = new \ReflectionMethod(__METHOD__);
 		$docs = $reflection->getDocComment();
 
-		return (is_string($docs) && strlen($docs) > 50);
+		return (\is_string($docs) && \strlen($docs) > 50);
 	}
 
 	/**
@@ -1241,7 +1233,7 @@ class OC_Util {
 	 * @return bool
 	 */
 	public static function fileInfoLoaded() {
-		return function_exists('finfo_open');
+		return \function_exists('finfo_open');
 	}
 
 	/**
@@ -1250,8 +1242,8 @@ class OC_Util {
 	 * @return void
 	 */
 	public static function obEnd() {
-		while (ob_get_level()) {
-			ob_end_clean();
+		while (\ob_get_level()) {
+			\ob_end_clean();
 		}
 	}
 
@@ -1262,12 +1254,12 @@ class OC_Util {
 	 * @return bool true if running on that OS type, false otherwise
 	 */
 	public static function runningOn($osType) {
-		$osType = strtolower($osType) === 'mac' ? 'darwin' : strtolower($osType);
+		$osType = \strtolower($osType) === 'mac' ? 'darwin' : \strtolower($osType);
 
 		if ($osType === 'bsd') {
-			return (strpos(strtolower(PHP_OS), $osType) !== false);
+			return (\strpos(\strtolower(PHP_OS), $osType) !== false);
 		} else {
-			return (strtolower(substr(PHP_OS, 0, strlen($osType))) === $osType);
+			return (\strtolower(\substr(PHP_OS, 0, \strlen($osType))) === $osType);
 		}
 	}
 
@@ -1277,7 +1269,7 @@ class OC_Util {
 	 * @return bool True if running on HHVM, false otherwise
 	 */
 	public static function runningOnHhvm() {
-		return defined('HHVM_VERSION');
+		return \defined('HHVM_VERSION');
 	}
 
 	/**
@@ -1307,12 +1299,12 @@ class OC_Util {
 		$ret = false;
 		if ($path) {
 			// APC >= 3.1.1
-			if (function_exists('apc_delete_file')) {
+			if (\function_exists('apc_delete_file')) {
 				$ret = @apc_delete_file($path);
 			}
 			// Zend OpCache >= 7.0.0, PHP >= 5.5.0
-			if (function_exists('opcache_invalidate')) {
-				$ret = opcache_invalidate($path);
+			if (\function_exists('opcache_invalidate')) {
+				$ret = \opcache_invalidate($path);
 			}
 		}
 		return $ret;
@@ -1327,15 +1319,15 @@ class OC_Util {
 	 */
 	public static function clearOpcodeCache() {
 		// APC
-		if (function_exists('apc_clear_cache')) {
-			apc_clear_cache();
+		if (\function_exists('apc_clear_cache')) {
+			\apc_clear_cache();
 		}
 		// Zend Opcache
-		if (function_exists('accelerator_reset')) {
+		if (\function_exists('accelerator_reset')) {
 			accelerator_reset();
 		}
 		// XCache
-		if (function_exists('xcache_clear_cache')) {
+		if (\function_exists('xcache_clear_cache')) {
 			if (\OC::$server->getIniWrapper()->getBool('xcache.admin.enable_auth')) {
 				\OCP\Util::writeLog('core', 'XCache opcode cache will not be cleared because "xcache.admin.enable_auth" is enabled.', \OCP\Util::WARN);
 			} else {
@@ -1343,8 +1335,8 @@ class OC_Util {
 			}
 		}
 		// Opcache (PHP >= 5.5)
-		if (function_exists('opcache_reset')) {
-			opcache_reset();
+		if (\function_exists('opcache_reset')) {
+			\opcache_reset();
 		}
 	}
 
@@ -1355,7 +1347,7 @@ class OC_Util {
 	 * @return bool|string
 	 */
 	public static function normalizeUnicode($value) {
-		if(Normalizer::isNormalized($value)) {
+		if (Normalizer::isNormalized($value)) {
 			return $value;
 		}
 
@@ -1373,9 +1365,9 @@ class OC_Util {
 	 * @return string
 	 */
 	public static function basename($file) {
-		$file = rtrim($file, '/');
-		$t = explode('/', $file);
-		return array_pop($t);
+		$file = \rtrim($file, '/');
+		$t = \explode('/', $file);
+		return \array_pop($t);
 	}
 
 	/**
@@ -1400,7 +1392,7 @@ class OC_Util {
 	 * @deprecated use \OC\Files\View::verifyPath()
 	 */
 	public static function isValidFileName($file) {
-		$trimmed = trim($file);
+		$trimmed = \trim($file);
 		if ($trimmed === '') {
 			return false;
 		}
@@ -1409,12 +1401,12 @@ class OC_Util {
 		}
 
 		// detect part files
-		if (preg_match('/' . \OCP\Files\FileInfo::BLACKLIST_FILES_REGEX . '/', $trimmed) !== 0) {
+		if (\preg_match('/' . \OCP\Files\FileInfo::BLACKLIST_FILES_REGEX . '/', $trimmed) !== 0) {
 			return false;
 		}
 
-		foreach (str_split($trimmed) as $char) {
-			if (strpos(\OCP\Constants::FILENAME_INVALID_CHARS, $char) !== false) {
+		foreach (\str_split($trimmed) as $char) {
+			if (\strpos(\OCP\Constants::FILENAME_INVALID_CHARS, $char) !== false) {
 				return false;
 			}
 		}
@@ -1433,15 +1425,15 @@ class OC_Util {
 	public static function needUpgrade(\OCP\IConfig $config) {
 		if ($config->getSystemValue('installed', false)) {
 			$installedVersion = $config->getSystemValue('version', '0.0.0');
-			$currentVersion = implode('.', \OCP\Util::getVersion());
-			$versionDiff = version_compare($currentVersion, $installedVersion);
+			$currentVersion = \implode('.', \OCP\Util::getVersion());
+			$versionDiff = \version_compare($currentVersion, $installedVersion);
 			if ($versionDiff > 0) {
 				return true;
-			} else if ($config->getSystemValue('debug', false) && $versionDiff < 0) {
+			} elseif ($config->getSystemValue('debug', false) && $versionDiff < 0) {
 				// downgrade with debug
-				$installedMajor = explode('.', $installedVersion);
+				$installedMajor = \explode('.', $installedVersion);
 				$installedMajor = $installedMajor[0] . '.' . $installedMajor[1];
-				$currentMajor = explode('.', $currentVersion);
+				$currentMajor = \explode('.', $currentVersion);
 				$currentMajor = $currentMajor[0] . '.' . $currentMajor[1];
 				if ($installedMajor === $currentMajor) {
 					// Same major, allow downgrade for developers
@@ -1450,7 +1442,7 @@ class OC_Util {
 					// downgrade attempt, throw exception
 					throw new \OC\HintException('Downgrading is not supported and is likely to cause unpredictable issues (from ' . $installedVersion . ' to ' . $currentVersion . ')');
 				}
-			} else if ($versionDiff < 0) {
+			} elseif ($versionDiff < 0) {
 				// downgrade attempt, throw exception
 				throw new \OC\HintException('Downgrading is not supported and is likely to cause unpredictable issues (from ' . $installedVersion . ' to ' . $currentVersion . ')');
 			}
@@ -1469,5 +1461,4 @@ class OC_Util {
 			return false;
 		}
 	}
-
 }
