@@ -3,7 +3,7 @@
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,4 +25,5 @@ namespace OCP\Comments;
  * Exception for illegal attempts to modify a comment ID
  * @since 9.0.0
  */
-class IllegalIDChangeException extends \Exception {}
+class IllegalIDChangeException extends \Exception {
+}
