@@ -12,7 +12,7 @@
  * @author Tom Needham <tom@owncloud.com>
  * @author Ujjwal Bhardwaj <ujjwalb1996@gmail.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -41,14 +41,15 @@ use OC\Settings\Controller\CertificateController;
 use OC\Settings\Controller\CheckSetupController;
 use OC\Settings\Controller\EncryptionController;
 use OC\Settings\Controller\GroupsController;
+use OC\Settings\Controller\LegalSettingsController;
 use OC\Settings\Controller\LogSettingsController;
 use OC\Settings\Controller\MailSettingsController;
-use OC\Settings\Controller\SecuritySettingsController;
 use OC\Settings\Controller\UsersController;
 use OC\Settings\Middleware\SubadminMiddleware;
 use OCP\AppFramework\App;
 use OCP\IContainer;
 use OCP\Util;
+use OC\Files\View;
 
 /**
  * @package OC\Settings
@@ -58,33 +59,25 @@ class Application extends App {
 	/**
 	 * @param array $urlParams
 	 */
-	public function __construct(array $urlParams=[]){
+	public function __construct(array $urlParams=[]) {
 		parent::__construct('settings', $urlParams);
 
 		$container = $this->getContainer();
 
-		$container->registerService('Profile', function(IContainer $c) {
-		   return new \OC\Settings\Panels\Personal\Profile(
-			   $c->query('Config'),
-			   $c->query('GroupManager'),
-			   $c->query('ServerContainer')->getURLGenerator()
-		   );
-	   });
-
 		/**
 		 * Controllers
 		 */
-		 $container->registerService('SettingsPageController', function(IContainer $c) {
- 			return new SettingsPageController(
- 				$c->query('AppName'),
+		$container->registerService('SettingsPageController', function (IContainer $c) {
+			return new SettingsPageController(
+				$c->query('AppName'),
 				$c->query('Request'),
 				$c->query('SettingsManager'),
 				$c->query('ServerContainer')->getURLGenerator(),
 				$c->query('GroupManager'),
 				$c->query('UserSession')
- 			);
- 		});
-		$container->registerService('MailSettingsController', function(IContainer $c) {
+			);
+		});
+		$container->registerService('MailSettingsController', function (IContainer $c) {
 			return new MailSettingsController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -96,7 +89,7 @@ class Application extends App {
 				$c->query('DefaultMailAddress')
 			);
 		});
-		$container->registerService('EncryptionController', function(IContainer $c) {
+		$container->registerService('EncryptionController', function (IContainer $c) {
 			return new EncryptionController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -108,7 +101,7 @@ class Application extends App {
 				$c->query('Logger')
 			);
 		});
-		$container->registerService('AppSettingsController', function(IContainer $c) {
+		$container->registerService('AppSettingsController', function (IContainer $c) {
 			return new AppSettingsController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -117,7 +110,7 @@ class Application extends App {
 				$c->query('IAppManager')
 			);
 		});
-		$container->registerService('AuthSettingsController', function(IContainer $c) {
+		$container->registerService('AuthSettingsController', function (IContainer $c) {
 			return new AuthSettingsController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -128,14 +121,7 @@ class Application extends App {
 				$c->query('UserId')
 			);
 		});
-		$container->registerService('SecuritySettingsController', function(IContainer $c) {
-			return new SecuritySettingsController(
-				$c->query('AppName'),
-				$c->query('Request'),
-				$c->query('Config')
-			);
-		});
-		$container->registerService('CertificateController', function(IContainer $c) {
+		$container->registerService('CertificateController', function (IContainer $c) {
 			return new CertificateController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -145,7 +131,7 @@ class Application extends App {
 				$c->query('IAppManager')
 			);
 		});
-		$container->registerService('GroupsController', function(IContainer $c) {
+		$container->registerService('GroupsController', function (IContainer $c) {
 			return new GroupsController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -155,7 +141,7 @@ class Application extends App {
 				$c->query('L10N')
 			);
 		});
-		$container->registerService('UsersController', function(IContainer $c) {
+		$container->registerService('UsersController', function (IContainer $c) {
 			return new UsersController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -173,10 +159,11 @@ class Application extends App {
 				$c->query('DefaultMailAddress'),
 				$c->query('URLGenerator'),
 				$c->query('OCP\\App\\IAppManager'),
-				$c->query('OCP\\IAvatarManager')
+				$c->query('OCP\\IAvatarManager'),
+				$c->query('ServerContainer')->getEventDispatcher()
 			);
 		});
-		$container->registerService('LogSettingsController', function(IContainer $c) {
+		$container->registerService('LogSettingsController', function (IContainer $c) {
 			return new LogSettingsController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -184,7 +171,15 @@ class Application extends App {
 				$c->query('L10N')
 			);
 		});
-		$container->registerService('CheckSetupController', function(IContainer $c) {
+		$container->registerService('LegalSettingsController', function (IContainer $c) {
+			return new LegalSettingsController(
+				$c->query('AppName'),
+				$c->query('Request'),
+				$c->query('L10N'),
+				$c->query('Config')
+			);
+		});
+		$container->registerService('CheckSetupController', function (IContainer $c) {
 			return new CheckSetupController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -196,7 +191,7 @@ class Application extends App {
 				$c->query('Checker')
 			);
 		});
-		$container->registerService('CorsController', function(IContainer $c) {
+		$container->registerService('CorsController', function (IContainer $c) {
 			return new CorsController(
 				$c->query('AppName'),
 				$c->query('Request'),
@@ -210,7 +205,7 @@ class Application extends App {
 		/**
 		 * Middleware
 		 */
-		$container->registerService('SubadminMiddleware', function(IContainer $c){
+		$container->registerService('SubadminMiddleware', function (IContainer $c) {
 			return new SubadminMiddleware(
 				$c->query('ControllerMethodReflector'),
 				$c->query('IsSubAdmin')
@@ -222,89 +217,89 @@ class Application extends App {
 		/**
 		 * Core class wrappers
 		 */
-		$container->registerService('Config', function(IContainer $c) {
+		$container->registerService('Config', function (IContainer $c) {
 			return $c->query('ServerContainer')->getConfig();
 		});
-		$container->registerService('ICacheFactory', function(IContainer $c) {
+		$container->registerService('ICacheFactory', function (IContainer $c) {
 			return $c->query('ServerContainer')->getMemCacheFactory();
 		});
-		$container->registerService('L10N', function(IContainer $c) {
+		$container->registerService('L10N', function (IContainer $c) {
 			return $c->query('ServerContainer')->getL10N('settings');
 		});
-		$container->registerService('GroupManager', function(IContainer $c) {
+		$container->registerService('GroupManager', function (IContainer $c) {
 			return $c->query('ServerContainer')->getGroupManager();
 		});
-		$container->registerService('UserManager', function(IContainer $c) {
+		$container->registerService('UserManager', function (IContainer $c) {
 			return $c->query('ServerContainer')->getUserManager();
 		});
-		$container->registerService('UserSession', function(IContainer $c) {
+		$container->registerService('UserSession', function (IContainer $c) {
 			return $c->query('ServerContainer')->getUserSession();
 		});
 		/** FIXME: Remove once OC_User is non-static and mockable */
-		$container->registerService('IsAdmin', function(IContainer $c) {
+		$container->registerService('IsAdmin', function (IContainer $c) {
 			return \OC_User::isAdminUser(\OC_User::getUser());
 		});
 		/** FIXME: Remove once OC_SubAdmin is non-static and mockable */
-		$container->registerService('IsSubAdmin', function(IContainer $c) {
+		$container->registerService('IsSubAdmin', function (IContainer $c) {
 			$userObject = \OC::$server->getUserSession()->getUser();
 			$isSubAdmin = false;
-			if($userObject !== null) {
+			if ($userObject !== null) {
 				$isSubAdmin = \OC::$server->getGroupManager()->getSubAdmin()->isSubAdmin($userObject);
 			}
 			return $isSubAdmin;
 		});
-		$container->registerService('Mailer', function(IContainer $c) {
+		$container->registerService('Mailer', function (IContainer $c) {
 			return $c->query('ServerContainer')->getMailer();
 		});
-		$container->registerService('Defaults', function(IContainer $c) {
+		$container->registerService('Defaults', function (IContainer $c) {
 			return new \OC_Defaults;
 		});
-		$container->registerService('DefaultMailAddress', function(IContainer $c) {
+		$container->registerService('DefaultMailAddress', function (IContainer $c) {
 			return Util::getDefaultEmailAddress('no-reply');
 		});
-		$container->registerService('Logger', function(IContainer $c) {
+		$container->registerService('Logger', function (IContainer $c) {
 			return $c->query('ServerContainer')->getLogger();
 		});
-		$container->registerService('URLGenerator', function(IContainer $c) {
+		$container->registerService('URLGenerator', function (IContainer $c) {
 			return $c->query('ServerContainer')->getURLGenerator();
 		});
-		$container->registerService('ClientService', function(IContainer $c) {
+		$container->registerService('ClientService', function (IContainer $c) {
 			return $c->query('ServerContainer')->getHTTPClientService();
 		});
-		$container->registerService('INavigationManager', function(IContainer $c) {
+		$container->registerService('INavigationManager', function (IContainer $c) {
 			return $c->query('ServerContainer')->getNavigationManager();
 		});
-		$container->registerService('IAppManager', function(IContainer $c) {
+		$container->registerService('IAppManager', function (IContainer $c) {
 			return $c->query('ServerContainer')->getAppManager();
 		});
-		$container->registerService('OcsClient', function(IContainer $c) {
+		$container->registerService('OcsClient', function (IContainer $c) {
 			return $c->query('ServerContainer')->getOcsClient();
 		});
-		$container->registerService('Util', function(IContainer $c) {
+		$container->registerService('Util', function (IContainer $c) {
 			return new \OC_Util();
 		});
-		$container->registerService('DatabaseConnection', function(IContainer $c) {
+		$container->registerService('DatabaseConnection', function (IContainer $c) {
 			return $c->query('ServerContainer')->getDatabaseConnection();
 		});
-		$container->registerService('CertificateManager', function(IContainer $c){
+		$container->registerService('CertificateManager', function (IContainer $c) {
 			return $c->query('ServerContainer')->getCertificateManager();
 		});
 		$container->registerService('SystemCertificateManager', function (IContainer $c) {
 			return $c->query('ServerContainer')->getCertificateManager(null);
 		});
-		$container->registerService('Checker', function(IContainer $c) {
+		$container->registerService('Checker', function (IContainer $c) {
 			/** @var Server $server */
 			$server = $c->query('ServerContainer');
 			return $server->getIntegrityCodeChecker();
 		});
-		$container->registerService('TimeFactory', function(IContainer $c) {
+		$container->registerService('TimeFactory', function (IContainer $c) {
 			return new TimeFactory();
 		});
-		$container->registerService('SecureRandom', function(IContainer $c) {
+		$container->registerService('SecureRandom', function (IContainer $c) {
 			return $c->query('ServerContainer')->getSecureRandom();
 		});
-		$container->registerService('SettingsManager', function(IContainer $c) {
+		$container->registerService('SettingsManager', function (IContainer $c) {
 			return $c->query('ServerContainer')->getSettingsManager();
-	 	});
+		});
 	}
 }
