@@ -14,7 +14,7 @@
  * @author Ujjwal Bhardwaj <ujjwalb1996@gmail.com>
  * @author Yarno Boelens <yarnoboelens@gmail.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -44,16 +44,16 @@ class Controller {
 
 		if (!\OC_User::checkPassword($username, $oldPassword)) {
 			$l = \OC::$server->getL10NFactory()->get('settings');
-			\OC_JSON::error(["data" => ["message" => $l->t("Wrong password")]]);
+			\OC_JSON::error(["data" => ["message" => $l->t("Wrong current password")]]);
 			exit();
 		}
 		if ($oldPassword === $password) {
 			$l = \OC::$server->getL10NFactory()->get('settings');
-			\OC_JSON::error(["data" => ["message" => $l->t("The new password can not be the same as the previous one")]]);
+			\OC_JSON::error(["data" => ["message" => $l->t("The new password cannot be the same as the previous one")]]);
 			exit();
-	        }
+		}
 		try {
-			if (!is_null($password) && \OC_User::setPassword($username, $password)) {
+			if ($password !== null && \OC_User::setPassword($username, $password)) {
 				\OC::$server->getUserSession()->updateSessionTokenPassword($password);
 
 				self::sendNotificationMail($username);
@@ -86,7 +86,7 @@ class Controller {
 		$isUserAccessible = false;
 		$currentUserObject = \OC::$server->getUserSession()->getUser();
 		$targetUserObject = \OC::$server->getUserManager()->get($username);
-		if($currentUserObject !== null && $targetUserObject !== null) {
+		if ($currentUserObject !== null && $targetUserObject !== null) {
 			$isUserAccessible = \OC::$server->getGroupManager()->getSubAdmin()->isUserAccessible($currentUserObject, $targetUserObject);
 		}
 
@@ -157,16 +157,15 @@ class Controller {
 						]
 					]);
 				} elseif (!$result && !$recoveryEnabledForUser) {
-					\OC_JSON::error(["data" => ["message" => $l->t("Unable to change password" )]]);
+					\OC_JSON::error(["data" => ["message" => $l->t("Unable to change password")]]);
 				} else {
 					self::sendNotificationMail($username);
 					\OC_JSON::success(["data" => ["username" => $username]]);
 				}
-
 			}
 		} else { // if encryption is disabled, proceed
 			try {
-				if (!is_null($password) && \OC_User::setPassword($username, $password)) {
+				if ($password !== null && \OC_User::setPassword($username, $password)) {
 					self::sendNotificationMail($username);
 					\OC_JSON::success(['data' => ['username' => $username]]);
 				} else {
@@ -184,7 +183,7 @@ class Controller {
 		$defaults = new \OC_Defaults();
 		$from = \OCP\Util::getDefaultEmailAddress('lostpassword-noreply');
 		$mailer = \OC::$server->getMailer();
-		$lion = \OC::$server->getL10N('lib');
+		$l10n = \OC::$server->getL10N('settings');
 
 		if ($email !== null && $email !== '') {
 			$tmpl = new \OC_Template('core', 'lostpassword/notify');
@@ -193,12 +192,12 @@ class Controller {
 			try {
 				$message = $mailer->createMessage();
 				$message->setTo([$email => $username]);
-				$message->setSubject($lion->t('%s password changed successfully', [$defaults->getName()]));
+				$message->setSubject($l10n->t('%s password changed successfully', [$defaults->getName()]));
 				$message->setPlainBody($msg);
 				$message->setFrom([$from => $defaults->getName()]);
 				$mailer->send($message);
 			} catch (\Exception $e) {
-				throw new \Exception($lion->t(
+				throw new \Exception($l10n->t(
 					'Couldn\'t send reset email. Please contact your administrator.'
 				));
 			}
