@@ -4,8 +4,9 @@
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Ujjwal Bhardwaj <ujjwalb1996@gmail.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -96,13 +97,21 @@ class MailSettingsController extends Controller {
 									$mail_smtpauthtype,
 									$mail_smtpauth,
 									$mail_smtpport) {
-
-		$params = get_defined_vars();
+		$params = \get_defined_vars();
 		$configs = [];
-		foreach($params as $key => $value) {
+		foreach ($params as $key => $value) {
 			$configs[$key] = (empty($value)) ? null : $value;
 		}
 
+		if (!$this->mailer->validateMailAddress($mail_from_address . '@' . $mail_domain)) {
+			return ['data' =>
+				['message' =>
+					(string) $this->l10n->t('Invalid email address')
+				],
+				'status' => 'error'
+			];
+		}
+
 		// Delete passwords from config in case no auth is specified
 		if ($params['mail_smtpauth'] !== 1) {
 			$configs['mail_smtpname'] = null;
@@ -177,5 +186,4 @@ class MailSettingsController extends Controller {
 			'status' => 'error'
 		];
 	}
-
 }
