@@ -2,7 +2,7 @@
 /**
  * @author Tom Needham <tom@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -117,11 +117,10 @@ class SettingsPageController extends Controller {
 	 */
 
 	protected function getIconForSettingsPanel($section) {
-
 		$icon = $section->getIconName() . '.svg';
 		$appPath = \OC_App::getAppPath($section->getID());
 
-		if (file_exists($appPath . '/img/' . $icon)) {
+		if (\file_exists($appPath . '/img/' . $icon)) {
 			$icon = $this->urlGenerator->imagePath($section->getID(), $icon);
 		} else {
 			$icon = $section->getIconName();
@@ -140,17 +139,16 @@ class SettingsPageController extends Controller {
 	protected function getNavigation($sections, $currentSectionID, $type) {
 		$nav = [];
 		// Iterate through sections and get id, name and see if currently active
-		foreach($sections as $section) {
-
+		foreach ($sections as $section) {
 			$icon = $this->getIconForSettingsPanel($section);
 
 			$nav[] = [
 				'id' => $section->getID(),
 				'link' => $this->urlGenerator->linkToRoute(
-					'settings.SettingsPage.get'.ucwords($type),
+					'settings.SettingsPage.get'.\ucwords($type),
 					['sectionid' => $section->getID()]
 				),
-				'name' => ucfirst($section->getName()),
+				'name' => \ucfirst($section->getName()),
 				'active' => $section->getID() === $currentSectionID,
 				'icon' => $icon
 			];
@@ -165,16 +163,15 @@ class SettingsPageController extends Controller {
 	 */
 	protected function getPanelsData($panels) {
 		$data = [];
-		foreach($panels as $panel) {
+		foreach ($panels as $panel) {
 			$template = $panel->getPanel();
-			if($template instanceof Template || $template instanceof TemplateResponse) {
+			if ($template instanceof Template || $template instanceof TemplateResponse) {
 				$data[] = [
-					'id' => get_class($panel),
+					'id' => \get_class($panel),
 					'content' => ($template instanceof Template) ? $template->fetchPage() : $template->render()
 				];
 			}
 		}
 		return $data;
 	}
-
 }
