@@ -2,7 +2,7 @@
 /**
  * @author Tom Needham <tom@owncloud.com>
  *
- * @copyright Copyright (c) 2017, ownCloud GmbH
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 namespace OC\Settings\Panels\Admin;
 
+use OC\Helper\LocaleHelper;
 use OC\Settings\Panels\Helper;
 use OCP\IConfig;
 use OCP\Settings\ISettings;
@@ -47,14 +48,49 @@ class FileSharing implements ISettings {
 	}
 
 	public function getPanel() {
+		$this->lfactory = \OC::$server->getL10NFactory();
+		$activeLangCode = $this->config->getAppValue(
+			'core',
+			'shareapi_public_notification_lang',
+			'owner'
+		);
+		$this->localeHelper = new LocaleHelper();
+		list($userLang, $commonLanguages, $languages) = $this->localeHelper->getNormalizedLanguages(
+			$this->lfactory,
+			$activeLangCode
+		);
+
+		// Allow reset to the defaults when mail notification is sent in the lang of owner
+		if ($userLang['code']  === "owner") {
+			$userLang['name'] = $this->l->t("Owner language");
+		} else {
+			\array_push(
+				$commonLanguages,
+				[
+					'code' => 'owner',
+					'name' => $this->l->t("Owner language")
+				]
+			);
+		}
+
+		$selector = new Template('settings', 'language');
+		$selector->assign('selectName', 'shareapi_public_notification_lang');
+		$selector->assign('selectId', 'shareapiPublicNotificationLang');
+		$selector->assign('activelanguage', $userLang);
+		$selector->assign('commonlanguages', $commonLanguages);
+		$selector->assign('languages', $languages);
+
 		$template = new Template('settings', 'panels/admin/filesharing');
 		$template->assign('allowResharing', $this->config->getAppValue('core', 'shareapi_allow_resharing', 'yes'));
 		$template->assign('shareAPIEnabled', $this->config->getAppValue('core', 'shareapi_enabled', 'yes'));
 		$template->assign('allowLinks', $this->config->getAppValue('core', 'shareapi_allow_links', 'yes'));
 		$template->assign('allowPublicUpload', $this->config->getAppValue('core', 'shareapi_allow_public_upload', 'yes'));
-		$template->assign('enforceLinkPassword', $this->helper->isPublicLinkPasswordRequired());
+		$template->assign('enforceLinkPasswordReadOnly', $this->config->getAppValue('core', 'shareapi_enforce_links_password_read_only', 'no'));
+		$template->assign('enforceLinkPasswordReadWrite', $this->config->getAppValue('core', 'shareapi_enforce_links_password_read_write', 'no'));
+		$template->assign('enforceLinkPasswordWriteOnly', $this->config->getAppValue('core', 'shareapi_enforce_links_password_write_only', 'no'));
 		$template->assign('shareDefaultExpireDateSet', $this->config->getAppValue('core', 'shareapi_default_expire_date', 'no'));
 		$template->assign('allowPublicMailNotification', $this->config->getAppValue('core', 'shareapi_allow_public_notification', 'no'));
+		$template->assign('publicMailNotificationLang', $selector->fetchPage());
 		$template->assign('allowSocialShare', $this->config->getAppValue('core', 'shareapi_allow_social_share', 'yes'));
 		$template->assign('allowGroupSharing', $this->config->getAppValue('core', 'shareapi_allow_group_sharing', 'yes'));
 		$template->assign('onlyShareWithGroupMembers', $this->helper->shareWithGroupMembersOnly());
@@ -65,10 +101,11 @@ class FileSharing implements ISettings {
 		$excludeGroups = $this->config->getAppValue('core', 'shareapi_exclude_groups', 'no') === 'yes' ? true : false;
 		$template->assign('shareExcludeGroups', $excludeGroups);
 		$excludedGroupsList = $this->config->getAppValue('core', 'shareapi_exclude_groups_list', '');
-		$excludedGroupsList = json_decode($excludedGroupsList);
-		$template->assign('shareExcludedGroupsList', !is_null($excludedGroupsList) ? implode('|', $excludedGroupsList) : '');
+		$excludedGroupsList = \json_decode($excludedGroupsList);
+		$template->assign('shareExcludedGroupsList', $excludedGroupsList !== null ? \implode('|', $excludedGroupsList) : '');
 		$template->assign('shareExpireAfterNDays', $this->config->getAppValue('core', 'shareapi_expire_after_n_days', '7'));
 		$template->assign('shareEnforceExpireDate', $this->config->getAppValue('core', 'shareapi_enforce_expire_date', 'no'));
+		$template->assign('autoAcceptShare', $this->config->getAppValue('core', 'shareapi_auto_accept_share', 'yes'));
 
 		$permList = [
 			[
@@ -101,5 +138,4 @@ class FileSharing implements ISettings {
 	public function getSectionID() {
 		return 'sharing';
 	}
-
 }
