@@ -212,6 +212,91 @@ OC.L10N.register(
     "change full name" : "промени пълното име",
     "set new password" : "сложи нова парола",
     "change email address" : "Смени адреса на елетронната поща",
-    "Default" : "По подразбиране"
+    "Default" : "По подразбиране",
+    "The new password can not be the same as the previous one" : "Новата парола не може да бъде същата като предишната",
+    "Change" : "Промени",
+    "Share" : "Споделяне",
+    "APCu" : "APCu",
+    "Official" : "Официално",
+    "Approved" : "Одобрено",
+    "The app will be downloaded from the app store" : "Приложението ще бъде изтеглено от магазина за приложения",
+    "App update" : "Актуализиране на приложението",
+    "Experimental" : "Експериментално",
+    "Migration in progress. Please wait until the migration is finished" : "Миграцията е в ход. Моля, изчакайте, докато мигрирането завърши",
+    "Disconnect" : "Прекъсване",
+    "User documentation" : "Потребителска документация",
+    "Administrator documentation" : "Документация за администратора",
+    "Online documentation" : "Онлайн документация",
+    "Commercial support" : "Търговска подкрепа",
+    "by %s" : "от %s",
+    "Admin documentation" : "Документация за администратора",
+    "Visit website" : "Посетете уебсайт",
+    "Server-side encryption" : "Криптиране от страна на сървъра",
+    "Enable server-side encryption" : "Включи криптиране от страна на сървъра",
+    "Start migration" : "Стартирайте мигрирането",
+    "Allow users to share file via social media" : "Позволете на потребителите да споделят файлове чрез социални медии",
+    "What to log" : "Какво да се записва",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "Имейл сървър",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Криптирането не гарантира сигурността на системата. Моля, вижте ownCloud документацията за повече информация, за това как функционира приложението за шифроване и за поддържаните случаи на използване.",
+    "System Status" : "Статус на системата",
+    "Tips & tricks" : "Съвети и трикове",
+    "Domain" : "Домейн",
+    "Add Domain" : "Добави домейн",
+    "Select from Files" : "Изберете от Файловете",
+    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 MB",
+    "Choose as profile picture" : "Избиране на профилна снимка",
+    "Change email" : "Промяна на имейла",
+    "Set email" : "Задайте имейл",
+    "You are using %s of %s" : "Вие използвате %s от %s",
+    "Sessions" : "Сесии",
+    "Browser" : "Браузър",
+    "Most recent activity" : "Последна активност",
+    "App passwords" : "Пароли за приложения",
+    "App name" : "Име на приложението",
+    "Create new app password" : "Създаване на нова парола за приложение",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Грешка: това приложение не може да бъде активирано, защото прави сървъра нестабилен",
+    "Error: could not disable broken app" : "Грешка: не може да се деактивира счупеното приложение",
+    "Error while disabling broken app" : "Грешка при деактивиране на счупено приложение",
+    "CORS" : "CORS",
+    "Apps Management" : "Управление на приложения",
+    "Show enabled apps" : "Показване на активираните приложения",
+    "Show disabled apps" : "Показване на изключените приложения",
+    "SSL Root Certificates" : "SSL root сертификати",
+    "Allow sharing with groups" : "Разрешаване на споделянето с групи",
+    "User ID" : "Потребителско ID",
+    "Email address" : "Имейл адрес",
+    "Picture provided by original account" : "Снимка, предоставена от оригиналния профил",
+    "For password recovery and notifications" : "За възстановяване на паролата и известия",
+    "You are using %s of %s (%s %%)" : "Вие използвате %s от %s (%s %%)",
+    "%s password changed successfully" : "%s паролата е сменена успешно",
+    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Официалните приложения се разработват от и в рамките на ownCloud общността. Те предлагат допълнителна функционалност на ownCloud и са готови за производствена употреба.",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Одобрените приложения се разработват от надеждни програмисти и преминават проверка за сигурност. Те се поддържат активно в хранилище с отворен код и техните поддържащи ги считат за стабилни при случайно до нормално използване.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Това приложение не е проверено за проблеми със сигурността, то е ново или е известно, че е нестабилно. Инсталирайте на свой собствен риск.",
+    "No apps found for {query}" : "Няма намерени приложения за {query}",
+    "Migration started …" : "Мигрирането започна ...",
+    "%s-licensed" : "%s-лицензирано",
+    "Be aware that encryption always increases the file size." : "Имайте предвид, че шифроването винаги увеличава размера на файла.",
+    "This is the final warning: Do you really want to enable encryption?" : "Това е последно предупреждение: Наистина ли искате да активирате шифроването?",
+    "Select default encryption module:" : "Изберете модул за шифроване по подразбиране:",
+    "Download logfile (%s)" : "Изтегляне на доклад (1%s)",
+    "No Domains." : "Няма домейни.",
+    "Are you sure you want to remove this domain?" : "Наистина ли искате да премахнете този домейн?",
+    "Add" : "Добави",
+    "You've linked these apps." : "Свързахте тези приложения.",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Паролата за приложение е парола, която дава на дадено приложение или устройство разрешение за достъп до вашия %s профил.",
+    "No panels for this section." : "Няма панели за този раздел.",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL използва неактуална %s версия (%s). Моля, актуализирайте операционната си система или функции, като %s няма да работят надеждно.",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Приложението е активирано, но трябва да бъде актуализирано. Ще бъдете пренасочени към страницата за актуализиране за 5 секунди.",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Възникна грешка. Моля, качете ASCII-кодиран PEM сертификат.",
+    "Empty app name is not allowed." : "Не е разрешено името на приложението да е празно.",
+    "Failed to change the email address." : "Промяната на имейл адреса не бе успешна.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Винаги е добре да създавате редовни резервни копия на данните си, в случай на криптиране не забравяйте да архивирате криптиращите ключове заедно с вашите данни.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Разреши автоматичното попълване на потребителското име в диалоговия прозорец за споделяне. Ако това е забранено, ще трябва ръчно да се въвежда пълното потребителско име.",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Конфигурационният файл е с права само за четене. Моля, коригирайте настройката си, като ръчно редактирате конфигурационния файл.",
+    "All checks passed." : "Всички проверки са преминати.",
+    "Use the credentials below to configure your app or device." : "Използвайте данните по-долу, за да конфигурирате приложението или устройството си.",
+    "Email has been changed successfully." : "Имейлът е променен успешно."
 },
 "nplurals=2; plural=(n != 1);");
