@@ -335,6 +335,21 @@ OC.L10N.register(
     "change full name" : "změnit celé jméno",
     "set new password" : "nastavit nové heslo",
     "change email address" : "změnit emailovou adresu",
-    "Default" : "Výchozí"
+    "Default" : "Výchozí",
+    "Change" : "Změnit",
+    "Share" : "Sdílet",
+    "White-listed Domains" : "Seznam povolených domén",
+    "Domain" : "Doména",
+    "Add Domain" : "Přidat doménu",
+    "Email address" : "Emailová adresa",
+    "Invalid email address" : "Chybná emailová adresa",
+    "Restrict enumeration to group members" : "Omezení výčtu na členy skupiny",
+    "Extra field to display in autocomplete results" : "Zobrazit další pole pro automatické dokončování",
+    "No Domains." : "Bez domén.",
+    "Are you sure you want to remove this domain?" : "Chcete odstranit tuto doménu?",
+    "Add" : "Přidat",
+    "Empty app name is not allowed." : "Prázdné jméno aplikace není dovoleno.",
+    "Email changed successfully for {user}." : "Email pro {user} byl změněn.",
+    "You are not a member of any groups." : "Nejste členem žádné skupiny."
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
