@@ -305,6 +305,24 @@ OC.L10N.register(
     "change full name" : "ændre fulde navn",
     "set new password" : "skift kodeord",
     "change email address" : "skift e-mailadresse",
-    "Default" : "Standard"
+    "Default" : "Standard",
+    "Change email" : "Skift email",
+    "Share" : "Del",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "installation og opdatering af apps via app-butikken eller Federated Cloud Cloud deling",
+    "System Status" : "Systemstatus",
+    "Domain" : "Domæne",
+    "Add" : "Tilføj",
+    "Set email" : "Indstil email",
+    "You are using %s of %s" : "Du bruger %s af %s",
+    "Apps Management" : "Apphåndtering",
+    "Show enabled apps" : "Vis aktiverede apps",
+    "Show disabled apps" : "Vis deaktiverede aps",
+    "Restrict enumeration to group members" : "Begræns nummereringen til gruppemedlemmer",
+    "You are using %s of %s (%s %%)" : "Du bruger %s af %s (%s %%)",
+    "%s password changed successfully" : "App %s succesfuldt opdateret",
+    "No panels for this section." : "Intet panel for denne sektion.",
+    "Failed to change the email address." : "Fejlede i at ændre emailadressen.",
+    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Vi anbefaler at aktivere stystem-cron eftersom andre cron-metoder muligvis kan påvirke performance og pålidelighed.",
+    "Email has been changed successfully." : "Email er succesfuldt blevet opdateret."
 },
 "nplurals=2; plural=(n != 1);");
