@@ -336,6 +336,45 @@ OC.L10N.register(
     "change full name" : "Vollständigen Namen ändern",
     "set new password" : "Neues Passwort setzen",
     "change email address" : "E-Mail-Adresse ändern",
-    "Default" : "Standard"
+    "Default" : "Standard",
+    "Change" : "Ändern",
+    "Share" : "Teilen",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
+    "White-listed Domains" : "Weiße Liste der Domains",
+    "Add Domain" : "Domain hinzufügen",
+    "Empty app name is not allowed." : "Ein leerer App-Name ist nicht erlaubt.",
+    "CORS" : "KERNE",
+    "User ID" : "Benutzer-ID",
+    "Email address" : "E-Mail-Adresse",
+    "Invalid email address" : "Ungültige E-Mail-Adresse",
+    "Extra field to display in autocomplete results" : "Separates Feld zur Anzeige des Autovervollständigen-Ergebnisses",
+    "Restrict users to only share with groups they are member of" : "Benutzer auf das Teilen innerhalb der Gruppen, deren Mitglied sie sind, beschränken",
+    "Default user and group share permissions" : "Nutzer und Gruppen Standard-Berechtigungen für das Teilen",
+    "Enforce password protection for read-only links" : "Passwort-Schutz für \"nur lesen\" Links durchsetzen",
+    "Enforce password protection for read & write links" : "Passwort-Schutz für lesbare und schreibbare Links durchsetzen.",
+    "Enforce password protection for upload-only (File Drop) links" : "Passwort-Schutz für \"nur hochladen\" Links/Dateien durchsetzen.",
+    "No Domains." : "Keine Domains.",
+    "Are you sure you want to remove this domain?" : "Sind Sie sicher, dass Sie diese Domain entfernen möchten?",
+    "Add" : "Hinzufügen",
+    "Domain" : "Domain",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Die Konfigurationsdatei ist schreibgeschützt. Bitte passen Sie Ihre Einstellungen durch manuelle Bearbeitung der Konfigurationsdatei selbst an.",
+    "Email changed successfully for {user}." : "E-Mail erfolgreich für {user} geändert.",
+    "You are not a member of any groups." : "Du bist kein Mitglied einer Gruppe.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "In einem gruppierten Umgebung stellen Sie bitte sicher, dass die config.php-Datei über alle Knoten synchronisiert wird.",
+    "You are using %s" : "Sie verwenden %s",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Diese Web-, Desktop- und Mobil-Clients sind aktuell an 1%s angemeldet",
+    "Automatically accept new incoming local user shares" : "Erhaltene lokale Benutzerfreigaben automatisch akzeptieren",
+    "Legal" : "Rechtliches",
+    "Imprint URL:" : "Impressum-URL:",
+    "Imprint URL" : "Impressum-URL",
+    "Privacy Policy URL:" : "Datenschutz-URL:",
+    "Privacy Policy URL" : "Datenschutz-URL",
+    "App passwords / tokens" : "App-Passwörter / Token",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "App-Passwörter oder Token sind passcodes, die einer App oder einem Gerät Zugriff auf Ihr %s-Konto geben.",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Benutzen Sie diese als Sicherheitsmaßnahme, um Ihr richtiges Passwort nur für den Webzugriff zu verwenden.",
+    "Create new app passcode" : "Neuen App-Passcode erstellen",
+    "Password / Token" : "Passwort / Token",
+    "Owner language" : "Sprache des Eigentümers",
+    "Language used for public mail notifications for shared files" : "Sprache, die für öffentliche Mail-Benachrichtigungen für geteilte Daten benutzt wird "
 },
 "nplurals=2; plural=(n != 1);");
