@@ -336,6 +336,47 @@ OC.L10N.register(
     "change full name" : "cambiar el nombre completo",
     "set new password" : "establecer nueva contraseña",
     "change email address" : "cambiar dirección de correo electrónico",
-    "Default" : "Predeterminado"
+    "Default" : "Predeterminado",
+    "Change" : "Cambiar",
+    "Share" : "Compartir",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "instalando y actualizando aplicaciones por medio de: Market o Nube compartida Federada",
+    "White-listed Domains" : "Dominios en la lista Blanca",
+    "Domain" : "Dominio",
+    "Add Domain" : "Añadir Dominio",
+    "CORS" : "CORS",
+    "User ID" : "ID de usuario",
+    "Email address" : "Dirección de correo electrónico",
+    "Invalid email address" : "Dirección de correo no válida",
+    "Extra field to display in autocomplete results" : "Campo adicional para mostrar en los resultados de autocompletar",
+    "Restrict users to only share with groups they are member of" : "Restrinja a los usuarios compartir sólo con grupos de los que son miembros",
+    "Default user and group share permissions" : "Permisos por defecto de usuarios y grupo",
+    "Enforce password protection for read-only links" : "Refuerza la protección de enlaces de solo-lectura con contraseña.",
+    "Enforce password protection for read & write links" : "Refuerza la protección de enlaces de lectura-escritura con contraseña.",
+    "Enforce password protection for upload-only (File Drop) links" : "Refuerza la protección de enlaces de solo subida (File Drop) con contraseña.",
+    "You are using %s" : "Estas usando %s",
+    "No Domains." : "Sin ominio",
+    "Are you sure you want to remove this domain?" : "¿Está seguro de que desea eliminar este dominio?",
+    "Add" : "Añadir",
+    "Empty app name is not allowed." : "No esta permitido un nombre de app en blanco",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "El archivo de configuración es de \"solo lectura\". Por favor ajuste su configuración para poder editar el archivo de configuración manualmente.",
+    "Email changed successfully for {user}." : "Este correo electrónico ha sido cambiado exitosamente por  {user}.",
+    "You are not a member of any groups." : "Tú no eres miembro de ningún grupo.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "En una configuración de cluster, asegurese de que el archivo config.php está sincronizado y es identico en todos los nodos.",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Estos son los clientes mobiles, web y de escritorio , actualmente logados: %s.",
+    "Automatically accept new incoming local user shares" : "Aceptar automáticamente nuevos compartidos de los usuarios locales.",
+    "Legal" : "Legal",
+    "Imprint URL:" : "Imprint URL:",
+    "Imprint URL" : "Imprint URL",
+    "Privacy Policy URL:" : "Privacy Policy URL:",
+    "Privacy Policy URL" : "Privacy Policy URL",
+    "App passwords / tokens" : "Contraseña de App / tokens",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "La contraseña de app o los tokens son contraseñas que permiten a la app o al dispositivo acceder a tu cuenta %s .",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Úselos como medida de seguridad para ocultar su contraseña actual, que debe ser usada unicamente para logarse en la interfaz Web.",
+    "Create new app passcode" : "Crear una contraseña de app nueva",
+    "Password / Token" : "Contraseña / Token",
+    "Owner language" : "Idioma del propietario",
+    "Language used for public mail notifications for shared files" : "Idioma usado para notificaciones por correo públicas para los archivos compartidos",
+    "Wrong current password" : "Contraseña actual equivocada",
+    "The new password cannot be the same as the previous one" : "La contraseña nueva no puede ser igual a la anterior"
 },
 "nplurals=2; plural=(n != 1);");
