@@ -295,6 +295,11 @@ OC.L10N.register(
     "change full name" : "muuta koko nimi",
     "set new password" : "aseta uusi salasana",
     "change email address" : "vaihda sähköpostiosoite",
-    "Default" : "Oletus"
+    "Default" : "Oletus",
+    "Change" : "Muuta",
+    "Share" : "Jaa",
+    "Add" : "Lisää",
+    "%s password changed successfully" : "%s salasana vaihdettiin onnistuneesti",
+    "Email has been changed successfully." : "Sähköpostiosoite vaihdettiin onnistuneesti."
 },
 "nplurals=2; plural=(n != 1);");
