@@ -316,6 +316,37 @@ OC.L10N.register(
     "change full name" : "Modifier le nom complet",
     "set new password" : "Changer le mot de passe",
     "change email address" : "changer l'adresse e-mail",
-    "Default" : "Défaut"
+    "Default" : "Défaut",
+    "Change" : "Modification",
+    "Share" : "Partager",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "installation et mise à jour des applications via le marché ou le Cloud Fédéré Partagé",
+    "Invalid email address" : "Adresse mail invalide",
+    "System Status" : "Statut du système",
+    "White-listed Domains" : "Liste blanche de domaines",
+    "Domain" : "Domaine",
+    "Add Domain" : "Ajouter un domaine",
+    "Change email" : "Changer l'adresse de courriel",
+    "Set email" : "Définir le courriel",
+    "You are using %s of %s" : "Vous utilisez %s sur %s",
+    "CORS" : "Partage de ressources d'origines croisées",
+    "Apps Management" : "Gestion des applications",
+    "Show enabled apps" : "Montrer les applications activées",
+    "Show disabled apps" : "Monter les applications désactivées",
+    "User ID" : "ID utilisateur",
+    "Email address" : "Adresse mail",
+    "Restrict enumeration to group members" : "Restreindre l'énumération aux membres du groupe",
+    "Restrict users to only share with groups they are member of" : "N'autoriser les utilisateurs qu'à partager avec les groupes dont ils sont membre",
+    "Default user and group share permissions" : "Autorisations par défaut de partage de groupe et d'utilisateur",
+    "You are using %s of %s (%s %%)" : "Vous utilisez %s sur %s (%s %%)",
+    "No Domains." : "Pas de domaines.",
+    "Are you sure you want to remove this domain?" : "Êtes-vous sûr de vouloir supprimer ce domaine ?",
+    "Add" : "Ajouter",
+    "No panels for this section." : "Pas de panneau dans cette section",
+    "Empty app name is not allowed." : "Un nom d'application vide n'est pas autorisé.",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Le fichier de configuration est en lecture seule. Veuillez ajuster votre configuration en éditant manuellement le fichier.",
+    "Email changed successfully for {user}." : "L'Email de {utilisateur} à été mis à jour.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Dans une configuration de grappe, assurez-vous de synchroniser le fichier config.php sur chaque nœud.",
+    "You are not a member of any groups." : "Vous n'êtes membre d'aucun groupe.",
+    "You are using %s" : "Vous utilisez %s"
 },
 "nplurals=2; plural=(n > 1);");
