@@ -336,6 +336,27 @@ OC.L10N.register(
     "change full name" : "שינוי שם מלא",
     "set new password" : "הגדרת סיסמא חדשה",
     "change email address" : "שינוי כתובת דואר אלקטרוני",
-    "Default" : "ברירת מחדל"
+    "Default" : "ברירת מחדל",
+    "Change" : "שינוי",
+    "Share" : "שיתוף",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "התקנה ועדכון יישומים באמצעות החנות או שיתוף ענן מאוגד",
+    "White-listed Domains" : "רשימת שמות מתחם בטוחים",
+    "Domain" : "שם תחום",
+    "Add Domain" : "הוספת שם מתחם",
+    "CORS" : "CORS",
+    "User ID" : "מזהה משתמש",
+    "Email address" : "כתובת דוא״ל",
+    "Invalid email address" : "כתובת דוא״ל שגויה",
+    "Extra field to display in autocomplete results" : "שדה נוסף להצגה בתוצאות ההשלמה האוטומטית.",
+    "Restrict users to only share with groups they are member of" : "הגבלת משתמשים לשתף רק עם קבוצות שהם חברים בהן",
+    "Default user and group share permissions" : "משתמש ברירת מחדל וקבוצה משתפים הרשאות",
+    "No Domains." : "אין שמות מתחם.",
+    "Are you sure you want to remove this domain?" : "האם באמת להסיר שם מתחם זה?",
+    "Add" : "הוספה",
+    "Empty app name is not allowed." : "אסור להשתמש בשם ריק ליישום",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "קובץ ה- config הנו לקריאה בלבד. יש להסדיר את ההתקנה על ידי עריכת קובץ ה- config באופן ידני.",
+    "Email changed successfully for {user}." : "כתובת הדוא״ל של {user} הוחלפה בהצלחה.",
+    "You are not a member of any groups." : "אין לך חברות באף קבוצה שהיא.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "בהתקנת clustered יש לוודא סנכרון קובץ config.php בין כל הנקודות."
 },
 "nplurals=2; plural=(n != 1);");
