@@ -7,6 +7,9 @@ OC.L10N.register(
     "New password" : "नया पासवर्ड",
     "Username" : "प्रयोक्ता का नाम",
     "Personal" : "यक्तिगत",
-    "Error" : "त्रुटि"
+    "Error" : "त्रुटि",
+    "Delete" : "हटाना",
+    "Share" : "साझा करें",
+    "Add" : "डाले"
 },
 "nplurals=2; plural=(n != 1);");
