@@ -315,6 +315,38 @@ OC.L10N.register(
     "change full name" : "modica nome completo",
     "set new password" : "imposta una nuova password",
     "change email address" : "cambia l'indirizzo email",
-    "Default" : "Predefinito"
+    "Default" : "Predefinito",
+    "Change" : "Cambia",
+    "Share" : "Condividi",
+    "Domain" : "Dominio",
+    "Add" : "Aggiungi",
+    "Change email" : "Cambia email",
+    "Set email" : "Imposta email",
+    "Invalid email address" : "Indirizzo email non valido",
+    "No panels for this section." : "Nessun pannello per questa sezione.",
+    "Email has been changed successfully." : "email cambiata con successo",
+    "No Domains." : "Nessun dominio.",
+    "Are you sure you want to remove this domain?" : "Sei sicuro di voler rimuovere questo dominio ?",
+    "Empty app name is not allowed." : "Nome ssente della app non consentito.",
+    "CORS" : "CORS",
+    "Failed to change the email address." : "Errore nel cambiare indirizzo email",
+    "User ID" : "ID Utente",
+    "Email address" : "Indirizzo email",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Il file di configurazione è di sola lettura. Controlla al configurazione editando il file manualmente",
+    "Add Domain" : "Aggiungi un dominio",
+    "Email changed successfully for {user}." : "Email cambiata con successo per utente {user}.",
+    "Restrict enumeration to group members" : "Restringi l'enumerazione ai membri del gruppo",
+    "Extra field to display in autocomplete results" : "Campo extra da mostrare in risultati di autocompletamento",
+    "White-listed Domains" : "Domini consentiti",
+    "You are not a member of any groups." : "Non sei membro di nesssuno dei gruppi",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "Installare o aggiornare apps via market o Federated Cloud Sharing",
+    "Enforce password protection for read-only links" : "Attivare la protezione con password per link a sola lettura",
+    "Enforce password protection for read & write links" : "Attivare la protezione con password per link di lettura e scrittura",
+    "Enforce password protection for upload-only (File Drop) links" : "Attivare la protezione con password solo per link di upload (file drop)",
+    "Restrict users to only share with groups they are member of" : "Limita gli utenti a condividere solo con gruppi di cui sono membri",
+    "Default user and group share permissions" : "Permessi normali per condivisioni utenti e gruppi",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "In una configurazione a cluser, assicurarsi di sincronizzare il file config.php tra tutti i nodi.",
+    "You are using %s" : "Sta usando %s",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Questi sono gli accessi web, da desktop e da mobile connessi attualmente al tuo %s."
 },
 "nplurals=2; plural=(n != 1);");
