@@ -15,6 +15,8 @@ OC.L10N.register(
     "Name" : "ناو",
     "Username" : "ناوی به‌کارهێنه‌ر",
     "Admin" : "به‌ڕێوه‌به‌ری سه‌ره‌كی",
-    "Error" : "هه‌ڵه"
+    "Error" : "هه‌ڵه",
+    "Share" : "هاوبەشی کردن",
+    "Add" : "زیادکردن"
 },
 "nplurals=2; plural=(n != 1);");
