@@ -149,6 +149,10 @@ OC.L10N.register(
     "Full Name" : "Pilns vārds",
     "Quota" : "Apjoms",
     "set new password" : "iestatīt jaunu paroli",
-    "Default" : "Noklusējuma"
+    "Default" : "Noklusējuma",
+    "Share" : "Dalīties",
+    "Add" : "Pievienot",
+    "%s password changed successfully" : "%s parole veiksmīgi nomainīta",
+    "Couldn't send reset email. Please contact your administrator." : "Neizdevās nosūt paroles maiņas e-pasta ziņojumu. Lūdzu sazinieties ar sistēmas administratoru."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
