@@ -335,6 +335,46 @@ OC.L10N.register(
     "change full name" : "endre fullt navn",
     "set new password" : "sett nytt passord",
     "change email address" : "endre e-postadresse",
-    "Default" : "Standard"
+    "Default" : "Standard",
+    "Change" : "Endre",
+    "Share" : "Delt ressurs",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "installering og oppdatering av apper via markedet eller ved deling i Forent sky",
+    "White-listed Domains" : "Hvitelistede domener",
+    "Domain" : "Domene",
+    "Add Domain" : "Legg til domene",
+    "CORS" : "CORS",
+    "User ID" : "User ID",
+    "Email address" : "E-postadresse",
+    "Invalid email address" : "Ugyldig e-postadresse",
+    "Restrict enumeration to group members" : "Begrens opplisting til gruppemedlemmer",
+    "Extra field to display in autocomplete results" : "Ekstra felt som skal vises i autofullføringsresultater",
+    "Restrict users to only share with groups they are member of" : "Begrens brukerne til å bare dele med grupper de er medlem av",
+    "Default user and group share permissions" : "Standard rettigheter ved deling med brukere og grupper",
+    "Enforce password protection for read-only links" : "Krev passordbeskyttelse for skrivebeskyttede linker",
+    "Enforce password protection for read & write links" : "Krev passordbeskyttelse for les og skriv linker",
+    "Enforce password protection for upload-only (File Drop) links" : "Krev passordbeskyttelse for bare opplasting (File Drop) linker",
+    "You are using %s" : "Du bruker %s ",
+    "No Domains." : "Ingen domener",
+    "Are you sure you want to remove this domain?" : "Er du sikker på at du vil fjerne dette domenet?",
+    "Add" : "Legg til",
+    "Empty app name is not allowed." : "Tomt appnavn er ikke tillatt.",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Konfigureringsfilen er skrivebeskyttet. Korriger oppsettet ved å redigere filen manuelt.",
+    "Email changed successfully for {user}." : "E-post ble endret for {user}.",
+    "You are not a member of any groups." : "Du er ikke medlem av noen grupper.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "I et klyngeoppsett må config.php synkroniseress til alle noder.",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Dette er web-, desktop- og mobilklienter som for øyeblikket er logget på din %s,",
+    "Automatically accept new incoming local user shares" : "Godta nye innkommende lokale brukerdelinger automatisk",
+    "Legal" : "Juridisk informasjon",
+    "Privacy Policy URL:" : "Personverns Regler URL:",
+    "Privacy Policy URL" : "Personverns Regler URL",
+    "App passwords / tokens" : "App-passord / tokens",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Et app-passord eller token er et passordfrase som gir en app eller en enhet lov til å bruke %s-kontoen din.",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Bruk dem som et sikkerhetstiltak for å skjule ditt faktiske passord som du kanskje bare vil bruke til webgrensesnittinnlogging.",
+    "Create new app passcode" : "Lag nytt app-passord",
+    "Password / Token" : "Password / Token",
+    "Owner language" : "Eierspråk",
+    "Language used for public mail notifications for shared files" : "Språk som brukes til offentlig postvarsling for delte filer",
+    "Wrong current password" : "Feil nåværende passord",
+    "The new password cannot be the same as the previous one" : "Det nye passordet kan ikke være det samme som det forrige"
 },
 "nplurals=2; plural=(n != 1);");
