@@ -336,6 +336,47 @@ OC.L10N.register(
     "change full name" : "alterar nome completo",
     "set new password" : "definir nova senha",
     "change email address" : "Trocar o endereço de email",
-    "Default" : "Padrão"
+    "Default" : "Padrão",
+    "Change" : "Substituir ",
+    "Share" : "Compartilhar",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "Instalando e atualizando aplicativos através do mercado ou Compartilhamento de Nuvem Federada",
+    "White-listed Domains" : "Lista-Branca de Domínios",
+    "Domain" : "Domínio",
+    "Add Domain" : "Adicionar Domínio",
+    "CORS" : "CORS",
+    "User ID" : "ID do usuário",
+    "Email address" : "Endereço de e-mail",
+    "Invalid email address" : "Endereço de email inválido",
+    "Extra field to display in autocomplete results" : "Campo extra para exibir em resultados de preenchimento automático",
+    "Restrict users to only share with groups they are member of" : "Restrinja os usuários para compartilhar somente com grupos de que são membros",
+    "Default user and group share permissions" : "Permissões padrão para usuários e grupos",
+    "Enforce password protection for read-only links" : "Aplicar proteção de senha para links somente de leitura",
+    "Enforce password protection for read & write links" : "Aplicar proteção de senha para links de leitura e gravação",
+    "Enforce password protection for upload-only (File Drop) links" : "Aplicar proteção de senha para links de upload-only (Baixar Arquivo)",
+    "You are using %s" : "Você está usando %s",
+    "No Domains." : "Sem Domínios.",
+    "Are you sure you want to remove this domain?" : "Tem certeza de que deseja remover esse domínio?",
+    "Add" : "Adicionar",
+    "Empty app name is not allowed." : "O nome do aplicativo vazio não é permitido.",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "O arquivo de configuração é somente leitura. Ajuste sua configuração editando o arquivo de configuração manualmente.",
+    "Email changed successfully for {user}." : "E-mail alterado com sucesso para {user}.",
+    "You are not a member of any groups." : "Você não é membro de nenhum grupo.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Em uma configuração em cluster, certifique-se de sincronizar o arquivo config.php em todos os nós.",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Estes são os clientes Web com dispositivos móveis e desktop, atualmente conectados ao seu %s.",
+    "Automatically accept new incoming local user shares" : "Aceitar automaticamente novos compartilhamentos recebidos de usuários locais",
+    "Legal" : "Legal",
+    "Imprint URL:" : "URL para impressão:",
+    "Imprint URL" : "URL de impressão:",
+    "Privacy Policy URL:" : "Política de Privacidade para URL:",
+    "Privacy Policy URL" : "Política de Privacidade para URL:",
+    "App passwords / tokens" : "Senhas/tokens de aplicativo",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Senhas de aplicativos ou tokens são códigos de acesso que fornecem permissões de aplicativo ou dispositivo para acessar sua %s conta.",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Use-os como uma medida de segurança para ocultar sua senha real, que você pode usar somente para o login da interface da web.",
+    "Create new app passcode" : "Criar nova senha do aplicativo",
+    "Password / Token" : "Senha/Token",
+    "Owner language" : "Idioma do proprietário",
+    "Language used for public mail notifications for shared files" : "Idioma usado para notificações de correio público para arquivos compartilhados",
+    "Wrong current password" : "Senha atual incorreta",
+    "The new password cannot be the same as the previous one" : "A nova senha não pode ser a mesma que a anterior"
 },
 "nplurals=2; plural=(n > 1);");
