@@ -209,6 +209,34 @@ OC.L10N.register(
     "change full name" : "schimbă numele complet",
     "set new password" : "setează parolă nouă",
     "change email address" : "schimbă adresa email",
-    "Default" : "Implicită"
+    "Default" : "Implicită",
+    "The new password can not be the same as the previous one" : "Noua parolă nu poate fi aceeași ca cea precedentă",
+    "Change email" : "Schimbă adresa email",
+    "Share" : "Partajează",
+    "APCu" : "APCu",
+    "Visit website" : "Vizitează website",
+    "Allow users to share file via social media" : "Permite utilizatorilor să partajeze fișier via rețele sociale",
+    "Plain" : "Simplu",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "System Status" : "Stare Sistem",
+    "Domain" : "Domeniu",
+    "Add" : "Adaugă",
+    "Select from Files" : "Alege din Fișiere",
+    "Choose as profile picture" : "Alege ca și imagine de profil",
+    "App name" : "Nume aplicație",
+    "Done" : "Gata",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Eroare: această aplicație nu poate fi activată, deoarece face serverul instabil",
+    "Apps Management" : "Administrarea aplicațiilor",
+    "Show enabled apps" : "Arată aplicații activate",
+    "Show disabled apps" : "Arată aplicații dezactivate",
+    "Performance tuning" : "Tuning de performanță",
+    "Improving the config.php" : "Îmbunătățirea config.php",
+    "%s password changed successfully" : "parola %s a fost schimbată cu succes",
+    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplicațiile oficiale sunt dezvoltate de și în cadrul comunității ownCloud. Acestea oferă funcționalitate centrală pentru ownCloud și sunt gata pentru utilizare în producție.",
+    "Download logfile (%s)" : "Descarcă fișierul cu loguri (%s)",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "A intervenit o eroare. Te rugăm încarcă un certificat PEM codat ASCII",
+    "Failed to change the email address." : "Schimbarea adresei de e-mail a eșuat.",
+    "Email has been changed successfully." : "Adresa email a fost schimbată cu succes."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
