@@ -336,6 +336,47 @@ OC.L10N.register(
     "change full name" : "изменить полное имя",
     "set new password" : "установить новый пароль",
     "change email address" : "изменить адрес почты",
-    "Default" : "По умолчанию"
+    "Default" : "По умолчанию",
+    "Change" : "Изменения",
+    "Share" : "Общий доступ",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "установка и обновление приложений через маркет или Объединение облачных хранилищ",
+    "White-listed Domains" : "Белый список доменов",
+    "Domain" : "Домен",
+    "Add Domain" : "Добавить домен",
+    "CORS" : "CORS",
+    "User ID" : "Логин пользователя",
+    "Email address" : "Адрес почты",
+    "Invalid email address" : "Недопустимый адрес почты",
+    "Extra field to display in autocomplete results" : "Дополнительное поле, показываемое в результатах автодополнения",
+    "Restrict users to only share with groups they are member of" : "Ограничить возможность предоставления доступа только теми группами, членом которых является пользователь",
+    "Default user and group share permissions" : "Разрешения общего доступа для пользователей и групп по умолчанию",
+    "Enforce password protection for read-only links" : "Принудительная защита паролем для ссылок только для чтения",
+    "Enforce password protection for read & write links" : "Принудительная защита паролем для ссылок для чтения и записи",
+    "Enforce password protection for upload-only (File Drop) links" : "Принудительная защита паролем для ссылок только для записи (отправка файлов)",
+    "You are using %s" : "Вы используете %s",
+    "No Domains." : "Доменов нет.",
+    "Are you sure you want to remove this domain?" : "Вы действительно хотите удалить этот домен?",
+    "Add" : "Добавить",
+    "Empty app name is not allowed." : "Пустое имя приложения недопустимо.",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Файл конфигурации доступен только для чтения. Пожалуйста поправьте настройки путём редактирования файла конфигурации вручную.",
+    "Email changed successfully for {user}." : "Почта для  {user} изменена успешно.",
+    "You are not a member of any groups." : "Вы не состоите в каких-либо группах.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "В кластерной конфигурации пожалуйста убедитесь, что файл config.php синхронизирован во всех узлах.",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Список клиентов, подключённых сейчас к вашему %s через веб, настольный или мобильный клиент.",
+    "Automatically accept new incoming local user shares" : "Автоматически принимать новые входящие предоставления доступа от локальных пользователей",
+    "Legal" : "Правовые сведения",
+    "Imprint URL:" : "Адрес выходных данных:",
+    "Imprint URL" : "Адрес выходных данных",
+    "Privacy Policy URL:" : "Адрес политики конфиденциальности:",
+    "Privacy Policy URL" : "Адрес политики конфиденциальности",
+    "App passwords / tokens" : "Пароли и токены приложений",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Пароли и токены приложений — это коды доступа, которые дают разрешение приложению или устройству на доступ к вашей учётной записи %s.",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Используйте их как меру безопасности, чтобы скрыть ваш основной пароль, который вы вероятно захотите использовать только для входа в веб-интерфейс.",
+    "Create new app passcode" : "Создать новый код доступа для приложения",
+    "Password / Token" : "Пароль / Токен",
+    "Owner language" : "Язык владельца",
+    "Language used for public mail notifications for shared files" : "Язык, используемый для рассылок почтовых уведомлений по поводу файлов в совместном доступе",
+    "Wrong current password" : "Старый пароль неверен",
+    "The new password cannot be the same as the previous one" : "Новый пароль не совпадать с предыдущим"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
