@@ -325,6 +325,9 @@ OC.L10N.register(
     "change full name" : "Spremeni polno ime",
     "set new password" : "nastavi novo geslo",
     "change email address" : "spremeni naslov elektronske pošte",
-    "Default" : "Privzeto"
+    "Default" : "Privzeto",
+    "Share" : "Souporaba",
+    "Domain" : "Domena",
+    "Add" : "Dodaj"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
