@@ -336,6 +336,47 @@ OC.L10N.register(
     "change full name" : "ndryshoni emrin e plotë",
     "set new password" : "caktoni fjalëkalim të ri",
     "change email address" : "ndryshoni adresën email",
-    "Default" : "Parazgjedhje"
+    "Default" : "Parazgjedhje",
+    "Change" : "Ndryshoje",
+    "Share" : "Ndaje",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "instalim dhe përditësim aplikacionesh përmes tregut ose Federated Cloud Sharing",
+    "White-listed Domains" : "Përkatësi të Lejuara",
+    "Domain" : "Përkatësi",
+    "Add Domain" : "Shtoni Përkatësi",
+    "CORS" : "CORS",
+    "User ID" : "ID përdoruesi",
+    "Email address" : "Adresë email",
+    "Invalid email address" : "Adresë email e pavlefshme",
+    "Extra field to display in autocomplete results" : "Fushë ekstra për shfaqje në përfundime vetëplotësimesh",
+    "Restrict users to only share with groups they are member of" : "Kufizoji përdoruesit të ndajnë vetëm me grupe anëtarë të të cilëve janë",
+    "Default user and group share permissions" : "Leje parazgjedhje për ndarje nga përdorues dhe grupe",
+    "Enforce password protection for read-only links" : "Zbato me detyrim mbrojtje përmes fjalëkalimi për lidhje të llojit vetëm-lexim",
+    "Enforce password protection for read & write links" : "Zbato me detyrim mbrojtje përmes fjalëkalimi për lidhje të llojit lexim & shkrim",
+    "Enforce password protection for upload-only (File Drop) links" : "Zbato me detyrim mbrojtje përmes fjalëkalimi për lidhje të llojit vetëm-ngarkim (File Drop)",
+    "You are using %s" : "Po përdorni %s",
+    "No Domains." : "S’ka Përkatësi.",
+    "Are you sure you want to remove this domain?" : "Jeni i sigurt se doni të hiqet kjo përkatësi?",
+    "Add" : "Shtoni",
+    "Empty app name is not allowed." : "Nuk lejohet emër hapësire i zbrazët.",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "Kartela e formësimit është vetëm e lexueshme. Ju lutemi, përpunojeni rregullimin tuaj duke e përpunuar dorazi e formësimit.",
+    "Email changed successfully for {user}." : "Email-i për {user} u ndryshua me sukses.",
+    "You are not a member of any groups." : "S’jeni anëtar i ndonjë grupi.",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Në një sistem cluster sigurohuni të njëkohësoni kartelën config.php në krejt nyjet.",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "Këta janë klientët web, desktop dhe celular të futur te %s juaj këtë çast.",
+    "Automatically accept new incoming local user shares" : "Prano vetvetiu ndarje të reja që vijnë nga përdorues vendorë",
+    "Legal" : "Ligjore",
+    "Imprint URL:" : "URL Imprint-i:",
+    "Imprint URL" : "URL Imprint-i",
+    "Privacy Policy URL:" : "URL Rregullash Privatësie:",
+    "Privacy Policy URL" : "URL Rregullash Privatësie",
+    "App passwords / tokens" : "Fjalëkalime / token aplikacioni",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Fjalëkalimet ose token-ët e aplikacionit janë frazëkalime që i japin leje një aplikacioni ose pajisjeje të hyjë në llogarinë tuaj %s.",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Përdorini ato si një masë sigurie për të fshehur fjalëkalimin tuaj faktik, të cilin mund të doni ta përdorni vetëm për hyrje në ndërfaqen web.",
+    "Create new app passcode" : "Krijo fjalëkalim të ri aplikacioni",
+    "Password / Token" : "Fjalëkalim / Token",
+    "Owner language" : "Gjuha e të zotit",
+    "Language used for public mail notifications for shared files" : "Gjuhë e përdorur për njoftime publike me email për kartela të ndara me të tjerët",
+    "Wrong current password" : "Fjalëkalim i tanishëm i gabuar",
+    "The new password cannot be the same as the previous one" : "Fjalëkalimi i ri s’mund të jetë i njëjtë me atë të mëparshmin"
 },
 "nplurals=2; plural=(n != 1);");
