@@ -336,6 +336,47 @@ OC.L10N.register(
     "change full name" : "เปลี่ยนชื่อเต็ม",
     "set new password" : "ตั้งค่ารหัสผ่านใหม่",
     "change email address" : "เปลี่ยนแปลงที่อยู่อีเมล",
-    "Default" : "ค่าเริ่มต้น"
+    "Default" : "ค่าเริ่มต้น",
+    "Change" : "เปลี่ยนแปลง",
+    "Share" : "แชร์",
+    "installing and updating apps via the market or Federated Cloud Sharing" : "กำลังติดตั้งและอัพเดทแอพผ่านตลาดหรือคลาวด์ของสหพันธ์ที่แชร์อยู่",
+    "White-listed Domains" : "รายการโดเมนที่ได้รับอนุญาติ",
+    "Domain" : "โดเมน",
+    "Add Domain" : "เพิ่มโดเมน",
+    "CORS" : "CORS",
+    "User ID" : "รหัสผู้ใช้",
+    "Email address" : "ที่อยู่อีเมล",
+    "Invalid email address" : "ที่อยู่อีเมลไม่ถูกต้อง",
+    "Extra field to display in autocomplete results" : "ฟิลด์พิเศษที่จะแสดงผลจถะถูกเติมข้อความอัตโนมัติ",
+    "Restrict users to only share with groups they are member of" : "จำกัดผู้ใช้เพื่อแชร์เฉพาะกับกลุ่มที่เป็นสมาชิกของ",
+    "Default user and group share permissions" : "สิทธิ์เริ่มต้นการแชร์ของผู้ใช้และกลุ่ม",
+    "Enforce password protection for read-only links" : "บังคับใช้การป้องกันด้วยรหัสผ่านสำหรับลิงก์แบบอ่านอย่างเดียว",
+    "Enforce password protection for read & write links" : "บังคับใช้การป้องกันด้วยรหัสผ่านสำหรับการอ่านและเขียนลิงก์",
+    "Enforce password protection for upload-only (File Drop) links" : "บังคับใช้การป้องกันด้วยรหัสผ่านสำหรับลิงก์ที่อัพโหลด (โยนไฟล์) เท่านั้น",
+    "You are using %s" : "คุณกำลังใช้ %s",
+    "No Domains." : "ไม่มีโดเมน",
+    "Are you sure you want to remove this domain?" : "คุณแน่ใจหรือไม่ว่าต้องการลบโดเมนนี้?",
+    "Add" : "เพิ่ม",
+    "Empty app name is not allowed." : "จำเป็นต้องใส่ชื่อแอพฯ",
+    "The config file is read only. Please adjust your setup by editing the config file manually." : "ไฟล์สามารถอ่านได้อย่างเดียวเท่านั้น โปรดเปลี่ยนการตั้งค่าของคุณโดยแก้ไขไฟล์ด้วยตนเอง",
+    "Email changed successfully for {user}." : "เปลี่ยนอีเมลเรียบร้อยแล้วสำหรับผู้ใช้ {user}",
+    "You are not a member of any groups." : "คุณยังไม่ได้เป็นสมาชิกในกลุ่มใดๆเลย",
+    "In a clustered setup please make sure to sync the config.php file across all nodes." : "ในการตั้งค่าแบบคลัสเตอร์โปรดตรวจสอบให้แน่ใจว่าได้ประสานไฟล์ config.php ในโหนดทั้งหมด",
+    "These are the web, desktop and mobile clients currently logged in to your %s." : "นี่คือเว็บ เดสก์ท็อปและโทรศัพท์มือถือที่ล็อกอินเข้าสู่ระบบ %s ของคุณแล้ว",
+    "Automatically accept new incoming local user shares" : "ยอมรับแชร์ที่เข้ามาใหม่โดยอัตโนมัติ",
+    "Legal" : "ถูกกฎหมาย",
+    "Imprint URL:" : "URL สำนักพิมพ์:",
+    "Imprint URL" : "URL สำนักพิมพ์",
+    "Privacy Policy URL:" : "URL นโยบายส่วนบุคคล:",
+    "Privacy Policy URL" : "URL นโยบายส่วนบุคคล",
+    "App passwords / tokens" : "รหัสผ่านหรือโทเค็นของแอพ",
+    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "รหัสผ่านหรือโทเค็นของแอพคือรหัสผ่านที่ให้สิทธิ์แอพหรืออุปกรณ์ในการเข้าถึงบัญชี %s ของคุณ",
+    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "ใช้มาตรการรักษาความปลอดภัยสำหรับการเข้าสู่ระบบผ่านหน้าเว็บเพื่อซ่อนรหัสผ่านจริงของคุณ",
+    "Create new app passcode" : "สร้างรหัสผ่านสำหรับแอพใหม่",
+    "Password / Token" : "รหัสผ่านหรือโทเค็น",
+    "Owner language" : "เจ้าของภาษา",
+    "Language used for public mail notifications for shared files" : "ภาษาที่ใช้แจ้งเตือนทางอีเมลสาธารณะสำหรับไฟล์ที่ใช้ร่วมกัน",
+    "Wrong current password" : "รหัสผ่านปัจจุบันไม่ถูกต้อง",
+    "The new password cannot be the same as the previous one" : "รหัสผ่านใหม่ต้องไม่ซ้ำกับรหัสเดิมที่เคยใช้มาก่อน"
 },
 "nplurals=1; plural=0;");
