@@ -251,6 +251,16 @@ OC.L10N.register(
     "change full name" : "змінити ім'я",
     "set new password" : "встановити новий пароль",
     "change email address" : "Змінити адресу електронної пошти",
-    "Default" : "За замовчуванням"
+    "Default" : "За замовчуванням",
+    "Share" : "Поділитися",
+    "What to log" : "Що зберігати в протокол",
+    "Add" : "Додати",
+    "Download logfile (%s)" : "Завантажити протокол (%s)",
+    "%s password changed successfully" : "%s пароль змінено успішно",
+    "Change" : "Змінити",
+    "Invalid email address" : "Хибна адреса ел. пошти",
+    "Owner language" : "Мова власника",
+    "Wrong current password" : "Хибний поточний пароль",
+    "The new password cannot be the same as the previous one" : "Новий пароль не може бути таким самим як і попередній"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
