@@ -277,6 +277,11 @@ OC.L10N.register(
     "change full name" : "變更全名",
     "set new password" : "設定新密碼",
     "change email address" : "更改電子郵件地址",
-    "Default" : "預設"
+    "Default" : "預設",
+    "Share" : "分享",
+    "Domain" : "網域名稱",
+    "Add" : "增加",
+    "Email has been changed successfully." : "電子郵件已經成功變更",
+    "%s password changed successfully" : "%s 密碼修改成功"
 },
 "nplurals=1; plural=0;");
