@@ -21,9 +21,9 @@ style('settings', 'settings');
 <div id="app-navigation">
 	<ul class="with-icon">
 		<li class="divider"><?php p($l->t('Personal')); ?></li>
-		<?php foreach($_['personalNav'] as $item): ?>
+		<?php foreach ($_['personalNav'] as $item): ?>
 		<li>
-			<?php if (strpos($item['icon'], '/', 1) !== false): ?>
+			<?php if (\strpos($item['icon'], '/', 1) !== false): ?>
 				<a class="svg <?php $item['active'] ? p(' active ') : p('') ?>" style="background-image: url(<?php p($item['icon']) ?>)" href='<?php p($item['link']); ?>'><?php p($item['name']) ?></a>
 			<?php else: ?>
 				<a class="svg <?php $item['active'] ? p(' active ') : p('') ?> icon-<?php p($item['icon']) ?>" href='<?php p($item['link']); ?>'><?php p($item['name']) ?></a>
@@ -33,9 +33,9 @@ style('settings', 'settings');
 
 		<?php if (!empty($_['adminNav'])): ?>
 			<li class="divider"><?php p($l->t('Admin')); ?></li>
-			<?php foreach($_['adminNav'] as $item): ?>
+			<?php foreach ($_['adminNav'] as $item): ?>
 				<li>
-					<?php if (strpos($item['icon'], '/', 1) !== false): ?>
+					<?php if (\strpos($item['icon'], '/', 1) !== false): ?>
 						<a class="svg <?php $item['active'] ? p(' active ') : p('') ?>" style="background-image: url(<?php p($item['icon']) ?>)" href='<?php p($item['link']); ?>'><?php p($item['name']) ?></a>
 					<?php else: ?>
 						<a class="svg <?php $item['active'] ? p(' active ') : p('') ?> icon-<?php p($item['icon']) ?>" href='<?php p($item['link']); ?>'><?php p($item['name']) ?></a>
@@ -46,17 +46,21 @@ style('settings', 'settings');
 	</ul>
 </div>
 <div id="app-content">
-	<?php foreach($_['panels'] as $panel) { ?>
+	<?php foreach ($_['panels'] as $panel) {
+	?>
         <div id="<?php print($panel['id']); ?>">
             <?php print_unescaped($panel['content']); ?>
         </div>
-	<?php }
-	$numPanels = count($_['panels']);
+	<?php
+}
+	$numPanels = \count($_['panels']);
 	$legacyClass = OC\Settings\Panels\Personal\Legacy::class;
-	if($numPanels === 0 || ($numPanels === 1 && $_['panels'][0]['id'] === $legacyClass && empty(trim($_['panels'][0]['content'])))) { ?>
+	if ($numPanels === 0 || ($numPanels === 1 && $_['panels'][0]['id'] === $legacyClass && empty(\trim($_['panels'][0]['content'])))) {
+		?>
 		<div class="section">
 			<h2><?php p($l->t('Error')); ?></h2>
 			<p><?php p($l->t('No panels for this section.')); ?></p>
 		</div>
-	<?php } ?>
+	<?php
+	} ?>
 </div>
