@@ -130,15 +130,17 @@ class ExecuteCoreUpgradeScriptsCommand extends Command {
 			
 			$fsHelper->copyr($tmpDir . '/config/config.php', $oldSourcesDir . '/config/config.php');
 
+			//Get a new shipped apps list
+			$newAppsDir = $fullExtractionPath . '/owncloud/apps';
+			$newAppsList = $fsHelper->scandirFiltered($newAppsDir);
+
 			//Remove old apps
 			$appDirectories = $fsHelper->scandirFiltered($oldSourcesDir . '/apps');
-			foreach ($appDirectories as $appDirectory){
+			$oldAppList = array_intersect($appDirectories, $newAppsList);
+			foreach ($oldAppList as $appDirectory){
 				$fsHelper->rmdirr($oldSourcesDir . '/apps/' . $appDirectory);
 			}
 
-			//Put new shipped apps
-			$newAppsDir = $fullExtractionPath . '/owncloud/apps';
-			$newAppsList = $fsHelper->scandirFiltered($newAppsDir);
 			foreach ($newAppsList as $appId){
 				$output->writeln('Copying the application ' . $appId);
 				$fsHelper->copyr($newAppsDir . '/' . $appId, $locator->getOwnCloudRootPath() . '/apps/' . $appId, false);
